/// <reference types="node" />
import type * as gax from 'google-gax';
import type { Callback, CallOptions, Descriptors, ClientOptions, PaginationCallback } from 'google-gax';
import { Transform } from 'stream';
import * as protos from '../../protos/protos';
/**
 *  Service to fetch Google Ads API fields.
 * @class
 * @memberof v14
 */
export declare class GoogleAdsFieldServiceClient {
    private _terminated;
    private _opts;
    private _providedCustomServicePath;
    private _gaxModule;
    private _gaxGrpc;
    private _protos;
    private _defaults;
    auth: gax.GoogleAuth;
    descriptors: Descriptors;
    warn: (code: string, message: string, warnType?: string) => void;
    innerApiCalls: {
        [name: string]: Function;
    };
    pathTemplates: {
        [name: string]: gax.PathTemplate;
    };
    googleAdsFieldServiceStub?: Promise<{
        [name: string]: Function;
    }>;
    /**
     * Construct an instance of GoogleAdsFieldServiceClient.
     *
     * @param {object} [options] - The configuration object.
     * The options accepted by the constructor are described in detail
     * in [this document](https://github.com/googleapis/gax-nodejs/blob/main/client-libraries.md#creating-the-client-instance).
     * The common options are:
     * @param {object} [options.credentials] - Credentials object.
     * @param {string} [options.credentials.client_email]
     * @param {string} [options.credentials.private_key]
     * @param {string} [options.email] - Account email address. Required when
     *     using a .pem or .p12 keyFilename.
     * @param {string} [options.keyFilename] - Full path to the a .json, .pem, or
     *     .p12 key downloaded from the Google Developers Console. If you provide
     *     a path to a JSON file, the projectId option below is not necessary.
     *     NOTE: .pem and .p12 require you to specify options.email as well.
     * @param {number} [options.port] - The port on which to connect to
     *     the remote host.
     * @param {string} [options.projectId] - The project ID from the Google
     *     Developer's Console, e.g. 'grape-spaceship-123'. We will also check
     *     the environment variable GCLOUD_PROJECT for your project ID. If your
     *     app is running in an environment which supports
     *     {@link https://developers.google.com/identity/protocols/application-default-credentials Application Default Credentials},
     *     your project ID will be detected automatically.
     * @param {string} [options.apiEndpoint] - The domain name of the
     *     API remote host.
     * @param {gax.ClientConfig} [options.clientConfig] - Client configuration override.
     *     Follows the structure of {@link gapicConfig}.
     * @param {boolean} [options.fallback] - Use HTTP/1.1 REST mode.
     *     For more information, please check the
     *     {@link https://github.com/googleapis/gax-nodejs/blob/main/client-libraries.md#http11-rest-api-mode documentation}.
     * @param {gax} [gaxInstance]: loaded instance of `google-gax`. Useful if you
     *     need to avoid loading the default gRPC version and want to use the fallback
     *     HTTP implementation. Load only fallback version and pass it to the constructor:
     *     ```
     *     const gax = require('google-gax/build/src/fallback'); // avoids loading google-gax with gRPC
     *     const client = new GoogleAdsFieldServiceClient({fallback: true}, gax);
     *     ```
     */
    constructor(opts?: ClientOptions, gaxInstance?: typeof gax | typeof gax.fallback);
    /**
     * Initialize the client.
     * Performs asynchronous operations (such as authentication) and prepares the client.
     * This function will be called automatically when any class method is called for the
     * first time, but if you need to initialize it before calling an actual method,
     * feel free to call initialize() directly.
     *
     * You can await on this method if you want to make sure the client is initialized.
     *
     * @returns {Promise} A promise that resolves to an authenticated service stub.
     */
    initialize(): Promise<{
        [name: string]: Function;
    }>;
    /**
     * The DNS address for this API service.
     * @returns {string} The DNS address for this service.
     */
    static get servicePath(): string;
    /**
     * The DNS address for this API service - same as servicePath(),
     * exists for compatibility reasons.
     * @returns {string} The DNS address for this service.
     */
    static get apiEndpoint(): string;
    /**
     * The port for this API service.
     * @returns {number} The default port for this service.
     */
    static get port(): number;
    /**
     * The scopes needed to make gRPC calls for every method defined
     * in this service.
     * @returns {string[]} List of default scopes.
     */
    static get scopes(): string[];
    getProjectId(): Promise<string>;
    getProjectId(callback: Callback<string, undefined, undefined>): void;
    /**
     * Returns just the requested field.
     *
     * List of thrown errors:
     *   [AuthenticationError]()
     *   [AuthorizationError]()
     *   [HeaderError]()
     *   [InternalError]()
     *   [QuotaError]()
     *   [RequestError]()
     *
     * @param {Object} request
     *   The request object that will be sent.
     * @param {string} request.resource_name
     *   Required. The resource name of the field to get.
     * @param {object} [options]
     *   Call options. See {@link https://googleapis.dev/nodejs/google-gax/latest/interfaces/CallOptions.html|CallOptions} for more details.
     * @returns {Promise} - The promise which resolves to an array.
     *   The first element of the array is an object representing {@link protos.google.ads.googleads.v14.resources.GoogleAdsField|GoogleAdsField}.
     *   Please see the {@link https://github.com/googleapis/gax-nodejs/blob/master/client-libraries.md#regular-methods | documentation }
     *   for more details and examples.
     * @example <caption>include:samples/generated/v14/google_ads_field_service.get_google_ads_field.js</caption>
     * region_tag:googleads_v14_generated_GoogleAdsFieldService_GetGoogleAdsField_async
     */
    getGoogleAdsField(request?: protos.google.ads.googleads.v14.services.IGetGoogleAdsFieldRequest, options?: CallOptions): Promise<[
        protos.google.ads.googleads.v14.resources.IGoogleAdsField,
        protos.google.ads.googleads.v14.services.IGetGoogleAdsFieldRequest | undefined,
        {} | undefined
    ]>;
    getGoogleAdsField(request: protos.google.ads.googleads.v14.services.IGetGoogleAdsFieldRequest, options: CallOptions, callback: Callback<protos.google.ads.googleads.v14.resources.IGoogleAdsField, protos.google.ads.googleads.v14.services.IGetGoogleAdsFieldRequest | null | undefined, {} | null | undefined>): void;
    getGoogleAdsField(request: protos.google.ads.googleads.v14.services.IGetGoogleAdsFieldRequest, callback: Callback<protos.google.ads.googleads.v14.resources.IGoogleAdsField, protos.google.ads.googleads.v14.services.IGetGoogleAdsFieldRequest | null | undefined, {} | null | undefined>): void;
    /**
    * Returns all fields that match the search query.
    *
    * List of thrown errors:
    *   [AuthenticationError]()
    *   [AuthorizationError]()
    *   [HeaderError]()
    *   [InternalError]()
    *   [QueryError]()
    *   [QuotaError]()
    *   [RequestError]()
    *
    * @param {Object} request
    *   The request object that will be sent.
    * @param {string} request.query
    *   Required. The query string.
    * @param {string} request.pageToken
    *   Token of the page to retrieve. If not specified, the first page of
    *   results will be returned. Use the value obtained from `next_page_token`
    *   in the previous response in order to request the next page of results.
    * @param {number} request.pageSize
    *   Number of elements to retrieve in a single page.
    *   When too large a page is requested, the server may decide to further
    *   limit the number of returned resources.
    * @param {object} [options]
    *   Call options. See {@link https://googleapis.dev/nodejs/google-gax/latest/interfaces/CallOptions.html|CallOptions} for more details.
    * @returns {Promise} - The promise which resolves to an array.
    *   The first element of the array is Array of {@link protos.google.ads.googleads.v14.resources.GoogleAdsField|GoogleAdsField}.
    *   The client library will perform auto-pagination by default: it will call the API as many
    *   times as needed and will merge results from all the pages into this array.
    *   Note that it can affect your quota.
    *   We recommend using `searchGoogleAdsFieldsAsync()`
    *   method described below for async iteration which you can stop as needed.
    *   Please see the {@link https://github.com/googleapis/gax-nodejs/blob/master/client-libraries.md#auto-pagination | documentation }
    *   for more details and examples.
    */
    searchGoogleAdsFields(request?: protos.google.ads.googleads.v14.services.ISearchGoogleAdsFieldsRequest, options?: CallOptions): Promise<[
        protos.google.ads.googleads.v14.resources.IGoogleAdsField[],
        protos.google.ads.googleads.v14.services.ISearchGoogleAdsFieldsRequest | null,
        protos.google.ads.googleads.v14.services.ISearchGoogleAdsFieldsResponse
    ]>;
    searchGoogleAdsFields(request: protos.google.ads.googleads.v14.services.ISearchGoogleAdsFieldsRequest, options: CallOptions, callback: PaginationCallback<protos.google.ads.googleads.v14.services.ISearchGoogleAdsFieldsRequest, protos.google.ads.googleads.v14.services.ISearchGoogleAdsFieldsResponse | null | undefined, protos.google.ads.googleads.v14.resources.IGoogleAdsField>): void;
    searchGoogleAdsFields(request: protos.google.ads.googleads.v14.services.ISearchGoogleAdsFieldsRequest, callback: PaginationCallback<protos.google.ads.googleads.v14.services.ISearchGoogleAdsFieldsRequest, protos.google.ads.googleads.v14.services.ISearchGoogleAdsFieldsResponse | null | undefined, protos.google.ads.googleads.v14.resources.IGoogleAdsField>): void;
    /**
     * Equivalent to `method.name.toCamelCase()`, but returns a NodeJS Stream object.
     * @param {Object} request
     *   The request object that will be sent.
     * @param {string} request.query
     *   Required. The query string.
     * @param {string} request.pageToken
     *   Token of the page to retrieve. If not specified, the first page of
     *   results will be returned. Use the value obtained from `next_page_token`
     *   in the previous response in order to request the next page of results.
     * @param {number} request.pageSize
     *   Number of elements to retrieve in a single page.
     *   When too large a page is requested, the server may decide to further
     *   limit the number of returned resources.
     * @param {object} [options]
     *   Call options. See {@link https://googleapis.dev/nodejs/google-gax/latest/interfaces/CallOptions.html|CallOptions} for more details.
     * @returns {Stream}
     *   An object stream which emits an object representing {@link protos.google.ads.googleads.v14.resources.GoogleAdsField|GoogleAdsField} on 'data' event.
     *   The client library will perform auto-pagination by default: it will call the API as many
     *   times as needed. Note that it can affect your quota.
     *   We recommend using `searchGoogleAdsFieldsAsync()`
     *   method described below for async iteration which you can stop as needed.
     *   Please see the {@link https://github.com/googleapis/gax-nodejs/blob/master/client-libraries.md#auto-pagination | documentation }
     *   for more details and examples.
     */
    searchGoogleAdsFieldsStream(request?: protos.google.ads.googleads.v14.services.ISearchGoogleAdsFieldsRequest, options?: CallOptions): Transform;
    /**
     * Equivalent to `searchGoogleAdsFields`, but returns an iterable object.
     *
     * `for`-`await`-`of` syntax is used with the iterable to get response elements on-demand.
     * @param {Object} request
     *   The request object that will be sent.
     * @param {string} request.query
     *   Required. The query string.
     * @param {string} request.pageToken
     *   Token of the page to retrieve. If not specified, the first page of
     *   results will be returned. Use the value obtained from `next_page_token`
     *   in the previous response in order to request the next page of results.
     * @param {number} request.pageSize
     *   Number of elements to retrieve in a single page.
     *   When too large a page is requested, the server may decide to further
     *   limit the number of returned resources.
     * @param {object} [options]
     *   Call options. See {@link https://googleapis.dev/nodejs/google-gax/latest/interfaces/CallOptions.html|CallOptions} for more details.
     * @returns {Object}
     *   An iterable Object that allows {@link https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Iteration_protocols | async iteration }.
     *   When you iterate the returned iterable, each element will be an object representing
     *   {@link protos.google.ads.googleads.v14.resources.GoogleAdsField|GoogleAdsField}. The API will be called under the hood as needed, once per the page,
     *   so you can stop the iteration when you don't need more results.
     *   Please see the {@link https://github.com/googleapis/gax-nodejs/blob/master/client-libraries.md#auto-pagination | documentation }
     *   for more details and examples.
     * @example <caption>include:samples/generated/v14/google_ads_field_service.search_google_ads_fields.js</caption>
     * region_tag:googleads_v14_generated_GoogleAdsFieldService_SearchGoogleAdsFields_async
     */
    searchGoogleAdsFieldsAsync(request?: protos.google.ads.googleads.v14.services.ISearchGoogleAdsFieldsRequest, options?: CallOptions): AsyncIterable<protos.google.ads.googleads.v14.resources.IGoogleAdsField>;
    /**
     * Return a fully-qualified accessibleBiddingStrategy resource name string.
     *
     * @param {string} customer_id
     * @param {string} bidding_strategy_id
     * @returns {string} Resource name string.
     */
    accessibleBiddingStrategyPath(customerId: string, biddingStrategyId: string): string;
    /**
     * Parse the customer_id from AccessibleBiddingStrategy resource.
     *
     * @param {string} accessibleBiddingStrategyName
     *   A fully-qualified path representing AccessibleBiddingStrategy resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAccessibleBiddingStrategyName(accessibleBiddingStrategyName: string): string | number;
    /**
     * Parse the bidding_strategy_id from AccessibleBiddingStrategy resource.
     *
     * @param {string} accessibleBiddingStrategyName
     *   A fully-qualified path representing AccessibleBiddingStrategy resource.
     * @returns {string} A string representing the bidding_strategy_id.
     */
    matchBiddingStrategyIdFromAccessibleBiddingStrategyName(accessibleBiddingStrategyName: string): string | number;
    /**
     * Return a fully-qualified accountBudget resource name string.
     *
     * @param {string} customer_id
     * @param {string} account_budget_id
     * @returns {string} Resource name string.
     */
    accountBudgetPath(customerId: string, accountBudgetId: string): string;
    /**
     * Parse the customer_id from AccountBudget resource.
     *
     * @param {string} accountBudgetName
     *   A fully-qualified path representing AccountBudget resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAccountBudgetName(accountBudgetName: string): string | number;
    /**
     * Parse the account_budget_id from AccountBudget resource.
     *
     * @param {string} accountBudgetName
     *   A fully-qualified path representing AccountBudget resource.
     * @returns {string} A string representing the account_budget_id.
     */
    matchAccountBudgetIdFromAccountBudgetName(accountBudgetName: string): string | number;
    /**
     * Return a fully-qualified accountBudgetProposal resource name string.
     *
     * @param {string} customer_id
     * @param {string} account_budget_proposal_id
     * @returns {string} Resource name string.
     */
    accountBudgetProposalPath(customerId: string, accountBudgetProposalId: string): string;
    /**
     * Parse the customer_id from AccountBudgetProposal resource.
     *
     * @param {string} accountBudgetProposalName
     *   A fully-qualified path representing AccountBudgetProposal resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAccountBudgetProposalName(accountBudgetProposalName: string): string | number;
    /**
     * Parse the account_budget_proposal_id from AccountBudgetProposal resource.
     *
     * @param {string} accountBudgetProposalName
     *   A fully-qualified path representing AccountBudgetProposal resource.
     * @returns {string} A string representing the account_budget_proposal_id.
     */
    matchAccountBudgetProposalIdFromAccountBudgetProposalName(accountBudgetProposalName: string): string | number;
    /**
     * Return a fully-qualified accountLink resource name string.
     *
     * @param {string} customer_id
     * @param {string} account_link_id
     * @returns {string} Resource name string.
     */
    accountLinkPath(customerId: string, accountLinkId: string): string;
    /**
     * Parse the customer_id from AccountLink resource.
     *
     * @param {string} accountLinkName
     *   A fully-qualified path representing AccountLink resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAccountLinkName(accountLinkName: string): string | number;
    /**
     * Parse the account_link_id from AccountLink resource.
     *
     * @param {string} accountLinkName
     *   A fully-qualified path representing AccountLink resource.
     * @returns {string} A string representing the account_link_id.
     */
    matchAccountLinkIdFromAccountLinkName(accountLinkName: string): string | number;
    /**
     * Return a fully-qualified ad resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_id
     * @returns {string} Resource name string.
     */
    adPath(customerId: string, adId: string): string;
    /**
     * Parse the customer_id from Ad resource.
     *
     * @param {string} adName
     *   A fully-qualified path representing Ad resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdName(adName: string): string | number;
    /**
     * Parse the ad_id from Ad resource.
     *
     * @param {string} adName
     *   A fully-qualified path representing Ad resource.
     * @returns {string} A string representing the ad_id.
     */
    matchAdIdFromAdName(adName: string): string | number;
    /**
     * Return a fully-qualified adGroup resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @returns {string} Resource name string.
     */
    adGroupPath(customerId: string, adGroupId: string): string;
    /**
     * Parse the customer_id from AdGroup resource.
     *
     * @param {string} adGroupName
     *   A fully-qualified path representing AdGroup resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdGroupName(adGroupName: string): string | number;
    /**
     * Parse the ad_group_id from AdGroup resource.
     *
     * @param {string} adGroupName
     *   A fully-qualified path representing AdGroup resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdGroupName(adGroupName: string): string | number;
    /**
     * Return a fully-qualified adGroupAd resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} ad_id
     * @returns {string} Resource name string.
     */
    adGroupAdPath(customerId: string, adGroupId: string, adId: string): string;
    /**
     * Parse the customer_id from AdGroupAd resource.
     *
     * @param {string} adGroupAdName
     *   A fully-qualified path representing AdGroupAd resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdGroupAdName(adGroupAdName: string): string | number;
    /**
     * Parse the ad_group_id from AdGroupAd resource.
     *
     * @param {string} adGroupAdName
     *   A fully-qualified path representing AdGroupAd resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdGroupAdName(adGroupAdName: string): string | number;
    /**
     * Parse the ad_id from AdGroupAd resource.
     *
     * @param {string} adGroupAdName
     *   A fully-qualified path representing AdGroupAd resource.
     * @returns {string} A string representing the ad_id.
     */
    matchAdIdFromAdGroupAdName(adGroupAdName: string): string | number;
    /**
     * Return a fully-qualified adGroupAdAssetCombinationView resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} ad_id
     * @param {string} asset_combination_id_low
     * @param {string} asset_combination_id_high
     * @returns {string} Resource name string.
     */
    adGroupAdAssetCombinationViewPath(customerId: string, adGroupId: string, adId: string, assetCombinationIdLow: string, assetCombinationIdHigh: string): string;
    /**
     * Parse the customer_id from AdGroupAdAssetCombinationView resource.
     *
     * @param {string} adGroupAdAssetCombinationViewName
     *   A fully-qualified path representing AdGroupAdAssetCombinationView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdGroupAdAssetCombinationViewName(adGroupAdAssetCombinationViewName: string): string | number;
    /**
     * Parse the ad_group_id from AdGroupAdAssetCombinationView resource.
     *
     * @param {string} adGroupAdAssetCombinationViewName
     *   A fully-qualified path representing AdGroupAdAssetCombinationView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdGroupAdAssetCombinationViewName(adGroupAdAssetCombinationViewName: string): string | number;
    /**
     * Parse the ad_id from AdGroupAdAssetCombinationView resource.
     *
     * @param {string} adGroupAdAssetCombinationViewName
     *   A fully-qualified path representing AdGroupAdAssetCombinationView resource.
     * @returns {string} A string representing the ad_id.
     */
    matchAdIdFromAdGroupAdAssetCombinationViewName(adGroupAdAssetCombinationViewName: string): string | number;
    /**
     * Parse the asset_combination_id_low from AdGroupAdAssetCombinationView resource.
     *
     * @param {string} adGroupAdAssetCombinationViewName
     *   A fully-qualified path representing AdGroupAdAssetCombinationView resource.
     * @returns {string} A string representing the asset_combination_id_low.
     */
    matchAssetCombinationIdLowFromAdGroupAdAssetCombinationViewName(adGroupAdAssetCombinationViewName: string): string | number;
    /**
     * Parse the asset_combination_id_high from AdGroupAdAssetCombinationView resource.
     *
     * @param {string} adGroupAdAssetCombinationViewName
     *   A fully-qualified path representing AdGroupAdAssetCombinationView resource.
     * @returns {string} A string representing the asset_combination_id_high.
     */
    matchAssetCombinationIdHighFromAdGroupAdAssetCombinationViewName(adGroupAdAssetCombinationViewName: string): string | number;
    /**
     * Return a fully-qualified adGroupAdAssetView resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} ad_id
     * @param {string} asset_id
     * @param {string} field_type
     * @returns {string} Resource name string.
     */
    adGroupAdAssetViewPath(customerId: string, adGroupId: string, adId: string, assetId: string, fieldType: string): string;
    /**
     * Parse the customer_id from AdGroupAdAssetView resource.
     *
     * @param {string} adGroupAdAssetViewName
     *   A fully-qualified path representing AdGroupAdAssetView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdGroupAdAssetViewName(adGroupAdAssetViewName: string): string | number;
    /**
     * Parse the ad_group_id from AdGroupAdAssetView resource.
     *
     * @param {string} adGroupAdAssetViewName
     *   A fully-qualified path representing AdGroupAdAssetView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdGroupAdAssetViewName(adGroupAdAssetViewName: string): string | number;
    /**
     * Parse the ad_id from AdGroupAdAssetView resource.
     *
     * @param {string} adGroupAdAssetViewName
     *   A fully-qualified path representing AdGroupAdAssetView resource.
     * @returns {string} A string representing the ad_id.
     */
    matchAdIdFromAdGroupAdAssetViewName(adGroupAdAssetViewName: string): string | number;
    /**
     * Parse the asset_id from AdGroupAdAssetView resource.
     *
     * @param {string} adGroupAdAssetViewName
     *   A fully-qualified path representing AdGroupAdAssetView resource.
     * @returns {string} A string representing the asset_id.
     */
    matchAssetIdFromAdGroupAdAssetViewName(adGroupAdAssetViewName: string): string | number;
    /**
     * Parse the field_type from AdGroupAdAssetView resource.
     *
     * @param {string} adGroupAdAssetViewName
     *   A fully-qualified path representing AdGroupAdAssetView resource.
     * @returns {string} A string representing the field_type.
     */
    matchFieldTypeFromAdGroupAdAssetViewName(adGroupAdAssetViewName: string): string | number;
    /**
     * Return a fully-qualified adGroupAdLabel resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} ad_id
     * @param {string} label_id
     * @returns {string} Resource name string.
     */
    adGroupAdLabelPath(customerId: string, adGroupId: string, adId: string, labelId: string): string;
    /**
     * Parse the customer_id from AdGroupAdLabel resource.
     *
     * @param {string} adGroupAdLabelName
     *   A fully-qualified path representing AdGroupAdLabel resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdGroupAdLabelName(adGroupAdLabelName: string): string | number;
    /**
     * Parse the ad_group_id from AdGroupAdLabel resource.
     *
     * @param {string} adGroupAdLabelName
     *   A fully-qualified path representing AdGroupAdLabel resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdGroupAdLabelName(adGroupAdLabelName: string): string | number;
    /**
     * Parse the ad_id from AdGroupAdLabel resource.
     *
     * @param {string} adGroupAdLabelName
     *   A fully-qualified path representing AdGroupAdLabel resource.
     * @returns {string} A string representing the ad_id.
     */
    matchAdIdFromAdGroupAdLabelName(adGroupAdLabelName: string): string | number;
    /**
     * Parse the label_id from AdGroupAdLabel resource.
     *
     * @param {string} adGroupAdLabelName
     *   A fully-qualified path representing AdGroupAdLabel resource.
     * @returns {string} A string representing the label_id.
     */
    matchLabelIdFromAdGroupAdLabelName(adGroupAdLabelName: string): string | number;
    /**
     * Return a fully-qualified adGroupAsset resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} asset_id
     * @param {string} field_type
     * @returns {string} Resource name string.
     */
    adGroupAssetPath(customerId: string, adGroupId: string, assetId: string, fieldType: string): string;
    /**
     * Parse the customer_id from AdGroupAsset resource.
     *
     * @param {string} adGroupAssetName
     *   A fully-qualified path representing AdGroupAsset resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdGroupAssetName(adGroupAssetName: string): string | number;
    /**
     * Parse the ad_group_id from AdGroupAsset resource.
     *
     * @param {string} adGroupAssetName
     *   A fully-qualified path representing AdGroupAsset resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdGroupAssetName(adGroupAssetName: string): string | number;
    /**
     * Parse the asset_id from AdGroupAsset resource.
     *
     * @param {string} adGroupAssetName
     *   A fully-qualified path representing AdGroupAsset resource.
     * @returns {string} A string representing the asset_id.
     */
    matchAssetIdFromAdGroupAssetName(adGroupAssetName: string): string | number;
    /**
     * Parse the field_type from AdGroupAsset resource.
     *
     * @param {string} adGroupAssetName
     *   A fully-qualified path representing AdGroupAsset resource.
     * @returns {string} A string representing the field_type.
     */
    matchFieldTypeFromAdGroupAssetName(adGroupAssetName: string): string | number;
    /**
     * Return a fully-qualified adGroupAssetSet resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} asset_set_id
     * @returns {string} Resource name string.
     */
    adGroupAssetSetPath(customerId: string, adGroupId: string, assetSetId: string): string;
    /**
     * Parse the customer_id from AdGroupAssetSet resource.
     *
     * @param {string} adGroupAssetSetName
     *   A fully-qualified path representing AdGroupAssetSet resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdGroupAssetSetName(adGroupAssetSetName: string): string | number;
    /**
     * Parse the ad_group_id from AdGroupAssetSet resource.
     *
     * @param {string} adGroupAssetSetName
     *   A fully-qualified path representing AdGroupAssetSet resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdGroupAssetSetName(adGroupAssetSetName: string): string | number;
    /**
     * Parse the asset_set_id from AdGroupAssetSet resource.
     *
     * @param {string} adGroupAssetSetName
     *   A fully-qualified path representing AdGroupAssetSet resource.
     * @returns {string} A string representing the asset_set_id.
     */
    matchAssetSetIdFromAdGroupAssetSetName(adGroupAssetSetName: string): string | number;
    /**
     * Return a fully-qualified adGroupAudienceView resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    adGroupAudienceViewPath(customerId: string, adGroupId: string, criterionId: string): string;
    /**
     * Parse the customer_id from AdGroupAudienceView resource.
     *
     * @param {string} adGroupAudienceViewName
     *   A fully-qualified path representing AdGroupAudienceView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdGroupAudienceViewName(adGroupAudienceViewName: string): string | number;
    /**
     * Parse the ad_group_id from AdGroupAudienceView resource.
     *
     * @param {string} adGroupAudienceViewName
     *   A fully-qualified path representing AdGroupAudienceView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdGroupAudienceViewName(adGroupAudienceViewName: string): string | number;
    /**
     * Parse the criterion_id from AdGroupAudienceView resource.
     *
     * @param {string} adGroupAudienceViewName
     *   A fully-qualified path representing AdGroupAudienceView resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromAdGroupAudienceViewName(adGroupAudienceViewName: string): string | number;
    /**
     * Return a fully-qualified adGroupBidModifier resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    adGroupBidModifierPath(customerId: string, adGroupId: string, criterionId: string): string;
    /**
     * Parse the customer_id from AdGroupBidModifier resource.
     *
     * @param {string} adGroupBidModifierName
     *   A fully-qualified path representing AdGroupBidModifier resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdGroupBidModifierName(adGroupBidModifierName: string): string | number;
    /**
     * Parse the ad_group_id from AdGroupBidModifier resource.
     *
     * @param {string} adGroupBidModifierName
     *   A fully-qualified path representing AdGroupBidModifier resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdGroupBidModifierName(adGroupBidModifierName: string): string | number;
    /**
     * Parse the criterion_id from AdGroupBidModifier resource.
     *
     * @param {string} adGroupBidModifierName
     *   A fully-qualified path representing AdGroupBidModifier resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromAdGroupBidModifierName(adGroupBidModifierName: string): string | number;
    /**
     * Return a fully-qualified adGroupCriterion resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    adGroupCriterionPath(customerId: string, adGroupId: string, criterionId: string): string;
    /**
     * Parse the customer_id from AdGroupCriterion resource.
     *
     * @param {string} adGroupCriterionName
     *   A fully-qualified path representing AdGroupCriterion resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdGroupCriterionName(adGroupCriterionName: string): string | number;
    /**
     * Parse the ad_group_id from AdGroupCriterion resource.
     *
     * @param {string} adGroupCriterionName
     *   A fully-qualified path representing AdGroupCriterion resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdGroupCriterionName(adGroupCriterionName: string): string | number;
    /**
     * Parse the criterion_id from AdGroupCriterion resource.
     *
     * @param {string} adGroupCriterionName
     *   A fully-qualified path representing AdGroupCriterion resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromAdGroupCriterionName(adGroupCriterionName: string): string | number;
    /**
     * Return a fully-qualified adGroupCriterionCustomizer resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} criterion_id
     * @param {string} customizer_attribute_id
     * @returns {string} Resource name string.
     */
    adGroupCriterionCustomizerPath(customerId: string, adGroupId: string, criterionId: string, customizerAttributeId: string): string;
    /**
     * Parse the customer_id from AdGroupCriterionCustomizer resource.
     *
     * @param {string} adGroupCriterionCustomizerName
     *   A fully-qualified path representing AdGroupCriterionCustomizer resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdGroupCriterionCustomizerName(adGroupCriterionCustomizerName: string): string | number;
    /**
     * Parse the ad_group_id from AdGroupCriterionCustomizer resource.
     *
     * @param {string} adGroupCriterionCustomizerName
     *   A fully-qualified path representing AdGroupCriterionCustomizer resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdGroupCriterionCustomizerName(adGroupCriterionCustomizerName: string): string | number;
    /**
     * Parse the criterion_id from AdGroupCriterionCustomizer resource.
     *
     * @param {string} adGroupCriterionCustomizerName
     *   A fully-qualified path representing AdGroupCriterionCustomizer resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromAdGroupCriterionCustomizerName(adGroupCriterionCustomizerName: string): string | number;
    /**
     * Parse the customizer_attribute_id from AdGroupCriterionCustomizer resource.
     *
     * @param {string} adGroupCriterionCustomizerName
     *   A fully-qualified path representing AdGroupCriterionCustomizer resource.
     * @returns {string} A string representing the customizer_attribute_id.
     */
    matchCustomizerAttributeIdFromAdGroupCriterionCustomizerName(adGroupCriterionCustomizerName: string): string | number;
    /**
     * Return a fully-qualified adGroupCriterionLabel resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} criterion_id
     * @param {string} label_id
     * @returns {string} Resource name string.
     */
    adGroupCriterionLabelPath(customerId: string, adGroupId: string, criterionId: string, labelId: string): string;
    /**
     * Parse the customer_id from AdGroupCriterionLabel resource.
     *
     * @param {string} adGroupCriterionLabelName
     *   A fully-qualified path representing AdGroupCriterionLabel resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdGroupCriterionLabelName(adGroupCriterionLabelName: string): string | number;
    /**
     * Parse the ad_group_id from AdGroupCriterionLabel resource.
     *
     * @param {string} adGroupCriterionLabelName
     *   A fully-qualified path representing AdGroupCriterionLabel resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdGroupCriterionLabelName(adGroupCriterionLabelName: string): string | number;
    /**
     * Parse the criterion_id from AdGroupCriterionLabel resource.
     *
     * @param {string} adGroupCriterionLabelName
     *   A fully-qualified path representing AdGroupCriterionLabel resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromAdGroupCriterionLabelName(adGroupCriterionLabelName: string): string | number;
    /**
     * Parse the label_id from AdGroupCriterionLabel resource.
     *
     * @param {string} adGroupCriterionLabelName
     *   A fully-qualified path representing AdGroupCriterionLabel resource.
     * @returns {string} A string representing the label_id.
     */
    matchLabelIdFromAdGroupCriterionLabelName(adGroupCriterionLabelName: string): string | number;
    /**
     * Return a fully-qualified adGroupCriterionSimulation resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} criterion_id
     * @param {string} type
     * @param {string} modification_method
     * @param {string} start_date
     * @param {string} end_date
     * @returns {string} Resource name string.
     */
    adGroupCriterionSimulationPath(customerId: string, adGroupId: string, criterionId: string, type: string, modificationMethod: string, startDate: string, endDate: string): string;
    /**
     * Parse the customer_id from AdGroupCriterionSimulation resource.
     *
     * @param {string} adGroupCriterionSimulationName
     *   A fully-qualified path representing AdGroupCriterionSimulation resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdGroupCriterionSimulationName(adGroupCriterionSimulationName: string): string | number;
    /**
     * Parse the ad_group_id from AdGroupCriterionSimulation resource.
     *
     * @param {string} adGroupCriterionSimulationName
     *   A fully-qualified path representing AdGroupCriterionSimulation resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdGroupCriterionSimulationName(adGroupCriterionSimulationName: string): string | number;
    /**
     * Parse the criterion_id from AdGroupCriterionSimulation resource.
     *
     * @param {string} adGroupCriterionSimulationName
     *   A fully-qualified path representing AdGroupCriterionSimulation resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromAdGroupCriterionSimulationName(adGroupCriterionSimulationName: string): string | number;
    /**
     * Parse the type from AdGroupCriterionSimulation resource.
     *
     * @param {string} adGroupCriterionSimulationName
     *   A fully-qualified path representing AdGroupCriterionSimulation resource.
     * @returns {string} A string representing the type.
     */
    matchTypeFromAdGroupCriterionSimulationName(adGroupCriterionSimulationName: string): string | number;
    /**
     * Parse the modification_method from AdGroupCriterionSimulation resource.
     *
     * @param {string} adGroupCriterionSimulationName
     *   A fully-qualified path representing AdGroupCriterionSimulation resource.
     * @returns {string} A string representing the modification_method.
     */
    matchModificationMethodFromAdGroupCriterionSimulationName(adGroupCriterionSimulationName: string): string | number;
    /**
     * Parse the start_date from AdGroupCriterionSimulation resource.
     *
     * @param {string} adGroupCriterionSimulationName
     *   A fully-qualified path representing AdGroupCriterionSimulation resource.
     * @returns {string} A string representing the start_date.
     */
    matchStartDateFromAdGroupCriterionSimulationName(adGroupCriterionSimulationName: string): string | number;
    /**
     * Parse the end_date from AdGroupCriterionSimulation resource.
     *
     * @param {string} adGroupCriterionSimulationName
     *   A fully-qualified path representing AdGroupCriterionSimulation resource.
     * @returns {string} A string representing the end_date.
     */
    matchEndDateFromAdGroupCriterionSimulationName(adGroupCriterionSimulationName: string): string | number;
    /**
     * Return a fully-qualified adGroupCustomizer resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} customizer_attribute_id
     * @returns {string} Resource name string.
     */
    adGroupCustomizerPath(customerId: string, adGroupId: string, customizerAttributeId: string): string;
    /**
     * Parse the customer_id from AdGroupCustomizer resource.
     *
     * @param {string} adGroupCustomizerName
     *   A fully-qualified path representing AdGroupCustomizer resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdGroupCustomizerName(adGroupCustomizerName: string): string | number;
    /**
     * Parse the ad_group_id from AdGroupCustomizer resource.
     *
     * @param {string} adGroupCustomizerName
     *   A fully-qualified path representing AdGroupCustomizer resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdGroupCustomizerName(adGroupCustomizerName: string): string | number;
    /**
     * Parse the customizer_attribute_id from AdGroupCustomizer resource.
     *
     * @param {string} adGroupCustomizerName
     *   A fully-qualified path representing AdGroupCustomizer resource.
     * @returns {string} A string representing the customizer_attribute_id.
     */
    matchCustomizerAttributeIdFromAdGroupCustomizerName(adGroupCustomizerName: string): string | number;
    /**
     * Return a fully-qualified adGroupExtensionSetting resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} extension_type
     * @returns {string} Resource name string.
     */
    adGroupExtensionSettingPath(customerId: string, adGroupId: string, extensionType: string): string;
    /**
     * Parse the customer_id from AdGroupExtensionSetting resource.
     *
     * @param {string} adGroupExtensionSettingName
     *   A fully-qualified path representing AdGroupExtensionSetting resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdGroupExtensionSettingName(adGroupExtensionSettingName: string): string | number;
    /**
     * Parse the ad_group_id from AdGroupExtensionSetting resource.
     *
     * @param {string} adGroupExtensionSettingName
     *   A fully-qualified path representing AdGroupExtensionSetting resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdGroupExtensionSettingName(adGroupExtensionSettingName: string): string | number;
    /**
     * Parse the extension_type from AdGroupExtensionSetting resource.
     *
     * @param {string} adGroupExtensionSettingName
     *   A fully-qualified path representing AdGroupExtensionSetting resource.
     * @returns {string} A string representing the extension_type.
     */
    matchExtensionTypeFromAdGroupExtensionSettingName(adGroupExtensionSettingName: string): string | number;
    /**
     * Return a fully-qualified adGroupFeed resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} feed_id
     * @returns {string} Resource name string.
     */
    adGroupFeedPath(customerId: string, adGroupId: string, feedId: string): string;
    /**
     * Parse the customer_id from AdGroupFeed resource.
     *
     * @param {string} adGroupFeedName
     *   A fully-qualified path representing AdGroupFeed resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdGroupFeedName(adGroupFeedName: string): string | number;
    /**
     * Parse the ad_group_id from AdGroupFeed resource.
     *
     * @param {string} adGroupFeedName
     *   A fully-qualified path representing AdGroupFeed resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdGroupFeedName(adGroupFeedName: string): string | number;
    /**
     * Parse the feed_id from AdGroupFeed resource.
     *
     * @param {string} adGroupFeedName
     *   A fully-qualified path representing AdGroupFeed resource.
     * @returns {string} A string representing the feed_id.
     */
    matchFeedIdFromAdGroupFeedName(adGroupFeedName: string): string | number;
    /**
     * Return a fully-qualified adGroupLabel resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} label_id
     * @returns {string} Resource name string.
     */
    adGroupLabelPath(customerId: string, adGroupId: string, labelId: string): string;
    /**
     * Parse the customer_id from AdGroupLabel resource.
     *
     * @param {string} adGroupLabelName
     *   A fully-qualified path representing AdGroupLabel resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdGroupLabelName(adGroupLabelName: string): string | number;
    /**
     * Parse the ad_group_id from AdGroupLabel resource.
     *
     * @param {string} adGroupLabelName
     *   A fully-qualified path representing AdGroupLabel resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdGroupLabelName(adGroupLabelName: string): string | number;
    /**
     * Parse the label_id from AdGroupLabel resource.
     *
     * @param {string} adGroupLabelName
     *   A fully-qualified path representing AdGroupLabel resource.
     * @returns {string} A string representing the label_id.
     */
    matchLabelIdFromAdGroupLabelName(adGroupLabelName: string): string | number;
    /**
     * Return a fully-qualified adGroupSimulation resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} type
     * @param {string} modification_method
     * @param {string} start_date
     * @param {string} end_date
     * @returns {string} Resource name string.
     */
    adGroupSimulationPath(customerId: string, adGroupId: string, type: string, modificationMethod: string, startDate: string, endDate: string): string;
    /**
     * Parse the customer_id from AdGroupSimulation resource.
     *
     * @param {string} adGroupSimulationName
     *   A fully-qualified path representing AdGroupSimulation resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdGroupSimulationName(adGroupSimulationName: string): string | number;
    /**
     * Parse the ad_group_id from AdGroupSimulation resource.
     *
     * @param {string} adGroupSimulationName
     *   A fully-qualified path representing AdGroupSimulation resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdGroupSimulationName(adGroupSimulationName: string): string | number;
    /**
     * Parse the type from AdGroupSimulation resource.
     *
     * @param {string} adGroupSimulationName
     *   A fully-qualified path representing AdGroupSimulation resource.
     * @returns {string} A string representing the type.
     */
    matchTypeFromAdGroupSimulationName(adGroupSimulationName: string): string | number;
    /**
     * Parse the modification_method from AdGroupSimulation resource.
     *
     * @param {string} adGroupSimulationName
     *   A fully-qualified path representing AdGroupSimulation resource.
     * @returns {string} A string representing the modification_method.
     */
    matchModificationMethodFromAdGroupSimulationName(adGroupSimulationName: string): string | number;
    /**
     * Parse the start_date from AdGroupSimulation resource.
     *
     * @param {string} adGroupSimulationName
     *   A fully-qualified path representing AdGroupSimulation resource.
     * @returns {string} A string representing the start_date.
     */
    matchStartDateFromAdGroupSimulationName(adGroupSimulationName: string): string | number;
    /**
     * Parse the end_date from AdGroupSimulation resource.
     *
     * @param {string} adGroupSimulationName
     *   A fully-qualified path representing AdGroupSimulation resource.
     * @returns {string} A string representing the end_date.
     */
    matchEndDateFromAdGroupSimulationName(adGroupSimulationName: string): string | number;
    /**
     * Return a fully-qualified adParameter resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} criterion_id
     * @param {string} parameter_index
     * @returns {string} Resource name string.
     */
    adParameterPath(customerId: string, adGroupId: string, criterionId: string, parameterIndex: string): string;
    /**
     * Parse the customer_id from AdParameter resource.
     *
     * @param {string} adParameterName
     *   A fully-qualified path representing AdParameter resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdParameterName(adParameterName: string): string | number;
    /**
     * Parse the ad_group_id from AdParameter resource.
     *
     * @param {string} adParameterName
     *   A fully-qualified path representing AdParameter resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdParameterName(adParameterName: string): string | number;
    /**
     * Parse the criterion_id from AdParameter resource.
     *
     * @param {string} adParameterName
     *   A fully-qualified path representing AdParameter resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromAdParameterName(adParameterName: string): string | number;
    /**
     * Parse the parameter_index from AdParameter resource.
     *
     * @param {string} adParameterName
     *   A fully-qualified path representing AdParameter resource.
     * @returns {string} A string representing the parameter_index.
     */
    matchParameterIndexFromAdParameterName(adParameterName: string): string | number;
    /**
     * Return a fully-qualified adScheduleView resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    adScheduleViewPath(customerId: string, campaignId: string, criterionId: string): string;
    /**
     * Parse the customer_id from AdScheduleView resource.
     *
     * @param {string} adScheduleViewName
     *   A fully-qualified path representing AdScheduleView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdScheduleViewName(adScheduleViewName: string): string | number;
    /**
     * Parse the campaign_id from AdScheduleView resource.
     *
     * @param {string} adScheduleViewName
     *   A fully-qualified path representing AdScheduleView resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromAdScheduleViewName(adScheduleViewName: string): string | number;
    /**
     * Parse the criterion_id from AdScheduleView resource.
     *
     * @param {string} adScheduleViewName
     *   A fully-qualified path representing AdScheduleView resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromAdScheduleViewName(adScheduleViewName: string): string | number;
    /**
     * Return a fully-qualified ageRangeView resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    ageRangeViewPath(customerId: string, adGroupId: string, criterionId: string): string;
    /**
     * Parse the customer_id from AgeRangeView resource.
     *
     * @param {string} ageRangeViewName
     *   A fully-qualified path representing AgeRangeView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAgeRangeViewName(ageRangeViewName: string): string | number;
    /**
     * Parse the ad_group_id from AgeRangeView resource.
     *
     * @param {string} ageRangeViewName
     *   A fully-qualified path representing AgeRangeView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAgeRangeViewName(ageRangeViewName: string): string | number;
    /**
     * Parse the criterion_id from AgeRangeView resource.
     *
     * @param {string} ageRangeViewName
     *   A fully-qualified path representing AgeRangeView resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromAgeRangeViewName(ageRangeViewName: string): string | number;
    /**
     * Return a fully-qualified asset resource name string.
     *
     * @param {string} customer_id
     * @param {string} asset_id
     * @returns {string} Resource name string.
     */
    assetPath(customerId: string, assetId: string): string;
    /**
     * Parse the customer_id from Asset resource.
     *
     * @param {string} assetName
     *   A fully-qualified path representing Asset resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAssetName(assetName: string): string | number;
    /**
     * Parse the asset_id from Asset resource.
     *
     * @param {string} assetName
     *   A fully-qualified path representing Asset resource.
     * @returns {string} A string representing the asset_id.
     */
    matchAssetIdFromAssetName(assetName: string): string | number;
    /**
     * Return a fully-qualified assetFieldTypeView resource name string.
     *
     * @param {string} customer_id
     * @param {string} field_type
     * @returns {string} Resource name string.
     */
    assetFieldTypeViewPath(customerId: string, fieldType: string): string;
    /**
     * Parse the customer_id from AssetFieldTypeView resource.
     *
     * @param {string} assetFieldTypeViewName
     *   A fully-qualified path representing AssetFieldTypeView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAssetFieldTypeViewName(assetFieldTypeViewName: string): string | number;
    /**
     * Parse the field_type from AssetFieldTypeView resource.
     *
     * @param {string} assetFieldTypeViewName
     *   A fully-qualified path representing AssetFieldTypeView resource.
     * @returns {string} A string representing the field_type.
     */
    matchFieldTypeFromAssetFieldTypeViewName(assetFieldTypeViewName: string): string | number;
    /**
     * Return a fully-qualified assetGroup resource name string.
     *
     * @param {string} customer_id
     * @param {string} asset_group_id
     * @returns {string} Resource name string.
     */
    assetGroupPath(customerId: string, assetGroupId: string): string;
    /**
     * Parse the customer_id from AssetGroup resource.
     *
     * @param {string} assetGroupName
     *   A fully-qualified path representing AssetGroup resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAssetGroupName(assetGroupName: string): string | number;
    /**
     * Parse the asset_group_id from AssetGroup resource.
     *
     * @param {string} assetGroupName
     *   A fully-qualified path representing AssetGroup resource.
     * @returns {string} A string representing the asset_group_id.
     */
    matchAssetGroupIdFromAssetGroupName(assetGroupName: string): string | number;
    /**
     * Return a fully-qualified assetGroupAsset resource name string.
     *
     * @param {string} customer_id
     * @param {string} asset_group_id
     * @param {string} asset_id
     * @param {string} field_type
     * @returns {string} Resource name string.
     */
    assetGroupAssetPath(customerId: string, assetGroupId: string, assetId: string, fieldType: string): string;
    /**
     * Parse the customer_id from AssetGroupAsset resource.
     *
     * @param {string} assetGroupAssetName
     *   A fully-qualified path representing AssetGroupAsset resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAssetGroupAssetName(assetGroupAssetName: string): string | number;
    /**
     * Parse the asset_group_id from AssetGroupAsset resource.
     *
     * @param {string} assetGroupAssetName
     *   A fully-qualified path representing AssetGroupAsset resource.
     * @returns {string} A string representing the asset_group_id.
     */
    matchAssetGroupIdFromAssetGroupAssetName(assetGroupAssetName: string): string | number;
    /**
     * Parse the asset_id from AssetGroupAsset resource.
     *
     * @param {string} assetGroupAssetName
     *   A fully-qualified path representing AssetGroupAsset resource.
     * @returns {string} A string representing the asset_id.
     */
    matchAssetIdFromAssetGroupAssetName(assetGroupAssetName: string): string | number;
    /**
     * Parse the field_type from AssetGroupAsset resource.
     *
     * @param {string} assetGroupAssetName
     *   A fully-qualified path representing AssetGroupAsset resource.
     * @returns {string} A string representing the field_type.
     */
    matchFieldTypeFromAssetGroupAssetName(assetGroupAssetName: string): string | number;
    /**
     * Return a fully-qualified assetGroupListingGroupFilter resource name string.
     *
     * @param {string} customer_id
     * @param {string} asset_group_id
     * @param {string} listing_group_filter_id
     * @returns {string} Resource name string.
     */
    assetGroupListingGroupFilterPath(customerId: string, assetGroupId: string, listingGroupFilterId: string): string;
    /**
     * Parse the customer_id from AssetGroupListingGroupFilter resource.
     *
     * @param {string} assetGroupListingGroupFilterName
     *   A fully-qualified path representing AssetGroupListingGroupFilter resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAssetGroupListingGroupFilterName(assetGroupListingGroupFilterName: string): string | number;
    /**
     * Parse the asset_group_id from AssetGroupListingGroupFilter resource.
     *
     * @param {string} assetGroupListingGroupFilterName
     *   A fully-qualified path representing AssetGroupListingGroupFilter resource.
     * @returns {string} A string representing the asset_group_id.
     */
    matchAssetGroupIdFromAssetGroupListingGroupFilterName(assetGroupListingGroupFilterName: string): string | number;
    /**
     * Parse the listing_group_filter_id from AssetGroupListingGroupFilter resource.
     *
     * @param {string} assetGroupListingGroupFilterName
     *   A fully-qualified path representing AssetGroupListingGroupFilter resource.
     * @returns {string} A string representing the listing_group_filter_id.
     */
    matchListingGroupFilterIdFromAssetGroupListingGroupFilterName(assetGroupListingGroupFilterName: string): string | number;
    /**
     * Return a fully-qualified assetGroupProductGroupView resource name string.
     *
     * @param {string} customer_id
     * @param {string} asset_group_id
     * @param {string} listing_group_filter_id
     * @returns {string} Resource name string.
     */
    assetGroupProductGroupViewPath(customerId: string, assetGroupId: string, listingGroupFilterId: string): string;
    /**
     * Parse the customer_id from AssetGroupProductGroupView resource.
     *
     * @param {string} assetGroupProductGroupViewName
     *   A fully-qualified path representing AssetGroupProductGroupView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAssetGroupProductGroupViewName(assetGroupProductGroupViewName: string): string | number;
    /**
     * Parse the asset_group_id from AssetGroupProductGroupView resource.
     *
     * @param {string} assetGroupProductGroupViewName
     *   A fully-qualified path representing AssetGroupProductGroupView resource.
     * @returns {string} A string representing the asset_group_id.
     */
    matchAssetGroupIdFromAssetGroupProductGroupViewName(assetGroupProductGroupViewName: string): string | number;
    /**
     * Parse the listing_group_filter_id from AssetGroupProductGroupView resource.
     *
     * @param {string} assetGroupProductGroupViewName
     *   A fully-qualified path representing AssetGroupProductGroupView resource.
     * @returns {string} A string representing the listing_group_filter_id.
     */
    matchListingGroupFilterIdFromAssetGroupProductGroupViewName(assetGroupProductGroupViewName: string): string | number;
    /**
     * Return a fully-qualified assetGroupSignal resource name string.
     *
     * @param {string} customer_id
     * @param {string} asset_group_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    assetGroupSignalPath(customerId: string, assetGroupId: string, criterionId: string): string;
    /**
     * Parse the customer_id from AssetGroupSignal resource.
     *
     * @param {string} assetGroupSignalName
     *   A fully-qualified path representing AssetGroupSignal resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAssetGroupSignalName(assetGroupSignalName: string): string | number;
    /**
     * Parse the asset_group_id from AssetGroupSignal resource.
     *
     * @param {string} assetGroupSignalName
     *   A fully-qualified path representing AssetGroupSignal resource.
     * @returns {string} A string representing the asset_group_id.
     */
    matchAssetGroupIdFromAssetGroupSignalName(assetGroupSignalName: string): string | number;
    /**
     * Parse the criterion_id from AssetGroupSignal resource.
     *
     * @param {string} assetGroupSignalName
     *   A fully-qualified path representing AssetGroupSignal resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromAssetGroupSignalName(assetGroupSignalName: string): string | number;
    /**
     * Return a fully-qualified assetSet resource name string.
     *
     * @param {string} customer_id
     * @param {string} asset_set_id
     * @returns {string} Resource name string.
     */
    assetSetPath(customerId: string, assetSetId: string): string;
    /**
     * Parse the customer_id from AssetSet resource.
     *
     * @param {string} assetSetName
     *   A fully-qualified path representing AssetSet resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAssetSetName(assetSetName: string): string | number;
    /**
     * Parse the asset_set_id from AssetSet resource.
     *
     * @param {string} assetSetName
     *   A fully-qualified path representing AssetSet resource.
     * @returns {string} A string representing the asset_set_id.
     */
    matchAssetSetIdFromAssetSetName(assetSetName: string): string | number;
    /**
     * Return a fully-qualified assetSetAsset resource name string.
     *
     * @param {string} customer_id
     * @param {string} asset_set_id
     * @param {string} asset_id
     * @returns {string} Resource name string.
     */
    assetSetAssetPath(customerId: string, assetSetId: string, assetId: string): string;
    /**
     * Parse the customer_id from AssetSetAsset resource.
     *
     * @param {string} assetSetAssetName
     *   A fully-qualified path representing AssetSetAsset resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAssetSetAssetName(assetSetAssetName: string): string | number;
    /**
     * Parse the asset_set_id from AssetSetAsset resource.
     *
     * @param {string} assetSetAssetName
     *   A fully-qualified path representing AssetSetAsset resource.
     * @returns {string} A string representing the asset_set_id.
     */
    matchAssetSetIdFromAssetSetAssetName(assetSetAssetName: string): string | number;
    /**
     * Parse the asset_id from AssetSetAsset resource.
     *
     * @param {string} assetSetAssetName
     *   A fully-qualified path representing AssetSetAsset resource.
     * @returns {string} A string representing the asset_id.
     */
    matchAssetIdFromAssetSetAssetName(assetSetAssetName: string): string | number;
    /**
     * Return a fully-qualified assetSetTypeView resource name string.
     *
     * @param {string} customer_id
     * @param {string} asset_set_type
     * @returns {string} Resource name string.
     */
    assetSetTypeViewPath(customerId: string, assetSetType: string): string;
    /**
     * Parse the customer_id from AssetSetTypeView resource.
     *
     * @param {string} assetSetTypeViewName
     *   A fully-qualified path representing AssetSetTypeView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAssetSetTypeViewName(assetSetTypeViewName: string): string | number;
    /**
     * Parse the asset_set_type from AssetSetTypeView resource.
     *
     * @param {string} assetSetTypeViewName
     *   A fully-qualified path representing AssetSetTypeView resource.
     * @returns {string} A string representing the asset_set_type.
     */
    matchAssetSetTypeFromAssetSetTypeViewName(assetSetTypeViewName: string): string | number;
    /**
     * Return a fully-qualified audience resource name string.
     *
     * @param {string} customer_id
     * @param {string} audience_id
     * @returns {string} Resource name string.
     */
    audiencePath(customerId: string, audienceId: string): string;
    /**
     * Parse the customer_id from Audience resource.
     *
     * @param {string} audienceName
     *   A fully-qualified path representing Audience resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAudienceName(audienceName: string): string | number;
    /**
     * Parse the audience_id from Audience resource.
     *
     * @param {string} audienceName
     *   A fully-qualified path representing Audience resource.
     * @returns {string} A string representing the audience_id.
     */
    matchAudienceIdFromAudienceName(audienceName: string): string | number;
    /**
     * Return a fully-qualified batchJob resource name string.
     *
     * @param {string} customer_id
     * @param {string} batch_job_id
     * @returns {string} Resource name string.
     */
    batchJobPath(customerId: string, batchJobId: string): string;
    /**
     * Parse the customer_id from BatchJob resource.
     *
     * @param {string} batchJobName
     *   A fully-qualified path representing BatchJob resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromBatchJobName(batchJobName: string): string | number;
    /**
     * Parse the batch_job_id from BatchJob resource.
     *
     * @param {string} batchJobName
     *   A fully-qualified path representing BatchJob resource.
     * @returns {string} A string representing the batch_job_id.
     */
    matchBatchJobIdFromBatchJobName(batchJobName: string): string | number;
    /**
     * Return a fully-qualified biddingDataExclusion resource name string.
     *
     * @param {string} customer_id
     * @param {string} seasonality_event_id
     * @returns {string} Resource name string.
     */
    biddingDataExclusionPath(customerId: string, seasonalityEventId: string): string;
    /**
     * Parse the customer_id from BiddingDataExclusion resource.
     *
     * @param {string} biddingDataExclusionName
     *   A fully-qualified path representing BiddingDataExclusion resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromBiddingDataExclusionName(biddingDataExclusionName: string): string | number;
    /**
     * Parse the seasonality_event_id from BiddingDataExclusion resource.
     *
     * @param {string} biddingDataExclusionName
     *   A fully-qualified path representing BiddingDataExclusion resource.
     * @returns {string} A string representing the seasonality_event_id.
     */
    matchSeasonalityEventIdFromBiddingDataExclusionName(biddingDataExclusionName: string): string | number;
    /**
     * Return a fully-qualified biddingSeasonalityAdjustment resource name string.
     *
     * @param {string} customer_id
     * @param {string} seasonality_event_id
     * @returns {string} Resource name string.
     */
    biddingSeasonalityAdjustmentPath(customerId: string, seasonalityEventId: string): string;
    /**
     * Parse the customer_id from BiddingSeasonalityAdjustment resource.
     *
     * @param {string} biddingSeasonalityAdjustmentName
     *   A fully-qualified path representing BiddingSeasonalityAdjustment resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromBiddingSeasonalityAdjustmentName(biddingSeasonalityAdjustmentName: string): string | number;
    /**
     * Parse the seasonality_event_id from BiddingSeasonalityAdjustment resource.
     *
     * @param {string} biddingSeasonalityAdjustmentName
     *   A fully-qualified path representing BiddingSeasonalityAdjustment resource.
     * @returns {string} A string representing the seasonality_event_id.
     */
    matchSeasonalityEventIdFromBiddingSeasonalityAdjustmentName(biddingSeasonalityAdjustmentName: string): string | number;
    /**
     * Return a fully-qualified biddingStrategy resource name string.
     *
     * @param {string} customer_id
     * @param {string} bidding_strategy_id
     * @returns {string} Resource name string.
     */
    biddingStrategyPath(customerId: string, biddingStrategyId: string): string;
    /**
     * Parse the customer_id from BiddingStrategy resource.
     *
     * @param {string} biddingStrategyName
     *   A fully-qualified path representing BiddingStrategy resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromBiddingStrategyName(biddingStrategyName: string): string | number;
    /**
     * Parse the bidding_strategy_id from BiddingStrategy resource.
     *
     * @param {string} biddingStrategyName
     *   A fully-qualified path representing BiddingStrategy resource.
     * @returns {string} A string representing the bidding_strategy_id.
     */
    matchBiddingStrategyIdFromBiddingStrategyName(biddingStrategyName: string): string | number;
    /**
     * Return a fully-qualified biddingStrategySimulation resource name string.
     *
     * @param {string} customer_id
     * @param {string} bidding_strategy_id
     * @param {string} type
     * @param {string} modification_method
     * @param {string} start_date
     * @param {string} end_date
     * @returns {string} Resource name string.
     */
    biddingStrategySimulationPath(customerId: string, biddingStrategyId: string, type: string, modificationMethod: string, startDate: string, endDate: string): string;
    /**
     * Parse the customer_id from BiddingStrategySimulation resource.
     *
     * @param {string} biddingStrategySimulationName
     *   A fully-qualified path representing BiddingStrategySimulation resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromBiddingStrategySimulationName(biddingStrategySimulationName: string): string | number;
    /**
     * Parse the bidding_strategy_id from BiddingStrategySimulation resource.
     *
     * @param {string} biddingStrategySimulationName
     *   A fully-qualified path representing BiddingStrategySimulation resource.
     * @returns {string} A string representing the bidding_strategy_id.
     */
    matchBiddingStrategyIdFromBiddingStrategySimulationName(biddingStrategySimulationName: string): string | number;
    /**
     * Parse the type from BiddingStrategySimulation resource.
     *
     * @param {string} biddingStrategySimulationName
     *   A fully-qualified path representing BiddingStrategySimulation resource.
     * @returns {string} A string representing the type.
     */
    matchTypeFromBiddingStrategySimulationName(biddingStrategySimulationName: string): string | number;
    /**
     * Parse the modification_method from BiddingStrategySimulation resource.
     *
     * @param {string} biddingStrategySimulationName
     *   A fully-qualified path representing BiddingStrategySimulation resource.
     * @returns {string} A string representing the modification_method.
     */
    matchModificationMethodFromBiddingStrategySimulationName(biddingStrategySimulationName: string): string | number;
    /**
     * Parse the start_date from BiddingStrategySimulation resource.
     *
     * @param {string} biddingStrategySimulationName
     *   A fully-qualified path representing BiddingStrategySimulation resource.
     * @returns {string} A string representing the start_date.
     */
    matchStartDateFromBiddingStrategySimulationName(biddingStrategySimulationName: string): string | number;
    /**
     * Parse the end_date from BiddingStrategySimulation resource.
     *
     * @param {string} biddingStrategySimulationName
     *   A fully-qualified path representing BiddingStrategySimulation resource.
     * @returns {string} A string representing the end_date.
     */
    matchEndDateFromBiddingStrategySimulationName(biddingStrategySimulationName: string): string | number;
    /**
     * Return a fully-qualified billingSetup resource name string.
     *
     * @param {string} customer_id
     * @param {string} billing_setup_id
     * @returns {string} Resource name string.
     */
    billingSetupPath(customerId: string, billingSetupId: string): string;
    /**
     * Parse the customer_id from BillingSetup resource.
     *
     * @param {string} billingSetupName
     *   A fully-qualified path representing BillingSetup resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromBillingSetupName(billingSetupName: string): string | number;
    /**
     * Parse the billing_setup_id from BillingSetup resource.
     *
     * @param {string} billingSetupName
     *   A fully-qualified path representing BillingSetup resource.
     * @returns {string} A string representing the billing_setup_id.
     */
    matchBillingSetupIdFromBillingSetupName(billingSetupName: string): string | number;
    /**
     * Return a fully-qualified callView resource name string.
     *
     * @param {string} customer_id
     * @param {string} call_detail_id
     * @returns {string} Resource name string.
     */
    callViewPath(customerId: string, callDetailId: string): string;
    /**
     * Parse the customer_id from CallView resource.
     *
     * @param {string} callViewName
     *   A fully-qualified path representing CallView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCallViewName(callViewName: string): string | number;
    /**
     * Parse the call_detail_id from CallView resource.
     *
     * @param {string} callViewName
     *   A fully-qualified path representing CallView resource.
     * @returns {string} A string representing the call_detail_id.
     */
    matchCallDetailIdFromCallViewName(callViewName: string): string | number;
    /**
     * Return a fully-qualified campaign resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @returns {string} Resource name string.
     */
    campaignPath(customerId: string, campaignId: string): string;
    /**
     * Parse the customer_id from Campaign resource.
     *
     * @param {string} campaignName
     *   A fully-qualified path representing Campaign resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCampaignName(campaignName: string): string | number;
    /**
     * Parse the campaign_id from Campaign resource.
     *
     * @param {string} campaignName
     *   A fully-qualified path representing Campaign resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromCampaignName(campaignName: string): string | number;
    /**
     * Return a fully-qualified campaignAsset resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} asset_id
     * @param {string} field_type
     * @returns {string} Resource name string.
     */
    campaignAssetPath(customerId: string, campaignId: string, assetId: string, fieldType: string): string;
    /**
     * Parse the customer_id from CampaignAsset resource.
     *
     * @param {string} campaignAssetName
     *   A fully-qualified path representing CampaignAsset resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCampaignAssetName(campaignAssetName: string): string | number;
    /**
     * Parse the campaign_id from CampaignAsset resource.
     *
     * @param {string} campaignAssetName
     *   A fully-qualified path representing CampaignAsset resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromCampaignAssetName(campaignAssetName: string): string | number;
    /**
     * Parse the asset_id from CampaignAsset resource.
     *
     * @param {string} campaignAssetName
     *   A fully-qualified path representing CampaignAsset resource.
     * @returns {string} A string representing the asset_id.
     */
    matchAssetIdFromCampaignAssetName(campaignAssetName: string): string | number;
    /**
     * Parse the field_type from CampaignAsset resource.
     *
     * @param {string} campaignAssetName
     *   A fully-qualified path representing CampaignAsset resource.
     * @returns {string} A string representing the field_type.
     */
    matchFieldTypeFromCampaignAssetName(campaignAssetName: string): string | number;
    /**
     * Return a fully-qualified campaignAssetSet resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} asset_set_id
     * @returns {string} Resource name string.
     */
    campaignAssetSetPath(customerId: string, campaignId: string, assetSetId: string): string;
    /**
     * Parse the customer_id from CampaignAssetSet resource.
     *
     * @param {string} campaignAssetSetName
     *   A fully-qualified path representing CampaignAssetSet resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCampaignAssetSetName(campaignAssetSetName: string): string | number;
    /**
     * Parse the campaign_id from CampaignAssetSet resource.
     *
     * @param {string} campaignAssetSetName
     *   A fully-qualified path representing CampaignAssetSet resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromCampaignAssetSetName(campaignAssetSetName: string): string | number;
    /**
     * Parse the asset_set_id from CampaignAssetSet resource.
     *
     * @param {string} campaignAssetSetName
     *   A fully-qualified path representing CampaignAssetSet resource.
     * @returns {string} A string representing the asset_set_id.
     */
    matchAssetSetIdFromCampaignAssetSetName(campaignAssetSetName: string): string | number;
    /**
     * Return a fully-qualified campaignAudienceView resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    campaignAudienceViewPath(customerId: string, campaignId: string, criterionId: string): string;
    /**
     * Parse the customer_id from CampaignAudienceView resource.
     *
     * @param {string} campaignAudienceViewName
     *   A fully-qualified path representing CampaignAudienceView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCampaignAudienceViewName(campaignAudienceViewName: string): string | number;
    /**
     * Parse the campaign_id from CampaignAudienceView resource.
     *
     * @param {string} campaignAudienceViewName
     *   A fully-qualified path representing CampaignAudienceView resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromCampaignAudienceViewName(campaignAudienceViewName: string): string | number;
    /**
     * Parse the criterion_id from CampaignAudienceView resource.
     *
     * @param {string} campaignAudienceViewName
     *   A fully-qualified path representing CampaignAudienceView resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromCampaignAudienceViewName(campaignAudienceViewName: string): string | number;
    /**
     * Return a fully-qualified campaignBidModifier resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    campaignBidModifierPath(customerId: string, campaignId: string, criterionId: string): string;
    /**
     * Parse the customer_id from CampaignBidModifier resource.
     *
     * @param {string} campaignBidModifierName
     *   A fully-qualified path representing CampaignBidModifier resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCampaignBidModifierName(campaignBidModifierName: string): string | number;
    /**
     * Parse the campaign_id from CampaignBidModifier resource.
     *
     * @param {string} campaignBidModifierName
     *   A fully-qualified path representing CampaignBidModifier resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromCampaignBidModifierName(campaignBidModifierName: string): string | number;
    /**
     * Parse the criterion_id from CampaignBidModifier resource.
     *
     * @param {string} campaignBidModifierName
     *   A fully-qualified path representing CampaignBidModifier resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromCampaignBidModifierName(campaignBidModifierName: string): string | number;
    /**
     * Return a fully-qualified campaignBudget resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_budget_id
     * @returns {string} Resource name string.
     */
    campaignBudgetPath(customerId: string, campaignBudgetId: string): string;
    /**
     * Parse the customer_id from CampaignBudget resource.
     *
     * @param {string} campaignBudgetName
     *   A fully-qualified path representing CampaignBudget resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCampaignBudgetName(campaignBudgetName: string): string | number;
    /**
     * Parse the campaign_budget_id from CampaignBudget resource.
     *
     * @param {string} campaignBudgetName
     *   A fully-qualified path representing CampaignBudget resource.
     * @returns {string} A string representing the campaign_budget_id.
     */
    matchCampaignBudgetIdFromCampaignBudgetName(campaignBudgetName: string): string | number;
    /**
     * Return a fully-qualified campaignConversionGoal resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} category
     * @param {string} source
     * @returns {string} Resource name string.
     */
    campaignConversionGoalPath(customerId: string, campaignId: string, category: string, source: string): string;
    /**
     * Parse the customer_id from CampaignConversionGoal resource.
     *
     * @param {string} campaignConversionGoalName
     *   A fully-qualified path representing CampaignConversionGoal resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCampaignConversionGoalName(campaignConversionGoalName: string): string | number;
    /**
     * Parse the campaign_id from CampaignConversionGoal resource.
     *
     * @param {string} campaignConversionGoalName
     *   A fully-qualified path representing CampaignConversionGoal resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromCampaignConversionGoalName(campaignConversionGoalName: string): string | number;
    /**
     * Parse the category from CampaignConversionGoal resource.
     *
     * @param {string} campaignConversionGoalName
     *   A fully-qualified path representing CampaignConversionGoal resource.
     * @returns {string} A string representing the category.
     */
    matchCategoryFromCampaignConversionGoalName(campaignConversionGoalName: string): string | number;
    /**
     * Parse the source from CampaignConversionGoal resource.
     *
     * @param {string} campaignConversionGoalName
     *   A fully-qualified path representing CampaignConversionGoal resource.
     * @returns {string} A string representing the source.
     */
    matchSourceFromCampaignConversionGoalName(campaignConversionGoalName: string): string | number;
    /**
     * Return a fully-qualified campaignCriterion resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    campaignCriterionPath(customerId: string, campaignId: string, criterionId: string): string;
    /**
     * Parse the customer_id from CampaignCriterion resource.
     *
     * @param {string} campaignCriterionName
     *   A fully-qualified path representing CampaignCriterion resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCampaignCriterionName(campaignCriterionName: string): string | number;
    /**
     * Parse the campaign_id from CampaignCriterion resource.
     *
     * @param {string} campaignCriterionName
     *   A fully-qualified path representing CampaignCriterion resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromCampaignCriterionName(campaignCriterionName: string): string | number;
    /**
     * Parse the criterion_id from CampaignCriterion resource.
     *
     * @param {string} campaignCriterionName
     *   A fully-qualified path representing CampaignCriterion resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromCampaignCriterionName(campaignCriterionName: string): string | number;
    /**
     * Return a fully-qualified campaignCustomizer resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} customizer_attribute_id
     * @returns {string} Resource name string.
     */
    campaignCustomizerPath(customerId: string, campaignId: string, customizerAttributeId: string): string;
    /**
     * Parse the customer_id from CampaignCustomizer resource.
     *
     * @param {string} campaignCustomizerName
     *   A fully-qualified path representing CampaignCustomizer resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCampaignCustomizerName(campaignCustomizerName: string): string | number;
    /**
     * Parse the campaign_id from CampaignCustomizer resource.
     *
     * @param {string} campaignCustomizerName
     *   A fully-qualified path representing CampaignCustomizer resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromCampaignCustomizerName(campaignCustomizerName: string): string | number;
    /**
     * Parse the customizer_attribute_id from CampaignCustomizer resource.
     *
     * @param {string} campaignCustomizerName
     *   A fully-qualified path representing CampaignCustomizer resource.
     * @returns {string} A string representing the customizer_attribute_id.
     */
    matchCustomizerAttributeIdFromCampaignCustomizerName(campaignCustomizerName: string): string | number;
    /**
     * Return a fully-qualified campaignDraft resource name string.
     *
     * @param {string} customer_id
     * @param {string} base_campaign_id
     * @param {string} draft_id
     * @returns {string} Resource name string.
     */
    campaignDraftPath(customerId: string, baseCampaignId: string, draftId: string): string;
    /**
     * Parse the customer_id from CampaignDraft resource.
     *
     * @param {string} campaignDraftName
     *   A fully-qualified path representing CampaignDraft resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCampaignDraftName(campaignDraftName: string): string | number;
    /**
     * Parse the base_campaign_id from CampaignDraft resource.
     *
     * @param {string} campaignDraftName
     *   A fully-qualified path representing CampaignDraft resource.
     * @returns {string} A string representing the base_campaign_id.
     */
    matchBaseCampaignIdFromCampaignDraftName(campaignDraftName: string): string | number;
    /**
     * Parse the draft_id from CampaignDraft resource.
     *
     * @param {string} campaignDraftName
     *   A fully-qualified path representing CampaignDraft resource.
     * @returns {string} A string representing the draft_id.
     */
    matchDraftIdFromCampaignDraftName(campaignDraftName: string): string | number;
    /**
     * Return a fully-qualified campaignExtensionSetting resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} extension_type
     * @returns {string} Resource name string.
     */
    campaignExtensionSettingPath(customerId: string, campaignId: string, extensionType: string): string;
    /**
     * Parse the customer_id from CampaignExtensionSetting resource.
     *
     * @param {string} campaignExtensionSettingName
     *   A fully-qualified path representing CampaignExtensionSetting resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCampaignExtensionSettingName(campaignExtensionSettingName: string): string | number;
    /**
     * Parse the campaign_id from CampaignExtensionSetting resource.
     *
     * @param {string} campaignExtensionSettingName
     *   A fully-qualified path representing CampaignExtensionSetting resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromCampaignExtensionSettingName(campaignExtensionSettingName: string): string | number;
    /**
     * Parse the extension_type from CampaignExtensionSetting resource.
     *
     * @param {string} campaignExtensionSettingName
     *   A fully-qualified path representing CampaignExtensionSetting resource.
     * @returns {string} A string representing the extension_type.
     */
    matchExtensionTypeFromCampaignExtensionSettingName(campaignExtensionSettingName: string): string | number;
    /**
     * Return a fully-qualified campaignFeed resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} feed_id
     * @returns {string} Resource name string.
     */
    campaignFeedPath(customerId: string, campaignId: string, feedId: string): string;
    /**
     * Parse the customer_id from CampaignFeed resource.
     *
     * @param {string} campaignFeedName
     *   A fully-qualified path representing CampaignFeed resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCampaignFeedName(campaignFeedName: string): string | number;
    /**
     * Parse the campaign_id from CampaignFeed resource.
     *
     * @param {string} campaignFeedName
     *   A fully-qualified path representing CampaignFeed resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromCampaignFeedName(campaignFeedName: string): string | number;
    /**
     * Parse the feed_id from CampaignFeed resource.
     *
     * @param {string} campaignFeedName
     *   A fully-qualified path representing CampaignFeed resource.
     * @returns {string} A string representing the feed_id.
     */
    matchFeedIdFromCampaignFeedName(campaignFeedName: string): string | number;
    /**
     * Return a fully-qualified campaignGroup resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_group_id
     * @returns {string} Resource name string.
     */
    campaignGroupPath(customerId: string, campaignGroupId: string): string;
    /**
     * Parse the customer_id from CampaignGroup resource.
     *
     * @param {string} campaignGroupName
     *   A fully-qualified path representing CampaignGroup resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCampaignGroupName(campaignGroupName: string): string | number;
    /**
     * Parse the campaign_group_id from CampaignGroup resource.
     *
     * @param {string} campaignGroupName
     *   A fully-qualified path representing CampaignGroup resource.
     * @returns {string} A string representing the campaign_group_id.
     */
    matchCampaignGroupIdFromCampaignGroupName(campaignGroupName: string): string | number;
    /**
     * Return a fully-qualified campaignLabel resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} label_id
     * @returns {string} Resource name string.
     */
    campaignLabelPath(customerId: string, campaignId: string, labelId: string): string;
    /**
     * Parse the customer_id from CampaignLabel resource.
     *
     * @param {string} campaignLabelName
     *   A fully-qualified path representing CampaignLabel resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCampaignLabelName(campaignLabelName: string): string | number;
    /**
     * Parse the campaign_id from CampaignLabel resource.
     *
     * @param {string} campaignLabelName
     *   A fully-qualified path representing CampaignLabel resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromCampaignLabelName(campaignLabelName: string): string | number;
    /**
     * Parse the label_id from CampaignLabel resource.
     *
     * @param {string} campaignLabelName
     *   A fully-qualified path representing CampaignLabel resource.
     * @returns {string} A string representing the label_id.
     */
    matchLabelIdFromCampaignLabelName(campaignLabelName: string): string | number;
    /**
     * Return a fully-qualified campaignSearchTermInsight resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} cluster_id
     * @returns {string} Resource name string.
     */
    campaignSearchTermInsightPath(customerId: string, campaignId: string, clusterId: string): string;
    /**
     * Parse the customer_id from CampaignSearchTermInsight resource.
     *
     * @param {string} campaignSearchTermInsightName
     *   A fully-qualified path representing CampaignSearchTermInsight resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCampaignSearchTermInsightName(campaignSearchTermInsightName: string): string | number;
    /**
     * Parse the campaign_id from CampaignSearchTermInsight resource.
     *
     * @param {string} campaignSearchTermInsightName
     *   A fully-qualified path representing CampaignSearchTermInsight resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromCampaignSearchTermInsightName(campaignSearchTermInsightName: string): string | number;
    /**
     * Parse the cluster_id from CampaignSearchTermInsight resource.
     *
     * @param {string} campaignSearchTermInsightName
     *   A fully-qualified path representing CampaignSearchTermInsight resource.
     * @returns {string} A string representing the cluster_id.
     */
    matchClusterIdFromCampaignSearchTermInsightName(campaignSearchTermInsightName: string): string | number;
    /**
     * Return a fully-qualified campaignSharedSet resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} shared_set_id
     * @returns {string} Resource name string.
     */
    campaignSharedSetPath(customerId: string, campaignId: string, sharedSetId: string): string;
    /**
     * Parse the customer_id from CampaignSharedSet resource.
     *
     * @param {string} campaignSharedSetName
     *   A fully-qualified path representing CampaignSharedSet resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCampaignSharedSetName(campaignSharedSetName: string): string | number;
    /**
     * Parse the campaign_id from CampaignSharedSet resource.
     *
     * @param {string} campaignSharedSetName
     *   A fully-qualified path representing CampaignSharedSet resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromCampaignSharedSetName(campaignSharedSetName: string): string | number;
    /**
     * Parse the shared_set_id from CampaignSharedSet resource.
     *
     * @param {string} campaignSharedSetName
     *   A fully-qualified path representing CampaignSharedSet resource.
     * @returns {string} A string representing the shared_set_id.
     */
    matchSharedSetIdFromCampaignSharedSetName(campaignSharedSetName: string): string | number;
    /**
     * Return a fully-qualified campaignSimulation resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} type
     * @param {string} modification_method
     * @param {string} start_date
     * @param {string} end_date
     * @returns {string} Resource name string.
     */
    campaignSimulationPath(customerId: string, campaignId: string, type: string, modificationMethod: string, startDate: string, endDate: string): string;
    /**
     * Parse the customer_id from CampaignSimulation resource.
     *
     * @param {string} campaignSimulationName
     *   A fully-qualified path representing CampaignSimulation resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCampaignSimulationName(campaignSimulationName: string): string | number;
    /**
     * Parse the campaign_id from CampaignSimulation resource.
     *
     * @param {string} campaignSimulationName
     *   A fully-qualified path representing CampaignSimulation resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromCampaignSimulationName(campaignSimulationName: string): string | number;
    /**
     * Parse the type from CampaignSimulation resource.
     *
     * @param {string} campaignSimulationName
     *   A fully-qualified path representing CampaignSimulation resource.
     * @returns {string} A string representing the type.
     */
    matchTypeFromCampaignSimulationName(campaignSimulationName: string): string | number;
    /**
     * Parse the modification_method from CampaignSimulation resource.
     *
     * @param {string} campaignSimulationName
     *   A fully-qualified path representing CampaignSimulation resource.
     * @returns {string} A string representing the modification_method.
     */
    matchModificationMethodFromCampaignSimulationName(campaignSimulationName: string): string | number;
    /**
     * Parse the start_date from CampaignSimulation resource.
     *
     * @param {string} campaignSimulationName
     *   A fully-qualified path representing CampaignSimulation resource.
     * @returns {string} A string representing the start_date.
     */
    matchStartDateFromCampaignSimulationName(campaignSimulationName: string): string | number;
    /**
     * Parse the end_date from CampaignSimulation resource.
     *
     * @param {string} campaignSimulationName
     *   A fully-qualified path representing CampaignSimulation resource.
     * @returns {string} A string representing the end_date.
     */
    matchEndDateFromCampaignSimulationName(campaignSimulationName: string): string | number;
    /**
     * Return a fully-qualified carrierConstant resource name string.
     *
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    carrierConstantPath(criterionId: string): string;
    /**
     * Parse the criterion_id from CarrierConstant resource.
     *
     * @param {string} carrierConstantName
     *   A fully-qualified path representing CarrierConstant resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromCarrierConstantName(carrierConstantName: string): string | number;
    /**
     * Return a fully-qualified changeEvent resource name string.
     *
     * @param {string} customer_id
     * @param {string} timestamp_micros
     * @param {string} command_index
     * @param {string} mutate_index
     * @returns {string} Resource name string.
     */
    changeEventPath(customerId: string, timestampMicros: string, commandIndex: string, mutateIndex: string): string;
    /**
     * Parse the customer_id from ChangeEvent resource.
     *
     * @param {string} changeEventName
     *   A fully-qualified path representing ChangeEvent resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromChangeEventName(changeEventName: string): string | number;
    /**
     * Parse the timestamp_micros from ChangeEvent resource.
     *
     * @param {string} changeEventName
     *   A fully-qualified path representing ChangeEvent resource.
     * @returns {string} A string representing the timestamp_micros.
     */
    matchTimestampMicrosFromChangeEventName(changeEventName: string): string | number;
    /**
     * Parse the command_index from ChangeEvent resource.
     *
     * @param {string} changeEventName
     *   A fully-qualified path representing ChangeEvent resource.
     * @returns {string} A string representing the command_index.
     */
    matchCommandIndexFromChangeEventName(changeEventName: string): string | number;
    /**
     * Parse the mutate_index from ChangeEvent resource.
     *
     * @param {string} changeEventName
     *   A fully-qualified path representing ChangeEvent resource.
     * @returns {string} A string representing the mutate_index.
     */
    matchMutateIndexFromChangeEventName(changeEventName: string): string | number;
    /**
     * Return a fully-qualified changeStatus resource name string.
     *
     * @param {string} customer_id
     * @param {string} change_status_id
     * @returns {string} Resource name string.
     */
    changeStatusPath(customerId: string, changeStatusId: string): string;
    /**
     * Parse the customer_id from ChangeStatus resource.
     *
     * @param {string} changeStatusName
     *   A fully-qualified path representing ChangeStatus resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromChangeStatusName(changeStatusName: string): string | number;
    /**
     * Parse the change_status_id from ChangeStatus resource.
     *
     * @param {string} changeStatusName
     *   A fully-qualified path representing ChangeStatus resource.
     * @returns {string} A string representing the change_status_id.
     */
    matchChangeStatusIdFromChangeStatusName(changeStatusName: string): string | number;
    /**
     * Return a fully-qualified clickView resource name string.
     *
     * @param {string} customer_id
     * @param {string} date
     * @param {string} gclid
     * @returns {string} Resource name string.
     */
    clickViewPath(customerId: string, date: string, gclid: string): string;
    /**
     * Parse the customer_id from ClickView resource.
     *
     * @param {string} clickViewName
     *   A fully-qualified path representing ClickView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromClickViewName(clickViewName: string): string | number;
    /**
     * Parse the date from ClickView resource.
     *
     * @param {string} clickViewName
     *   A fully-qualified path representing ClickView resource.
     * @returns {string} A string representing the date.
     */
    matchDateFromClickViewName(clickViewName: string): string | number;
    /**
     * Parse the gclid from ClickView resource.
     *
     * @param {string} clickViewName
     *   A fully-qualified path representing ClickView resource.
     * @returns {string} A string representing the gclid.
     */
    matchGclidFromClickViewName(clickViewName: string): string | number;
    /**
     * Return a fully-qualified combinedAudience resource name string.
     *
     * @param {string} customer_id
     * @param {string} combined_audience_id
     * @returns {string} Resource name string.
     */
    combinedAudiencePath(customerId: string, combinedAudienceId: string): string;
    /**
     * Parse the customer_id from CombinedAudience resource.
     *
     * @param {string} combinedAudienceName
     *   A fully-qualified path representing CombinedAudience resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCombinedAudienceName(combinedAudienceName: string): string | number;
    /**
     * Parse the combined_audience_id from CombinedAudience resource.
     *
     * @param {string} combinedAudienceName
     *   A fully-qualified path representing CombinedAudience resource.
     * @returns {string} A string representing the combined_audience_id.
     */
    matchCombinedAudienceIdFromCombinedAudienceName(combinedAudienceName: string): string | number;
    /**
     * Return a fully-qualified conversionAction resource name string.
     *
     * @param {string} customer_id
     * @param {string} conversion_action_id
     * @returns {string} Resource name string.
     */
    conversionActionPath(customerId: string, conversionActionId: string): string;
    /**
     * Parse the customer_id from ConversionAction resource.
     *
     * @param {string} conversionActionName
     *   A fully-qualified path representing ConversionAction resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromConversionActionName(conversionActionName: string): string | number;
    /**
     * Parse the conversion_action_id from ConversionAction resource.
     *
     * @param {string} conversionActionName
     *   A fully-qualified path representing ConversionAction resource.
     * @returns {string} A string representing the conversion_action_id.
     */
    matchConversionActionIdFromConversionActionName(conversionActionName: string): string | number;
    /**
     * Return a fully-qualified conversionCustomVariable resource name string.
     *
     * @param {string} customer_id
     * @param {string} conversion_custom_variable_id
     * @returns {string} Resource name string.
     */
    conversionCustomVariablePath(customerId: string, conversionCustomVariableId: string): string;
    /**
     * Parse the customer_id from ConversionCustomVariable resource.
     *
     * @param {string} conversionCustomVariableName
     *   A fully-qualified path representing ConversionCustomVariable resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromConversionCustomVariableName(conversionCustomVariableName: string): string | number;
    /**
     * Parse the conversion_custom_variable_id from ConversionCustomVariable resource.
     *
     * @param {string} conversionCustomVariableName
     *   A fully-qualified path representing ConversionCustomVariable resource.
     * @returns {string} A string representing the conversion_custom_variable_id.
     */
    matchConversionCustomVariableIdFromConversionCustomVariableName(conversionCustomVariableName: string): string | number;
    /**
     * Return a fully-qualified conversionGoalCampaignConfig resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @returns {string} Resource name string.
     */
    conversionGoalCampaignConfigPath(customerId: string, campaignId: string): string;
    /**
     * Parse the customer_id from ConversionGoalCampaignConfig resource.
     *
     * @param {string} conversionGoalCampaignConfigName
     *   A fully-qualified path representing ConversionGoalCampaignConfig resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromConversionGoalCampaignConfigName(conversionGoalCampaignConfigName: string): string | number;
    /**
     * Parse the campaign_id from ConversionGoalCampaignConfig resource.
     *
     * @param {string} conversionGoalCampaignConfigName
     *   A fully-qualified path representing ConversionGoalCampaignConfig resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromConversionGoalCampaignConfigName(conversionGoalCampaignConfigName: string): string | number;
    /**
     * Return a fully-qualified conversionValueRule resource name string.
     *
     * @param {string} customer_id
     * @param {string} conversion_value_rule_id
     * @returns {string} Resource name string.
     */
    conversionValueRulePath(customerId: string, conversionValueRuleId: string): string;
    /**
     * Parse the customer_id from ConversionValueRule resource.
     *
     * @param {string} conversionValueRuleName
     *   A fully-qualified path representing ConversionValueRule resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromConversionValueRuleName(conversionValueRuleName: string): string | number;
    /**
     * Parse the conversion_value_rule_id from ConversionValueRule resource.
     *
     * @param {string} conversionValueRuleName
     *   A fully-qualified path representing ConversionValueRule resource.
     * @returns {string} A string representing the conversion_value_rule_id.
     */
    matchConversionValueRuleIdFromConversionValueRuleName(conversionValueRuleName: string): string | number;
    /**
     * Return a fully-qualified conversionValueRuleSet resource name string.
     *
     * @param {string} customer_id
     * @param {string} conversion_value_rule_set_id
     * @returns {string} Resource name string.
     */
    conversionValueRuleSetPath(customerId: string, conversionValueRuleSetId: string): string;
    /**
     * Parse the customer_id from ConversionValueRuleSet resource.
     *
     * @param {string} conversionValueRuleSetName
     *   A fully-qualified path representing ConversionValueRuleSet resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromConversionValueRuleSetName(conversionValueRuleSetName: string): string | number;
    /**
     * Parse the conversion_value_rule_set_id from ConversionValueRuleSet resource.
     *
     * @param {string} conversionValueRuleSetName
     *   A fully-qualified path representing ConversionValueRuleSet resource.
     * @returns {string} A string representing the conversion_value_rule_set_id.
     */
    matchConversionValueRuleSetIdFromConversionValueRuleSetName(conversionValueRuleSetName: string): string | number;
    /**
     * Return a fully-qualified currencyConstant resource name string.
     *
     * @param {string} code
     * @returns {string} Resource name string.
     */
    currencyConstantPath(code: string): string;
    /**
     * Parse the code from CurrencyConstant resource.
     *
     * @param {string} currencyConstantName
     *   A fully-qualified path representing CurrencyConstant resource.
     * @returns {string} A string representing the code.
     */
    matchCodeFromCurrencyConstantName(currencyConstantName: string): string | number;
    /**
     * Return a fully-qualified customAudience resource name string.
     *
     * @param {string} customer_id
     * @param {string} custom_audience_id
     * @returns {string} Resource name string.
     */
    customAudiencePath(customerId: string, customAudienceId: string): string;
    /**
     * Parse the customer_id from CustomAudience resource.
     *
     * @param {string} customAudienceName
     *   A fully-qualified path representing CustomAudience resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomAudienceName(customAudienceName: string): string | number;
    /**
     * Parse the custom_audience_id from CustomAudience resource.
     *
     * @param {string} customAudienceName
     *   A fully-qualified path representing CustomAudience resource.
     * @returns {string} A string representing the custom_audience_id.
     */
    matchCustomAudienceIdFromCustomAudienceName(customAudienceName: string): string | number;
    /**
     * Return a fully-qualified customConversionGoal resource name string.
     *
     * @param {string} customer_id
     * @param {string} goal_id
     * @returns {string} Resource name string.
     */
    customConversionGoalPath(customerId: string, goalId: string): string;
    /**
     * Parse the customer_id from CustomConversionGoal resource.
     *
     * @param {string} customConversionGoalName
     *   A fully-qualified path representing CustomConversionGoal resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomConversionGoalName(customConversionGoalName: string): string | number;
    /**
     * Parse the goal_id from CustomConversionGoal resource.
     *
     * @param {string} customConversionGoalName
     *   A fully-qualified path representing CustomConversionGoal resource.
     * @returns {string} A string representing the goal_id.
     */
    matchGoalIdFromCustomConversionGoalName(customConversionGoalName: string): string | number;
    /**
     * Return a fully-qualified customInterest resource name string.
     *
     * @param {string} customer_id
     * @param {string} custom_interest_id
     * @returns {string} Resource name string.
     */
    customInterestPath(customerId: string, customInterestId: string): string;
    /**
     * Parse the customer_id from CustomInterest resource.
     *
     * @param {string} customInterestName
     *   A fully-qualified path representing CustomInterest resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomInterestName(customInterestName: string): string | number;
    /**
     * Parse the custom_interest_id from CustomInterest resource.
     *
     * @param {string} customInterestName
     *   A fully-qualified path representing CustomInterest resource.
     * @returns {string} A string representing the custom_interest_id.
     */
    matchCustomInterestIdFromCustomInterestName(customInterestName: string): string | number;
    /**
     * Return a fully-qualified customer resource name string.
     *
     * @param {string} customer_id
     * @returns {string} Resource name string.
     */
    customerPath(customerId: string): string;
    /**
     * Parse the customer_id from Customer resource.
     *
     * @param {string} customerName
     *   A fully-qualified path representing Customer resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomerName(customerName: string): string | number;
    /**
     * Return a fully-qualified customerAsset resource name string.
     *
     * @param {string} customer_id
     * @param {string} asset_id
     * @param {string} field_type
     * @returns {string} Resource name string.
     */
    customerAssetPath(customerId: string, assetId: string, fieldType: string): string;
    /**
     * Parse the customer_id from CustomerAsset resource.
     *
     * @param {string} customerAssetName
     *   A fully-qualified path representing CustomerAsset resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomerAssetName(customerAssetName: string): string | number;
    /**
     * Parse the asset_id from CustomerAsset resource.
     *
     * @param {string} customerAssetName
     *   A fully-qualified path representing CustomerAsset resource.
     * @returns {string} A string representing the asset_id.
     */
    matchAssetIdFromCustomerAssetName(customerAssetName: string): string | number;
    /**
     * Parse the field_type from CustomerAsset resource.
     *
     * @param {string} customerAssetName
     *   A fully-qualified path representing CustomerAsset resource.
     * @returns {string} A string representing the field_type.
     */
    matchFieldTypeFromCustomerAssetName(customerAssetName: string): string | number;
    /**
     * Return a fully-qualified customerAssetSet resource name string.
     *
     * @param {string} customer_id
     * @param {string} asset_set_id
     * @returns {string} Resource name string.
     */
    customerAssetSetPath(customerId: string, assetSetId: string): string;
    /**
     * Parse the customer_id from CustomerAssetSet resource.
     *
     * @param {string} customerAssetSetName
     *   A fully-qualified path representing CustomerAssetSet resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomerAssetSetName(customerAssetSetName: string): string | number;
    /**
     * Parse the asset_set_id from CustomerAssetSet resource.
     *
     * @param {string} customerAssetSetName
     *   A fully-qualified path representing CustomerAssetSet resource.
     * @returns {string} A string representing the asset_set_id.
     */
    matchAssetSetIdFromCustomerAssetSetName(customerAssetSetName: string): string | number;
    /**
     * Return a fully-qualified customerClient resource name string.
     *
     * @param {string} customer_id
     * @param {string} client_customer_id
     * @returns {string} Resource name string.
     */
    customerClientPath(customerId: string, clientCustomerId: string): string;
    /**
     * Parse the customer_id from CustomerClient resource.
     *
     * @param {string} customerClientName
     *   A fully-qualified path representing CustomerClient resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomerClientName(customerClientName: string): string | number;
    /**
     * Parse the client_customer_id from CustomerClient resource.
     *
     * @param {string} customerClientName
     *   A fully-qualified path representing CustomerClient resource.
     * @returns {string} A string representing the client_customer_id.
     */
    matchClientCustomerIdFromCustomerClientName(customerClientName: string): string | number;
    /**
     * Return a fully-qualified customerClientLink resource name string.
     *
     * @param {string} customer_id
     * @param {string} client_customer_id
     * @param {string} manager_link_id
     * @returns {string} Resource name string.
     */
    customerClientLinkPath(customerId: string, clientCustomerId: string, managerLinkId: string): string;
    /**
     * Parse the customer_id from CustomerClientLink resource.
     *
     * @param {string} customerClientLinkName
     *   A fully-qualified path representing CustomerClientLink resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomerClientLinkName(customerClientLinkName: string): string | number;
    /**
     * Parse the client_customer_id from CustomerClientLink resource.
     *
     * @param {string} customerClientLinkName
     *   A fully-qualified path representing CustomerClientLink resource.
     * @returns {string} A string representing the client_customer_id.
     */
    matchClientCustomerIdFromCustomerClientLinkName(customerClientLinkName: string): string | number;
    /**
     * Parse the manager_link_id from CustomerClientLink resource.
     *
     * @param {string} customerClientLinkName
     *   A fully-qualified path representing CustomerClientLink resource.
     * @returns {string} A string representing the manager_link_id.
     */
    matchManagerLinkIdFromCustomerClientLinkName(customerClientLinkName: string): string | number;
    /**
     * Return a fully-qualified customerConversionGoal resource name string.
     *
     * @param {string} customer_id
     * @param {string} category
     * @param {string} source
     * @returns {string} Resource name string.
     */
    customerConversionGoalPath(customerId: string, category: string, source: string): string;
    /**
     * Parse the customer_id from CustomerConversionGoal resource.
     *
     * @param {string} customerConversionGoalName
     *   A fully-qualified path representing CustomerConversionGoal resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomerConversionGoalName(customerConversionGoalName: string): string | number;
    /**
     * Parse the category from CustomerConversionGoal resource.
     *
     * @param {string} customerConversionGoalName
     *   A fully-qualified path representing CustomerConversionGoal resource.
     * @returns {string} A string representing the category.
     */
    matchCategoryFromCustomerConversionGoalName(customerConversionGoalName: string): string | number;
    /**
     * Parse the source from CustomerConversionGoal resource.
     *
     * @param {string} customerConversionGoalName
     *   A fully-qualified path representing CustomerConversionGoal resource.
     * @returns {string} A string representing the source.
     */
    matchSourceFromCustomerConversionGoalName(customerConversionGoalName: string): string | number;
    /**
     * Return a fully-qualified customerCustomizer resource name string.
     *
     * @param {string} customer_id
     * @param {string} customizer_attribute_id
     * @returns {string} Resource name string.
     */
    customerCustomizerPath(customerId: string, customizerAttributeId: string): string;
    /**
     * Parse the customer_id from CustomerCustomizer resource.
     *
     * @param {string} customerCustomizerName
     *   A fully-qualified path representing CustomerCustomizer resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomerCustomizerName(customerCustomizerName: string): string | number;
    /**
     * Parse the customizer_attribute_id from CustomerCustomizer resource.
     *
     * @param {string} customerCustomizerName
     *   A fully-qualified path representing CustomerCustomizer resource.
     * @returns {string} A string representing the customizer_attribute_id.
     */
    matchCustomizerAttributeIdFromCustomerCustomizerName(customerCustomizerName: string): string | number;
    /**
     * Return a fully-qualified customerExtensionSetting resource name string.
     *
     * @param {string} customer_id
     * @param {string} extension_type
     * @returns {string} Resource name string.
     */
    customerExtensionSettingPath(customerId: string, extensionType: string): string;
    /**
     * Parse the customer_id from CustomerExtensionSetting resource.
     *
     * @param {string} customerExtensionSettingName
     *   A fully-qualified path representing CustomerExtensionSetting resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomerExtensionSettingName(customerExtensionSettingName: string): string | number;
    /**
     * Parse the extension_type from CustomerExtensionSetting resource.
     *
     * @param {string} customerExtensionSettingName
     *   A fully-qualified path representing CustomerExtensionSetting resource.
     * @returns {string} A string representing the extension_type.
     */
    matchExtensionTypeFromCustomerExtensionSettingName(customerExtensionSettingName: string): string | number;
    /**
     * Return a fully-qualified customerFeed resource name string.
     *
     * @param {string} customer_id
     * @param {string} feed_id
     * @returns {string} Resource name string.
     */
    customerFeedPath(customerId: string, feedId: string): string;
    /**
     * Parse the customer_id from CustomerFeed resource.
     *
     * @param {string} customerFeedName
     *   A fully-qualified path representing CustomerFeed resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomerFeedName(customerFeedName: string): string | number;
    /**
     * Parse the feed_id from CustomerFeed resource.
     *
     * @param {string} customerFeedName
     *   A fully-qualified path representing CustomerFeed resource.
     * @returns {string} A string representing the feed_id.
     */
    matchFeedIdFromCustomerFeedName(customerFeedName: string): string | number;
    /**
     * Return a fully-qualified customerLabel resource name string.
     *
     * @param {string} customer_id
     * @param {string} label_id
     * @returns {string} Resource name string.
     */
    customerLabelPath(customerId: string, labelId: string): string;
    /**
     * Parse the customer_id from CustomerLabel resource.
     *
     * @param {string} customerLabelName
     *   A fully-qualified path representing CustomerLabel resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomerLabelName(customerLabelName: string): string | number;
    /**
     * Parse the label_id from CustomerLabel resource.
     *
     * @param {string} customerLabelName
     *   A fully-qualified path representing CustomerLabel resource.
     * @returns {string} A string representing the label_id.
     */
    matchLabelIdFromCustomerLabelName(customerLabelName: string): string | number;
    /**
     * Return a fully-qualified customerManagerLink resource name string.
     *
     * @param {string} customer_id
     * @param {string} manager_customer_id
     * @param {string} manager_link_id
     * @returns {string} Resource name string.
     */
    customerManagerLinkPath(customerId: string, managerCustomerId: string, managerLinkId: string): string;
    /**
     * Parse the customer_id from CustomerManagerLink resource.
     *
     * @param {string} customerManagerLinkName
     *   A fully-qualified path representing CustomerManagerLink resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomerManagerLinkName(customerManagerLinkName: string): string | number;
    /**
     * Parse the manager_customer_id from CustomerManagerLink resource.
     *
     * @param {string} customerManagerLinkName
     *   A fully-qualified path representing CustomerManagerLink resource.
     * @returns {string} A string representing the manager_customer_id.
     */
    matchManagerCustomerIdFromCustomerManagerLinkName(customerManagerLinkName: string): string | number;
    /**
     * Parse the manager_link_id from CustomerManagerLink resource.
     *
     * @param {string} customerManagerLinkName
     *   A fully-qualified path representing CustomerManagerLink resource.
     * @returns {string} A string representing the manager_link_id.
     */
    matchManagerLinkIdFromCustomerManagerLinkName(customerManagerLinkName: string): string | number;
    /**
     * Return a fully-qualified customerNegativeCriterion resource name string.
     *
     * @param {string} customer_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    customerNegativeCriterionPath(customerId: string, criterionId: string): string;
    /**
     * Parse the customer_id from CustomerNegativeCriterion resource.
     *
     * @param {string} customerNegativeCriterionName
     *   A fully-qualified path representing CustomerNegativeCriterion resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomerNegativeCriterionName(customerNegativeCriterionName: string): string | number;
    /**
     * Parse the criterion_id from CustomerNegativeCriterion resource.
     *
     * @param {string} customerNegativeCriterionName
     *   A fully-qualified path representing CustomerNegativeCriterion resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromCustomerNegativeCriterionName(customerNegativeCriterionName: string): string | number;
    /**
     * Return a fully-qualified customerSearchTermInsight resource name string.
     *
     * @param {string} customer_id
     * @param {string} cluster_id
     * @returns {string} Resource name string.
     */
    customerSearchTermInsightPath(customerId: string, clusterId: string): string;
    /**
     * Parse the customer_id from CustomerSearchTermInsight resource.
     *
     * @param {string} customerSearchTermInsightName
     *   A fully-qualified path representing CustomerSearchTermInsight resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomerSearchTermInsightName(customerSearchTermInsightName: string): string | number;
    /**
     * Parse the cluster_id from CustomerSearchTermInsight resource.
     *
     * @param {string} customerSearchTermInsightName
     *   A fully-qualified path representing CustomerSearchTermInsight resource.
     * @returns {string} A string representing the cluster_id.
     */
    matchClusterIdFromCustomerSearchTermInsightName(customerSearchTermInsightName: string): string | number;
    /**
     * Return a fully-qualified customerSkAdNetworkConversionValueSchema resource name string.
     *
     * @param {string} customer_id
     * @param {string} account_link_id
     * @returns {string} Resource name string.
     */
    customerSkAdNetworkConversionValueSchemaPath(customerId: string, accountLinkId: string): string;
    /**
     * Parse the customer_id from CustomerSkAdNetworkConversionValueSchema resource.
     *
     * @param {string} customerSkAdNetworkConversionValueSchemaName
     *   A fully-qualified path representing CustomerSkAdNetworkConversionValueSchema resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomerSkAdNetworkConversionValueSchemaName(customerSkAdNetworkConversionValueSchemaName: string): string | number;
    /**
     * Parse the account_link_id from CustomerSkAdNetworkConversionValueSchema resource.
     *
     * @param {string} customerSkAdNetworkConversionValueSchemaName
     *   A fully-qualified path representing CustomerSkAdNetworkConversionValueSchema resource.
     * @returns {string} A string representing the account_link_id.
     */
    matchAccountLinkIdFromCustomerSkAdNetworkConversionValueSchemaName(customerSkAdNetworkConversionValueSchemaName: string): string | number;
    /**
     * Return a fully-qualified customerUserAccess resource name string.
     *
     * @param {string} customer_id
     * @param {string} user_id
     * @returns {string} Resource name string.
     */
    customerUserAccessPath(customerId: string, userId: string): string;
    /**
     * Parse the customer_id from CustomerUserAccess resource.
     *
     * @param {string} customerUserAccessName
     *   A fully-qualified path representing CustomerUserAccess resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomerUserAccessName(customerUserAccessName: string): string | number;
    /**
     * Parse the user_id from CustomerUserAccess resource.
     *
     * @param {string} customerUserAccessName
     *   A fully-qualified path representing CustomerUserAccess resource.
     * @returns {string} A string representing the user_id.
     */
    matchUserIdFromCustomerUserAccessName(customerUserAccessName: string): string | number;
    /**
     * Return a fully-qualified customerUserAccessInvitation resource name string.
     *
     * @param {string} customer_id
     * @param {string} invitation_id
     * @returns {string} Resource name string.
     */
    customerUserAccessInvitationPath(customerId: string, invitationId: string): string;
    /**
     * Parse the customer_id from CustomerUserAccessInvitation resource.
     *
     * @param {string} customerUserAccessInvitationName
     *   A fully-qualified path representing CustomerUserAccessInvitation resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomerUserAccessInvitationName(customerUserAccessInvitationName: string): string | number;
    /**
     * Parse the invitation_id from CustomerUserAccessInvitation resource.
     *
     * @param {string} customerUserAccessInvitationName
     *   A fully-qualified path representing CustomerUserAccessInvitation resource.
     * @returns {string} A string representing the invitation_id.
     */
    matchInvitationIdFromCustomerUserAccessInvitationName(customerUserAccessInvitationName: string): string | number;
    /**
     * Return a fully-qualified customizerAttribute resource name string.
     *
     * @param {string} customer_id
     * @param {string} customizer_attribute_id
     * @returns {string} Resource name string.
     */
    customizerAttributePath(customerId: string, customizerAttributeId: string): string;
    /**
     * Parse the customer_id from CustomizerAttribute resource.
     *
     * @param {string} customizerAttributeName
     *   A fully-qualified path representing CustomizerAttribute resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomizerAttributeName(customizerAttributeName: string): string | number;
    /**
     * Parse the customizer_attribute_id from CustomizerAttribute resource.
     *
     * @param {string} customizerAttributeName
     *   A fully-qualified path representing CustomizerAttribute resource.
     * @returns {string} A string representing the customizer_attribute_id.
     */
    matchCustomizerAttributeIdFromCustomizerAttributeName(customizerAttributeName: string): string | number;
    /**
     * Return a fully-qualified detailPlacementView resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @returns {string} Resource name string.
     */
    detailPlacementViewPath(customerId: string, adGroupId: string): string;
    /**
     * Parse the customer_id from DetailPlacementView resource.
     *
     * @param {string} detailPlacementViewName
     *   A fully-qualified path representing DetailPlacementView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromDetailPlacementViewName(detailPlacementViewName: string): string | number;
    /**
     * Parse the ad_group_id from DetailPlacementView resource.
     *
     * @param {string} detailPlacementViewName
     *   A fully-qualified path representing DetailPlacementView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromDetailPlacementViewName(detailPlacementViewName: string): string | number;
    /**
     * Return a fully-qualified detailedDemographic resource name string.
     *
     * @param {string} customer_id
     * @param {string} detailed_demographic_id
     * @returns {string} Resource name string.
     */
    detailedDemographicPath(customerId: string, detailedDemographicId: string): string;
    /**
     * Parse the customer_id from DetailedDemographic resource.
     *
     * @param {string} detailedDemographicName
     *   A fully-qualified path representing DetailedDemographic resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromDetailedDemographicName(detailedDemographicName: string): string | number;
    /**
     * Parse the detailed_demographic_id from DetailedDemographic resource.
     *
     * @param {string} detailedDemographicName
     *   A fully-qualified path representing DetailedDemographic resource.
     * @returns {string} A string representing the detailed_demographic_id.
     */
    matchDetailedDemographicIdFromDetailedDemographicName(detailedDemographicName: string): string | number;
    /**
     * Return a fully-qualified displayKeywordView resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    displayKeywordViewPath(customerId: string, adGroupId: string, criterionId: string): string;
    /**
     * Parse the customer_id from DisplayKeywordView resource.
     *
     * @param {string} displayKeywordViewName
     *   A fully-qualified path representing DisplayKeywordView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromDisplayKeywordViewName(displayKeywordViewName: string): string | number;
    /**
     * Parse the ad_group_id from DisplayKeywordView resource.
     *
     * @param {string} displayKeywordViewName
     *   A fully-qualified path representing DisplayKeywordView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromDisplayKeywordViewName(displayKeywordViewName: string): string | number;
    /**
     * Parse the criterion_id from DisplayKeywordView resource.
     *
     * @param {string} displayKeywordViewName
     *   A fully-qualified path representing DisplayKeywordView resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromDisplayKeywordViewName(displayKeywordViewName: string): string | number;
    /**
     * Return a fully-qualified distanceView resource name string.
     *
     * @param {string} customer_id
     * @param {string} placeholder_chain_id
     * @param {string} distance_bucket
     * @returns {string} Resource name string.
     */
    distanceViewPath(customerId: string, placeholderChainId: string, distanceBucket: string): string;
    /**
     * Parse the customer_id from DistanceView resource.
     *
     * @param {string} distanceViewName
     *   A fully-qualified path representing DistanceView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromDistanceViewName(distanceViewName: string): string | number;
    /**
     * Parse the placeholder_chain_id from DistanceView resource.
     *
     * @param {string} distanceViewName
     *   A fully-qualified path representing DistanceView resource.
     * @returns {string} A string representing the placeholder_chain_id.
     */
    matchPlaceholderChainIdFromDistanceViewName(distanceViewName: string): string | number;
    /**
     * Parse the distance_bucket from DistanceView resource.
     *
     * @param {string} distanceViewName
     *   A fully-qualified path representing DistanceView resource.
     * @returns {string} A string representing the distance_bucket.
     */
    matchDistanceBucketFromDistanceViewName(distanceViewName: string): string | number;
    /**
     * Return a fully-qualified domainCategory resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} language_code
     * @returns {string} Resource name string.
     */
    domainCategoryPath(customerId: string, campaignId: string, languageCode: string): string;
    /**
     * Parse the customer_id from DomainCategory resource.
     *
     * @param {string} domainCategoryName
     *   A fully-qualified path representing DomainCategory resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromDomainCategoryName(domainCategoryName: string): string | number;
    /**
     * Parse the campaign_id from DomainCategory resource.
     *
     * @param {string} domainCategoryName
     *   A fully-qualified path representing DomainCategory resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromDomainCategoryName(domainCategoryName: string): string | number;
    /**
     * Parse the language_code from DomainCategory resource.
     *
     * @param {string} domainCategoryName
     *   A fully-qualified path representing DomainCategory resource.
     * @returns {string} A string representing the language_code.
     */
    matchLanguageCodeFromDomainCategoryName(domainCategoryName: string): string | number;
    /**
     * Return a fully-qualified dynamicSearchAdsSearchTermView resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} search_term_fingerprint
     * @param {string} headline_fingerprint
     * @param {string} landing_page_fingerprint
     * @param {string} page_url_fingerprint
     * @returns {string} Resource name string.
     */
    dynamicSearchAdsSearchTermViewPath(customerId: string, adGroupId: string, searchTermFingerprint: string, headlineFingerprint: string, landingPageFingerprint: string, pageUrlFingerprint: string): string;
    /**
     * Parse the customer_id from DynamicSearchAdsSearchTermView resource.
     *
     * @param {string} dynamicSearchAdsSearchTermViewName
     *   A fully-qualified path representing DynamicSearchAdsSearchTermView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromDynamicSearchAdsSearchTermViewName(dynamicSearchAdsSearchTermViewName: string): string | number;
    /**
     * Parse the ad_group_id from DynamicSearchAdsSearchTermView resource.
     *
     * @param {string} dynamicSearchAdsSearchTermViewName
     *   A fully-qualified path representing DynamicSearchAdsSearchTermView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromDynamicSearchAdsSearchTermViewName(dynamicSearchAdsSearchTermViewName: string): string | number;
    /**
     * Parse the search_term_fingerprint from DynamicSearchAdsSearchTermView resource.
     *
     * @param {string} dynamicSearchAdsSearchTermViewName
     *   A fully-qualified path representing DynamicSearchAdsSearchTermView resource.
     * @returns {string} A string representing the search_term_fingerprint.
     */
    matchSearchTermFingerprintFromDynamicSearchAdsSearchTermViewName(dynamicSearchAdsSearchTermViewName: string): string | number;
    /**
     * Parse the headline_fingerprint from DynamicSearchAdsSearchTermView resource.
     *
     * @param {string} dynamicSearchAdsSearchTermViewName
     *   A fully-qualified path representing DynamicSearchAdsSearchTermView resource.
     * @returns {string} A string representing the headline_fingerprint.
     */
    matchHeadlineFingerprintFromDynamicSearchAdsSearchTermViewName(dynamicSearchAdsSearchTermViewName: string): string | number;
    /**
     * Parse the landing_page_fingerprint from DynamicSearchAdsSearchTermView resource.
     *
     * @param {string} dynamicSearchAdsSearchTermViewName
     *   A fully-qualified path representing DynamicSearchAdsSearchTermView resource.
     * @returns {string} A string representing the landing_page_fingerprint.
     */
    matchLandingPageFingerprintFromDynamicSearchAdsSearchTermViewName(dynamicSearchAdsSearchTermViewName: string): string | number;
    /**
     * Parse the page_url_fingerprint from DynamicSearchAdsSearchTermView resource.
     *
     * @param {string} dynamicSearchAdsSearchTermViewName
     *   A fully-qualified path representing DynamicSearchAdsSearchTermView resource.
     * @returns {string} A string representing the page_url_fingerprint.
     */
    matchPageUrlFingerprintFromDynamicSearchAdsSearchTermViewName(dynamicSearchAdsSearchTermViewName: string): string | number;
    /**
     * Return a fully-qualified expandedLandingPageView resource name string.
     *
     * @param {string} customer_id
     * @param {string} expanded_final_url_fingerprint
     * @returns {string} Resource name string.
     */
    expandedLandingPageViewPath(customerId: string, expandedFinalUrlFingerprint: string): string;
    /**
     * Parse the customer_id from ExpandedLandingPageView resource.
     *
     * @param {string} expandedLandingPageViewName
     *   A fully-qualified path representing ExpandedLandingPageView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromExpandedLandingPageViewName(expandedLandingPageViewName: string): string | number;
    /**
     * Parse the expanded_final_url_fingerprint from ExpandedLandingPageView resource.
     *
     * @param {string} expandedLandingPageViewName
     *   A fully-qualified path representing ExpandedLandingPageView resource.
     * @returns {string} A string representing the expanded_final_url_fingerprint.
     */
    matchExpandedFinalUrlFingerprintFromExpandedLandingPageViewName(expandedLandingPageViewName: string): string | number;
    /**
     * Return a fully-qualified experiment resource name string.
     *
     * @param {string} customer_id
     * @param {string} trial_id
     * @returns {string} Resource name string.
     */
    experimentPath(customerId: string, trialId: string): string;
    /**
     * Parse the customer_id from Experiment resource.
     *
     * @param {string} experimentName
     *   A fully-qualified path representing Experiment resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromExperimentName(experimentName: string): string | number;
    /**
     * Parse the trial_id from Experiment resource.
     *
     * @param {string} experimentName
     *   A fully-qualified path representing Experiment resource.
     * @returns {string} A string representing the trial_id.
     */
    matchTrialIdFromExperimentName(experimentName: string): string | number;
    /**
     * Return a fully-qualified experimentArm resource name string.
     *
     * @param {string} customer_id
     * @param {string} trial_id
     * @param {string} trial_arm_id
     * @returns {string} Resource name string.
     */
    experimentArmPath(customerId: string, trialId: string, trialArmId: string): string;
    /**
     * Parse the customer_id from ExperimentArm resource.
     *
     * @param {string} experimentArmName
     *   A fully-qualified path representing ExperimentArm resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromExperimentArmName(experimentArmName: string): string | number;
    /**
     * Parse the trial_id from ExperimentArm resource.
     *
     * @param {string} experimentArmName
     *   A fully-qualified path representing ExperimentArm resource.
     * @returns {string} A string representing the trial_id.
     */
    matchTrialIdFromExperimentArmName(experimentArmName: string): string | number;
    /**
     * Parse the trial_arm_id from ExperimentArm resource.
     *
     * @param {string} experimentArmName
     *   A fully-qualified path representing ExperimentArm resource.
     * @returns {string} A string representing the trial_arm_id.
     */
    matchTrialArmIdFromExperimentArmName(experimentArmName: string): string | number;
    /**
     * Return a fully-qualified extensionFeedItem resource name string.
     *
     * @param {string} customer_id
     * @param {string} feed_item_id
     * @returns {string} Resource name string.
     */
    extensionFeedItemPath(customerId: string, feedItemId: string): string;
    /**
     * Parse the customer_id from ExtensionFeedItem resource.
     *
     * @param {string} extensionFeedItemName
     *   A fully-qualified path representing ExtensionFeedItem resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromExtensionFeedItemName(extensionFeedItemName: string): string | number;
    /**
     * Parse the feed_item_id from ExtensionFeedItem resource.
     *
     * @param {string} extensionFeedItemName
     *   A fully-qualified path representing ExtensionFeedItem resource.
     * @returns {string} A string representing the feed_item_id.
     */
    matchFeedItemIdFromExtensionFeedItemName(extensionFeedItemName: string): string | number;
    /**
     * Return a fully-qualified feed resource name string.
     *
     * @param {string} customer_id
     * @param {string} feed_id
     * @returns {string} Resource name string.
     */
    feedPath(customerId: string, feedId: string): string;
    /**
     * Parse the customer_id from Feed resource.
     *
     * @param {string} feedName
     *   A fully-qualified path representing Feed resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromFeedName(feedName: string): string | number;
    /**
     * Parse the feed_id from Feed resource.
     *
     * @param {string} feedName
     *   A fully-qualified path representing Feed resource.
     * @returns {string} A string representing the feed_id.
     */
    matchFeedIdFromFeedName(feedName: string): string | number;
    /**
     * Return a fully-qualified feedItem resource name string.
     *
     * @param {string} customer_id
     * @param {string} feed_id
     * @param {string} feed_item_id
     * @returns {string} Resource name string.
     */
    feedItemPath(customerId: string, feedId: string, feedItemId: string): string;
    /**
     * Parse the customer_id from FeedItem resource.
     *
     * @param {string} feedItemName
     *   A fully-qualified path representing FeedItem resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromFeedItemName(feedItemName: string): string | number;
    /**
     * Parse the feed_id from FeedItem resource.
     *
     * @param {string} feedItemName
     *   A fully-qualified path representing FeedItem resource.
     * @returns {string} A string representing the feed_id.
     */
    matchFeedIdFromFeedItemName(feedItemName: string): string | number;
    /**
     * Parse the feed_item_id from FeedItem resource.
     *
     * @param {string} feedItemName
     *   A fully-qualified path representing FeedItem resource.
     * @returns {string} A string representing the feed_item_id.
     */
    matchFeedItemIdFromFeedItemName(feedItemName: string): string | number;
    /**
     * Return a fully-qualified feedItemSet resource name string.
     *
     * @param {string} customer_id
     * @param {string} feed_id
     * @param {string} feed_item_set_id
     * @returns {string} Resource name string.
     */
    feedItemSetPath(customerId: string, feedId: string, feedItemSetId: string): string;
    /**
     * Parse the customer_id from FeedItemSet resource.
     *
     * @param {string} feedItemSetName
     *   A fully-qualified path representing FeedItemSet resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromFeedItemSetName(feedItemSetName: string): string | number;
    /**
     * Parse the feed_id from FeedItemSet resource.
     *
     * @param {string} feedItemSetName
     *   A fully-qualified path representing FeedItemSet resource.
     * @returns {string} A string representing the feed_id.
     */
    matchFeedIdFromFeedItemSetName(feedItemSetName: string): string | number;
    /**
     * Parse the feed_item_set_id from FeedItemSet resource.
     *
     * @param {string} feedItemSetName
     *   A fully-qualified path representing FeedItemSet resource.
     * @returns {string} A string representing the feed_item_set_id.
     */
    matchFeedItemSetIdFromFeedItemSetName(feedItemSetName: string): string | number;
    /**
     * Return a fully-qualified feedItemSetLink resource name string.
     *
     * @param {string} customer_id
     * @param {string} feed_id
     * @param {string} feed_item_set_id
     * @param {string} feed_item_id
     * @returns {string} Resource name string.
     */
    feedItemSetLinkPath(customerId: string, feedId: string, feedItemSetId: string, feedItemId: string): string;
    /**
     * Parse the customer_id from FeedItemSetLink resource.
     *
     * @param {string} feedItemSetLinkName
     *   A fully-qualified path representing FeedItemSetLink resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromFeedItemSetLinkName(feedItemSetLinkName: string): string | number;
    /**
     * Parse the feed_id from FeedItemSetLink resource.
     *
     * @param {string} feedItemSetLinkName
     *   A fully-qualified path representing FeedItemSetLink resource.
     * @returns {string} A string representing the feed_id.
     */
    matchFeedIdFromFeedItemSetLinkName(feedItemSetLinkName: string): string | number;
    /**
     * Parse the feed_item_set_id from FeedItemSetLink resource.
     *
     * @param {string} feedItemSetLinkName
     *   A fully-qualified path representing FeedItemSetLink resource.
     * @returns {string} A string representing the feed_item_set_id.
     */
    matchFeedItemSetIdFromFeedItemSetLinkName(feedItemSetLinkName: string): string | number;
    /**
     * Parse the feed_item_id from FeedItemSetLink resource.
     *
     * @param {string} feedItemSetLinkName
     *   A fully-qualified path representing FeedItemSetLink resource.
     * @returns {string} A string representing the feed_item_id.
     */
    matchFeedItemIdFromFeedItemSetLinkName(feedItemSetLinkName: string): string | number;
    /**
     * Return a fully-qualified feedItemTarget resource name string.
     *
     * @param {string} customer_id
     * @param {string} feed_id
     * @param {string} feed_item_id
     * @param {string} feed_item_target_type
     * @param {string} feed_item_target_id
     * @returns {string} Resource name string.
     */
    feedItemTargetPath(customerId: string, feedId: string, feedItemId: string, feedItemTargetType: string, feedItemTargetId: string): string;
    /**
     * Parse the customer_id from FeedItemTarget resource.
     *
     * @param {string} feedItemTargetName
     *   A fully-qualified path representing FeedItemTarget resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromFeedItemTargetName(feedItemTargetName: string): string | number;
    /**
     * Parse the feed_id from FeedItemTarget resource.
     *
     * @param {string} feedItemTargetName
     *   A fully-qualified path representing FeedItemTarget resource.
     * @returns {string} A string representing the feed_id.
     */
    matchFeedIdFromFeedItemTargetName(feedItemTargetName: string): string | number;
    /**
     * Parse the feed_item_id from FeedItemTarget resource.
     *
     * @param {string} feedItemTargetName
     *   A fully-qualified path representing FeedItemTarget resource.
     * @returns {string} A string representing the feed_item_id.
     */
    matchFeedItemIdFromFeedItemTargetName(feedItemTargetName: string): string | number;
    /**
     * Parse the feed_item_target_type from FeedItemTarget resource.
     *
     * @param {string} feedItemTargetName
     *   A fully-qualified path representing FeedItemTarget resource.
     * @returns {string} A string representing the feed_item_target_type.
     */
    matchFeedItemTargetTypeFromFeedItemTargetName(feedItemTargetName: string): string | number;
    /**
     * Parse the feed_item_target_id from FeedItemTarget resource.
     *
     * @param {string} feedItemTargetName
     *   A fully-qualified path representing FeedItemTarget resource.
     * @returns {string} A string representing the feed_item_target_id.
     */
    matchFeedItemTargetIdFromFeedItemTargetName(feedItemTargetName: string): string | number;
    /**
     * Return a fully-qualified feedMapping resource name string.
     *
     * @param {string} customer_id
     * @param {string} feed_id
     * @param {string} feed_mapping_id
     * @returns {string} Resource name string.
     */
    feedMappingPath(customerId: string, feedId: string, feedMappingId: string): string;
    /**
     * Parse the customer_id from FeedMapping resource.
     *
     * @param {string} feedMappingName
     *   A fully-qualified path representing FeedMapping resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromFeedMappingName(feedMappingName: string): string | number;
    /**
     * Parse the feed_id from FeedMapping resource.
     *
     * @param {string} feedMappingName
     *   A fully-qualified path representing FeedMapping resource.
     * @returns {string} A string representing the feed_id.
     */
    matchFeedIdFromFeedMappingName(feedMappingName: string): string | number;
    /**
     * Parse the feed_mapping_id from FeedMapping resource.
     *
     * @param {string} feedMappingName
     *   A fully-qualified path representing FeedMapping resource.
     * @returns {string} A string representing the feed_mapping_id.
     */
    matchFeedMappingIdFromFeedMappingName(feedMappingName: string): string | number;
    /**
     * Return a fully-qualified feedPlaceholderView resource name string.
     *
     * @param {string} customer_id
     * @param {string} placeholder_type
     * @returns {string} Resource name string.
     */
    feedPlaceholderViewPath(customerId: string, placeholderType: string): string;
    /**
     * Parse the customer_id from FeedPlaceholderView resource.
     *
     * @param {string} feedPlaceholderViewName
     *   A fully-qualified path representing FeedPlaceholderView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromFeedPlaceholderViewName(feedPlaceholderViewName: string): string | number;
    /**
     * Parse the placeholder_type from FeedPlaceholderView resource.
     *
     * @param {string} feedPlaceholderViewName
     *   A fully-qualified path representing FeedPlaceholderView resource.
     * @returns {string} A string representing the placeholder_type.
     */
    matchPlaceholderTypeFromFeedPlaceholderViewName(feedPlaceholderViewName: string): string | number;
    /**
     * Return a fully-qualified genderView resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    genderViewPath(customerId: string, adGroupId: string, criterionId: string): string;
    /**
     * Parse the customer_id from GenderView resource.
     *
     * @param {string} genderViewName
     *   A fully-qualified path representing GenderView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromGenderViewName(genderViewName: string): string | number;
    /**
     * Parse the ad_group_id from GenderView resource.
     *
     * @param {string} genderViewName
     *   A fully-qualified path representing GenderView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromGenderViewName(genderViewName: string): string | number;
    /**
     * Parse the criterion_id from GenderView resource.
     *
     * @param {string} genderViewName
     *   A fully-qualified path representing GenderView resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromGenderViewName(genderViewName: string): string | number;
    /**
     * Return a fully-qualified geoTargetConstant resource name string.
     *
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    geoTargetConstantPath(criterionId: string): string;
    /**
     * Parse the criterion_id from GeoTargetConstant resource.
     *
     * @param {string} geoTargetConstantName
     *   A fully-qualified path representing GeoTargetConstant resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromGeoTargetConstantName(geoTargetConstantName: string): string | number;
    /**
     * Return a fully-qualified geographicView resource name string.
     *
     * @param {string} customer_id
     * @param {string} country_criterion_id
     * @param {string} location_type
     * @returns {string} Resource name string.
     */
    geographicViewPath(customerId: string, countryCriterionId: string, locationType: string): string;
    /**
     * Parse the customer_id from GeographicView resource.
     *
     * @param {string} geographicViewName
     *   A fully-qualified path representing GeographicView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromGeographicViewName(geographicViewName: string): string | number;
    /**
     * Parse the country_criterion_id from GeographicView resource.
     *
     * @param {string} geographicViewName
     *   A fully-qualified path representing GeographicView resource.
     * @returns {string} A string representing the country_criterion_id.
     */
    matchCountryCriterionIdFromGeographicViewName(geographicViewName: string): string | number;
    /**
     * Parse the location_type from GeographicView resource.
     *
     * @param {string} geographicViewName
     *   A fully-qualified path representing GeographicView resource.
     * @returns {string} A string representing the location_type.
     */
    matchLocationTypeFromGeographicViewName(geographicViewName: string): string | number;
    /**
     * Return a fully-qualified googleAdsField resource name string.
     *
     * @param {string} google_ads_field
     * @returns {string} Resource name string.
     */
    googleAdsFieldPath(googleAdsField: string): string;
    /**
     * Parse the google_ads_field from GoogleAdsField resource.
     *
     * @param {string} googleAdsFieldName
     *   A fully-qualified path representing GoogleAdsField resource.
     * @returns {string} A string representing the google_ads_field.
     */
    matchGoogleAdsFieldFromGoogleAdsFieldName(googleAdsFieldName: string): string | number;
    /**
     * Return a fully-qualified groupPlacementView resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @returns {string} Resource name string.
     */
    groupPlacementViewPath(customerId: string, adGroupId: string): string;
    /**
     * Parse the customer_id from GroupPlacementView resource.
     *
     * @param {string} groupPlacementViewName
     *   A fully-qualified path representing GroupPlacementView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromGroupPlacementViewName(groupPlacementViewName: string): string | number;
    /**
     * Parse the ad_group_id from GroupPlacementView resource.
     *
     * @param {string} groupPlacementViewName
     *   A fully-qualified path representing GroupPlacementView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromGroupPlacementViewName(groupPlacementViewName: string): string | number;
    /**
     * Return a fully-qualified hotelGroupView resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    hotelGroupViewPath(customerId: string, adGroupId: string, criterionId: string): string;
    /**
     * Parse the customer_id from HotelGroupView resource.
     *
     * @param {string} hotelGroupViewName
     *   A fully-qualified path representing HotelGroupView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromHotelGroupViewName(hotelGroupViewName: string): string | number;
    /**
     * Parse the ad_group_id from HotelGroupView resource.
     *
     * @param {string} hotelGroupViewName
     *   A fully-qualified path representing HotelGroupView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromHotelGroupViewName(hotelGroupViewName: string): string | number;
    /**
     * Parse the criterion_id from HotelGroupView resource.
     *
     * @param {string} hotelGroupViewName
     *   A fully-qualified path representing HotelGroupView resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromHotelGroupViewName(hotelGroupViewName: string): string | number;
    /**
     * Return a fully-qualified hotelPerformanceView resource name string.
     *
     * @param {string} customer_id
     * @returns {string} Resource name string.
     */
    hotelPerformanceViewPath(customerId: string): string;
    /**
     * Parse the customer_id from HotelPerformanceView resource.
     *
     * @param {string} hotelPerformanceViewName
     *   A fully-qualified path representing HotelPerformanceView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromHotelPerformanceViewName(hotelPerformanceViewName: string): string | number;
    /**
     * Return a fully-qualified hotelReconciliation resource name string.
     *
     * @param {string} customer_id
     * @param {string} commission_id
     * @returns {string} Resource name string.
     */
    hotelReconciliationPath(customerId: string, commissionId: string): string;
    /**
     * Parse the customer_id from HotelReconciliation resource.
     *
     * @param {string} hotelReconciliationName
     *   A fully-qualified path representing HotelReconciliation resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromHotelReconciliationName(hotelReconciliationName: string): string | number;
    /**
     * Parse the commission_id from HotelReconciliation resource.
     *
     * @param {string} hotelReconciliationName
     *   A fully-qualified path representing HotelReconciliation resource.
     * @returns {string} A string representing the commission_id.
     */
    matchCommissionIdFromHotelReconciliationName(hotelReconciliationName: string): string | number;
    /**
     * Return a fully-qualified incomeRangeView resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    incomeRangeViewPath(customerId: string, adGroupId: string, criterionId: string): string;
    /**
     * Parse the customer_id from IncomeRangeView resource.
     *
     * @param {string} incomeRangeViewName
     *   A fully-qualified path representing IncomeRangeView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromIncomeRangeViewName(incomeRangeViewName: string): string | number;
    /**
     * Parse the ad_group_id from IncomeRangeView resource.
     *
     * @param {string} incomeRangeViewName
     *   A fully-qualified path representing IncomeRangeView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromIncomeRangeViewName(incomeRangeViewName: string): string | number;
    /**
     * Parse the criterion_id from IncomeRangeView resource.
     *
     * @param {string} incomeRangeViewName
     *   A fully-qualified path representing IncomeRangeView resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromIncomeRangeViewName(incomeRangeViewName: string): string | number;
    /**
     * Return a fully-qualified invoice resource name string.
     *
     * @param {string} customer_id
     * @param {string} invoice_id
     * @returns {string} Resource name string.
     */
    invoicePath(customerId: string, invoiceId: string): string;
    /**
     * Parse the customer_id from Invoice resource.
     *
     * @param {string} invoiceName
     *   A fully-qualified path representing Invoice resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromInvoiceName(invoiceName: string): string | number;
    /**
     * Parse the invoice_id from Invoice resource.
     *
     * @param {string} invoiceName
     *   A fully-qualified path representing Invoice resource.
     * @returns {string} A string representing the invoice_id.
     */
    matchInvoiceIdFromInvoiceName(invoiceName: string): string | number;
    /**
     * Return a fully-qualified keywordPlan resource name string.
     *
     * @param {string} customer_id
     * @param {string} keyword_plan_id
     * @returns {string} Resource name string.
     */
    keywordPlanPath(customerId: string, keywordPlanId: string): string;
    /**
     * Parse the customer_id from KeywordPlan resource.
     *
     * @param {string} keywordPlanName
     *   A fully-qualified path representing KeywordPlan resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromKeywordPlanName(keywordPlanName: string): string | number;
    /**
     * Parse the keyword_plan_id from KeywordPlan resource.
     *
     * @param {string} keywordPlanName
     *   A fully-qualified path representing KeywordPlan resource.
     * @returns {string} A string representing the keyword_plan_id.
     */
    matchKeywordPlanIdFromKeywordPlanName(keywordPlanName: string): string | number;
    /**
     * Return a fully-qualified keywordPlanAdGroup resource name string.
     *
     * @param {string} customer_id
     * @param {string} keyword_plan_ad_group_id
     * @returns {string} Resource name string.
     */
    keywordPlanAdGroupPath(customerId: string, keywordPlanAdGroupId: string): string;
    /**
     * Parse the customer_id from KeywordPlanAdGroup resource.
     *
     * @param {string} keywordPlanAdGroupName
     *   A fully-qualified path representing KeywordPlanAdGroup resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromKeywordPlanAdGroupName(keywordPlanAdGroupName: string): string | number;
    /**
     * Parse the keyword_plan_ad_group_id from KeywordPlanAdGroup resource.
     *
     * @param {string} keywordPlanAdGroupName
     *   A fully-qualified path representing KeywordPlanAdGroup resource.
     * @returns {string} A string representing the keyword_plan_ad_group_id.
     */
    matchKeywordPlanAdGroupIdFromKeywordPlanAdGroupName(keywordPlanAdGroupName: string): string | number;
    /**
     * Return a fully-qualified keywordPlanAdGroupKeyword resource name string.
     *
     * @param {string} customer_id
     * @param {string} keyword_plan_ad_group_keyword_id
     * @returns {string} Resource name string.
     */
    keywordPlanAdGroupKeywordPath(customerId: string, keywordPlanAdGroupKeywordId: string): string;
    /**
     * Parse the customer_id from KeywordPlanAdGroupKeyword resource.
     *
     * @param {string} keywordPlanAdGroupKeywordName
     *   A fully-qualified path representing KeywordPlanAdGroupKeyword resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromKeywordPlanAdGroupKeywordName(keywordPlanAdGroupKeywordName: string): string | number;
    /**
     * Parse the keyword_plan_ad_group_keyword_id from KeywordPlanAdGroupKeyword resource.
     *
     * @param {string} keywordPlanAdGroupKeywordName
     *   A fully-qualified path representing KeywordPlanAdGroupKeyword resource.
     * @returns {string} A string representing the keyword_plan_ad_group_keyword_id.
     */
    matchKeywordPlanAdGroupKeywordIdFromKeywordPlanAdGroupKeywordName(keywordPlanAdGroupKeywordName: string): string | number;
    /**
     * Return a fully-qualified keywordPlanCampaign resource name string.
     *
     * @param {string} customer_id
     * @param {string} keyword_plan_campaign_id
     * @returns {string} Resource name string.
     */
    keywordPlanCampaignPath(customerId: string, keywordPlanCampaignId: string): string;
    /**
     * Parse the customer_id from KeywordPlanCampaign resource.
     *
     * @param {string} keywordPlanCampaignName
     *   A fully-qualified path representing KeywordPlanCampaign resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromKeywordPlanCampaignName(keywordPlanCampaignName: string): string | number;
    /**
     * Parse the keyword_plan_campaign_id from KeywordPlanCampaign resource.
     *
     * @param {string} keywordPlanCampaignName
     *   A fully-qualified path representing KeywordPlanCampaign resource.
     * @returns {string} A string representing the keyword_plan_campaign_id.
     */
    matchKeywordPlanCampaignIdFromKeywordPlanCampaignName(keywordPlanCampaignName: string): string | number;
    /**
     * Return a fully-qualified keywordPlanCampaignKeyword resource name string.
     *
     * @param {string} customer_id
     * @param {string} keyword_plan_campaign_keyword_id
     * @returns {string} Resource name string.
     */
    keywordPlanCampaignKeywordPath(customerId: string, keywordPlanCampaignKeywordId: string): string;
    /**
     * Parse the customer_id from KeywordPlanCampaignKeyword resource.
     *
     * @param {string} keywordPlanCampaignKeywordName
     *   A fully-qualified path representing KeywordPlanCampaignKeyword resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromKeywordPlanCampaignKeywordName(keywordPlanCampaignKeywordName: string): string | number;
    /**
     * Parse the keyword_plan_campaign_keyword_id from KeywordPlanCampaignKeyword resource.
     *
     * @param {string} keywordPlanCampaignKeywordName
     *   A fully-qualified path representing KeywordPlanCampaignKeyword resource.
     * @returns {string} A string representing the keyword_plan_campaign_keyword_id.
     */
    matchKeywordPlanCampaignKeywordIdFromKeywordPlanCampaignKeywordName(keywordPlanCampaignKeywordName: string): string | number;
    /**
     * Return a fully-qualified keywordThemeConstant resource name string.
     *
     * @param {string} express_category_id
     * @param {string} express_sub_category_id
     * @returns {string} Resource name string.
     */
    keywordThemeConstantPath(expressCategoryId: string, expressSubCategoryId: string): string;
    /**
     * Parse the express_category_id from KeywordThemeConstant resource.
     *
     * @param {string} keywordThemeConstantName
     *   A fully-qualified path representing KeywordThemeConstant resource.
     * @returns {string} A string representing the express_category_id.
     */
    matchExpressCategoryIdFromKeywordThemeConstantName(keywordThemeConstantName: string): string | number;
    /**
     * Parse the express_sub_category_id from KeywordThemeConstant resource.
     *
     * @param {string} keywordThemeConstantName
     *   A fully-qualified path representing KeywordThemeConstant resource.
     * @returns {string} A string representing the express_sub_category_id.
     */
    matchExpressSubCategoryIdFromKeywordThemeConstantName(keywordThemeConstantName: string): string | number;
    /**
     * Return a fully-qualified keywordView resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    keywordViewPath(customerId: string, adGroupId: string, criterionId: string): string;
    /**
     * Parse the customer_id from KeywordView resource.
     *
     * @param {string} keywordViewName
     *   A fully-qualified path representing KeywordView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromKeywordViewName(keywordViewName: string): string | number;
    /**
     * Parse the ad_group_id from KeywordView resource.
     *
     * @param {string} keywordViewName
     *   A fully-qualified path representing KeywordView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromKeywordViewName(keywordViewName: string): string | number;
    /**
     * Parse the criterion_id from KeywordView resource.
     *
     * @param {string} keywordViewName
     *   A fully-qualified path representing KeywordView resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromKeywordViewName(keywordViewName: string): string | number;
    /**
     * Return a fully-qualified label resource name string.
     *
     * @param {string} customer_id
     * @param {string} label_id
     * @returns {string} Resource name string.
     */
    labelPath(customerId: string, labelId: string): string;
    /**
     * Parse the customer_id from Label resource.
     *
     * @param {string} labelName
     *   A fully-qualified path representing Label resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromLabelName(labelName: string): string | number;
    /**
     * Parse the label_id from Label resource.
     *
     * @param {string} labelName
     *   A fully-qualified path representing Label resource.
     * @returns {string} A string representing the label_id.
     */
    matchLabelIdFromLabelName(labelName: string): string | number;
    /**
     * Return a fully-qualified landingPageView resource name string.
     *
     * @param {string} customer_id
     * @param {string} unexpanded_final_url_fingerprint
     * @returns {string} Resource name string.
     */
    landingPageViewPath(customerId: string, unexpandedFinalUrlFingerprint: string): string;
    /**
     * Parse the customer_id from LandingPageView resource.
     *
     * @param {string} landingPageViewName
     *   A fully-qualified path representing LandingPageView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromLandingPageViewName(landingPageViewName: string): string | number;
    /**
     * Parse the unexpanded_final_url_fingerprint from LandingPageView resource.
     *
     * @param {string} landingPageViewName
     *   A fully-qualified path representing LandingPageView resource.
     * @returns {string} A string representing the unexpanded_final_url_fingerprint.
     */
    matchUnexpandedFinalUrlFingerprintFromLandingPageViewName(landingPageViewName: string): string | number;
    /**
     * Return a fully-qualified languageConstant resource name string.
     *
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    languageConstantPath(criterionId: string): string;
    /**
     * Parse the criterion_id from LanguageConstant resource.
     *
     * @param {string} languageConstantName
     *   A fully-qualified path representing LanguageConstant resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromLanguageConstantName(languageConstantName: string): string | number;
    /**
     * Return a fully-qualified leadFormSubmissionData resource name string.
     *
     * @param {string} customer_id
     * @param {string} lead_form_user_submission_id
     * @returns {string} Resource name string.
     */
    leadFormSubmissionDataPath(customerId: string, leadFormUserSubmissionId: string): string;
    /**
     * Parse the customer_id from LeadFormSubmissionData resource.
     *
     * @param {string} leadFormSubmissionDataName
     *   A fully-qualified path representing LeadFormSubmissionData resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromLeadFormSubmissionDataName(leadFormSubmissionDataName: string): string | number;
    /**
     * Parse the lead_form_user_submission_id from LeadFormSubmissionData resource.
     *
     * @param {string} leadFormSubmissionDataName
     *   A fully-qualified path representing LeadFormSubmissionData resource.
     * @returns {string} A string representing the lead_form_user_submission_id.
     */
    matchLeadFormUserSubmissionIdFromLeadFormSubmissionDataName(leadFormSubmissionDataName: string): string | number;
    /**
     * Return a fully-qualified lifeEvent resource name string.
     *
     * @param {string} customer_id
     * @param {string} life_event_id
     * @returns {string} Resource name string.
     */
    lifeEventPath(customerId: string, lifeEventId: string): string;
    /**
     * Parse the customer_id from LifeEvent resource.
     *
     * @param {string} lifeEventName
     *   A fully-qualified path representing LifeEvent resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromLifeEventName(lifeEventName: string): string | number;
    /**
     * Parse the life_event_id from LifeEvent resource.
     *
     * @param {string} lifeEventName
     *   A fully-qualified path representing LifeEvent resource.
     * @returns {string} A string representing the life_event_id.
     */
    matchLifeEventIdFromLifeEventName(lifeEventName: string): string | number;
    /**
     * Return a fully-qualified locationView resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    locationViewPath(customerId: string, campaignId: string, criterionId: string): string;
    /**
     * Parse the customer_id from LocationView resource.
     *
     * @param {string} locationViewName
     *   A fully-qualified path representing LocationView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromLocationViewName(locationViewName: string): string | number;
    /**
     * Parse the campaign_id from LocationView resource.
     *
     * @param {string} locationViewName
     *   A fully-qualified path representing LocationView resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromLocationViewName(locationViewName: string): string | number;
    /**
     * Parse the criterion_id from LocationView resource.
     *
     * @param {string} locationViewName
     *   A fully-qualified path representing LocationView resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromLocationViewName(locationViewName: string): string | number;
    /**
     * Return a fully-qualified managedPlacementView resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    managedPlacementViewPath(customerId: string, adGroupId: string, criterionId: string): string;
    /**
     * Parse the customer_id from ManagedPlacementView resource.
     *
     * @param {string} managedPlacementViewName
     *   A fully-qualified path representing ManagedPlacementView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromManagedPlacementViewName(managedPlacementViewName: string): string | number;
    /**
     * Parse the ad_group_id from ManagedPlacementView resource.
     *
     * @param {string} managedPlacementViewName
     *   A fully-qualified path representing ManagedPlacementView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromManagedPlacementViewName(managedPlacementViewName: string): string | number;
    /**
     * Parse the criterion_id from ManagedPlacementView resource.
     *
     * @param {string} managedPlacementViewName
     *   A fully-qualified path representing ManagedPlacementView resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromManagedPlacementViewName(managedPlacementViewName: string): string | number;
    /**
     * Return a fully-qualified mediaFile resource name string.
     *
     * @param {string} customer_id
     * @param {string} media_file_id
     * @returns {string} Resource name string.
     */
    mediaFilePath(customerId: string, mediaFileId: string): string;
    /**
     * Parse the customer_id from MediaFile resource.
     *
     * @param {string} mediaFileName
     *   A fully-qualified path representing MediaFile resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromMediaFileName(mediaFileName: string): string | number;
    /**
     * Parse the media_file_id from MediaFile resource.
     *
     * @param {string} mediaFileName
     *   A fully-qualified path representing MediaFile resource.
     * @returns {string} A string representing the media_file_id.
     */
    matchMediaFileIdFromMediaFileName(mediaFileName: string): string | number;
    /**
     * Return a fully-qualified merchantCenterLink resource name string.
     *
     * @param {string} customer_id
     * @param {string} merchant_center_id
     * @returns {string} Resource name string.
     */
    merchantCenterLinkPath(customerId: string, merchantCenterId: string): string;
    /**
     * Parse the customer_id from MerchantCenterLink resource.
     *
     * @param {string} merchantCenterLinkName
     *   A fully-qualified path representing MerchantCenterLink resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromMerchantCenterLinkName(merchantCenterLinkName: string): string | number;
    /**
     * Parse the merchant_center_id from MerchantCenterLink resource.
     *
     * @param {string} merchantCenterLinkName
     *   A fully-qualified path representing MerchantCenterLink resource.
     * @returns {string} A string representing the merchant_center_id.
     */
    matchMerchantCenterIdFromMerchantCenterLinkName(merchantCenterLinkName: string): string | number;
    /**
     * Return a fully-qualified mobileAppCategoryConstant resource name string.
     *
     * @param {string} mobile_app_category_id
     * @returns {string} Resource name string.
     */
    mobileAppCategoryConstantPath(mobileAppCategoryId: string): string;
    /**
     * Parse the mobile_app_category_id from MobileAppCategoryConstant resource.
     *
     * @param {string} mobileAppCategoryConstantName
     *   A fully-qualified path representing MobileAppCategoryConstant resource.
     * @returns {string} A string representing the mobile_app_category_id.
     */
    matchMobileAppCategoryIdFromMobileAppCategoryConstantName(mobileAppCategoryConstantName: string): string | number;
    /**
     * Return a fully-qualified mobileDeviceConstant resource name string.
     *
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    mobileDeviceConstantPath(criterionId: string): string;
    /**
     * Parse the criterion_id from MobileDeviceConstant resource.
     *
     * @param {string} mobileDeviceConstantName
     *   A fully-qualified path representing MobileDeviceConstant resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromMobileDeviceConstantName(mobileDeviceConstantName: string): string | number;
    /**
     * Return a fully-qualified offlineUserDataJob resource name string.
     *
     * @param {string} customer_id
     * @param {string} offline_user_data_update_id
     * @returns {string} Resource name string.
     */
    offlineUserDataJobPath(customerId: string, offlineUserDataUpdateId: string): string;
    /**
     * Parse the customer_id from OfflineUserDataJob resource.
     *
     * @param {string} offlineUserDataJobName
     *   A fully-qualified path representing OfflineUserDataJob resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromOfflineUserDataJobName(offlineUserDataJobName: string): string | number;
    /**
     * Parse the offline_user_data_update_id from OfflineUserDataJob resource.
     *
     * @param {string} offlineUserDataJobName
     *   A fully-qualified path representing OfflineUserDataJob resource.
     * @returns {string} A string representing the offline_user_data_update_id.
     */
    matchOfflineUserDataUpdateIdFromOfflineUserDataJobName(offlineUserDataJobName: string): string | number;
    /**
     * Return a fully-qualified operatingSystemVersionConstant resource name string.
     *
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    operatingSystemVersionConstantPath(criterionId: string): string;
    /**
     * Parse the criterion_id from OperatingSystemVersionConstant resource.
     *
     * @param {string} operatingSystemVersionConstantName
     *   A fully-qualified path representing OperatingSystemVersionConstant resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromOperatingSystemVersionConstantName(operatingSystemVersionConstantName: string): string | number;
    /**
     * Return a fully-qualified paidOrganicSearchTermView resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} ad_group_id
     * @returns {string} Resource name string.
     */
    paidOrganicSearchTermViewPath(customerId: string, campaignId: string, adGroupId: string): string;
    /**
     * Parse the customer_id from PaidOrganicSearchTermView resource.
     *
     * @param {string} paidOrganicSearchTermViewName
     *   A fully-qualified path representing PaidOrganicSearchTermView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromPaidOrganicSearchTermViewName(paidOrganicSearchTermViewName: string): string | number;
    /**
     * Parse the campaign_id from PaidOrganicSearchTermView resource.
     *
     * @param {string} paidOrganicSearchTermViewName
     *   A fully-qualified path representing PaidOrganicSearchTermView resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromPaidOrganicSearchTermViewName(paidOrganicSearchTermViewName: string): string | number;
    /**
     * Parse the ad_group_id from PaidOrganicSearchTermView resource.
     *
     * @param {string} paidOrganicSearchTermViewName
     *   A fully-qualified path representing PaidOrganicSearchTermView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromPaidOrganicSearchTermViewName(paidOrganicSearchTermViewName: string): string | number;
    /**
     * Return a fully-qualified parentalStatusView resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    parentalStatusViewPath(customerId: string, adGroupId: string, criterionId: string): string;
    /**
     * Parse the customer_id from ParentalStatusView resource.
     *
     * @param {string} parentalStatusViewName
     *   A fully-qualified path representing ParentalStatusView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromParentalStatusViewName(parentalStatusViewName: string): string | number;
    /**
     * Parse the ad_group_id from ParentalStatusView resource.
     *
     * @param {string} parentalStatusViewName
     *   A fully-qualified path representing ParentalStatusView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromParentalStatusViewName(parentalStatusViewName: string): string | number;
    /**
     * Parse the criterion_id from ParentalStatusView resource.
     *
     * @param {string} parentalStatusViewName
     *   A fully-qualified path representing ParentalStatusView resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromParentalStatusViewName(parentalStatusViewName: string): string | number;
    /**
     * Return a fully-qualified paymentsAccount resource name string.
     *
     * @param {string} customer_id
     * @param {string} payments_account_id
     * @returns {string} Resource name string.
     */
    paymentsAccountPath(customerId: string, paymentsAccountId: string): string;
    /**
     * Parse the customer_id from PaymentsAccount resource.
     *
     * @param {string} paymentsAccountName
     *   A fully-qualified path representing PaymentsAccount resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromPaymentsAccountName(paymentsAccountName: string): string | number;
    /**
     * Parse the payments_account_id from PaymentsAccount resource.
     *
     * @param {string} paymentsAccountName
     *   A fully-qualified path representing PaymentsAccount resource.
     * @returns {string} A string representing the payments_account_id.
     */
    matchPaymentsAccountIdFromPaymentsAccountName(paymentsAccountName: string): string | number;
    /**
     * Return a fully-qualified perStoreView resource name string.
     *
     * @param {string} customer_id
     * @param {string} place_id
     * @returns {string} Resource name string.
     */
    perStoreViewPath(customerId: string, placeId: string): string;
    /**
     * Parse the customer_id from PerStoreView resource.
     *
     * @param {string} perStoreViewName
     *   A fully-qualified path representing PerStoreView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromPerStoreViewName(perStoreViewName: string): string | number;
    /**
     * Parse the place_id from PerStoreView resource.
     *
     * @param {string} perStoreViewName
     *   A fully-qualified path representing PerStoreView resource.
     * @returns {string} A string representing the place_id.
     */
    matchPlaceIdFromPerStoreViewName(perStoreViewName: string): string | number;
    /**
     * Return a fully-qualified productBiddingCategoryConstant resource name string.
     *
     * @param {string} country_code
     * @param {string} level
     * @param {string} id
     * @returns {string} Resource name string.
     */
    productBiddingCategoryConstantPath(countryCode: string, level: string, id: string): string;
    /**
     * Parse the country_code from ProductBiddingCategoryConstant resource.
     *
     * @param {string} productBiddingCategoryConstantName
     *   A fully-qualified path representing ProductBiddingCategoryConstant resource.
     * @returns {string} A string representing the country_code.
     */
    matchCountryCodeFromProductBiddingCategoryConstantName(productBiddingCategoryConstantName: string): string | number;
    /**
     * Parse the level from ProductBiddingCategoryConstant resource.
     *
     * @param {string} productBiddingCategoryConstantName
     *   A fully-qualified path representing ProductBiddingCategoryConstant resource.
     * @returns {string} A string representing the level.
     */
    matchLevelFromProductBiddingCategoryConstantName(productBiddingCategoryConstantName: string): string | number;
    /**
     * Parse the id from ProductBiddingCategoryConstant resource.
     *
     * @param {string} productBiddingCategoryConstantName
     *   A fully-qualified path representing ProductBiddingCategoryConstant resource.
     * @returns {string} A string representing the id.
     */
    matchIdFromProductBiddingCategoryConstantName(productBiddingCategoryConstantName: string): string | number;
    /**
     * Return a fully-qualified productGroupView resource name string.
     *
     * @param {string} customer_id
     * @param {string} adgroup_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    productGroupViewPath(customerId: string, adgroupId: string, criterionId: string): string;
    /**
     * Parse the customer_id from ProductGroupView resource.
     *
     * @param {string} productGroupViewName
     *   A fully-qualified path representing ProductGroupView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromProductGroupViewName(productGroupViewName: string): string | number;
    /**
     * Parse the adgroup_id from ProductGroupView resource.
     *
     * @param {string} productGroupViewName
     *   A fully-qualified path representing ProductGroupView resource.
     * @returns {string} A string representing the adgroup_id.
     */
    matchAdgroupIdFromProductGroupViewName(productGroupViewName: string): string | number;
    /**
     * Parse the criterion_id from ProductGroupView resource.
     *
     * @param {string} productGroupViewName
     *   A fully-qualified path representing ProductGroupView resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromProductGroupViewName(productGroupViewName: string): string | number;
    /**
     * Return a fully-qualified productLink resource name string.
     *
     * @param {string} customer_id
     * @param {string} product_link_id
     * @returns {string} Resource name string.
     */
    productLinkPath(customerId: string, productLinkId: string): string;
    /**
     * Parse the customer_id from ProductLink resource.
     *
     * @param {string} productLinkName
     *   A fully-qualified path representing ProductLink resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromProductLinkName(productLinkName: string): string | number;
    /**
     * Parse the product_link_id from ProductLink resource.
     *
     * @param {string} productLinkName
     *   A fully-qualified path representing ProductLink resource.
     * @returns {string} A string representing the product_link_id.
     */
    matchProductLinkIdFromProductLinkName(productLinkName: string): string | number;
    /**
     * Return a fully-qualified qualifyingQuestion resource name string.
     *
     * @param {string} qualifying_question_id
     * @returns {string} Resource name string.
     */
    qualifyingQuestionPath(qualifyingQuestionId: string): string;
    /**
     * Parse the qualifying_question_id from QualifyingQuestion resource.
     *
     * @param {string} qualifyingQuestionName
     *   A fully-qualified path representing QualifyingQuestion resource.
     * @returns {string} A string representing the qualifying_question_id.
     */
    matchQualifyingQuestionIdFromQualifyingQuestionName(qualifyingQuestionName: string): string | number;
    /**
     * Return a fully-qualified recommendation resource name string.
     *
     * @param {string} customer_id
     * @param {string} recommendation_id
     * @returns {string} Resource name string.
     */
    recommendationPath(customerId: string, recommendationId: string): string;
    /**
     * Parse the customer_id from Recommendation resource.
     *
     * @param {string} recommendationName
     *   A fully-qualified path representing Recommendation resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromRecommendationName(recommendationName: string): string | number;
    /**
     * Parse the recommendation_id from Recommendation resource.
     *
     * @param {string} recommendationName
     *   A fully-qualified path representing Recommendation resource.
     * @returns {string} A string representing the recommendation_id.
     */
    matchRecommendationIdFromRecommendationName(recommendationName: string): string | number;
    /**
     * Return a fully-qualified remarketingAction resource name string.
     *
     * @param {string} customer_id
     * @param {string} remarketing_action_id
     * @returns {string} Resource name string.
     */
    remarketingActionPath(customerId: string, remarketingActionId: string): string;
    /**
     * Parse the customer_id from RemarketingAction resource.
     *
     * @param {string} remarketingActionName
     *   A fully-qualified path representing RemarketingAction resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromRemarketingActionName(remarketingActionName: string): string | number;
    /**
     * Parse the remarketing_action_id from RemarketingAction resource.
     *
     * @param {string} remarketingActionName
     *   A fully-qualified path representing RemarketingAction resource.
     * @returns {string} A string representing the remarketing_action_id.
     */
    matchRemarketingActionIdFromRemarketingActionName(remarketingActionName: string): string | number;
    /**
     * Return a fully-qualified searchTermView resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} ad_group_id
     * @param {string} query
     * @returns {string} Resource name string.
     */
    searchTermViewPath(customerId: string, campaignId: string, adGroupId: string, query: string): string;
    /**
     * Parse the customer_id from SearchTermView resource.
     *
     * @param {string} searchTermViewName
     *   A fully-qualified path representing SearchTermView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromSearchTermViewName(searchTermViewName: string): string | number;
    /**
     * Parse the campaign_id from SearchTermView resource.
     *
     * @param {string} searchTermViewName
     *   A fully-qualified path representing SearchTermView resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromSearchTermViewName(searchTermViewName: string): string | number;
    /**
     * Parse the ad_group_id from SearchTermView resource.
     *
     * @param {string} searchTermViewName
     *   A fully-qualified path representing SearchTermView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromSearchTermViewName(searchTermViewName: string): string | number;
    /**
     * Parse the query from SearchTermView resource.
     *
     * @param {string} searchTermViewName
     *   A fully-qualified path representing SearchTermView resource.
     * @returns {string} A string representing the query.
     */
    matchQueryFromSearchTermViewName(searchTermViewName: string): string | number;
    /**
     * Return a fully-qualified sharedCriterion resource name string.
     *
     * @param {string} customer_id
     * @param {string} shared_set_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    sharedCriterionPath(customerId: string, sharedSetId: string, criterionId: string): string;
    /**
     * Parse the customer_id from SharedCriterion resource.
     *
     * @param {string} sharedCriterionName
     *   A fully-qualified path representing SharedCriterion resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromSharedCriterionName(sharedCriterionName: string): string | number;
    /**
     * Parse the shared_set_id from SharedCriterion resource.
     *
     * @param {string} sharedCriterionName
     *   A fully-qualified path representing SharedCriterion resource.
     * @returns {string} A string representing the shared_set_id.
     */
    matchSharedSetIdFromSharedCriterionName(sharedCriterionName: string): string | number;
    /**
     * Parse the criterion_id from SharedCriterion resource.
     *
     * @param {string} sharedCriterionName
     *   A fully-qualified path representing SharedCriterion resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromSharedCriterionName(sharedCriterionName: string): string | number;
    /**
     * Return a fully-qualified sharedSet resource name string.
     *
     * @param {string} customer_id
     * @param {string} shared_set_id
     * @returns {string} Resource name string.
     */
    sharedSetPath(customerId: string, sharedSetId: string): string;
    /**
     * Parse the customer_id from SharedSet resource.
     *
     * @param {string} sharedSetName
     *   A fully-qualified path representing SharedSet resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromSharedSetName(sharedSetName: string): string | number;
    /**
     * Parse the shared_set_id from SharedSet resource.
     *
     * @param {string} sharedSetName
     *   A fully-qualified path representing SharedSet resource.
     * @returns {string} A string representing the shared_set_id.
     */
    matchSharedSetIdFromSharedSetName(sharedSetName: string): string | number;
    /**
     * Return a fully-qualified shoppingPerformanceView resource name string.
     *
     * @param {string} customer_id
     * @returns {string} Resource name string.
     */
    shoppingPerformanceViewPath(customerId: string): string;
    /**
     * Parse the customer_id from ShoppingPerformanceView resource.
     *
     * @param {string} shoppingPerformanceViewName
     *   A fully-qualified path representing ShoppingPerformanceView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromShoppingPerformanceViewName(shoppingPerformanceViewName: string): string | number;
    /**
     * Return a fully-qualified smartCampaignSearchTermView resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} query
     * @returns {string} Resource name string.
     */
    smartCampaignSearchTermViewPath(customerId: string, campaignId: string, query: string): string;
    /**
     * Parse the customer_id from SmartCampaignSearchTermView resource.
     *
     * @param {string} smartCampaignSearchTermViewName
     *   A fully-qualified path representing SmartCampaignSearchTermView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromSmartCampaignSearchTermViewName(smartCampaignSearchTermViewName: string): string | number;
    /**
     * Parse the campaign_id from SmartCampaignSearchTermView resource.
     *
     * @param {string} smartCampaignSearchTermViewName
     *   A fully-qualified path representing SmartCampaignSearchTermView resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromSmartCampaignSearchTermViewName(smartCampaignSearchTermViewName: string): string | number;
    /**
     * Parse the query from SmartCampaignSearchTermView resource.
     *
     * @param {string} smartCampaignSearchTermViewName
     *   A fully-qualified path representing SmartCampaignSearchTermView resource.
     * @returns {string} A string representing the query.
     */
    matchQueryFromSmartCampaignSearchTermViewName(smartCampaignSearchTermViewName: string): string | number;
    /**
     * Return a fully-qualified smartCampaignSetting resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @returns {string} Resource name string.
     */
    smartCampaignSettingPath(customerId: string, campaignId: string): string;
    /**
     * Parse the customer_id from SmartCampaignSetting resource.
     *
     * @param {string} smartCampaignSettingName
     *   A fully-qualified path representing SmartCampaignSetting resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromSmartCampaignSettingName(smartCampaignSettingName: string): string | number;
    /**
     * Parse the campaign_id from SmartCampaignSetting resource.
     *
     * @param {string} smartCampaignSettingName
     *   A fully-qualified path representing SmartCampaignSetting resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromSmartCampaignSettingName(smartCampaignSettingName: string): string | number;
    /**
     * Return a fully-qualified thirdPartyAppAnalyticsLink resource name string.
     *
     * @param {string} customer_id
     * @param {string} customer_link_id
     * @returns {string} Resource name string.
     */
    thirdPartyAppAnalyticsLinkPath(customerId: string, customerLinkId: string): string;
    /**
     * Parse the customer_id from ThirdPartyAppAnalyticsLink resource.
     *
     * @param {string} thirdPartyAppAnalyticsLinkName
     *   A fully-qualified path representing ThirdPartyAppAnalyticsLink resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromThirdPartyAppAnalyticsLinkName(thirdPartyAppAnalyticsLinkName: string): string | number;
    /**
     * Parse the customer_link_id from ThirdPartyAppAnalyticsLink resource.
     *
     * @param {string} thirdPartyAppAnalyticsLinkName
     *   A fully-qualified path representing ThirdPartyAppAnalyticsLink resource.
     * @returns {string} A string representing the customer_link_id.
     */
    matchCustomerLinkIdFromThirdPartyAppAnalyticsLinkName(thirdPartyAppAnalyticsLinkName: string): string | number;
    /**
     * Return a fully-qualified topicConstant resource name string.
     *
     * @param {string} topic_id
     * @returns {string} Resource name string.
     */
    topicConstantPath(topicId: string): string;
    /**
     * Parse the topic_id from TopicConstant resource.
     *
     * @param {string} topicConstantName
     *   A fully-qualified path representing TopicConstant resource.
     * @returns {string} A string representing the topic_id.
     */
    matchTopicIdFromTopicConstantName(topicConstantName: string): string | number;
    /**
     * Return a fully-qualified topicView resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    topicViewPath(customerId: string, adGroupId: string, criterionId: string): string;
    /**
     * Parse the customer_id from TopicView resource.
     *
     * @param {string} topicViewName
     *   A fully-qualified path representing TopicView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromTopicViewName(topicViewName: string): string | number;
    /**
     * Parse the ad_group_id from TopicView resource.
     *
     * @param {string} topicViewName
     *   A fully-qualified path representing TopicView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromTopicViewName(topicViewName: string): string | number;
    /**
     * Parse the criterion_id from TopicView resource.
     *
     * @param {string} topicViewName
     *   A fully-qualified path representing TopicView resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromTopicViewName(topicViewName: string): string | number;
    /**
     * Return a fully-qualified travelActivityGroupView resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    travelActivityGroupViewPath(customerId: string, adGroupId: string, criterionId: string): string;
    /**
     * Parse the customer_id from TravelActivityGroupView resource.
     *
     * @param {string} travelActivityGroupViewName
     *   A fully-qualified path representing TravelActivityGroupView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromTravelActivityGroupViewName(travelActivityGroupViewName: string): string | number;
    /**
     * Parse the ad_group_id from TravelActivityGroupView resource.
     *
     * @param {string} travelActivityGroupViewName
     *   A fully-qualified path representing TravelActivityGroupView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromTravelActivityGroupViewName(travelActivityGroupViewName: string): string | number;
    /**
     * Parse the criterion_id from TravelActivityGroupView resource.
     *
     * @param {string} travelActivityGroupViewName
     *   A fully-qualified path representing TravelActivityGroupView resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromTravelActivityGroupViewName(travelActivityGroupViewName: string): string | number;
    /**
     * Return a fully-qualified travelActivityPerformanceView resource name string.
     *
     * @param {string} customer_id
     * @returns {string} Resource name string.
     */
    travelActivityPerformanceViewPath(customerId: string): string;
    /**
     * Parse the customer_id from TravelActivityPerformanceView resource.
     *
     * @param {string} travelActivityPerformanceViewName
     *   A fully-qualified path representing TravelActivityPerformanceView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromTravelActivityPerformanceViewName(travelActivityPerformanceViewName: string): string | number;
    /**
     * Return a fully-qualified userInterest resource name string.
     *
     * @param {string} customer_id
     * @param {string} user_interest_id
     * @returns {string} Resource name string.
     */
    userInterestPath(customerId: string, userInterestId: string): string;
    /**
     * Parse the customer_id from UserInterest resource.
     *
     * @param {string} userInterestName
     *   A fully-qualified path representing UserInterest resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromUserInterestName(userInterestName: string): string | number;
    /**
     * Parse the user_interest_id from UserInterest resource.
     *
     * @param {string} userInterestName
     *   A fully-qualified path representing UserInterest resource.
     * @returns {string} A string representing the user_interest_id.
     */
    matchUserInterestIdFromUserInterestName(userInterestName: string): string | number;
    /**
     * Return a fully-qualified userList resource name string.
     *
     * @param {string} customer_id
     * @param {string} user_list_id
     * @returns {string} Resource name string.
     */
    userListPath(customerId: string, userListId: string): string;
    /**
     * Parse the customer_id from UserList resource.
     *
     * @param {string} userListName
     *   A fully-qualified path representing UserList resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromUserListName(userListName: string): string | number;
    /**
     * Parse the user_list_id from UserList resource.
     *
     * @param {string} userListName
     *   A fully-qualified path representing UserList resource.
     * @returns {string} A string representing the user_list_id.
     */
    matchUserListIdFromUserListName(userListName: string): string | number;
    /**
     * Return a fully-qualified userLocationView resource name string.
     *
     * @param {string} customer_id
     * @param {string} country_criterion_id
     * @param {string} is_targeting_location
     * @returns {string} Resource name string.
     */
    userLocationViewPath(customerId: string, countryCriterionId: string, isTargetingLocation: string): string;
    /**
     * Parse the customer_id from UserLocationView resource.
     *
     * @param {string} userLocationViewName
     *   A fully-qualified path representing UserLocationView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromUserLocationViewName(userLocationViewName: string): string | number;
    /**
     * Parse the country_criterion_id from UserLocationView resource.
     *
     * @param {string} userLocationViewName
     *   A fully-qualified path representing UserLocationView resource.
     * @returns {string} A string representing the country_criterion_id.
     */
    matchCountryCriterionIdFromUserLocationViewName(userLocationViewName: string): string | number;
    /**
     * Parse the is_targeting_location from UserLocationView resource.
     *
     * @param {string} userLocationViewName
     *   A fully-qualified path representing UserLocationView resource.
     * @returns {string} A string representing the is_targeting_location.
     */
    matchIsTargetingLocationFromUserLocationViewName(userLocationViewName: string): string | number;
    /**
     * Return a fully-qualified video resource name string.
     *
     * @param {string} customer_id
     * @param {string} video_id
     * @returns {string} Resource name string.
     */
    videoPath(customerId: string, videoId: string): string;
    /**
     * Parse the customer_id from Video resource.
     *
     * @param {string} videoName
     *   A fully-qualified path representing Video resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromVideoName(videoName: string): string | number;
    /**
     * Parse the video_id from Video resource.
     *
     * @param {string} videoName
     *   A fully-qualified path representing Video resource.
     * @returns {string} A string representing the video_id.
     */
    matchVideoIdFromVideoName(videoName: string): string | number;
    /**
     * Return a fully-qualified webpageView resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    webpageViewPath(customerId: string, adGroupId: string, criterionId: string): string;
    /**
     * Parse the customer_id from WebpageView resource.
     *
     * @param {string} webpageViewName
     *   A fully-qualified path representing WebpageView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromWebpageViewName(webpageViewName: string): string | number;
    /**
     * Parse the ad_group_id from WebpageView resource.
     *
     * @param {string} webpageViewName
     *   A fully-qualified path representing WebpageView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromWebpageViewName(webpageViewName: string): string | number;
    /**
     * Parse the criterion_id from WebpageView resource.
     *
     * @param {string} webpageViewName
     *   A fully-qualified path representing WebpageView resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromWebpageViewName(webpageViewName: string): string | number;
    /**
     * Terminate the gRPC channel and close the client.
     *
     * The client will no longer be usable and all future behavior is undefined.
     * @returns {Promise} A promise that resolves when the client is closed.
     */
    close(): Promise<void>;
}
