"use strict";
// Copyright 2023 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     https://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
// ** This file is automatically generated by gapic-generator-typescript. **
// ** https://github.com/googleapis/gapic-generator-typescript **
// ** All changes to this file may be overwritten. **
Object.defineProperty(exports, "__esModule", { value: true });
exports.BillingSetupServiceClient = void 0;
const jsonProtos = require("../../protos/protos.json");
/**
 * Client JSON configuration object, loaded from
 * `src/v14/billing_setup_service_client_config.json`.
 * This file defines retry strategy and timeouts for all API methods in this library.
 */
const gapicConfig = require("./billing_setup_service_client_config.json");
const version = require('../../../package.json').version;
/**
 *  A service for designating the business entity responsible for accrued costs.
 *
 *  A billing setup is associated with a payments account.  Billing-related
 *  activity for all billing setups associated with a particular payments account
 *  will appear on a single invoice generated monthly.
 *
 *  Mutates:
 *  The REMOVE operation cancels a pending billing setup.
 *  The CREATE operation creates a new billing setup.
 * @class
 * @memberof v14
 */
class BillingSetupServiceClient {
    /**
     * Construct an instance of BillingSetupServiceClient.
     *
     * @param {object} [options] - The configuration object.
     * The options accepted by the constructor are described in detail
     * in [this document](https://github.com/googleapis/gax-nodejs/blob/main/client-libraries.md#creating-the-client-instance).
     * The common options are:
     * @param {object} [options.credentials] - Credentials object.
     * @param {string} [options.credentials.client_email]
     * @param {string} [options.credentials.private_key]
     * @param {string} [options.email] - Account email address. Required when
     *     using a .pem or .p12 keyFilename.
     * @param {string} [options.keyFilename] - Full path to the a .json, .pem, or
     *     .p12 key downloaded from the Google Developers Console. If you provide
     *     a path to a JSON file, the projectId option below is not necessary.
     *     NOTE: .pem and .p12 require you to specify options.email as well.
     * @param {number} [options.port] - The port on which to connect to
     *     the remote host.
     * @param {string} [options.projectId] - The project ID from the Google
     *     Developer's Console, e.g. 'grape-spaceship-123'. We will also check
     *     the environment variable GCLOUD_PROJECT for your project ID. If your
     *     app is running in an environment which supports
     *     {@link https://developers.google.com/identity/protocols/application-default-credentials Application Default Credentials},
     *     your project ID will be detected automatically.
     * @param {string} [options.apiEndpoint] - The domain name of the
     *     API remote host.
     * @param {gax.ClientConfig} [options.clientConfig] - Client configuration override.
     *     Follows the structure of {@link gapicConfig}.
     * @param {boolean} [options.fallback] - Use HTTP/1.1 REST mode.
     *     For more information, please check the
     *     {@link https://github.com/googleapis/gax-nodejs/blob/main/client-libraries.md#http11-rest-api-mode documentation}.
     * @param {gax} [gaxInstance]: loaded instance of `google-gax`. Useful if you
     *     need to avoid loading the default gRPC version and want to use the fallback
     *     HTTP implementation. Load only fallback version and pass it to the constructor:
     *     ```
     *     const gax = require('google-gax/build/src/fallback'); // avoids loading google-gax with gRPC
     *     const client = new BillingSetupServiceClient({fallback: true}, gax);
     *     ```
     */
    constructor(opts, gaxInstance) {
        var _a, _b;
        this._terminated = false;
        this.descriptors = {
            page: {},
            stream: {},
            longrunning: {},
            batching: {},
        };
        // Ensure that options include all the required fields.
        const staticMembers = this.constructor;
        const servicePath = (opts === null || opts === void 0 ? void 0 : opts.servicePath) || (opts === null || opts === void 0 ? void 0 : opts.apiEndpoint) || staticMembers.servicePath;
        this._providedCustomServicePath = !!((opts === null || opts === void 0 ? void 0 : opts.servicePath) || (opts === null || opts === void 0 ? void 0 : opts.apiEndpoint));
        const port = (opts === null || opts === void 0 ? void 0 : opts.port) || staticMembers.port;
        const clientConfig = (_a = opts === null || opts === void 0 ? void 0 : opts.clientConfig) !== null && _a !== void 0 ? _a : {};
        const fallback = (_b = opts === null || opts === void 0 ? void 0 : opts.fallback) !== null && _b !== void 0 ? _b : (typeof window !== 'undefined' && typeof (window === null || window === void 0 ? void 0 : window.fetch) === 'function');
        opts = Object.assign({ servicePath, port, clientConfig, fallback }, opts);
        // If scopes are unset in options and we're connecting to a non-default endpoint, set scopes just in case.
        if (servicePath !== staticMembers.servicePath && !('scopes' in opts)) {
            opts['scopes'] = staticMembers.scopes;
        }
        // Load google-gax module synchronously if needed
        if (!gaxInstance) {
            gaxInstance = require('google-gax');
        }
        // Choose either gRPC or proto-over-HTTP implementation of google-gax.
        this._gaxModule = opts.fallback ? gaxInstance.fallback : gaxInstance;
        // Create a `gaxGrpc` object, with any grpc-specific options sent to the client.
        this._gaxGrpc = new this._gaxModule.GrpcClient(opts);
        // Save options to use in initialize() method.
        this._opts = opts;
        // Save the auth object to the client, for use by other methods.
        this.auth = this._gaxGrpc.auth;
        // Set useJWTAccessWithScope on the auth object.
        this.auth.useJWTAccessWithScope = true;
        // Set defaultServicePath on the auth object.
        this.auth.defaultServicePath = staticMembers.servicePath;
        // Set the default scopes in auth client if needed.
        if (servicePath === staticMembers.servicePath) {
            this.auth.defaultScopes = staticMembers.scopes;
        }
        // Determine the client header string.
        const clientHeader = [
            `gax/${this._gaxModule.version}`,
            `gapic/${version}`,
        ];
        if (typeof process !== 'undefined' && 'versions' in process) {
            clientHeader.push(`gl-node/${process.versions.node}`);
        }
        else {
            clientHeader.push(`gl-web/${this._gaxModule.version}`);
        }
        if (!opts.fallback) {
            clientHeader.push(`grpc/${this._gaxGrpc.grpcVersion}`);
        }
        else {
            clientHeader.push(`rest/${this._gaxGrpc.grpcVersion}`);
        }
        if (opts.libName && opts.libVersion) {
            clientHeader.push(`${opts.libName}/${opts.libVersion}`);
        }
        // Load the applicable protos.
        this._protos = this._gaxGrpc.loadProtoJSON(jsonProtos);
        // This API contains "path templates"; forward-slash-separated
        // identifiers to uniquely identify resources within the API.
        // Create useful helper objects for these.
        this.pathTemplates = {
            accessibleBiddingStrategyPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/accessibleBiddingStrategies/{bidding_strategy_id}'),
            accountBudgetPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/accountBudgets/{account_budget_id}'),
            accountBudgetProposalPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/accountBudgetProposals/{account_budget_proposal_id}'),
            accountLinkPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/accountLinks/{account_link_id}'),
            adPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/ads/{ad_id}'),
            adGroupPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/adGroups/{ad_group_id}'),
            adGroupAdPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/adGroupAds/{ad_group_id}~{ad_id}'),
            adGroupAdAssetCombinationViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/adGroupAdAssetCombinationViews/{ad_group_id}~{ad_id}~{asset_combination_id_low}~{asset_combination_id_high}'),
            adGroupAdAssetViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/adGroupAdAssetViews/{ad_group_id}~{ad_id}~{asset_id}~{field_type}'),
            adGroupAdLabelPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/adGroupAdLabels/{ad_group_id}~{ad_id}~{label_id}'),
            adGroupAssetPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/adGroupAssets/{ad_group_id}~{asset_id}~{field_type}'),
            adGroupAssetSetPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/adGroupAssetSets/{ad_group_id}~{asset_set_id}'),
            adGroupAudienceViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/adGroupAudienceViews/{ad_group_id}~{criterion_id}'),
            adGroupBidModifierPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/adGroupBidModifiers/{ad_group_id}~{criterion_id}'),
            adGroupCriterionPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/adGroupCriteria/{ad_group_id}~{criterion_id}'),
            adGroupCriterionCustomizerPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/adGroupCriterionCustomizers/{ad_group_id}~{criterion_id}~{customizer_attribute_id}'),
            adGroupCriterionLabelPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/adGroupCriterionLabels/{ad_group_id}~{criterion_id}~{label_id}'),
            adGroupCriterionSimulationPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/adGroupCriterionSimulations/{ad_group_id}~{criterion_id}~{type}~{modification_method}~{start_date}~{end_date}'),
            adGroupCustomizerPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/adGroupCustomizers/{ad_group_id}~{customizer_attribute_id}'),
            adGroupExtensionSettingPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/adGroupExtensionSettings/{ad_group_id}~{extension_type}'),
            adGroupFeedPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/adGroupFeeds/{ad_group_id}~{feed_id}'),
            adGroupLabelPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/adGroupLabels/{ad_group_id}~{label_id}'),
            adGroupSimulationPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/adGroupSimulations/{ad_group_id}~{type}~{modification_method}~{start_date}~{end_date}'),
            adParameterPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/adParameters/{ad_group_id}~{criterion_id}~{parameter_index}'),
            adScheduleViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/adScheduleViews/{campaign_id}~{criterion_id}'),
            ageRangeViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/ageRangeViews/{ad_group_id}~{criterion_id}'),
            assetPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/assets/{asset_id}'),
            assetFieldTypeViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/assetFieldTypeViews/{field_type}'),
            assetGroupPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/assetGroups/{asset_group_id}'),
            assetGroupAssetPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/assetGroupAssets/{asset_group_id}~{asset_id}~{field_type}'),
            assetGroupListingGroupFilterPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/assetGroupListingGroupFilters/{asset_group_id}~{listing_group_filter_id}'),
            assetGroupProductGroupViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/assetGroupProductGroupViews/{asset_group_id}~{listing_group_filter_id}'),
            assetGroupSignalPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/assetGroupSignals/{asset_group_id}~{criterion_id}'),
            assetSetPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/assetSets/{asset_set_id}'),
            assetSetAssetPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/assetSetAssets/{asset_set_id}~{asset_id}'),
            assetSetTypeViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/assetSetTypeViews/{asset_set_type}'),
            audiencePathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/audiences/{audience_id}'),
            batchJobPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/batchJobs/{batch_job_id}'),
            biddingDataExclusionPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/biddingDataExclusions/{seasonality_event_id}'),
            biddingSeasonalityAdjustmentPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/biddingSeasonalityAdjustments/{seasonality_event_id}'),
            biddingStrategyPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/biddingStrategies/{bidding_strategy_id}'),
            biddingStrategySimulationPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/biddingStrategySimulations/{bidding_strategy_id}~{type}~{modification_method}~{start_date}~{end_date}'),
            billingSetupPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/billingSetups/{billing_setup_id}'),
            callViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/callViews/{call_detail_id}'),
            campaignPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/campaigns/{campaign_id}'),
            campaignAssetPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/campaignAssets/{campaign_id}~{asset_id}~{field_type}'),
            campaignAssetSetPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/campaignAssetSets/{campaign_id}~{asset_set_id}'),
            campaignAudienceViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/campaignAudienceViews/{campaign_id}~{criterion_id}'),
            campaignBidModifierPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/campaignBidModifiers/{campaign_id}~{criterion_id}'),
            campaignBudgetPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/campaignBudgets/{campaign_budget_id}'),
            campaignConversionGoalPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/campaignConversionGoals/{campaign_id}~{category}~{source}'),
            campaignCriterionPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/campaignCriteria/{campaign_id}~{criterion_id}'),
            campaignCustomizerPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/campaignCustomizers/{campaign_id}~{customizer_attribute_id}'),
            campaignDraftPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/campaignDrafts/{base_campaign_id}~{draft_id}'),
            campaignExtensionSettingPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/campaignExtensionSettings/{campaign_id}~{extension_type}'),
            campaignFeedPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/campaignFeeds/{campaign_id}~{feed_id}'),
            campaignGroupPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/campaignGroups/{campaign_group_id}'),
            campaignLabelPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/campaignLabels/{campaign_id}~{label_id}'),
            campaignSearchTermInsightPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/campaignSearchTermInsights/{campaign_id}~{cluster_id}'),
            campaignSharedSetPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/campaignSharedSets/{campaign_id}~{shared_set_id}'),
            campaignSimulationPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/campaignSimulations/{campaign_id}~{type}~{modification_method}~{start_date}~{end_date}'),
            carrierConstantPathTemplate: new this._gaxModule.PathTemplate('carrierConstants/{criterion_id}'),
            changeEventPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/changeEvents/{timestamp_micros}~{command_index}~{mutate_index}'),
            changeStatusPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/changeStatus/{change_status_id}'),
            clickViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/clickViews/{date}~{gclid}'),
            combinedAudiencePathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/combinedAudiences/{combined_audience_id}'),
            conversionActionPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/conversionActions/{conversion_action_id}'),
            conversionCustomVariablePathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/conversionCustomVariables/{conversion_custom_variable_id}'),
            conversionGoalCampaignConfigPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/conversionGoalCampaignConfigs/{campaign_id}'),
            conversionValueRulePathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/conversionValueRules/{conversion_value_rule_id}'),
            conversionValueRuleSetPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/conversionValueRuleSets/{conversion_value_rule_set_id}'),
            currencyConstantPathTemplate: new this._gaxModule.PathTemplate('currencyConstants/{code}'),
            customAudiencePathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/customAudiences/{custom_audience_id}'),
            customConversionGoalPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/customConversionGoals/{goal_id}'),
            customInterestPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/customInterests/{custom_interest_id}'),
            customerPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}'),
            customerAssetPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/customerAssets/{asset_id}~{field_type}'),
            customerAssetSetPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/customerAssetSets/{asset_set_id}'),
            customerClientPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/customerClients/{client_customer_id}'),
            customerClientLinkPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/customerClientLinks/{client_customer_id}~{manager_link_id}'),
            customerConversionGoalPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/customerConversionGoals/{category}~{source}'),
            customerCustomizerPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/customerCustomizers/{customizer_attribute_id}'),
            customerExtensionSettingPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/customerExtensionSettings/{extension_type}'),
            customerFeedPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/customerFeeds/{feed_id}'),
            customerLabelPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/customerLabels/{label_id}'),
            customerManagerLinkPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/customerManagerLinks/{manager_customer_id}~{manager_link_id}'),
            customerNegativeCriterionPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/customerNegativeCriteria/{criterion_id}'),
            customerSearchTermInsightPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/customerSearchTermInsights/{cluster_id}'),
            customerSkAdNetworkConversionValueSchemaPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/customerSkAdNetworkConversionValueSchemas/{account_link_id}'),
            customerUserAccessPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/customerUserAccesses/{user_id}'),
            customerUserAccessInvitationPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/customerUserAccessInvitations/{invitation_id}'),
            customizerAttributePathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/customizerAttributes/{customizer_attribute_id}'),
            detailPlacementViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/detailPlacementViews/{ad_group_id}~{base64_placement}'),
            detailedDemographicPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/detailedDemographics/{detailed_demographic_id}'),
            displayKeywordViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/displayKeywordViews/{ad_group_id}~{criterion_id}'),
            distanceViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/distanceViews/{placeholder_chain_id}~{distance_bucket}'),
            domainCategoryPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/domainCategories/{campaign_id}~{base64_category}~{language_code}'),
            dynamicSearchAdsSearchTermViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/dynamicSearchAdsSearchTermViews/{ad_group_id}~{search_term_fingerprint}~{headline_fingerprint}~{landing_page_fingerprint}~{page_url_fingerprint}'),
            expandedLandingPageViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/expandedLandingPageViews/{expanded_final_url_fingerprint}'),
            experimentPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/experiments/{trial_id}'),
            experimentArmPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/experimentArms/{trial_id}~{trial_arm_id}'),
            extensionFeedItemPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/extensionFeedItems/{feed_item_id}'),
            feedPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/feeds/{feed_id}'),
            feedItemPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/feedItems/{feed_id}~{feed_item_id}'),
            feedItemSetPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/feedItemSets/{feed_id}~{feed_item_set_id}'),
            feedItemSetLinkPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/feedItemSetLinks/{feed_id}~{feed_item_set_id}~{feed_item_id}'),
            feedItemTargetPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/feedItemTargets/{feed_id}~{feed_item_id}~{feed_item_target_type}~{feed_item_target_id}'),
            feedMappingPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/feedMappings/{feed_id}~{feed_mapping_id}'),
            feedPlaceholderViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/feedPlaceholderViews/{placeholder_type}'),
            genderViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/genderViews/{ad_group_id}~{criterion_id}'),
            geoTargetConstantPathTemplate: new this._gaxModule.PathTemplate('geoTargetConstants/{criterion_id}'),
            geographicViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/geographicViews/{country_criterion_id}~{location_type}'),
            googleAdsFieldPathTemplate: new this._gaxModule.PathTemplate('googleAdsFields/{google_ads_field}'),
            groupPlacementViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/groupPlacementViews/{ad_group_id}~{base64_placement}'),
            hotelGroupViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/hotelGroupViews/{ad_group_id}~{criterion_id}'),
            hotelPerformanceViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/hotelPerformanceView'),
            hotelReconciliationPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/hotelReconciliations/{commission_id}'),
            incomeRangeViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/incomeRangeViews/{ad_group_id}~{criterion_id}'),
            invoicePathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/invoices/{invoice_id}'),
            keywordPlanPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/keywordPlans/{keyword_plan_id}'),
            keywordPlanAdGroupPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/keywordPlanAdGroups/{keyword_plan_ad_group_id}'),
            keywordPlanAdGroupKeywordPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/keywordPlanAdGroupKeywords/{keyword_plan_ad_group_keyword_id}'),
            keywordPlanCampaignPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/keywordPlanCampaigns/{keyword_plan_campaign_id}'),
            keywordPlanCampaignKeywordPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/keywordPlanCampaignKeywords/{keyword_plan_campaign_keyword_id}'),
            keywordThemeConstantPathTemplate: new this._gaxModule.PathTemplate('keywordThemeConstants/{express_category_id}~{express_sub_category_id}'),
            keywordViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/keywordViews/{ad_group_id}~{criterion_id}'),
            labelPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/labels/{label_id}'),
            landingPageViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/landingPageViews/{unexpanded_final_url_fingerprint}'),
            languageConstantPathTemplate: new this._gaxModule.PathTemplate('languageConstants/{criterion_id}'),
            leadFormSubmissionDataPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/leadFormSubmissionData/{lead_form_user_submission_id}'),
            lifeEventPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/lifeEvents/{life_event_id}'),
            locationViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/locationViews/{campaign_id}~{criterion_id}'),
            managedPlacementViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/managedPlacementViews/{ad_group_id}~{criterion_id}'),
            mediaFilePathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/mediaFiles/{media_file_id}'),
            merchantCenterLinkPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/merchantCenterLinks/{merchant_center_id}'),
            mobileAppCategoryConstantPathTemplate: new this._gaxModule.PathTemplate('mobileAppCategoryConstants/{mobile_app_category_id}'),
            mobileDeviceConstantPathTemplate: new this._gaxModule.PathTemplate('mobileDeviceConstants/{criterion_id}'),
            offlineUserDataJobPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/offlineUserDataJobs/{offline_user_data_update_id}'),
            operatingSystemVersionConstantPathTemplate: new this._gaxModule.PathTemplate('operatingSystemVersionConstants/{criterion_id}'),
            paidOrganicSearchTermViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/paidOrganicSearchTermViews/{campaign_id}~{ad_group_id}~{base64_search_term}'),
            parentalStatusViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/parentalStatusViews/{ad_group_id}~{criterion_id}'),
            paymentsAccountPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/paymentsAccounts/{payments_account_id}'),
            perStoreViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/perStoreViews/{place_id}'),
            productBiddingCategoryConstantPathTemplate: new this._gaxModule.PathTemplate('productBiddingCategoryConstants/{country_code}~{level}~{id}'),
            productGroupViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/productGroupViews/{adgroup_id}~{criterion_id}'),
            productLinkPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/productLinks/{product_link_id}'),
            qualifyingQuestionPathTemplate: new this._gaxModule.PathTemplate('qualifyingQuestions/{qualifying_question_id}'),
            recommendationPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/recommendations/{recommendation_id}'),
            remarketingActionPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/remarketingActions/{remarketing_action_id}'),
            searchTermViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/searchTermViews/{campaign_id}~{ad_group_id}~{query}'),
            sharedCriterionPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/sharedCriteria/{shared_set_id}~{criterion_id}'),
            sharedSetPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/sharedSets/{shared_set_id}'),
            shoppingPerformanceViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/shoppingPerformanceView'),
            smartCampaignSearchTermViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/smartCampaignSearchTermViews/{campaign_id}~{query}'),
            smartCampaignSettingPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/smartCampaignSettings/{campaign_id}'),
            thirdPartyAppAnalyticsLinkPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/thirdPartyAppAnalyticsLinks/{customer_link_id}'),
            topicConstantPathTemplate: new this._gaxModule.PathTemplate('topicConstants/{topic_id}'),
            topicViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/topicViews/{ad_group_id}~{criterion_id}'),
            travelActivityGroupViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/travelActivityGroupViews/{ad_group_id}~{criterion_id}'),
            travelActivityPerformanceViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/travelActivityPerformanceViews'),
            userInterestPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/userInterests/{user_interest_id}'),
            userListPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/userLists/{user_list_id}'),
            userLocationViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/userLocationViews/{country_criterion_id}~{is_targeting_location}'),
            videoPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/videos/{video_id}'),
            webpageViewPathTemplate: new this._gaxModule.PathTemplate('customers/{customer_id}/webpageViews/{ad_group_id}~{criterion_id}'),
        };
        // Put together the default options sent with requests.
        this._defaults = this._gaxGrpc.constructSettings('google.ads.googleads.v14.services.BillingSetupService', gapicConfig, opts.clientConfig || {}, { 'x-goog-api-client': clientHeader.join(' ') });
        // Set up a dictionary of "inner API calls"; the core implementation
        // of calling the API is handled in `google-gax`, with this code
        // merely providing the destination and request information.
        this.innerApiCalls = {};
        // Add a warn function to the client constructor so it can be easily tested.
        this.warn = this._gaxModule.warn;
    }
    /**
     * Initialize the client.
     * Performs asynchronous operations (such as authentication) and prepares the client.
     * This function will be called automatically when any class method is called for the
     * first time, but if you need to initialize it before calling an actual method,
     * feel free to call initialize() directly.
     *
     * You can await on this method if you want to make sure the client is initialized.
     *
     * @returns {Promise} A promise that resolves to an authenticated service stub.
     */
    initialize() {
        // If the client stub promise is already initialized, return immediately.
        if (this.billingSetupServiceStub) {
            return this.billingSetupServiceStub;
        }
        // Put together the "service stub" for
        // google.ads.googleads.v14.services.BillingSetupService.
        this.billingSetupServiceStub = this._gaxGrpc.createStub(this._opts.fallback ?
            this._protos.lookupService('google.ads.googleads.v14.services.BillingSetupService') :
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            this._protos.google.ads.googleads.v14.services.BillingSetupService, this._opts, this._providedCustomServicePath);
        // Iterate over each of the methods that the service provides
        // and create an API call method for each.
        const billingSetupServiceStubMethods = ['mutateBillingSetup'];
        for (const methodName of billingSetupServiceStubMethods) {
            const callPromise = this.billingSetupServiceStub.then(stub => (...args) => {
                if (this._terminated) {
                    return Promise.reject('The client has already been closed.');
                }
                const func = stub[methodName];
                return func.apply(stub, args);
            }, (err) => () => {
                throw err;
            });
            const descriptor = undefined;
            const apiCall = this._gaxModule.createApiCall(callPromise, this._defaults[methodName], descriptor, this._opts.fallback);
            this.innerApiCalls[methodName] = apiCall;
        }
        return this.billingSetupServiceStub;
    }
    /**
     * The DNS address for this API service.
     * @returns {string} The DNS address for this service.
     */
    static get servicePath() {
        return 'googleads.googleapis.com';
    }
    /**
     * The DNS address for this API service - same as servicePath(),
     * exists for compatibility reasons.
     * @returns {string} The DNS address for this service.
     */
    static get apiEndpoint() {
        return 'googleads.googleapis.com';
    }
    /**
     * The port for this API service.
     * @returns {number} The default port for this service.
     */
    static get port() {
        return 443;
    }
    /**
     * The scopes needed to make gRPC calls for every method defined
     * in this service.
     * @returns {string[]} List of default scopes.
     */
    static get scopes() {
        return [
            'https://www.googleapis.com/auth/adwords'
        ];
    }
    /**
     * Return the project ID used by this class.
     * @returns {Promise} A promise that resolves to string containing the project ID.
     */
    getProjectId(callback) {
        if (callback) {
            this.auth.getProjectId(callback);
            return;
        }
        return this.auth.getProjectId();
    }
    mutateBillingSetup(request, optionsOrCallback, callback) {
        var _a;
        request = request || {};
        let options;
        if (typeof optionsOrCallback === 'function' && callback === undefined) {
            callback = optionsOrCallback;
            options = {};
        }
        else {
            options = optionsOrCallback;
        }
        options = options || {};
        options.otherArgs = options.otherArgs || {};
        options.otherArgs.headers = options.otherArgs.headers || {};
        options.otherArgs.headers['x-goog-request-params'] = this._gaxModule.routingHeader.fromParams({
            'customer_id': (_a = request.customer_id) !== null && _a !== void 0 ? _a : '',
        });
        this.initialize();
        return this.innerApiCalls.mutateBillingSetup(request, options, callback);
    }
    // --------------------
    // -- Path templates --
    // --------------------
    /**
     * Return a fully-qualified accessibleBiddingStrategy resource name string.
     *
     * @param {string} customer_id
     * @param {string} bidding_strategy_id
     * @returns {string} Resource name string.
     */
    accessibleBiddingStrategyPath(customerId, biddingStrategyId) {
        return this.pathTemplates.accessibleBiddingStrategyPathTemplate.render({
            customer_id: customerId,
            bidding_strategy_id: biddingStrategyId,
        });
    }
    /**
     * Parse the customer_id from AccessibleBiddingStrategy resource.
     *
     * @param {string} accessibleBiddingStrategyName
     *   A fully-qualified path representing AccessibleBiddingStrategy resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAccessibleBiddingStrategyName(accessibleBiddingStrategyName) {
        return this.pathTemplates.accessibleBiddingStrategyPathTemplate.match(accessibleBiddingStrategyName).customer_id;
    }
    /**
     * Parse the bidding_strategy_id from AccessibleBiddingStrategy resource.
     *
     * @param {string} accessibleBiddingStrategyName
     *   A fully-qualified path representing AccessibleBiddingStrategy resource.
     * @returns {string} A string representing the bidding_strategy_id.
     */
    matchBiddingStrategyIdFromAccessibleBiddingStrategyName(accessibleBiddingStrategyName) {
        return this.pathTemplates.accessibleBiddingStrategyPathTemplate.match(accessibleBiddingStrategyName).bidding_strategy_id;
    }
    /**
     * Return a fully-qualified accountBudget resource name string.
     *
     * @param {string} customer_id
     * @param {string} account_budget_id
     * @returns {string} Resource name string.
     */
    accountBudgetPath(customerId, accountBudgetId) {
        return this.pathTemplates.accountBudgetPathTemplate.render({
            customer_id: customerId,
            account_budget_id: accountBudgetId,
        });
    }
    /**
     * Parse the customer_id from AccountBudget resource.
     *
     * @param {string} accountBudgetName
     *   A fully-qualified path representing AccountBudget resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAccountBudgetName(accountBudgetName) {
        return this.pathTemplates.accountBudgetPathTemplate.match(accountBudgetName).customer_id;
    }
    /**
     * Parse the account_budget_id from AccountBudget resource.
     *
     * @param {string} accountBudgetName
     *   A fully-qualified path representing AccountBudget resource.
     * @returns {string} A string representing the account_budget_id.
     */
    matchAccountBudgetIdFromAccountBudgetName(accountBudgetName) {
        return this.pathTemplates.accountBudgetPathTemplate.match(accountBudgetName).account_budget_id;
    }
    /**
     * Return a fully-qualified accountBudgetProposal resource name string.
     *
     * @param {string} customer_id
     * @param {string} account_budget_proposal_id
     * @returns {string} Resource name string.
     */
    accountBudgetProposalPath(customerId, accountBudgetProposalId) {
        return this.pathTemplates.accountBudgetProposalPathTemplate.render({
            customer_id: customerId,
            account_budget_proposal_id: accountBudgetProposalId,
        });
    }
    /**
     * Parse the customer_id from AccountBudgetProposal resource.
     *
     * @param {string} accountBudgetProposalName
     *   A fully-qualified path representing AccountBudgetProposal resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAccountBudgetProposalName(accountBudgetProposalName) {
        return this.pathTemplates.accountBudgetProposalPathTemplate.match(accountBudgetProposalName).customer_id;
    }
    /**
     * Parse the account_budget_proposal_id from AccountBudgetProposal resource.
     *
     * @param {string} accountBudgetProposalName
     *   A fully-qualified path representing AccountBudgetProposal resource.
     * @returns {string} A string representing the account_budget_proposal_id.
     */
    matchAccountBudgetProposalIdFromAccountBudgetProposalName(accountBudgetProposalName) {
        return this.pathTemplates.accountBudgetProposalPathTemplate.match(accountBudgetProposalName).account_budget_proposal_id;
    }
    /**
     * Return a fully-qualified accountLink resource name string.
     *
     * @param {string} customer_id
     * @param {string} account_link_id
     * @returns {string} Resource name string.
     */
    accountLinkPath(customerId, accountLinkId) {
        return this.pathTemplates.accountLinkPathTemplate.render({
            customer_id: customerId,
            account_link_id: accountLinkId,
        });
    }
    /**
     * Parse the customer_id from AccountLink resource.
     *
     * @param {string} accountLinkName
     *   A fully-qualified path representing AccountLink resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAccountLinkName(accountLinkName) {
        return this.pathTemplates.accountLinkPathTemplate.match(accountLinkName).customer_id;
    }
    /**
     * Parse the account_link_id from AccountLink resource.
     *
     * @param {string} accountLinkName
     *   A fully-qualified path representing AccountLink resource.
     * @returns {string} A string representing the account_link_id.
     */
    matchAccountLinkIdFromAccountLinkName(accountLinkName) {
        return this.pathTemplates.accountLinkPathTemplate.match(accountLinkName).account_link_id;
    }
    /**
     * Return a fully-qualified ad resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_id
     * @returns {string} Resource name string.
     */
    adPath(customerId, adId) {
        return this.pathTemplates.adPathTemplate.render({
            customer_id: customerId,
            ad_id: adId,
        });
    }
    /**
     * Parse the customer_id from Ad resource.
     *
     * @param {string} adName
     *   A fully-qualified path representing Ad resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdName(adName) {
        return this.pathTemplates.adPathTemplate.match(adName).customer_id;
    }
    /**
     * Parse the ad_id from Ad resource.
     *
     * @param {string} adName
     *   A fully-qualified path representing Ad resource.
     * @returns {string} A string representing the ad_id.
     */
    matchAdIdFromAdName(adName) {
        return this.pathTemplates.adPathTemplate.match(adName).ad_id;
    }
    /**
     * Return a fully-qualified adGroup resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @returns {string} Resource name string.
     */
    adGroupPath(customerId, adGroupId) {
        return this.pathTemplates.adGroupPathTemplate.render({
            customer_id: customerId,
            ad_group_id: adGroupId,
        });
    }
    /**
     * Parse the customer_id from AdGroup resource.
     *
     * @param {string} adGroupName
     *   A fully-qualified path representing AdGroup resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdGroupName(adGroupName) {
        return this.pathTemplates.adGroupPathTemplate.match(adGroupName).customer_id;
    }
    /**
     * Parse the ad_group_id from AdGroup resource.
     *
     * @param {string} adGroupName
     *   A fully-qualified path representing AdGroup resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdGroupName(adGroupName) {
        return this.pathTemplates.adGroupPathTemplate.match(adGroupName).ad_group_id;
    }
    /**
     * Return a fully-qualified adGroupAd resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} ad_id
     * @returns {string} Resource name string.
     */
    adGroupAdPath(customerId, adGroupId, adId) {
        return this.pathTemplates.adGroupAdPathTemplate.render({
            customer_id: customerId,
            ad_group_id: adGroupId,
            ad_id: adId,
        });
    }
    /**
     * Parse the customer_id from AdGroupAd resource.
     *
     * @param {string} adGroupAdName
     *   A fully-qualified path representing AdGroupAd resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdGroupAdName(adGroupAdName) {
        return this.pathTemplates.adGroupAdPathTemplate.match(adGroupAdName).customer_id;
    }
    /**
     * Parse the ad_group_id from AdGroupAd resource.
     *
     * @param {string} adGroupAdName
     *   A fully-qualified path representing AdGroupAd resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdGroupAdName(adGroupAdName) {
        return this.pathTemplates.adGroupAdPathTemplate.match(adGroupAdName).ad_group_id;
    }
    /**
     * Parse the ad_id from AdGroupAd resource.
     *
     * @param {string} adGroupAdName
     *   A fully-qualified path representing AdGroupAd resource.
     * @returns {string} A string representing the ad_id.
     */
    matchAdIdFromAdGroupAdName(adGroupAdName) {
        return this.pathTemplates.adGroupAdPathTemplate.match(adGroupAdName).ad_id;
    }
    /**
     * Return a fully-qualified adGroupAdAssetCombinationView resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} ad_id
     * @param {string} asset_combination_id_low
     * @param {string} asset_combination_id_high
     * @returns {string} Resource name string.
     */
    adGroupAdAssetCombinationViewPath(customerId, adGroupId, adId, assetCombinationIdLow, assetCombinationIdHigh) {
        return this.pathTemplates.adGroupAdAssetCombinationViewPathTemplate.render({
            customer_id: customerId,
            ad_group_id: adGroupId,
            ad_id: adId,
            asset_combination_id_low: assetCombinationIdLow,
            asset_combination_id_high: assetCombinationIdHigh,
        });
    }
    /**
     * Parse the customer_id from AdGroupAdAssetCombinationView resource.
     *
     * @param {string} adGroupAdAssetCombinationViewName
     *   A fully-qualified path representing AdGroupAdAssetCombinationView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdGroupAdAssetCombinationViewName(adGroupAdAssetCombinationViewName) {
        return this.pathTemplates.adGroupAdAssetCombinationViewPathTemplate.match(adGroupAdAssetCombinationViewName).customer_id;
    }
    /**
     * Parse the ad_group_id from AdGroupAdAssetCombinationView resource.
     *
     * @param {string} adGroupAdAssetCombinationViewName
     *   A fully-qualified path representing AdGroupAdAssetCombinationView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdGroupAdAssetCombinationViewName(adGroupAdAssetCombinationViewName) {
        return this.pathTemplates.adGroupAdAssetCombinationViewPathTemplate.match(adGroupAdAssetCombinationViewName).ad_group_id;
    }
    /**
     * Parse the ad_id from AdGroupAdAssetCombinationView resource.
     *
     * @param {string} adGroupAdAssetCombinationViewName
     *   A fully-qualified path representing AdGroupAdAssetCombinationView resource.
     * @returns {string} A string representing the ad_id.
     */
    matchAdIdFromAdGroupAdAssetCombinationViewName(adGroupAdAssetCombinationViewName) {
        return this.pathTemplates.adGroupAdAssetCombinationViewPathTemplate.match(adGroupAdAssetCombinationViewName).ad_id;
    }
    /**
     * Parse the asset_combination_id_low from AdGroupAdAssetCombinationView resource.
     *
     * @param {string} adGroupAdAssetCombinationViewName
     *   A fully-qualified path representing AdGroupAdAssetCombinationView resource.
     * @returns {string} A string representing the asset_combination_id_low.
     */
    matchAssetCombinationIdLowFromAdGroupAdAssetCombinationViewName(adGroupAdAssetCombinationViewName) {
        return this.pathTemplates.adGroupAdAssetCombinationViewPathTemplate.match(adGroupAdAssetCombinationViewName).asset_combination_id_low;
    }
    /**
     * Parse the asset_combination_id_high from AdGroupAdAssetCombinationView resource.
     *
     * @param {string} adGroupAdAssetCombinationViewName
     *   A fully-qualified path representing AdGroupAdAssetCombinationView resource.
     * @returns {string} A string representing the asset_combination_id_high.
     */
    matchAssetCombinationIdHighFromAdGroupAdAssetCombinationViewName(adGroupAdAssetCombinationViewName) {
        return this.pathTemplates.adGroupAdAssetCombinationViewPathTemplate.match(adGroupAdAssetCombinationViewName).asset_combination_id_high;
    }
    /**
     * Return a fully-qualified adGroupAdAssetView resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} ad_id
     * @param {string} asset_id
     * @param {string} field_type
     * @returns {string} Resource name string.
     */
    adGroupAdAssetViewPath(customerId, adGroupId, adId, assetId, fieldType) {
        return this.pathTemplates.adGroupAdAssetViewPathTemplate.render({
            customer_id: customerId,
            ad_group_id: adGroupId,
            ad_id: adId,
            asset_id: assetId,
            field_type: fieldType,
        });
    }
    /**
     * Parse the customer_id from AdGroupAdAssetView resource.
     *
     * @param {string} adGroupAdAssetViewName
     *   A fully-qualified path representing AdGroupAdAssetView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdGroupAdAssetViewName(adGroupAdAssetViewName) {
        return this.pathTemplates.adGroupAdAssetViewPathTemplate.match(adGroupAdAssetViewName).customer_id;
    }
    /**
     * Parse the ad_group_id from AdGroupAdAssetView resource.
     *
     * @param {string} adGroupAdAssetViewName
     *   A fully-qualified path representing AdGroupAdAssetView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdGroupAdAssetViewName(adGroupAdAssetViewName) {
        return this.pathTemplates.adGroupAdAssetViewPathTemplate.match(adGroupAdAssetViewName).ad_group_id;
    }
    /**
     * Parse the ad_id from AdGroupAdAssetView resource.
     *
     * @param {string} adGroupAdAssetViewName
     *   A fully-qualified path representing AdGroupAdAssetView resource.
     * @returns {string} A string representing the ad_id.
     */
    matchAdIdFromAdGroupAdAssetViewName(adGroupAdAssetViewName) {
        return this.pathTemplates.adGroupAdAssetViewPathTemplate.match(adGroupAdAssetViewName).ad_id;
    }
    /**
     * Parse the asset_id from AdGroupAdAssetView resource.
     *
     * @param {string} adGroupAdAssetViewName
     *   A fully-qualified path representing AdGroupAdAssetView resource.
     * @returns {string} A string representing the asset_id.
     */
    matchAssetIdFromAdGroupAdAssetViewName(adGroupAdAssetViewName) {
        return this.pathTemplates.adGroupAdAssetViewPathTemplate.match(adGroupAdAssetViewName).asset_id;
    }
    /**
     * Parse the field_type from AdGroupAdAssetView resource.
     *
     * @param {string} adGroupAdAssetViewName
     *   A fully-qualified path representing AdGroupAdAssetView resource.
     * @returns {string} A string representing the field_type.
     */
    matchFieldTypeFromAdGroupAdAssetViewName(adGroupAdAssetViewName) {
        return this.pathTemplates.adGroupAdAssetViewPathTemplate.match(adGroupAdAssetViewName).field_type;
    }
    /**
     * Return a fully-qualified adGroupAdLabel resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} ad_id
     * @param {string} label_id
     * @returns {string} Resource name string.
     */
    adGroupAdLabelPath(customerId, adGroupId, adId, labelId) {
        return this.pathTemplates.adGroupAdLabelPathTemplate.render({
            customer_id: customerId,
            ad_group_id: adGroupId,
            ad_id: adId,
            label_id: labelId,
        });
    }
    /**
     * Parse the customer_id from AdGroupAdLabel resource.
     *
     * @param {string} adGroupAdLabelName
     *   A fully-qualified path representing AdGroupAdLabel resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdGroupAdLabelName(adGroupAdLabelName) {
        return this.pathTemplates.adGroupAdLabelPathTemplate.match(adGroupAdLabelName).customer_id;
    }
    /**
     * Parse the ad_group_id from AdGroupAdLabel resource.
     *
     * @param {string} adGroupAdLabelName
     *   A fully-qualified path representing AdGroupAdLabel resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdGroupAdLabelName(adGroupAdLabelName) {
        return this.pathTemplates.adGroupAdLabelPathTemplate.match(adGroupAdLabelName).ad_group_id;
    }
    /**
     * Parse the ad_id from AdGroupAdLabel resource.
     *
     * @param {string} adGroupAdLabelName
     *   A fully-qualified path representing AdGroupAdLabel resource.
     * @returns {string} A string representing the ad_id.
     */
    matchAdIdFromAdGroupAdLabelName(adGroupAdLabelName) {
        return this.pathTemplates.adGroupAdLabelPathTemplate.match(adGroupAdLabelName).ad_id;
    }
    /**
     * Parse the label_id from AdGroupAdLabel resource.
     *
     * @param {string} adGroupAdLabelName
     *   A fully-qualified path representing AdGroupAdLabel resource.
     * @returns {string} A string representing the label_id.
     */
    matchLabelIdFromAdGroupAdLabelName(adGroupAdLabelName) {
        return this.pathTemplates.adGroupAdLabelPathTemplate.match(adGroupAdLabelName).label_id;
    }
    /**
     * Return a fully-qualified adGroupAsset resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} asset_id
     * @param {string} field_type
     * @returns {string} Resource name string.
     */
    adGroupAssetPath(customerId, adGroupId, assetId, fieldType) {
        return this.pathTemplates.adGroupAssetPathTemplate.render({
            customer_id: customerId,
            ad_group_id: adGroupId,
            asset_id: assetId,
            field_type: fieldType,
        });
    }
    /**
     * Parse the customer_id from AdGroupAsset resource.
     *
     * @param {string} adGroupAssetName
     *   A fully-qualified path representing AdGroupAsset resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdGroupAssetName(adGroupAssetName) {
        return this.pathTemplates.adGroupAssetPathTemplate.match(adGroupAssetName).customer_id;
    }
    /**
     * Parse the ad_group_id from AdGroupAsset resource.
     *
     * @param {string} adGroupAssetName
     *   A fully-qualified path representing AdGroupAsset resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdGroupAssetName(adGroupAssetName) {
        return this.pathTemplates.adGroupAssetPathTemplate.match(adGroupAssetName).ad_group_id;
    }
    /**
     * Parse the asset_id from AdGroupAsset resource.
     *
     * @param {string} adGroupAssetName
     *   A fully-qualified path representing AdGroupAsset resource.
     * @returns {string} A string representing the asset_id.
     */
    matchAssetIdFromAdGroupAssetName(adGroupAssetName) {
        return this.pathTemplates.adGroupAssetPathTemplate.match(adGroupAssetName).asset_id;
    }
    /**
     * Parse the field_type from AdGroupAsset resource.
     *
     * @param {string} adGroupAssetName
     *   A fully-qualified path representing AdGroupAsset resource.
     * @returns {string} A string representing the field_type.
     */
    matchFieldTypeFromAdGroupAssetName(adGroupAssetName) {
        return this.pathTemplates.adGroupAssetPathTemplate.match(adGroupAssetName).field_type;
    }
    /**
     * Return a fully-qualified adGroupAssetSet resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} asset_set_id
     * @returns {string} Resource name string.
     */
    adGroupAssetSetPath(customerId, adGroupId, assetSetId) {
        return this.pathTemplates.adGroupAssetSetPathTemplate.render({
            customer_id: customerId,
            ad_group_id: adGroupId,
            asset_set_id: assetSetId,
        });
    }
    /**
     * Parse the customer_id from AdGroupAssetSet resource.
     *
     * @param {string} adGroupAssetSetName
     *   A fully-qualified path representing AdGroupAssetSet resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdGroupAssetSetName(adGroupAssetSetName) {
        return this.pathTemplates.adGroupAssetSetPathTemplate.match(adGroupAssetSetName).customer_id;
    }
    /**
     * Parse the ad_group_id from AdGroupAssetSet resource.
     *
     * @param {string} adGroupAssetSetName
     *   A fully-qualified path representing AdGroupAssetSet resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdGroupAssetSetName(adGroupAssetSetName) {
        return this.pathTemplates.adGroupAssetSetPathTemplate.match(adGroupAssetSetName).ad_group_id;
    }
    /**
     * Parse the asset_set_id from AdGroupAssetSet resource.
     *
     * @param {string} adGroupAssetSetName
     *   A fully-qualified path representing AdGroupAssetSet resource.
     * @returns {string} A string representing the asset_set_id.
     */
    matchAssetSetIdFromAdGroupAssetSetName(adGroupAssetSetName) {
        return this.pathTemplates.adGroupAssetSetPathTemplate.match(adGroupAssetSetName).asset_set_id;
    }
    /**
     * Return a fully-qualified adGroupAudienceView resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    adGroupAudienceViewPath(customerId, adGroupId, criterionId) {
        return this.pathTemplates.adGroupAudienceViewPathTemplate.render({
            customer_id: customerId,
            ad_group_id: adGroupId,
            criterion_id: criterionId,
        });
    }
    /**
     * Parse the customer_id from AdGroupAudienceView resource.
     *
     * @param {string} adGroupAudienceViewName
     *   A fully-qualified path representing AdGroupAudienceView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdGroupAudienceViewName(adGroupAudienceViewName) {
        return this.pathTemplates.adGroupAudienceViewPathTemplate.match(adGroupAudienceViewName).customer_id;
    }
    /**
     * Parse the ad_group_id from AdGroupAudienceView resource.
     *
     * @param {string} adGroupAudienceViewName
     *   A fully-qualified path representing AdGroupAudienceView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdGroupAudienceViewName(adGroupAudienceViewName) {
        return this.pathTemplates.adGroupAudienceViewPathTemplate.match(adGroupAudienceViewName).ad_group_id;
    }
    /**
     * Parse the criterion_id from AdGroupAudienceView resource.
     *
     * @param {string} adGroupAudienceViewName
     *   A fully-qualified path representing AdGroupAudienceView resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromAdGroupAudienceViewName(adGroupAudienceViewName) {
        return this.pathTemplates.adGroupAudienceViewPathTemplate.match(adGroupAudienceViewName).criterion_id;
    }
    /**
     * Return a fully-qualified adGroupBidModifier resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    adGroupBidModifierPath(customerId, adGroupId, criterionId) {
        return this.pathTemplates.adGroupBidModifierPathTemplate.render({
            customer_id: customerId,
            ad_group_id: adGroupId,
            criterion_id: criterionId,
        });
    }
    /**
     * Parse the customer_id from AdGroupBidModifier resource.
     *
     * @param {string} adGroupBidModifierName
     *   A fully-qualified path representing AdGroupBidModifier resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdGroupBidModifierName(adGroupBidModifierName) {
        return this.pathTemplates.adGroupBidModifierPathTemplate.match(adGroupBidModifierName).customer_id;
    }
    /**
     * Parse the ad_group_id from AdGroupBidModifier resource.
     *
     * @param {string} adGroupBidModifierName
     *   A fully-qualified path representing AdGroupBidModifier resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdGroupBidModifierName(adGroupBidModifierName) {
        return this.pathTemplates.adGroupBidModifierPathTemplate.match(adGroupBidModifierName).ad_group_id;
    }
    /**
     * Parse the criterion_id from AdGroupBidModifier resource.
     *
     * @param {string} adGroupBidModifierName
     *   A fully-qualified path representing AdGroupBidModifier resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromAdGroupBidModifierName(adGroupBidModifierName) {
        return this.pathTemplates.adGroupBidModifierPathTemplate.match(adGroupBidModifierName).criterion_id;
    }
    /**
     * Return a fully-qualified adGroupCriterion resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    adGroupCriterionPath(customerId, adGroupId, criterionId) {
        return this.pathTemplates.adGroupCriterionPathTemplate.render({
            customer_id: customerId,
            ad_group_id: adGroupId,
            criterion_id: criterionId,
        });
    }
    /**
     * Parse the customer_id from AdGroupCriterion resource.
     *
     * @param {string} adGroupCriterionName
     *   A fully-qualified path representing AdGroupCriterion resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdGroupCriterionName(adGroupCriterionName) {
        return this.pathTemplates.adGroupCriterionPathTemplate.match(adGroupCriterionName).customer_id;
    }
    /**
     * Parse the ad_group_id from AdGroupCriterion resource.
     *
     * @param {string} adGroupCriterionName
     *   A fully-qualified path representing AdGroupCriterion resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdGroupCriterionName(adGroupCriterionName) {
        return this.pathTemplates.adGroupCriterionPathTemplate.match(adGroupCriterionName).ad_group_id;
    }
    /**
     * Parse the criterion_id from AdGroupCriterion resource.
     *
     * @param {string} adGroupCriterionName
     *   A fully-qualified path representing AdGroupCriterion resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromAdGroupCriterionName(adGroupCriterionName) {
        return this.pathTemplates.adGroupCriterionPathTemplate.match(adGroupCriterionName).criterion_id;
    }
    /**
     * Return a fully-qualified adGroupCriterionCustomizer resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} criterion_id
     * @param {string} customizer_attribute_id
     * @returns {string} Resource name string.
     */
    adGroupCriterionCustomizerPath(customerId, adGroupId, criterionId, customizerAttributeId) {
        return this.pathTemplates.adGroupCriterionCustomizerPathTemplate.render({
            customer_id: customerId,
            ad_group_id: adGroupId,
            criterion_id: criterionId,
            customizer_attribute_id: customizerAttributeId,
        });
    }
    /**
     * Parse the customer_id from AdGroupCriterionCustomizer resource.
     *
     * @param {string} adGroupCriterionCustomizerName
     *   A fully-qualified path representing AdGroupCriterionCustomizer resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdGroupCriterionCustomizerName(adGroupCriterionCustomizerName) {
        return this.pathTemplates.adGroupCriterionCustomizerPathTemplate.match(adGroupCriterionCustomizerName).customer_id;
    }
    /**
     * Parse the ad_group_id from AdGroupCriterionCustomizer resource.
     *
     * @param {string} adGroupCriterionCustomizerName
     *   A fully-qualified path representing AdGroupCriterionCustomizer resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdGroupCriterionCustomizerName(adGroupCriterionCustomizerName) {
        return this.pathTemplates.adGroupCriterionCustomizerPathTemplate.match(adGroupCriterionCustomizerName).ad_group_id;
    }
    /**
     * Parse the criterion_id from AdGroupCriterionCustomizer resource.
     *
     * @param {string} adGroupCriterionCustomizerName
     *   A fully-qualified path representing AdGroupCriterionCustomizer resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromAdGroupCriterionCustomizerName(adGroupCriterionCustomizerName) {
        return this.pathTemplates.adGroupCriterionCustomizerPathTemplate.match(adGroupCriterionCustomizerName).criterion_id;
    }
    /**
     * Parse the customizer_attribute_id from AdGroupCriterionCustomizer resource.
     *
     * @param {string} adGroupCriterionCustomizerName
     *   A fully-qualified path representing AdGroupCriterionCustomizer resource.
     * @returns {string} A string representing the customizer_attribute_id.
     */
    matchCustomizerAttributeIdFromAdGroupCriterionCustomizerName(adGroupCriterionCustomizerName) {
        return this.pathTemplates.adGroupCriterionCustomizerPathTemplate.match(adGroupCriterionCustomizerName).customizer_attribute_id;
    }
    /**
     * Return a fully-qualified adGroupCriterionLabel resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} criterion_id
     * @param {string} label_id
     * @returns {string} Resource name string.
     */
    adGroupCriterionLabelPath(customerId, adGroupId, criterionId, labelId) {
        return this.pathTemplates.adGroupCriterionLabelPathTemplate.render({
            customer_id: customerId,
            ad_group_id: adGroupId,
            criterion_id: criterionId,
            label_id: labelId,
        });
    }
    /**
     * Parse the customer_id from AdGroupCriterionLabel resource.
     *
     * @param {string} adGroupCriterionLabelName
     *   A fully-qualified path representing AdGroupCriterionLabel resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdGroupCriterionLabelName(adGroupCriterionLabelName) {
        return this.pathTemplates.adGroupCriterionLabelPathTemplate.match(adGroupCriterionLabelName).customer_id;
    }
    /**
     * Parse the ad_group_id from AdGroupCriterionLabel resource.
     *
     * @param {string} adGroupCriterionLabelName
     *   A fully-qualified path representing AdGroupCriterionLabel resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdGroupCriterionLabelName(adGroupCriterionLabelName) {
        return this.pathTemplates.adGroupCriterionLabelPathTemplate.match(adGroupCriterionLabelName).ad_group_id;
    }
    /**
     * Parse the criterion_id from AdGroupCriterionLabel resource.
     *
     * @param {string} adGroupCriterionLabelName
     *   A fully-qualified path representing AdGroupCriterionLabel resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromAdGroupCriterionLabelName(adGroupCriterionLabelName) {
        return this.pathTemplates.adGroupCriterionLabelPathTemplate.match(adGroupCriterionLabelName).criterion_id;
    }
    /**
     * Parse the label_id from AdGroupCriterionLabel resource.
     *
     * @param {string} adGroupCriterionLabelName
     *   A fully-qualified path representing AdGroupCriterionLabel resource.
     * @returns {string} A string representing the label_id.
     */
    matchLabelIdFromAdGroupCriterionLabelName(adGroupCriterionLabelName) {
        return this.pathTemplates.adGroupCriterionLabelPathTemplate.match(adGroupCriterionLabelName).label_id;
    }
    /**
     * Return a fully-qualified adGroupCriterionSimulation resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} criterion_id
     * @param {string} type
     * @param {string} modification_method
     * @param {string} start_date
     * @param {string} end_date
     * @returns {string} Resource name string.
     */
    adGroupCriterionSimulationPath(customerId, adGroupId, criterionId, type, modificationMethod, startDate, endDate) {
        return this.pathTemplates.adGroupCriterionSimulationPathTemplate.render({
            customer_id: customerId,
            ad_group_id: adGroupId,
            criterion_id: criterionId,
            type: type,
            modification_method: modificationMethod,
            start_date: startDate,
            end_date: endDate,
        });
    }
    /**
     * Parse the customer_id from AdGroupCriterionSimulation resource.
     *
     * @param {string} adGroupCriterionSimulationName
     *   A fully-qualified path representing AdGroupCriterionSimulation resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdGroupCriterionSimulationName(adGroupCriterionSimulationName) {
        return this.pathTemplates.adGroupCriterionSimulationPathTemplate.match(adGroupCriterionSimulationName).customer_id;
    }
    /**
     * Parse the ad_group_id from AdGroupCriterionSimulation resource.
     *
     * @param {string} adGroupCriterionSimulationName
     *   A fully-qualified path representing AdGroupCriterionSimulation resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdGroupCriterionSimulationName(adGroupCriterionSimulationName) {
        return this.pathTemplates.adGroupCriterionSimulationPathTemplate.match(adGroupCriterionSimulationName).ad_group_id;
    }
    /**
     * Parse the criterion_id from AdGroupCriterionSimulation resource.
     *
     * @param {string} adGroupCriterionSimulationName
     *   A fully-qualified path representing AdGroupCriterionSimulation resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromAdGroupCriterionSimulationName(adGroupCriterionSimulationName) {
        return this.pathTemplates.adGroupCriterionSimulationPathTemplate.match(adGroupCriterionSimulationName).criterion_id;
    }
    /**
     * Parse the type from AdGroupCriterionSimulation resource.
     *
     * @param {string} adGroupCriterionSimulationName
     *   A fully-qualified path representing AdGroupCriterionSimulation resource.
     * @returns {string} A string representing the type.
     */
    matchTypeFromAdGroupCriterionSimulationName(adGroupCriterionSimulationName) {
        return this.pathTemplates.adGroupCriterionSimulationPathTemplate.match(adGroupCriterionSimulationName).type;
    }
    /**
     * Parse the modification_method from AdGroupCriterionSimulation resource.
     *
     * @param {string} adGroupCriterionSimulationName
     *   A fully-qualified path representing AdGroupCriterionSimulation resource.
     * @returns {string} A string representing the modification_method.
     */
    matchModificationMethodFromAdGroupCriterionSimulationName(adGroupCriterionSimulationName) {
        return this.pathTemplates.adGroupCriterionSimulationPathTemplate.match(adGroupCriterionSimulationName).modification_method;
    }
    /**
     * Parse the start_date from AdGroupCriterionSimulation resource.
     *
     * @param {string} adGroupCriterionSimulationName
     *   A fully-qualified path representing AdGroupCriterionSimulation resource.
     * @returns {string} A string representing the start_date.
     */
    matchStartDateFromAdGroupCriterionSimulationName(adGroupCriterionSimulationName) {
        return this.pathTemplates.adGroupCriterionSimulationPathTemplate.match(adGroupCriterionSimulationName).start_date;
    }
    /**
     * Parse the end_date from AdGroupCriterionSimulation resource.
     *
     * @param {string} adGroupCriterionSimulationName
     *   A fully-qualified path representing AdGroupCriterionSimulation resource.
     * @returns {string} A string representing the end_date.
     */
    matchEndDateFromAdGroupCriterionSimulationName(adGroupCriterionSimulationName) {
        return this.pathTemplates.adGroupCriterionSimulationPathTemplate.match(adGroupCriterionSimulationName).end_date;
    }
    /**
     * Return a fully-qualified adGroupCustomizer resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} customizer_attribute_id
     * @returns {string} Resource name string.
     */
    adGroupCustomizerPath(customerId, adGroupId, customizerAttributeId) {
        return this.pathTemplates.adGroupCustomizerPathTemplate.render({
            customer_id: customerId,
            ad_group_id: adGroupId,
            customizer_attribute_id: customizerAttributeId,
        });
    }
    /**
     * Parse the customer_id from AdGroupCustomizer resource.
     *
     * @param {string} adGroupCustomizerName
     *   A fully-qualified path representing AdGroupCustomizer resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdGroupCustomizerName(adGroupCustomizerName) {
        return this.pathTemplates.adGroupCustomizerPathTemplate.match(adGroupCustomizerName).customer_id;
    }
    /**
     * Parse the ad_group_id from AdGroupCustomizer resource.
     *
     * @param {string} adGroupCustomizerName
     *   A fully-qualified path representing AdGroupCustomizer resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdGroupCustomizerName(adGroupCustomizerName) {
        return this.pathTemplates.adGroupCustomizerPathTemplate.match(adGroupCustomizerName).ad_group_id;
    }
    /**
     * Parse the customizer_attribute_id from AdGroupCustomizer resource.
     *
     * @param {string} adGroupCustomizerName
     *   A fully-qualified path representing AdGroupCustomizer resource.
     * @returns {string} A string representing the customizer_attribute_id.
     */
    matchCustomizerAttributeIdFromAdGroupCustomizerName(adGroupCustomizerName) {
        return this.pathTemplates.adGroupCustomizerPathTemplate.match(adGroupCustomizerName).customizer_attribute_id;
    }
    /**
     * Return a fully-qualified adGroupExtensionSetting resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} extension_type
     * @returns {string} Resource name string.
     */
    adGroupExtensionSettingPath(customerId, adGroupId, extensionType) {
        return this.pathTemplates.adGroupExtensionSettingPathTemplate.render({
            customer_id: customerId,
            ad_group_id: adGroupId,
            extension_type: extensionType,
        });
    }
    /**
     * Parse the customer_id from AdGroupExtensionSetting resource.
     *
     * @param {string} adGroupExtensionSettingName
     *   A fully-qualified path representing AdGroupExtensionSetting resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdGroupExtensionSettingName(adGroupExtensionSettingName) {
        return this.pathTemplates.adGroupExtensionSettingPathTemplate.match(adGroupExtensionSettingName).customer_id;
    }
    /**
     * Parse the ad_group_id from AdGroupExtensionSetting resource.
     *
     * @param {string} adGroupExtensionSettingName
     *   A fully-qualified path representing AdGroupExtensionSetting resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdGroupExtensionSettingName(adGroupExtensionSettingName) {
        return this.pathTemplates.adGroupExtensionSettingPathTemplate.match(adGroupExtensionSettingName).ad_group_id;
    }
    /**
     * Parse the extension_type from AdGroupExtensionSetting resource.
     *
     * @param {string} adGroupExtensionSettingName
     *   A fully-qualified path representing AdGroupExtensionSetting resource.
     * @returns {string} A string representing the extension_type.
     */
    matchExtensionTypeFromAdGroupExtensionSettingName(adGroupExtensionSettingName) {
        return this.pathTemplates.adGroupExtensionSettingPathTemplate.match(adGroupExtensionSettingName).extension_type;
    }
    /**
     * Return a fully-qualified adGroupFeed resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} feed_id
     * @returns {string} Resource name string.
     */
    adGroupFeedPath(customerId, adGroupId, feedId) {
        return this.pathTemplates.adGroupFeedPathTemplate.render({
            customer_id: customerId,
            ad_group_id: adGroupId,
            feed_id: feedId,
        });
    }
    /**
     * Parse the customer_id from AdGroupFeed resource.
     *
     * @param {string} adGroupFeedName
     *   A fully-qualified path representing AdGroupFeed resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdGroupFeedName(adGroupFeedName) {
        return this.pathTemplates.adGroupFeedPathTemplate.match(adGroupFeedName).customer_id;
    }
    /**
     * Parse the ad_group_id from AdGroupFeed resource.
     *
     * @param {string} adGroupFeedName
     *   A fully-qualified path representing AdGroupFeed resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdGroupFeedName(adGroupFeedName) {
        return this.pathTemplates.adGroupFeedPathTemplate.match(adGroupFeedName).ad_group_id;
    }
    /**
     * Parse the feed_id from AdGroupFeed resource.
     *
     * @param {string} adGroupFeedName
     *   A fully-qualified path representing AdGroupFeed resource.
     * @returns {string} A string representing the feed_id.
     */
    matchFeedIdFromAdGroupFeedName(adGroupFeedName) {
        return this.pathTemplates.adGroupFeedPathTemplate.match(adGroupFeedName).feed_id;
    }
    /**
     * Return a fully-qualified adGroupLabel resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} label_id
     * @returns {string} Resource name string.
     */
    adGroupLabelPath(customerId, adGroupId, labelId) {
        return this.pathTemplates.adGroupLabelPathTemplate.render({
            customer_id: customerId,
            ad_group_id: adGroupId,
            label_id: labelId,
        });
    }
    /**
     * Parse the customer_id from AdGroupLabel resource.
     *
     * @param {string} adGroupLabelName
     *   A fully-qualified path representing AdGroupLabel resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdGroupLabelName(adGroupLabelName) {
        return this.pathTemplates.adGroupLabelPathTemplate.match(adGroupLabelName).customer_id;
    }
    /**
     * Parse the ad_group_id from AdGroupLabel resource.
     *
     * @param {string} adGroupLabelName
     *   A fully-qualified path representing AdGroupLabel resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdGroupLabelName(adGroupLabelName) {
        return this.pathTemplates.adGroupLabelPathTemplate.match(adGroupLabelName).ad_group_id;
    }
    /**
     * Parse the label_id from AdGroupLabel resource.
     *
     * @param {string} adGroupLabelName
     *   A fully-qualified path representing AdGroupLabel resource.
     * @returns {string} A string representing the label_id.
     */
    matchLabelIdFromAdGroupLabelName(adGroupLabelName) {
        return this.pathTemplates.adGroupLabelPathTemplate.match(adGroupLabelName).label_id;
    }
    /**
     * Return a fully-qualified adGroupSimulation resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} type
     * @param {string} modification_method
     * @param {string} start_date
     * @param {string} end_date
     * @returns {string} Resource name string.
     */
    adGroupSimulationPath(customerId, adGroupId, type, modificationMethod, startDate, endDate) {
        return this.pathTemplates.adGroupSimulationPathTemplate.render({
            customer_id: customerId,
            ad_group_id: adGroupId,
            type: type,
            modification_method: modificationMethod,
            start_date: startDate,
            end_date: endDate,
        });
    }
    /**
     * Parse the customer_id from AdGroupSimulation resource.
     *
     * @param {string} adGroupSimulationName
     *   A fully-qualified path representing AdGroupSimulation resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdGroupSimulationName(adGroupSimulationName) {
        return this.pathTemplates.adGroupSimulationPathTemplate.match(adGroupSimulationName).customer_id;
    }
    /**
     * Parse the ad_group_id from AdGroupSimulation resource.
     *
     * @param {string} adGroupSimulationName
     *   A fully-qualified path representing AdGroupSimulation resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdGroupSimulationName(adGroupSimulationName) {
        return this.pathTemplates.adGroupSimulationPathTemplate.match(adGroupSimulationName).ad_group_id;
    }
    /**
     * Parse the type from AdGroupSimulation resource.
     *
     * @param {string} adGroupSimulationName
     *   A fully-qualified path representing AdGroupSimulation resource.
     * @returns {string} A string representing the type.
     */
    matchTypeFromAdGroupSimulationName(adGroupSimulationName) {
        return this.pathTemplates.adGroupSimulationPathTemplate.match(adGroupSimulationName).type;
    }
    /**
     * Parse the modification_method from AdGroupSimulation resource.
     *
     * @param {string} adGroupSimulationName
     *   A fully-qualified path representing AdGroupSimulation resource.
     * @returns {string} A string representing the modification_method.
     */
    matchModificationMethodFromAdGroupSimulationName(adGroupSimulationName) {
        return this.pathTemplates.adGroupSimulationPathTemplate.match(adGroupSimulationName).modification_method;
    }
    /**
     * Parse the start_date from AdGroupSimulation resource.
     *
     * @param {string} adGroupSimulationName
     *   A fully-qualified path representing AdGroupSimulation resource.
     * @returns {string} A string representing the start_date.
     */
    matchStartDateFromAdGroupSimulationName(adGroupSimulationName) {
        return this.pathTemplates.adGroupSimulationPathTemplate.match(adGroupSimulationName).start_date;
    }
    /**
     * Parse the end_date from AdGroupSimulation resource.
     *
     * @param {string} adGroupSimulationName
     *   A fully-qualified path representing AdGroupSimulation resource.
     * @returns {string} A string representing the end_date.
     */
    matchEndDateFromAdGroupSimulationName(adGroupSimulationName) {
        return this.pathTemplates.adGroupSimulationPathTemplate.match(adGroupSimulationName).end_date;
    }
    /**
     * Return a fully-qualified adParameter resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} criterion_id
     * @param {string} parameter_index
     * @returns {string} Resource name string.
     */
    adParameterPath(customerId, adGroupId, criterionId, parameterIndex) {
        return this.pathTemplates.adParameterPathTemplate.render({
            customer_id: customerId,
            ad_group_id: adGroupId,
            criterion_id: criterionId,
            parameter_index: parameterIndex,
        });
    }
    /**
     * Parse the customer_id from AdParameter resource.
     *
     * @param {string} adParameterName
     *   A fully-qualified path representing AdParameter resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdParameterName(adParameterName) {
        return this.pathTemplates.adParameterPathTemplate.match(adParameterName).customer_id;
    }
    /**
     * Parse the ad_group_id from AdParameter resource.
     *
     * @param {string} adParameterName
     *   A fully-qualified path representing AdParameter resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAdParameterName(adParameterName) {
        return this.pathTemplates.adParameterPathTemplate.match(adParameterName).ad_group_id;
    }
    /**
     * Parse the criterion_id from AdParameter resource.
     *
     * @param {string} adParameterName
     *   A fully-qualified path representing AdParameter resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromAdParameterName(adParameterName) {
        return this.pathTemplates.adParameterPathTemplate.match(adParameterName).criterion_id;
    }
    /**
     * Parse the parameter_index from AdParameter resource.
     *
     * @param {string} adParameterName
     *   A fully-qualified path representing AdParameter resource.
     * @returns {string} A string representing the parameter_index.
     */
    matchParameterIndexFromAdParameterName(adParameterName) {
        return this.pathTemplates.adParameterPathTemplate.match(adParameterName).parameter_index;
    }
    /**
     * Return a fully-qualified adScheduleView resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    adScheduleViewPath(customerId, campaignId, criterionId) {
        return this.pathTemplates.adScheduleViewPathTemplate.render({
            customer_id: customerId,
            campaign_id: campaignId,
            criterion_id: criterionId,
        });
    }
    /**
     * Parse the customer_id from AdScheduleView resource.
     *
     * @param {string} adScheduleViewName
     *   A fully-qualified path representing AdScheduleView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAdScheduleViewName(adScheduleViewName) {
        return this.pathTemplates.adScheduleViewPathTemplate.match(adScheduleViewName).customer_id;
    }
    /**
     * Parse the campaign_id from AdScheduleView resource.
     *
     * @param {string} adScheduleViewName
     *   A fully-qualified path representing AdScheduleView resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromAdScheduleViewName(adScheduleViewName) {
        return this.pathTemplates.adScheduleViewPathTemplate.match(adScheduleViewName).campaign_id;
    }
    /**
     * Parse the criterion_id from AdScheduleView resource.
     *
     * @param {string} adScheduleViewName
     *   A fully-qualified path representing AdScheduleView resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromAdScheduleViewName(adScheduleViewName) {
        return this.pathTemplates.adScheduleViewPathTemplate.match(adScheduleViewName).criterion_id;
    }
    /**
     * Return a fully-qualified ageRangeView resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    ageRangeViewPath(customerId, adGroupId, criterionId) {
        return this.pathTemplates.ageRangeViewPathTemplate.render({
            customer_id: customerId,
            ad_group_id: adGroupId,
            criterion_id: criterionId,
        });
    }
    /**
     * Parse the customer_id from AgeRangeView resource.
     *
     * @param {string} ageRangeViewName
     *   A fully-qualified path representing AgeRangeView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAgeRangeViewName(ageRangeViewName) {
        return this.pathTemplates.ageRangeViewPathTemplate.match(ageRangeViewName).customer_id;
    }
    /**
     * Parse the ad_group_id from AgeRangeView resource.
     *
     * @param {string} ageRangeViewName
     *   A fully-qualified path representing AgeRangeView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromAgeRangeViewName(ageRangeViewName) {
        return this.pathTemplates.ageRangeViewPathTemplate.match(ageRangeViewName).ad_group_id;
    }
    /**
     * Parse the criterion_id from AgeRangeView resource.
     *
     * @param {string} ageRangeViewName
     *   A fully-qualified path representing AgeRangeView resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromAgeRangeViewName(ageRangeViewName) {
        return this.pathTemplates.ageRangeViewPathTemplate.match(ageRangeViewName).criterion_id;
    }
    /**
     * Return a fully-qualified asset resource name string.
     *
     * @param {string} customer_id
     * @param {string} asset_id
     * @returns {string} Resource name string.
     */
    assetPath(customerId, assetId) {
        return this.pathTemplates.assetPathTemplate.render({
            customer_id: customerId,
            asset_id: assetId,
        });
    }
    /**
     * Parse the customer_id from Asset resource.
     *
     * @param {string} assetName
     *   A fully-qualified path representing Asset resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAssetName(assetName) {
        return this.pathTemplates.assetPathTemplate.match(assetName).customer_id;
    }
    /**
     * Parse the asset_id from Asset resource.
     *
     * @param {string} assetName
     *   A fully-qualified path representing Asset resource.
     * @returns {string} A string representing the asset_id.
     */
    matchAssetIdFromAssetName(assetName) {
        return this.pathTemplates.assetPathTemplate.match(assetName).asset_id;
    }
    /**
     * Return a fully-qualified assetFieldTypeView resource name string.
     *
     * @param {string} customer_id
     * @param {string} field_type
     * @returns {string} Resource name string.
     */
    assetFieldTypeViewPath(customerId, fieldType) {
        return this.pathTemplates.assetFieldTypeViewPathTemplate.render({
            customer_id: customerId,
            field_type: fieldType,
        });
    }
    /**
     * Parse the customer_id from AssetFieldTypeView resource.
     *
     * @param {string} assetFieldTypeViewName
     *   A fully-qualified path representing AssetFieldTypeView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAssetFieldTypeViewName(assetFieldTypeViewName) {
        return this.pathTemplates.assetFieldTypeViewPathTemplate.match(assetFieldTypeViewName).customer_id;
    }
    /**
     * Parse the field_type from AssetFieldTypeView resource.
     *
     * @param {string} assetFieldTypeViewName
     *   A fully-qualified path representing AssetFieldTypeView resource.
     * @returns {string} A string representing the field_type.
     */
    matchFieldTypeFromAssetFieldTypeViewName(assetFieldTypeViewName) {
        return this.pathTemplates.assetFieldTypeViewPathTemplate.match(assetFieldTypeViewName).field_type;
    }
    /**
     * Return a fully-qualified assetGroup resource name string.
     *
     * @param {string} customer_id
     * @param {string} asset_group_id
     * @returns {string} Resource name string.
     */
    assetGroupPath(customerId, assetGroupId) {
        return this.pathTemplates.assetGroupPathTemplate.render({
            customer_id: customerId,
            asset_group_id: assetGroupId,
        });
    }
    /**
     * Parse the customer_id from AssetGroup resource.
     *
     * @param {string} assetGroupName
     *   A fully-qualified path representing AssetGroup resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAssetGroupName(assetGroupName) {
        return this.pathTemplates.assetGroupPathTemplate.match(assetGroupName).customer_id;
    }
    /**
     * Parse the asset_group_id from AssetGroup resource.
     *
     * @param {string} assetGroupName
     *   A fully-qualified path representing AssetGroup resource.
     * @returns {string} A string representing the asset_group_id.
     */
    matchAssetGroupIdFromAssetGroupName(assetGroupName) {
        return this.pathTemplates.assetGroupPathTemplate.match(assetGroupName).asset_group_id;
    }
    /**
     * Return a fully-qualified assetGroupAsset resource name string.
     *
     * @param {string} customer_id
     * @param {string} asset_group_id
     * @param {string} asset_id
     * @param {string} field_type
     * @returns {string} Resource name string.
     */
    assetGroupAssetPath(customerId, assetGroupId, assetId, fieldType) {
        return this.pathTemplates.assetGroupAssetPathTemplate.render({
            customer_id: customerId,
            asset_group_id: assetGroupId,
            asset_id: assetId,
            field_type: fieldType,
        });
    }
    /**
     * Parse the customer_id from AssetGroupAsset resource.
     *
     * @param {string} assetGroupAssetName
     *   A fully-qualified path representing AssetGroupAsset resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAssetGroupAssetName(assetGroupAssetName) {
        return this.pathTemplates.assetGroupAssetPathTemplate.match(assetGroupAssetName).customer_id;
    }
    /**
     * Parse the asset_group_id from AssetGroupAsset resource.
     *
     * @param {string} assetGroupAssetName
     *   A fully-qualified path representing AssetGroupAsset resource.
     * @returns {string} A string representing the asset_group_id.
     */
    matchAssetGroupIdFromAssetGroupAssetName(assetGroupAssetName) {
        return this.pathTemplates.assetGroupAssetPathTemplate.match(assetGroupAssetName).asset_group_id;
    }
    /**
     * Parse the asset_id from AssetGroupAsset resource.
     *
     * @param {string} assetGroupAssetName
     *   A fully-qualified path representing AssetGroupAsset resource.
     * @returns {string} A string representing the asset_id.
     */
    matchAssetIdFromAssetGroupAssetName(assetGroupAssetName) {
        return this.pathTemplates.assetGroupAssetPathTemplate.match(assetGroupAssetName).asset_id;
    }
    /**
     * Parse the field_type from AssetGroupAsset resource.
     *
     * @param {string} assetGroupAssetName
     *   A fully-qualified path representing AssetGroupAsset resource.
     * @returns {string} A string representing the field_type.
     */
    matchFieldTypeFromAssetGroupAssetName(assetGroupAssetName) {
        return this.pathTemplates.assetGroupAssetPathTemplate.match(assetGroupAssetName).field_type;
    }
    /**
     * Return a fully-qualified assetGroupListingGroupFilter resource name string.
     *
     * @param {string} customer_id
     * @param {string} asset_group_id
     * @param {string} listing_group_filter_id
     * @returns {string} Resource name string.
     */
    assetGroupListingGroupFilterPath(customerId, assetGroupId, listingGroupFilterId) {
        return this.pathTemplates.assetGroupListingGroupFilterPathTemplate.render({
            customer_id: customerId,
            asset_group_id: assetGroupId,
            listing_group_filter_id: listingGroupFilterId,
        });
    }
    /**
     * Parse the customer_id from AssetGroupListingGroupFilter resource.
     *
     * @param {string} assetGroupListingGroupFilterName
     *   A fully-qualified path representing AssetGroupListingGroupFilter resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAssetGroupListingGroupFilterName(assetGroupListingGroupFilterName) {
        return this.pathTemplates.assetGroupListingGroupFilterPathTemplate.match(assetGroupListingGroupFilterName).customer_id;
    }
    /**
     * Parse the asset_group_id from AssetGroupListingGroupFilter resource.
     *
     * @param {string} assetGroupListingGroupFilterName
     *   A fully-qualified path representing AssetGroupListingGroupFilter resource.
     * @returns {string} A string representing the asset_group_id.
     */
    matchAssetGroupIdFromAssetGroupListingGroupFilterName(assetGroupListingGroupFilterName) {
        return this.pathTemplates.assetGroupListingGroupFilterPathTemplate.match(assetGroupListingGroupFilterName).asset_group_id;
    }
    /**
     * Parse the listing_group_filter_id from AssetGroupListingGroupFilter resource.
     *
     * @param {string} assetGroupListingGroupFilterName
     *   A fully-qualified path representing AssetGroupListingGroupFilter resource.
     * @returns {string} A string representing the listing_group_filter_id.
     */
    matchListingGroupFilterIdFromAssetGroupListingGroupFilterName(assetGroupListingGroupFilterName) {
        return this.pathTemplates.assetGroupListingGroupFilterPathTemplate.match(assetGroupListingGroupFilterName).listing_group_filter_id;
    }
    /**
     * Return a fully-qualified assetGroupProductGroupView resource name string.
     *
     * @param {string} customer_id
     * @param {string} asset_group_id
     * @param {string} listing_group_filter_id
     * @returns {string} Resource name string.
     */
    assetGroupProductGroupViewPath(customerId, assetGroupId, listingGroupFilterId) {
        return this.pathTemplates.assetGroupProductGroupViewPathTemplate.render({
            customer_id: customerId,
            asset_group_id: assetGroupId,
            listing_group_filter_id: listingGroupFilterId,
        });
    }
    /**
     * Parse the customer_id from AssetGroupProductGroupView resource.
     *
     * @param {string} assetGroupProductGroupViewName
     *   A fully-qualified path representing AssetGroupProductGroupView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAssetGroupProductGroupViewName(assetGroupProductGroupViewName) {
        return this.pathTemplates.assetGroupProductGroupViewPathTemplate.match(assetGroupProductGroupViewName).customer_id;
    }
    /**
     * Parse the asset_group_id from AssetGroupProductGroupView resource.
     *
     * @param {string} assetGroupProductGroupViewName
     *   A fully-qualified path representing AssetGroupProductGroupView resource.
     * @returns {string} A string representing the asset_group_id.
     */
    matchAssetGroupIdFromAssetGroupProductGroupViewName(assetGroupProductGroupViewName) {
        return this.pathTemplates.assetGroupProductGroupViewPathTemplate.match(assetGroupProductGroupViewName).asset_group_id;
    }
    /**
     * Parse the listing_group_filter_id from AssetGroupProductGroupView resource.
     *
     * @param {string} assetGroupProductGroupViewName
     *   A fully-qualified path representing AssetGroupProductGroupView resource.
     * @returns {string} A string representing the listing_group_filter_id.
     */
    matchListingGroupFilterIdFromAssetGroupProductGroupViewName(assetGroupProductGroupViewName) {
        return this.pathTemplates.assetGroupProductGroupViewPathTemplate.match(assetGroupProductGroupViewName).listing_group_filter_id;
    }
    /**
     * Return a fully-qualified assetGroupSignal resource name string.
     *
     * @param {string} customer_id
     * @param {string} asset_group_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    assetGroupSignalPath(customerId, assetGroupId, criterionId) {
        return this.pathTemplates.assetGroupSignalPathTemplate.render({
            customer_id: customerId,
            asset_group_id: assetGroupId,
            criterion_id: criterionId,
        });
    }
    /**
     * Parse the customer_id from AssetGroupSignal resource.
     *
     * @param {string} assetGroupSignalName
     *   A fully-qualified path representing AssetGroupSignal resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAssetGroupSignalName(assetGroupSignalName) {
        return this.pathTemplates.assetGroupSignalPathTemplate.match(assetGroupSignalName).customer_id;
    }
    /**
     * Parse the asset_group_id from AssetGroupSignal resource.
     *
     * @param {string} assetGroupSignalName
     *   A fully-qualified path representing AssetGroupSignal resource.
     * @returns {string} A string representing the asset_group_id.
     */
    matchAssetGroupIdFromAssetGroupSignalName(assetGroupSignalName) {
        return this.pathTemplates.assetGroupSignalPathTemplate.match(assetGroupSignalName).asset_group_id;
    }
    /**
     * Parse the criterion_id from AssetGroupSignal resource.
     *
     * @param {string} assetGroupSignalName
     *   A fully-qualified path representing AssetGroupSignal resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromAssetGroupSignalName(assetGroupSignalName) {
        return this.pathTemplates.assetGroupSignalPathTemplate.match(assetGroupSignalName).criterion_id;
    }
    /**
     * Return a fully-qualified assetSet resource name string.
     *
     * @param {string} customer_id
     * @param {string} asset_set_id
     * @returns {string} Resource name string.
     */
    assetSetPath(customerId, assetSetId) {
        return this.pathTemplates.assetSetPathTemplate.render({
            customer_id: customerId,
            asset_set_id: assetSetId,
        });
    }
    /**
     * Parse the customer_id from AssetSet resource.
     *
     * @param {string} assetSetName
     *   A fully-qualified path representing AssetSet resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAssetSetName(assetSetName) {
        return this.pathTemplates.assetSetPathTemplate.match(assetSetName).customer_id;
    }
    /**
     * Parse the asset_set_id from AssetSet resource.
     *
     * @param {string} assetSetName
     *   A fully-qualified path representing AssetSet resource.
     * @returns {string} A string representing the asset_set_id.
     */
    matchAssetSetIdFromAssetSetName(assetSetName) {
        return this.pathTemplates.assetSetPathTemplate.match(assetSetName).asset_set_id;
    }
    /**
     * Return a fully-qualified assetSetAsset resource name string.
     *
     * @param {string} customer_id
     * @param {string} asset_set_id
     * @param {string} asset_id
     * @returns {string} Resource name string.
     */
    assetSetAssetPath(customerId, assetSetId, assetId) {
        return this.pathTemplates.assetSetAssetPathTemplate.render({
            customer_id: customerId,
            asset_set_id: assetSetId,
            asset_id: assetId,
        });
    }
    /**
     * Parse the customer_id from AssetSetAsset resource.
     *
     * @param {string} assetSetAssetName
     *   A fully-qualified path representing AssetSetAsset resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAssetSetAssetName(assetSetAssetName) {
        return this.pathTemplates.assetSetAssetPathTemplate.match(assetSetAssetName).customer_id;
    }
    /**
     * Parse the asset_set_id from AssetSetAsset resource.
     *
     * @param {string} assetSetAssetName
     *   A fully-qualified path representing AssetSetAsset resource.
     * @returns {string} A string representing the asset_set_id.
     */
    matchAssetSetIdFromAssetSetAssetName(assetSetAssetName) {
        return this.pathTemplates.assetSetAssetPathTemplate.match(assetSetAssetName).asset_set_id;
    }
    /**
     * Parse the asset_id from AssetSetAsset resource.
     *
     * @param {string} assetSetAssetName
     *   A fully-qualified path representing AssetSetAsset resource.
     * @returns {string} A string representing the asset_id.
     */
    matchAssetIdFromAssetSetAssetName(assetSetAssetName) {
        return this.pathTemplates.assetSetAssetPathTemplate.match(assetSetAssetName).asset_id;
    }
    /**
     * Return a fully-qualified assetSetTypeView resource name string.
     *
     * @param {string} customer_id
     * @param {string} asset_set_type
     * @returns {string} Resource name string.
     */
    assetSetTypeViewPath(customerId, assetSetType) {
        return this.pathTemplates.assetSetTypeViewPathTemplate.render({
            customer_id: customerId,
            asset_set_type: assetSetType,
        });
    }
    /**
     * Parse the customer_id from AssetSetTypeView resource.
     *
     * @param {string} assetSetTypeViewName
     *   A fully-qualified path representing AssetSetTypeView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAssetSetTypeViewName(assetSetTypeViewName) {
        return this.pathTemplates.assetSetTypeViewPathTemplate.match(assetSetTypeViewName).customer_id;
    }
    /**
     * Parse the asset_set_type from AssetSetTypeView resource.
     *
     * @param {string} assetSetTypeViewName
     *   A fully-qualified path representing AssetSetTypeView resource.
     * @returns {string} A string representing the asset_set_type.
     */
    matchAssetSetTypeFromAssetSetTypeViewName(assetSetTypeViewName) {
        return this.pathTemplates.assetSetTypeViewPathTemplate.match(assetSetTypeViewName).asset_set_type;
    }
    /**
     * Return a fully-qualified audience resource name string.
     *
     * @param {string} customer_id
     * @param {string} audience_id
     * @returns {string} Resource name string.
     */
    audiencePath(customerId, audienceId) {
        return this.pathTemplates.audiencePathTemplate.render({
            customer_id: customerId,
            audience_id: audienceId,
        });
    }
    /**
     * Parse the customer_id from Audience resource.
     *
     * @param {string} audienceName
     *   A fully-qualified path representing Audience resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromAudienceName(audienceName) {
        return this.pathTemplates.audiencePathTemplate.match(audienceName).customer_id;
    }
    /**
     * Parse the audience_id from Audience resource.
     *
     * @param {string} audienceName
     *   A fully-qualified path representing Audience resource.
     * @returns {string} A string representing the audience_id.
     */
    matchAudienceIdFromAudienceName(audienceName) {
        return this.pathTemplates.audiencePathTemplate.match(audienceName).audience_id;
    }
    /**
     * Return a fully-qualified batchJob resource name string.
     *
     * @param {string} customer_id
     * @param {string} batch_job_id
     * @returns {string} Resource name string.
     */
    batchJobPath(customerId, batchJobId) {
        return this.pathTemplates.batchJobPathTemplate.render({
            customer_id: customerId,
            batch_job_id: batchJobId,
        });
    }
    /**
     * Parse the customer_id from BatchJob resource.
     *
     * @param {string} batchJobName
     *   A fully-qualified path representing BatchJob resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromBatchJobName(batchJobName) {
        return this.pathTemplates.batchJobPathTemplate.match(batchJobName).customer_id;
    }
    /**
     * Parse the batch_job_id from BatchJob resource.
     *
     * @param {string} batchJobName
     *   A fully-qualified path representing BatchJob resource.
     * @returns {string} A string representing the batch_job_id.
     */
    matchBatchJobIdFromBatchJobName(batchJobName) {
        return this.pathTemplates.batchJobPathTemplate.match(batchJobName).batch_job_id;
    }
    /**
     * Return a fully-qualified biddingDataExclusion resource name string.
     *
     * @param {string} customer_id
     * @param {string} seasonality_event_id
     * @returns {string} Resource name string.
     */
    biddingDataExclusionPath(customerId, seasonalityEventId) {
        return this.pathTemplates.biddingDataExclusionPathTemplate.render({
            customer_id: customerId,
            seasonality_event_id: seasonalityEventId,
        });
    }
    /**
     * Parse the customer_id from BiddingDataExclusion resource.
     *
     * @param {string} biddingDataExclusionName
     *   A fully-qualified path representing BiddingDataExclusion resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromBiddingDataExclusionName(biddingDataExclusionName) {
        return this.pathTemplates.biddingDataExclusionPathTemplate.match(biddingDataExclusionName).customer_id;
    }
    /**
     * Parse the seasonality_event_id from BiddingDataExclusion resource.
     *
     * @param {string} biddingDataExclusionName
     *   A fully-qualified path representing BiddingDataExclusion resource.
     * @returns {string} A string representing the seasonality_event_id.
     */
    matchSeasonalityEventIdFromBiddingDataExclusionName(biddingDataExclusionName) {
        return this.pathTemplates.biddingDataExclusionPathTemplate.match(biddingDataExclusionName).seasonality_event_id;
    }
    /**
     * Return a fully-qualified biddingSeasonalityAdjustment resource name string.
     *
     * @param {string} customer_id
     * @param {string} seasonality_event_id
     * @returns {string} Resource name string.
     */
    biddingSeasonalityAdjustmentPath(customerId, seasonalityEventId) {
        return this.pathTemplates.biddingSeasonalityAdjustmentPathTemplate.render({
            customer_id: customerId,
            seasonality_event_id: seasonalityEventId,
        });
    }
    /**
     * Parse the customer_id from BiddingSeasonalityAdjustment resource.
     *
     * @param {string} biddingSeasonalityAdjustmentName
     *   A fully-qualified path representing BiddingSeasonalityAdjustment resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromBiddingSeasonalityAdjustmentName(biddingSeasonalityAdjustmentName) {
        return this.pathTemplates.biddingSeasonalityAdjustmentPathTemplate.match(biddingSeasonalityAdjustmentName).customer_id;
    }
    /**
     * Parse the seasonality_event_id from BiddingSeasonalityAdjustment resource.
     *
     * @param {string} biddingSeasonalityAdjustmentName
     *   A fully-qualified path representing BiddingSeasonalityAdjustment resource.
     * @returns {string} A string representing the seasonality_event_id.
     */
    matchSeasonalityEventIdFromBiddingSeasonalityAdjustmentName(biddingSeasonalityAdjustmentName) {
        return this.pathTemplates.biddingSeasonalityAdjustmentPathTemplate.match(biddingSeasonalityAdjustmentName).seasonality_event_id;
    }
    /**
     * Return a fully-qualified biddingStrategy resource name string.
     *
     * @param {string} customer_id
     * @param {string} bidding_strategy_id
     * @returns {string} Resource name string.
     */
    biddingStrategyPath(customerId, biddingStrategyId) {
        return this.pathTemplates.biddingStrategyPathTemplate.render({
            customer_id: customerId,
            bidding_strategy_id: biddingStrategyId,
        });
    }
    /**
     * Parse the customer_id from BiddingStrategy resource.
     *
     * @param {string} biddingStrategyName
     *   A fully-qualified path representing BiddingStrategy resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromBiddingStrategyName(biddingStrategyName) {
        return this.pathTemplates.biddingStrategyPathTemplate.match(biddingStrategyName).customer_id;
    }
    /**
     * Parse the bidding_strategy_id from BiddingStrategy resource.
     *
     * @param {string} biddingStrategyName
     *   A fully-qualified path representing BiddingStrategy resource.
     * @returns {string} A string representing the bidding_strategy_id.
     */
    matchBiddingStrategyIdFromBiddingStrategyName(biddingStrategyName) {
        return this.pathTemplates.biddingStrategyPathTemplate.match(biddingStrategyName).bidding_strategy_id;
    }
    /**
     * Return a fully-qualified biddingStrategySimulation resource name string.
     *
     * @param {string} customer_id
     * @param {string} bidding_strategy_id
     * @param {string} type
     * @param {string} modification_method
     * @param {string} start_date
     * @param {string} end_date
     * @returns {string} Resource name string.
     */
    biddingStrategySimulationPath(customerId, biddingStrategyId, type, modificationMethod, startDate, endDate) {
        return this.pathTemplates.biddingStrategySimulationPathTemplate.render({
            customer_id: customerId,
            bidding_strategy_id: biddingStrategyId,
            type: type,
            modification_method: modificationMethod,
            start_date: startDate,
            end_date: endDate,
        });
    }
    /**
     * Parse the customer_id from BiddingStrategySimulation resource.
     *
     * @param {string} biddingStrategySimulationName
     *   A fully-qualified path representing BiddingStrategySimulation resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromBiddingStrategySimulationName(biddingStrategySimulationName) {
        return this.pathTemplates.biddingStrategySimulationPathTemplate.match(biddingStrategySimulationName).customer_id;
    }
    /**
     * Parse the bidding_strategy_id from BiddingStrategySimulation resource.
     *
     * @param {string} biddingStrategySimulationName
     *   A fully-qualified path representing BiddingStrategySimulation resource.
     * @returns {string} A string representing the bidding_strategy_id.
     */
    matchBiddingStrategyIdFromBiddingStrategySimulationName(biddingStrategySimulationName) {
        return this.pathTemplates.biddingStrategySimulationPathTemplate.match(biddingStrategySimulationName).bidding_strategy_id;
    }
    /**
     * Parse the type from BiddingStrategySimulation resource.
     *
     * @param {string} biddingStrategySimulationName
     *   A fully-qualified path representing BiddingStrategySimulation resource.
     * @returns {string} A string representing the type.
     */
    matchTypeFromBiddingStrategySimulationName(biddingStrategySimulationName) {
        return this.pathTemplates.biddingStrategySimulationPathTemplate.match(biddingStrategySimulationName).type;
    }
    /**
     * Parse the modification_method from BiddingStrategySimulation resource.
     *
     * @param {string} biddingStrategySimulationName
     *   A fully-qualified path representing BiddingStrategySimulation resource.
     * @returns {string} A string representing the modification_method.
     */
    matchModificationMethodFromBiddingStrategySimulationName(biddingStrategySimulationName) {
        return this.pathTemplates.biddingStrategySimulationPathTemplate.match(biddingStrategySimulationName).modification_method;
    }
    /**
     * Parse the start_date from BiddingStrategySimulation resource.
     *
     * @param {string} biddingStrategySimulationName
     *   A fully-qualified path representing BiddingStrategySimulation resource.
     * @returns {string} A string representing the start_date.
     */
    matchStartDateFromBiddingStrategySimulationName(biddingStrategySimulationName) {
        return this.pathTemplates.biddingStrategySimulationPathTemplate.match(biddingStrategySimulationName).start_date;
    }
    /**
     * Parse the end_date from BiddingStrategySimulation resource.
     *
     * @param {string} biddingStrategySimulationName
     *   A fully-qualified path representing BiddingStrategySimulation resource.
     * @returns {string} A string representing the end_date.
     */
    matchEndDateFromBiddingStrategySimulationName(biddingStrategySimulationName) {
        return this.pathTemplates.biddingStrategySimulationPathTemplate.match(biddingStrategySimulationName).end_date;
    }
    /**
     * Return a fully-qualified billingSetup resource name string.
     *
     * @param {string} customer_id
     * @param {string} billing_setup_id
     * @returns {string} Resource name string.
     */
    billingSetupPath(customerId, billingSetupId) {
        return this.pathTemplates.billingSetupPathTemplate.render({
            customer_id: customerId,
            billing_setup_id: billingSetupId,
        });
    }
    /**
     * Parse the customer_id from BillingSetup resource.
     *
     * @param {string} billingSetupName
     *   A fully-qualified path representing BillingSetup resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromBillingSetupName(billingSetupName) {
        return this.pathTemplates.billingSetupPathTemplate.match(billingSetupName).customer_id;
    }
    /**
     * Parse the billing_setup_id from BillingSetup resource.
     *
     * @param {string} billingSetupName
     *   A fully-qualified path representing BillingSetup resource.
     * @returns {string} A string representing the billing_setup_id.
     */
    matchBillingSetupIdFromBillingSetupName(billingSetupName) {
        return this.pathTemplates.billingSetupPathTemplate.match(billingSetupName).billing_setup_id;
    }
    /**
     * Return a fully-qualified callView resource name string.
     *
     * @param {string} customer_id
     * @param {string} call_detail_id
     * @returns {string} Resource name string.
     */
    callViewPath(customerId, callDetailId) {
        return this.pathTemplates.callViewPathTemplate.render({
            customer_id: customerId,
            call_detail_id: callDetailId,
        });
    }
    /**
     * Parse the customer_id from CallView resource.
     *
     * @param {string} callViewName
     *   A fully-qualified path representing CallView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCallViewName(callViewName) {
        return this.pathTemplates.callViewPathTemplate.match(callViewName).customer_id;
    }
    /**
     * Parse the call_detail_id from CallView resource.
     *
     * @param {string} callViewName
     *   A fully-qualified path representing CallView resource.
     * @returns {string} A string representing the call_detail_id.
     */
    matchCallDetailIdFromCallViewName(callViewName) {
        return this.pathTemplates.callViewPathTemplate.match(callViewName).call_detail_id;
    }
    /**
     * Return a fully-qualified campaign resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @returns {string} Resource name string.
     */
    campaignPath(customerId, campaignId) {
        return this.pathTemplates.campaignPathTemplate.render({
            customer_id: customerId,
            campaign_id: campaignId,
        });
    }
    /**
     * Parse the customer_id from Campaign resource.
     *
     * @param {string} campaignName
     *   A fully-qualified path representing Campaign resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCampaignName(campaignName) {
        return this.pathTemplates.campaignPathTemplate.match(campaignName).customer_id;
    }
    /**
     * Parse the campaign_id from Campaign resource.
     *
     * @param {string} campaignName
     *   A fully-qualified path representing Campaign resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromCampaignName(campaignName) {
        return this.pathTemplates.campaignPathTemplate.match(campaignName).campaign_id;
    }
    /**
     * Return a fully-qualified campaignAsset resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} asset_id
     * @param {string} field_type
     * @returns {string} Resource name string.
     */
    campaignAssetPath(customerId, campaignId, assetId, fieldType) {
        return this.pathTemplates.campaignAssetPathTemplate.render({
            customer_id: customerId,
            campaign_id: campaignId,
            asset_id: assetId,
            field_type: fieldType,
        });
    }
    /**
     * Parse the customer_id from CampaignAsset resource.
     *
     * @param {string} campaignAssetName
     *   A fully-qualified path representing CampaignAsset resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCampaignAssetName(campaignAssetName) {
        return this.pathTemplates.campaignAssetPathTemplate.match(campaignAssetName).customer_id;
    }
    /**
     * Parse the campaign_id from CampaignAsset resource.
     *
     * @param {string} campaignAssetName
     *   A fully-qualified path representing CampaignAsset resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromCampaignAssetName(campaignAssetName) {
        return this.pathTemplates.campaignAssetPathTemplate.match(campaignAssetName).campaign_id;
    }
    /**
     * Parse the asset_id from CampaignAsset resource.
     *
     * @param {string} campaignAssetName
     *   A fully-qualified path representing CampaignAsset resource.
     * @returns {string} A string representing the asset_id.
     */
    matchAssetIdFromCampaignAssetName(campaignAssetName) {
        return this.pathTemplates.campaignAssetPathTemplate.match(campaignAssetName).asset_id;
    }
    /**
     * Parse the field_type from CampaignAsset resource.
     *
     * @param {string} campaignAssetName
     *   A fully-qualified path representing CampaignAsset resource.
     * @returns {string} A string representing the field_type.
     */
    matchFieldTypeFromCampaignAssetName(campaignAssetName) {
        return this.pathTemplates.campaignAssetPathTemplate.match(campaignAssetName).field_type;
    }
    /**
     * Return a fully-qualified campaignAssetSet resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} asset_set_id
     * @returns {string} Resource name string.
     */
    campaignAssetSetPath(customerId, campaignId, assetSetId) {
        return this.pathTemplates.campaignAssetSetPathTemplate.render({
            customer_id: customerId,
            campaign_id: campaignId,
            asset_set_id: assetSetId,
        });
    }
    /**
     * Parse the customer_id from CampaignAssetSet resource.
     *
     * @param {string} campaignAssetSetName
     *   A fully-qualified path representing CampaignAssetSet resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCampaignAssetSetName(campaignAssetSetName) {
        return this.pathTemplates.campaignAssetSetPathTemplate.match(campaignAssetSetName).customer_id;
    }
    /**
     * Parse the campaign_id from CampaignAssetSet resource.
     *
     * @param {string} campaignAssetSetName
     *   A fully-qualified path representing CampaignAssetSet resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromCampaignAssetSetName(campaignAssetSetName) {
        return this.pathTemplates.campaignAssetSetPathTemplate.match(campaignAssetSetName).campaign_id;
    }
    /**
     * Parse the asset_set_id from CampaignAssetSet resource.
     *
     * @param {string} campaignAssetSetName
     *   A fully-qualified path representing CampaignAssetSet resource.
     * @returns {string} A string representing the asset_set_id.
     */
    matchAssetSetIdFromCampaignAssetSetName(campaignAssetSetName) {
        return this.pathTemplates.campaignAssetSetPathTemplate.match(campaignAssetSetName).asset_set_id;
    }
    /**
     * Return a fully-qualified campaignAudienceView resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    campaignAudienceViewPath(customerId, campaignId, criterionId) {
        return this.pathTemplates.campaignAudienceViewPathTemplate.render({
            customer_id: customerId,
            campaign_id: campaignId,
            criterion_id: criterionId,
        });
    }
    /**
     * Parse the customer_id from CampaignAudienceView resource.
     *
     * @param {string} campaignAudienceViewName
     *   A fully-qualified path representing CampaignAudienceView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCampaignAudienceViewName(campaignAudienceViewName) {
        return this.pathTemplates.campaignAudienceViewPathTemplate.match(campaignAudienceViewName).customer_id;
    }
    /**
     * Parse the campaign_id from CampaignAudienceView resource.
     *
     * @param {string} campaignAudienceViewName
     *   A fully-qualified path representing CampaignAudienceView resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromCampaignAudienceViewName(campaignAudienceViewName) {
        return this.pathTemplates.campaignAudienceViewPathTemplate.match(campaignAudienceViewName).campaign_id;
    }
    /**
     * Parse the criterion_id from CampaignAudienceView resource.
     *
     * @param {string} campaignAudienceViewName
     *   A fully-qualified path representing CampaignAudienceView resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromCampaignAudienceViewName(campaignAudienceViewName) {
        return this.pathTemplates.campaignAudienceViewPathTemplate.match(campaignAudienceViewName).criterion_id;
    }
    /**
     * Return a fully-qualified campaignBidModifier resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    campaignBidModifierPath(customerId, campaignId, criterionId) {
        return this.pathTemplates.campaignBidModifierPathTemplate.render({
            customer_id: customerId,
            campaign_id: campaignId,
            criterion_id: criterionId,
        });
    }
    /**
     * Parse the customer_id from CampaignBidModifier resource.
     *
     * @param {string} campaignBidModifierName
     *   A fully-qualified path representing CampaignBidModifier resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCampaignBidModifierName(campaignBidModifierName) {
        return this.pathTemplates.campaignBidModifierPathTemplate.match(campaignBidModifierName).customer_id;
    }
    /**
     * Parse the campaign_id from CampaignBidModifier resource.
     *
     * @param {string} campaignBidModifierName
     *   A fully-qualified path representing CampaignBidModifier resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromCampaignBidModifierName(campaignBidModifierName) {
        return this.pathTemplates.campaignBidModifierPathTemplate.match(campaignBidModifierName).campaign_id;
    }
    /**
     * Parse the criterion_id from CampaignBidModifier resource.
     *
     * @param {string} campaignBidModifierName
     *   A fully-qualified path representing CampaignBidModifier resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromCampaignBidModifierName(campaignBidModifierName) {
        return this.pathTemplates.campaignBidModifierPathTemplate.match(campaignBidModifierName).criterion_id;
    }
    /**
     * Return a fully-qualified campaignBudget resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_budget_id
     * @returns {string} Resource name string.
     */
    campaignBudgetPath(customerId, campaignBudgetId) {
        return this.pathTemplates.campaignBudgetPathTemplate.render({
            customer_id: customerId,
            campaign_budget_id: campaignBudgetId,
        });
    }
    /**
     * Parse the customer_id from CampaignBudget resource.
     *
     * @param {string} campaignBudgetName
     *   A fully-qualified path representing CampaignBudget resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCampaignBudgetName(campaignBudgetName) {
        return this.pathTemplates.campaignBudgetPathTemplate.match(campaignBudgetName).customer_id;
    }
    /**
     * Parse the campaign_budget_id from CampaignBudget resource.
     *
     * @param {string} campaignBudgetName
     *   A fully-qualified path representing CampaignBudget resource.
     * @returns {string} A string representing the campaign_budget_id.
     */
    matchCampaignBudgetIdFromCampaignBudgetName(campaignBudgetName) {
        return this.pathTemplates.campaignBudgetPathTemplate.match(campaignBudgetName).campaign_budget_id;
    }
    /**
     * Return a fully-qualified campaignConversionGoal resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} category
     * @param {string} source
     * @returns {string} Resource name string.
     */
    campaignConversionGoalPath(customerId, campaignId, category, source) {
        return this.pathTemplates.campaignConversionGoalPathTemplate.render({
            customer_id: customerId,
            campaign_id: campaignId,
            category: category,
            source: source,
        });
    }
    /**
     * Parse the customer_id from CampaignConversionGoal resource.
     *
     * @param {string} campaignConversionGoalName
     *   A fully-qualified path representing CampaignConversionGoal resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCampaignConversionGoalName(campaignConversionGoalName) {
        return this.pathTemplates.campaignConversionGoalPathTemplate.match(campaignConversionGoalName).customer_id;
    }
    /**
     * Parse the campaign_id from CampaignConversionGoal resource.
     *
     * @param {string} campaignConversionGoalName
     *   A fully-qualified path representing CampaignConversionGoal resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromCampaignConversionGoalName(campaignConversionGoalName) {
        return this.pathTemplates.campaignConversionGoalPathTemplate.match(campaignConversionGoalName).campaign_id;
    }
    /**
     * Parse the category from CampaignConversionGoal resource.
     *
     * @param {string} campaignConversionGoalName
     *   A fully-qualified path representing CampaignConversionGoal resource.
     * @returns {string} A string representing the category.
     */
    matchCategoryFromCampaignConversionGoalName(campaignConversionGoalName) {
        return this.pathTemplates.campaignConversionGoalPathTemplate.match(campaignConversionGoalName).category;
    }
    /**
     * Parse the source from CampaignConversionGoal resource.
     *
     * @param {string} campaignConversionGoalName
     *   A fully-qualified path representing CampaignConversionGoal resource.
     * @returns {string} A string representing the source.
     */
    matchSourceFromCampaignConversionGoalName(campaignConversionGoalName) {
        return this.pathTemplates.campaignConversionGoalPathTemplate.match(campaignConversionGoalName).source;
    }
    /**
     * Return a fully-qualified campaignCriterion resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    campaignCriterionPath(customerId, campaignId, criterionId) {
        return this.pathTemplates.campaignCriterionPathTemplate.render({
            customer_id: customerId,
            campaign_id: campaignId,
            criterion_id: criterionId,
        });
    }
    /**
     * Parse the customer_id from CampaignCriterion resource.
     *
     * @param {string} campaignCriterionName
     *   A fully-qualified path representing CampaignCriterion resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCampaignCriterionName(campaignCriterionName) {
        return this.pathTemplates.campaignCriterionPathTemplate.match(campaignCriterionName).customer_id;
    }
    /**
     * Parse the campaign_id from CampaignCriterion resource.
     *
     * @param {string} campaignCriterionName
     *   A fully-qualified path representing CampaignCriterion resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromCampaignCriterionName(campaignCriterionName) {
        return this.pathTemplates.campaignCriterionPathTemplate.match(campaignCriterionName).campaign_id;
    }
    /**
     * Parse the criterion_id from CampaignCriterion resource.
     *
     * @param {string} campaignCriterionName
     *   A fully-qualified path representing CampaignCriterion resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromCampaignCriterionName(campaignCriterionName) {
        return this.pathTemplates.campaignCriterionPathTemplate.match(campaignCriterionName).criterion_id;
    }
    /**
     * Return a fully-qualified campaignCustomizer resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} customizer_attribute_id
     * @returns {string} Resource name string.
     */
    campaignCustomizerPath(customerId, campaignId, customizerAttributeId) {
        return this.pathTemplates.campaignCustomizerPathTemplate.render({
            customer_id: customerId,
            campaign_id: campaignId,
            customizer_attribute_id: customizerAttributeId,
        });
    }
    /**
     * Parse the customer_id from CampaignCustomizer resource.
     *
     * @param {string} campaignCustomizerName
     *   A fully-qualified path representing CampaignCustomizer resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCampaignCustomizerName(campaignCustomizerName) {
        return this.pathTemplates.campaignCustomizerPathTemplate.match(campaignCustomizerName).customer_id;
    }
    /**
     * Parse the campaign_id from CampaignCustomizer resource.
     *
     * @param {string} campaignCustomizerName
     *   A fully-qualified path representing CampaignCustomizer resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromCampaignCustomizerName(campaignCustomizerName) {
        return this.pathTemplates.campaignCustomizerPathTemplate.match(campaignCustomizerName).campaign_id;
    }
    /**
     * Parse the customizer_attribute_id from CampaignCustomizer resource.
     *
     * @param {string} campaignCustomizerName
     *   A fully-qualified path representing CampaignCustomizer resource.
     * @returns {string} A string representing the customizer_attribute_id.
     */
    matchCustomizerAttributeIdFromCampaignCustomizerName(campaignCustomizerName) {
        return this.pathTemplates.campaignCustomizerPathTemplate.match(campaignCustomizerName).customizer_attribute_id;
    }
    /**
     * Return a fully-qualified campaignDraft resource name string.
     *
     * @param {string} customer_id
     * @param {string} base_campaign_id
     * @param {string} draft_id
     * @returns {string} Resource name string.
     */
    campaignDraftPath(customerId, baseCampaignId, draftId) {
        return this.pathTemplates.campaignDraftPathTemplate.render({
            customer_id: customerId,
            base_campaign_id: baseCampaignId,
            draft_id: draftId,
        });
    }
    /**
     * Parse the customer_id from CampaignDraft resource.
     *
     * @param {string} campaignDraftName
     *   A fully-qualified path representing CampaignDraft resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCampaignDraftName(campaignDraftName) {
        return this.pathTemplates.campaignDraftPathTemplate.match(campaignDraftName).customer_id;
    }
    /**
     * Parse the base_campaign_id from CampaignDraft resource.
     *
     * @param {string} campaignDraftName
     *   A fully-qualified path representing CampaignDraft resource.
     * @returns {string} A string representing the base_campaign_id.
     */
    matchBaseCampaignIdFromCampaignDraftName(campaignDraftName) {
        return this.pathTemplates.campaignDraftPathTemplate.match(campaignDraftName).base_campaign_id;
    }
    /**
     * Parse the draft_id from CampaignDraft resource.
     *
     * @param {string} campaignDraftName
     *   A fully-qualified path representing CampaignDraft resource.
     * @returns {string} A string representing the draft_id.
     */
    matchDraftIdFromCampaignDraftName(campaignDraftName) {
        return this.pathTemplates.campaignDraftPathTemplate.match(campaignDraftName).draft_id;
    }
    /**
     * Return a fully-qualified campaignExtensionSetting resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} extension_type
     * @returns {string} Resource name string.
     */
    campaignExtensionSettingPath(customerId, campaignId, extensionType) {
        return this.pathTemplates.campaignExtensionSettingPathTemplate.render({
            customer_id: customerId,
            campaign_id: campaignId,
            extension_type: extensionType,
        });
    }
    /**
     * Parse the customer_id from CampaignExtensionSetting resource.
     *
     * @param {string} campaignExtensionSettingName
     *   A fully-qualified path representing CampaignExtensionSetting resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCampaignExtensionSettingName(campaignExtensionSettingName) {
        return this.pathTemplates.campaignExtensionSettingPathTemplate.match(campaignExtensionSettingName).customer_id;
    }
    /**
     * Parse the campaign_id from CampaignExtensionSetting resource.
     *
     * @param {string} campaignExtensionSettingName
     *   A fully-qualified path representing CampaignExtensionSetting resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromCampaignExtensionSettingName(campaignExtensionSettingName) {
        return this.pathTemplates.campaignExtensionSettingPathTemplate.match(campaignExtensionSettingName).campaign_id;
    }
    /**
     * Parse the extension_type from CampaignExtensionSetting resource.
     *
     * @param {string} campaignExtensionSettingName
     *   A fully-qualified path representing CampaignExtensionSetting resource.
     * @returns {string} A string representing the extension_type.
     */
    matchExtensionTypeFromCampaignExtensionSettingName(campaignExtensionSettingName) {
        return this.pathTemplates.campaignExtensionSettingPathTemplate.match(campaignExtensionSettingName).extension_type;
    }
    /**
     * Return a fully-qualified campaignFeed resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} feed_id
     * @returns {string} Resource name string.
     */
    campaignFeedPath(customerId, campaignId, feedId) {
        return this.pathTemplates.campaignFeedPathTemplate.render({
            customer_id: customerId,
            campaign_id: campaignId,
            feed_id: feedId,
        });
    }
    /**
     * Parse the customer_id from CampaignFeed resource.
     *
     * @param {string} campaignFeedName
     *   A fully-qualified path representing CampaignFeed resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCampaignFeedName(campaignFeedName) {
        return this.pathTemplates.campaignFeedPathTemplate.match(campaignFeedName).customer_id;
    }
    /**
     * Parse the campaign_id from CampaignFeed resource.
     *
     * @param {string} campaignFeedName
     *   A fully-qualified path representing CampaignFeed resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromCampaignFeedName(campaignFeedName) {
        return this.pathTemplates.campaignFeedPathTemplate.match(campaignFeedName).campaign_id;
    }
    /**
     * Parse the feed_id from CampaignFeed resource.
     *
     * @param {string} campaignFeedName
     *   A fully-qualified path representing CampaignFeed resource.
     * @returns {string} A string representing the feed_id.
     */
    matchFeedIdFromCampaignFeedName(campaignFeedName) {
        return this.pathTemplates.campaignFeedPathTemplate.match(campaignFeedName).feed_id;
    }
    /**
     * Return a fully-qualified campaignGroup resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_group_id
     * @returns {string} Resource name string.
     */
    campaignGroupPath(customerId, campaignGroupId) {
        return this.pathTemplates.campaignGroupPathTemplate.render({
            customer_id: customerId,
            campaign_group_id: campaignGroupId,
        });
    }
    /**
     * Parse the customer_id from CampaignGroup resource.
     *
     * @param {string} campaignGroupName
     *   A fully-qualified path representing CampaignGroup resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCampaignGroupName(campaignGroupName) {
        return this.pathTemplates.campaignGroupPathTemplate.match(campaignGroupName).customer_id;
    }
    /**
     * Parse the campaign_group_id from CampaignGroup resource.
     *
     * @param {string} campaignGroupName
     *   A fully-qualified path representing CampaignGroup resource.
     * @returns {string} A string representing the campaign_group_id.
     */
    matchCampaignGroupIdFromCampaignGroupName(campaignGroupName) {
        return this.pathTemplates.campaignGroupPathTemplate.match(campaignGroupName).campaign_group_id;
    }
    /**
     * Return a fully-qualified campaignLabel resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} label_id
     * @returns {string} Resource name string.
     */
    campaignLabelPath(customerId, campaignId, labelId) {
        return this.pathTemplates.campaignLabelPathTemplate.render({
            customer_id: customerId,
            campaign_id: campaignId,
            label_id: labelId,
        });
    }
    /**
     * Parse the customer_id from CampaignLabel resource.
     *
     * @param {string} campaignLabelName
     *   A fully-qualified path representing CampaignLabel resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCampaignLabelName(campaignLabelName) {
        return this.pathTemplates.campaignLabelPathTemplate.match(campaignLabelName).customer_id;
    }
    /**
     * Parse the campaign_id from CampaignLabel resource.
     *
     * @param {string} campaignLabelName
     *   A fully-qualified path representing CampaignLabel resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromCampaignLabelName(campaignLabelName) {
        return this.pathTemplates.campaignLabelPathTemplate.match(campaignLabelName).campaign_id;
    }
    /**
     * Parse the label_id from CampaignLabel resource.
     *
     * @param {string} campaignLabelName
     *   A fully-qualified path representing CampaignLabel resource.
     * @returns {string} A string representing the label_id.
     */
    matchLabelIdFromCampaignLabelName(campaignLabelName) {
        return this.pathTemplates.campaignLabelPathTemplate.match(campaignLabelName).label_id;
    }
    /**
     * Return a fully-qualified campaignSearchTermInsight resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} cluster_id
     * @returns {string} Resource name string.
     */
    campaignSearchTermInsightPath(customerId, campaignId, clusterId) {
        return this.pathTemplates.campaignSearchTermInsightPathTemplate.render({
            customer_id: customerId,
            campaign_id: campaignId,
            cluster_id: clusterId,
        });
    }
    /**
     * Parse the customer_id from CampaignSearchTermInsight resource.
     *
     * @param {string} campaignSearchTermInsightName
     *   A fully-qualified path representing CampaignSearchTermInsight resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCampaignSearchTermInsightName(campaignSearchTermInsightName) {
        return this.pathTemplates.campaignSearchTermInsightPathTemplate.match(campaignSearchTermInsightName).customer_id;
    }
    /**
     * Parse the campaign_id from CampaignSearchTermInsight resource.
     *
     * @param {string} campaignSearchTermInsightName
     *   A fully-qualified path representing CampaignSearchTermInsight resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromCampaignSearchTermInsightName(campaignSearchTermInsightName) {
        return this.pathTemplates.campaignSearchTermInsightPathTemplate.match(campaignSearchTermInsightName).campaign_id;
    }
    /**
     * Parse the cluster_id from CampaignSearchTermInsight resource.
     *
     * @param {string} campaignSearchTermInsightName
     *   A fully-qualified path representing CampaignSearchTermInsight resource.
     * @returns {string} A string representing the cluster_id.
     */
    matchClusterIdFromCampaignSearchTermInsightName(campaignSearchTermInsightName) {
        return this.pathTemplates.campaignSearchTermInsightPathTemplate.match(campaignSearchTermInsightName).cluster_id;
    }
    /**
     * Return a fully-qualified campaignSharedSet resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} shared_set_id
     * @returns {string} Resource name string.
     */
    campaignSharedSetPath(customerId, campaignId, sharedSetId) {
        return this.pathTemplates.campaignSharedSetPathTemplate.render({
            customer_id: customerId,
            campaign_id: campaignId,
            shared_set_id: sharedSetId,
        });
    }
    /**
     * Parse the customer_id from CampaignSharedSet resource.
     *
     * @param {string} campaignSharedSetName
     *   A fully-qualified path representing CampaignSharedSet resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCampaignSharedSetName(campaignSharedSetName) {
        return this.pathTemplates.campaignSharedSetPathTemplate.match(campaignSharedSetName).customer_id;
    }
    /**
     * Parse the campaign_id from CampaignSharedSet resource.
     *
     * @param {string} campaignSharedSetName
     *   A fully-qualified path representing CampaignSharedSet resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromCampaignSharedSetName(campaignSharedSetName) {
        return this.pathTemplates.campaignSharedSetPathTemplate.match(campaignSharedSetName).campaign_id;
    }
    /**
     * Parse the shared_set_id from CampaignSharedSet resource.
     *
     * @param {string} campaignSharedSetName
     *   A fully-qualified path representing CampaignSharedSet resource.
     * @returns {string} A string representing the shared_set_id.
     */
    matchSharedSetIdFromCampaignSharedSetName(campaignSharedSetName) {
        return this.pathTemplates.campaignSharedSetPathTemplate.match(campaignSharedSetName).shared_set_id;
    }
    /**
     * Return a fully-qualified campaignSimulation resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} type
     * @param {string} modification_method
     * @param {string} start_date
     * @param {string} end_date
     * @returns {string} Resource name string.
     */
    campaignSimulationPath(customerId, campaignId, type, modificationMethod, startDate, endDate) {
        return this.pathTemplates.campaignSimulationPathTemplate.render({
            customer_id: customerId,
            campaign_id: campaignId,
            type: type,
            modification_method: modificationMethod,
            start_date: startDate,
            end_date: endDate,
        });
    }
    /**
     * Parse the customer_id from CampaignSimulation resource.
     *
     * @param {string} campaignSimulationName
     *   A fully-qualified path representing CampaignSimulation resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCampaignSimulationName(campaignSimulationName) {
        return this.pathTemplates.campaignSimulationPathTemplate.match(campaignSimulationName).customer_id;
    }
    /**
     * Parse the campaign_id from CampaignSimulation resource.
     *
     * @param {string} campaignSimulationName
     *   A fully-qualified path representing CampaignSimulation resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromCampaignSimulationName(campaignSimulationName) {
        return this.pathTemplates.campaignSimulationPathTemplate.match(campaignSimulationName).campaign_id;
    }
    /**
     * Parse the type from CampaignSimulation resource.
     *
     * @param {string} campaignSimulationName
     *   A fully-qualified path representing CampaignSimulation resource.
     * @returns {string} A string representing the type.
     */
    matchTypeFromCampaignSimulationName(campaignSimulationName) {
        return this.pathTemplates.campaignSimulationPathTemplate.match(campaignSimulationName).type;
    }
    /**
     * Parse the modification_method from CampaignSimulation resource.
     *
     * @param {string} campaignSimulationName
     *   A fully-qualified path representing CampaignSimulation resource.
     * @returns {string} A string representing the modification_method.
     */
    matchModificationMethodFromCampaignSimulationName(campaignSimulationName) {
        return this.pathTemplates.campaignSimulationPathTemplate.match(campaignSimulationName).modification_method;
    }
    /**
     * Parse the start_date from CampaignSimulation resource.
     *
     * @param {string} campaignSimulationName
     *   A fully-qualified path representing CampaignSimulation resource.
     * @returns {string} A string representing the start_date.
     */
    matchStartDateFromCampaignSimulationName(campaignSimulationName) {
        return this.pathTemplates.campaignSimulationPathTemplate.match(campaignSimulationName).start_date;
    }
    /**
     * Parse the end_date from CampaignSimulation resource.
     *
     * @param {string} campaignSimulationName
     *   A fully-qualified path representing CampaignSimulation resource.
     * @returns {string} A string representing the end_date.
     */
    matchEndDateFromCampaignSimulationName(campaignSimulationName) {
        return this.pathTemplates.campaignSimulationPathTemplate.match(campaignSimulationName).end_date;
    }
    /**
     * Return a fully-qualified carrierConstant resource name string.
     *
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    carrierConstantPath(criterionId) {
        return this.pathTemplates.carrierConstantPathTemplate.render({
            criterion_id: criterionId,
        });
    }
    /**
     * Parse the criterion_id from CarrierConstant resource.
     *
     * @param {string} carrierConstantName
     *   A fully-qualified path representing CarrierConstant resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromCarrierConstantName(carrierConstantName) {
        return this.pathTemplates.carrierConstantPathTemplate.match(carrierConstantName).criterion_id;
    }
    /**
     * Return a fully-qualified changeEvent resource name string.
     *
     * @param {string} customer_id
     * @param {string} timestamp_micros
     * @param {string} command_index
     * @param {string} mutate_index
     * @returns {string} Resource name string.
     */
    changeEventPath(customerId, timestampMicros, commandIndex, mutateIndex) {
        return this.pathTemplates.changeEventPathTemplate.render({
            customer_id: customerId,
            timestamp_micros: timestampMicros,
            command_index: commandIndex,
            mutate_index: mutateIndex,
        });
    }
    /**
     * Parse the customer_id from ChangeEvent resource.
     *
     * @param {string} changeEventName
     *   A fully-qualified path representing ChangeEvent resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromChangeEventName(changeEventName) {
        return this.pathTemplates.changeEventPathTemplate.match(changeEventName).customer_id;
    }
    /**
     * Parse the timestamp_micros from ChangeEvent resource.
     *
     * @param {string} changeEventName
     *   A fully-qualified path representing ChangeEvent resource.
     * @returns {string} A string representing the timestamp_micros.
     */
    matchTimestampMicrosFromChangeEventName(changeEventName) {
        return this.pathTemplates.changeEventPathTemplate.match(changeEventName).timestamp_micros;
    }
    /**
     * Parse the command_index from ChangeEvent resource.
     *
     * @param {string} changeEventName
     *   A fully-qualified path representing ChangeEvent resource.
     * @returns {string} A string representing the command_index.
     */
    matchCommandIndexFromChangeEventName(changeEventName) {
        return this.pathTemplates.changeEventPathTemplate.match(changeEventName).command_index;
    }
    /**
     * Parse the mutate_index from ChangeEvent resource.
     *
     * @param {string} changeEventName
     *   A fully-qualified path representing ChangeEvent resource.
     * @returns {string} A string representing the mutate_index.
     */
    matchMutateIndexFromChangeEventName(changeEventName) {
        return this.pathTemplates.changeEventPathTemplate.match(changeEventName).mutate_index;
    }
    /**
     * Return a fully-qualified changeStatus resource name string.
     *
     * @param {string} customer_id
     * @param {string} change_status_id
     * @returns {string} Resource name string.
     */
    changeStatusPath(customerId, changeStatusId) {
        return this.pathTemplates.changeStatusPathTemplate.render({
            customer_id: customerId,
            change_status_id: changeStatusId,
        });
    }
    /**
     * Parse the customer_id from ChangeStatus resource.
     *
     * @param {string} changeStatusName
     *   A fully-qualified path representing ChangeStatus resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromChangeStatusName(changeStatusName) {
        return this.pathTemplates.changeStatusPathTemplate.match(changeStatusName).customer_id;
    }
    /**
     * Parse the change_status_id from ChangeStatus resource.
     *
     * @param {string} changeStatusName
     *   A fully-qualified path representing ChangeStatus resource.
     * @returns {string} A string representing the change_status_id.
     */
    matchChangeStatusIdFromChangeStatusName(changeStatusName) {
        return this.pathTemplates.changeStatusPathTemplate.match(changeStatusName).change_status_id;
    }
    /**
     * Return a fully-qualified clickView resource name string.
     *
     * @param {string} customer_id
     * @param {string} date
     * @param {string} gclid
     * @returns {string} Resource name string.
     */
    clickViewPath(customerId, date, gclid) {
        return this.pathTemplates.clickViewPathTemplate.render({
            customer_id: customerId,
            date: date,
            gclid: gclid,
        });
    }
    /**
     * Parse the customer_id from ClickView resource.
     *
     * @param {string} clickViewName
     *   A fully-qualified path representing ClickView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromClickViewName(clickViewName) {
        return this.pathTemplates.clickViewPathTemplate.match(clickViewName).customer_id;
    }
    /**
     * Parse the date from ClickView resource.
     *
     * @param {string} clickViewName
     *   A fully-qualified path representing ClickView resource.
     * @returns {string} A string representing the date.
     */
    matchDateFromClickViewName(clickViewName) {
        return this.pathTemplates.clickViewPathTemplate.match(clickViewName).date;
    }
    /**
     * Parse the gclid from ClickView resource.
     *
     * @param {string} clickViewName
     *   A fully-qualified path representing ClickView resource.
     * @returns {string} A string representing the gclid.
     */
    matchGclidFromClickViewName(clickViewName) {
        return this.pathTemplates.clickViewPathTemplate.match(clickViewName).gclid;
    }
    /**
     * Return a fully-qualified combinedAudience resource name string.
     *
     * @param {string} customer_id
     * @param {string} combined_audience_id
     * @returns {string} Resource name string.
     */
    combinedAudiencePath(customerId, combinedAudienceId) {
        return this.pathTemplates.combinedAudiencePathTemplate.render({
            customer_id: customerId,
            combined_audience_id: combinedAudienceId,
        });
    }
    /**
     * Parse the customer_id from CombinedAudience resource.
     *
     * @param {string} combinedAudienceName
     *   A fully-qualified path representing CombinedAudience resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCombinedAudienceName(combinedAudienceName) {
        return this.pathTemplates.combinedAudiencePathTemplate.match(combinedAudienceName).customer_id;
    }
    /**
     * Parse the combined_audience_id from CombinedAudience resource.
     *
     * @param {string} combinedAudienceName
     *   A fully-qualified path representing CombinedAudience resource.
     * @returns {string} A string representing the combined_audience_id.
     */
    matchCombinedAudienceIdFromCombinedAudienceName(combinedAudienceName) {
        return this.pathTemplates.combinedAudiencePathTemplate.match(combinedAudienceName).combined_audience_id;
    }
    /**
     * Return a fully-qualified conversionAction resource name string.
     *
     * @param {string} customer_id
     * @param {string} conversion_action_id
     * @returns {string} Resource name string.
     */
    conversionActionPath(customerId, conversionActionId) {
        return this.pathTemplates.conversionActionPathTemplate.render({
            customer_id: customerId,
            conversion_action_id: conversionActionId,
        });
    }
    /**
     * Parse the customer_id from ConversionAction resource.
     *
     * @param {string} conversionActionName
     *   A fully-qualified path representing ConversionAction resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromConversionActionName(conversionActionName) {
        return this.pathTemplates.conversionActionPathTemplate.match(conversionActionName).customer_id;
    }
    /**
     * Parse the conversion_action_id from ConversionAction resource.
     *
     * @param {string} conversionActionName
     *   A fully-qualified path representing ConversionAction resource.
     * @returns {string} A string representing the conversion_action_id.
     */
    matchConversionActionIdFromConversionActionName(conversionActionName) {
        return this.pathTemplates.conversionActionPathTemplate.match(conversionActionName).conversion_action_id;
    }
    /**
     * Return a fully-qualified conversionCustomVariable resource name string.
     *
     * @param {string} customer_id
     * @param {string} conversion_custom_variable_id
     * @returns {string} Resource name string.
     */
    conversionCustomVariablePath(customerId, conversionCustomVariableId) {
        return this.pathTemplates.conversionCustomVariablePathTemplate.render({
            customer_id: customerId,
            conversion_custom_variable_id: conversionCustomVariableId,
        });
    }
    /**
     * Parse the customer_id from ConversionCustomVariable resource.
     *
     * @param {string} conversionCustomVariableName
     *   A fully-qualified path representing ConversionCustomVariable resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromConversionCustomVariableName(conversionCustomVariableName) {
        return this.pathTemplates.conversionCustomVariablePathTemplate.match(conversionCustomVariableName).customer_id;
    }
    /**
     * Parse the conversion_custom_variable_id from ConversionCustomVariable resource.
     *
     * @param {string} conversionCustomVariableName
     *   A fully-qualified path representing ConversionCustomVariable resource.
     * @returns {string} A string representing the conversion_custom_variable_id.
     */
    matchConversionCustomVariableIdFromConversionCustomVariableName(conversionCustomVariableName) {
        return this.pathTemplates.conversionCustomVariablePathTemplate.match(conversionCustomVariableName).conversion_custom_variable_id;
    }
    /**
     * Return a fully-qualified conversionGoalCampaignConfig resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @returns {string} Resource name string.
     */
    conversionGoalCampaignConfigPath(customerId, campaignId) {
        return this.pathTemplates.conversionGoalCampaignConfigPathTemplate.render({
            customer_id: customerId,
            campaign_id: campaignId,
        });
    }
    /**
     * Parse the customer_id from ConversionGoalCampaignConfig resource.
     *
     * @param {string} conversionGoalCampaignConfigName
     *   A fully-qualified path representing ConversionGoalCampaignConfig resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromConversionGoalCampaignConfigName(conversionGoalCampaignConfigName) {
        return this.pathTemplates.conversionGoalCampaignConfigPathTemplate.match(conversionGoalCampaignConfigName).customer_id;
    }
    /**
     * Parse the campaign_id from ConversionGoalCampaignConfig resource.
     *
     * @param {string} conversionGoalCampaignConfigName
     *   A fully-qualified path representing ConversionGoalCampaignConfig resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromConversionGoalCampaignConfigName(conversionGoalCampaignConfigName) {
        return this.pathTemplates.conversionGoalCampaignConfigPathTemplate.match(conversionGoalCampaignConfigName).campaign_id;
    }
    /**
     * Return a fully-qualified conversionValueRule resource name string.
     *
     * @param {string} customer_id
     * @param {string} conversion_value_rule_id
     * @returns {string} Resource name string.
     */
    conversionValueRulePath(customerId, conversionValueRuleId) {
        return this.pathTemplates.conversionValueRulePathTemplate.render({
            customer_id: customerId,
            conversion_value_rule_id: conversionValueRuleId,
        });
    }
    /**
     * Parse the customer_id from ConversionValueRule resource.
     *
     * @param {string} conversionValueRuleName
     *   A fully-qualified path representing ConversionValueRule resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromConversionValueRuleName(conversionValueRuleName) {
        return this.pathTemplates.conversionValueRulePathTemplate.match(conversionValueRuleName).customer_id;
    }
    /**
     * Parse the conversion_value_rule_id from ConversionValueRule resource.
     *
     * @param {string} conversionValueRuleName
     *   A fully-qualified path representing ConversionValueRule resource.
     * @returns {string} A string representing the conversion_value_rule_id.
     */
    matchConversionValueRuleIdFromConversionValueRuleName(conversionValueRuleName) {
        return this.pathTemplates.conversionValueRulePathTemplate.match(conversionValueRuleName).conversion_value_rule_id;
    }
    /**
     * Return a fully-qualified conversionValueRuleSet resource name string.
     *
     * @param {string} customer_id
     * @param {string} conversion_value_rule_set_id
     * @returns {string} Resource name string.
     */
    conversionValueRuleSetPath(customerId, conversionValueRuleSetId) {
        return this.pathTemplates.conversionValueRuleSetPathTemplate.render({
            customer_id: customerId,
            conversion_value_rule_set_id: conversionValueRuleSetId,
        });
    }
    /**
     * Parse the customer_id from ConversionValueRuleSet resource.
     *
     * @param {string} conversionValueRuleSetName
     *   A fully-qualified path representing ConversionValueRuleSet resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromConversionValueRuleSetName(conversionValueRuleSetName) {
        return this.pathTemplates.conversionValueRuleSetPathTemplate.match(conversionValueRuleSetName).customer_id;
    }
    /**
     * Parse the conversion_value_rule_set_id from ConversionValueRuleSet resource.
     *
     * @param {string} conversionValueRuleSetName
     *   A fully-qualified path representing ConversionValueRuleSet resource.
     * @returns {string} A string representing the conversion_value_rule_set_id.
     */
    matchConversionValueRuleSetIdFromConversionValueRuleSetName(conversionValueRuleSetName) {
        return this.pathTemplates.conversionValueRuleSetPathTemplate.match(conversionValueRuleSetName).conversion_value_rule_set_id;
    }
    /**
     * Return a fully-qualified currencyConstant resource name string.
     *
     * @param {string} code
     * @returns {string} Resource name string.
     */
    currencyConstantPath(code) {
        return this.pathTemplates.currencyConstantPathTemplate.render({
            code: code,
        });
    }
    /**
     * Parse the code from CurrencyConstant resource.
     *
     * @param {string} currencyConstantName
     *   A fully-qualified path representing CurrencyConstant resource.
     * @returns {string} A string representing the code.
     */
    matchCodeFromCurrencyConstantName(currencyConstantName) {
        return this.pathTemplates.currencyConstantPathTemplate.match(currencyConstantName).code;
    }
    /**
     * Return a fully-qualified customAudience resource name string.
     *
     * @param {string} customer_id
     * @param {string} custom_audience_id
     * @returns {string} Resource name string.
     */
    customAudiencePath(customerId, customAudienceId) {
        return this.pathTemplates.customAudiencePathTemplate.render({
            customer_id: customerId,
            custom_audience_id: customAudienceId,
        });
    }
    /**
     * Parse the customer_id from CustomAudience resource.
     *
     * @param {string} customAudienceName
     *   A fully-qualified path representing CustomAudience resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomAudienceName(customAudienceName) {
        return this.pathTemplates.customAudiencePathTemplate.match(customAudienceName).customer_id;
    }
    /**
     * Parse the custom_audience_id from CustomAudience resource.
     *
     * @param {string} customAudienceName
     *   A fully-qualified path representing CustomAudience resource.
     * @returns {string} A string representing the custom_audience_id.
     */
    matchCustomAudienceIdFromCustomAudienceName(customAudienceName) {
        return this.pathTemplates.customAudiencePathTemplate.match(customAudienceName).custom_audience_id;
    }
    /**
     * Return a fully-qualified customConversionGoal resource name string.
     *
     * @param {string} customer_id
     * @param {string} goal_id
     * @returns {string} Resource name string.
     */
    customConversionGoalPath(customerId, goalId) {
        return this.pathTemplates.customConversionGoalPathTemplate.render({
            customer_id: customerId,
            goal_id: goalId,
        });
    }
    /**
     * Parse the customer_id from CustomConversionGoal resource.
     *
     * @param {string} customConversionGoalName
     *   A fully-qualified path representing CustomConversionGoal resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomConversionGoalName(customConversionGoalName) {
        return this.pathTemplates.customConversionGoalPathTemplate.match(customConversionGoalName).customer_id;
    }
    /**
     * Parse the goal_id from CustomConversionGoal resource.
     *
     * @param {string} customConversionGoalName
     *   A fully-qualified path representing CustomConversionGoal resource.
     * @returns {string} A string representing the goal_id.
     */
    matchGoalIdFromCustomConversionGoalName(customConversionGoalName) {
        return this.pathTemplates.customConversionGoalPathTemplate.match(customConversionGoalName).goal_id;
    }
    /**
     * Return a fully-qualified customInterest resource name string.
     *
     * @param {string} customer_id
     * @param {string} custom_interest_id
     * @returns {string} Resource name string.
     */
    customInterestPath(customerId, customInterestId) {
        return this.pathTemplates.customInterestPathTemplate.render({
            customer_id: customerId,
            custom_interest_id: customInterestId,
        });
    }
    /**
     * Parse the customer_id from CustomInterest resource.
     *
     * @param {string} customInterestName
     *   A fully-qualified path representing CustomInterest resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomInterestName(customInterestName) {
        return this.pathTemplates.customInterestPathTemplate.match(customInterestName).customer_id;
    }
    /**
     * Parse the custom_interest_id from CustomInterest resource.
     *
     * @param {string} customInterestName
     *   A fully-qualified path representing CustomInterest resource.
     * @returns {string} A string representing the custom_interest_id.
     */
    matchCustomInterestIdFromCustomInterestName(customInterestName) {
        return this.pathTemplates.customInterestPathTemplate.match(customInterestName).custom_interest_id;
    }
    /**
     * Return a fully-qualified customer resource name string.
     *
     * @param {string} customer_id
     * @returns {string} Resource name string.
     */
    customerPath(customerId) {
        return this.pathTemplates.customerPathTemplate.render({
            customer_id: customerId,
        });
    }
    /**
     * Parse the customer_id from Customer resource.
     *
     * @param {string} customerName
     *   A fully-qualified path representing Customer resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomerName(customerName) {
        return this.pathTemplates.customerPathTemplate.match(customerName).customer_id;
    }
    /**
     * Return a fully-qualified customerAsset resource name string.
     *
     * @param {string} customer_id
     * @param {string} asset_id
     * @param {string} field_type
     * @returns {string} Resource name string.
     */
    customerAssetPath(customerId, assetId, fieldType) {
        return this.pathTemplates.customerAssetPathTemplate.render({
            customer_id: customerId,
            asset_id: assetId,
            field_type: fieldType,
        });
    }
    /**
     * Parse the customer_id from CustomerAsset resource.
     *
     * @param {string} customerAssetName
     *   A fully-qualified path representing CustomerAsset resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomerAssetName(customerAssetName) {
        return this.pathTemplates.customerAssetPathTemplate.match(customerAssetName).customer_id;
    }
    /**
     * Parse the asset_id from CustomerAsset resource.
     *
     * @param {string} customerAssetName
     *   A fully-qualified path representing CustomerAsset resource.
     * @returns {string} A string representing the asset_id.
     */
    matchAssetIdFromCustomerAssetName(customerAssetName) {
        return this.pathTemplates.customerAssetPathTemplate.match(customerAssetName).asset_id;
    }
    /**
     * Parse the field_type from CustomerAsset resource.
     *
     * @param {string} customerAssetName
     *   A fully-qualified path representing CustomerAsset resource.
     * @returns {string} A string representing the field_type.
     */
    matchFieldTypeFromCustomerAssetName(customerAssetName) {
        return this.pathTemplates.customerAssetPathTemplate.match(customerAssetName).field_type;
    }
    /**
     * Return a fully-qualified customerAssetSet resource name string.
     *
     * @param {string} customer_id
     * @param {string} asset_set_id
     * @returns {string} Resource name string.
     */
    customerAssetSetPath(customerId, assetSetId) {
        return this.pathTemplates.customerAssetSetPathTemplate.render({
            customer_id: customerId,
            asset_set_id: assetSetId,
        });
    }
    /**
     * Parse the customer_id from CustomerAssetSet resource.
     *
     * @param {string} customerAssetSetName
     *   A fully-qualified path representing CustomerAssetSet resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomerAssetSetName(customerAssetSetName) {
        return this.pathTemplates.customerAssetSetPathTemplate.match(customerAssetSetName).customer_id;
    }
    /**
     * Parse the asset_set_id from CustomerAssetSet resource.
     *
     * @param {string} customerAssetSetName
     *   A fully-qualified path representing CustomerAssetSet resource.
     * @returns {string} A string representing the asset_set_id.
     */
    matchAssetSetIdFromCustomerAssetSetName(customerAssetSetName) {
        return this.pathTemplates.customerAssetSetPathTemplate.match(customerAssetSetName).asset_set_id;
    }
    /**
     * Return a fully-qualified customerClient resource name string.
     *
     * @param {string} customer_id
     * @param {string} client_customer_id
     * @returns {string} Resource name string.
     */
    customerClientPath(customerId, clientCustomerId) {
        return this.pathTemplates.customerClientPathTemplate.render({
            customer_id: customerId,
            client_customer_id: clientCustomerId,
        });
    }
    /**
     * Parse the customer_id from CustomerClient resource.
     *
     * @param {string} customerClientName
     *   A fully-qualified path representing CustomerClient resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomerClientName(customerClientName) {
        return this.pathTemplates.customerClientPathTemplate.match(customerClientName).customer_id;
    }
    /**
     * Parse the client_customer_id from CustomerClient resource.
     *
     * @param {string} customerClientName
     *   A fully-qualified path representing CustomerClient resource.
     * @returns {string} A string representing the client_customer_id.
     */
    matchClientCustomerIdFromCustomerClientName(customerClientName) {
        return this.pathTemplates.customerClientPathTemplate.match(customerClientName).client_customer_id;
    }
    /**
     * Return a fully-qualified customerClientLink resource name string.
     *
     * @param {string} customer_id
     * @param {string} client_customer_id
     * @param {string} manager_link_id
     * @returns {string} Resource name string.
     */
    customerClientLinkPath(customerId, clientCustomerId, managerLinkId) {
        return this.pathTemplates.customerClientLinkPathTemplate.render({
            customer_id: customerId,
            client_customer_id: clientCustomerId,
            manager_link_id: managerLinkId,
        });
    }
    /**
     * Parse the customer_id from CustomerClientLink resource.
     *
     * @param {string} customerClientLinkName
     *   A fully-qualified path representing CustomerClientLink resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomerClientLinkName(customerClientLinkName) {
        return this.pathTemplates.customerClientLinkPathTemplate.match(customerClientLinkName).customer_id;
    }
    /**
     * Parse the client_customer_id from CustomerClientLink resource.
     *
     * @param {string} customerClientLinkName
     *   A fully-qualified path representing CustomerClientLink resource.
     * @returns {string} A string representing the client_customer_id.
     */
    matchClientCustomerIdFromCustomerClientLinkName(customerClientLinkName) {
        return this.pathTemplates.customerClientLinkPathTemplate.match(customerClientLinkName).client_customer_id;
    }
    /**
     * Parse the manager_link_id from CustomerClientLink resource.
     *
     * @param {string} customerClientLinkName
     *   A fully-qualified path representing CustomerClientLink resource.
     * @returns {string} A string representing the manager_link_id.
     */
    matchManagerLinkIdFromCustomerClientLinkName(customerClientLinkName) {
        return this.pathTemplates.customerClientLinkPathTemplate.match(customerClientLinkName).manager_link_id;
    }
    /**
     * Return a fully-qualified customerConversionGoal resource name string.
     *
     * @param {string} customer_id
     * @param {string} category
     * @param {string} source
     * @returns {string} Resource name string.
     */
    customerConversionGoalPath(customerId, category, source) {
        return this.pathTemplates.customerConversionGoalPathTemplate.render({
            customer_id: customerId,
            category: category,
            source: source,
        });
    }
    /**
     * Parse the customer_id from CustomerConversionGoal resource.
     *
     * @param {string} customerConversionGoalName
     *   A fully-qualified path representing CustomerConversionGoal resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomerConversionGoalName(customerConversionGoalName) {
        return this.pathTemplates.customerConversionGoalPathTemplate.match(customerConversionGoalName).customer_id;
    }
    /**
     * Parse the category from CustomerConversionGoal resource.
     *
     * @param {string} customerConversionGoalName
     *   A fully-qualified path representing CustomerConversionGoal resource.
     * @returns {string} A string representing the category.
     */
    matchCategoryFromCustomerConversionGoalName(customerConversionGoalName) {
        return this.pathTemplates.customerConversionGoalPathTemplate.match(customerConversionGoalName).category;
    }
    /**
     * Parse the source from CustomerConversionGoal resource.
     *
     * @param {string} customerConversionGoalName
     *   A fully-qualified path representing CustomerConversionGoal resource.
     * @returns {string} A string representing the source.
     */
    matchSourceFromCustomerConversionGoalName(customerConversionGoalName) {
        return this.pathTemplates.customerConversionGoalPathTemplate.match(customerConversionGoalName).source;
    }
    /**
     * Return a fully-qualified customerCustomizer resource name string.
     *
     * @param {string} customer_id
     * @param {string} customizer_attribute_id
     * @returns {string} Resource name string.
     */
    customerCustomizerPath(customerId, customizerAttributeId) {
        return this.pathTemplates.customerCustomizerPathTemplate.render({
            customer_id: customerId,
            customizer_attribute_id: customizerAttributeId,
        });
    }
    /**
     * Parse the customer_id from CustomerCustomizer resource.
     *
     * @param {string} customerCustomizerName
     *   A fully-qualified path representing CustomerCustomizer resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomerCustomizerName(customerCustomizerName) {
        return this.pathTemplates.customerCustomizerPathTemplate.match(customerCustomizerName).customer_id;
    }
    /**
     * Parse the customizer_attribute_id from CustomerCustomizer resource.
     *
     * @param {string} customerCustomizerName
     *   A fully-qualified path representing CustomerCustomizer resource.
     * @returns {string} A string representing the customizer_attribute_id.
     */
    matchCustomizerAttributeIdFromCustomerCustomizerName(customerCustomizerName) {
        return this.pathTemplates.customerCustomizerPathTemplate.match(customerCustomizerName).customizer_attribute_id;
    }
    /**
     * Return a fully-qualified customerExtensionSetting resource name string.
     *
     * @param {string} customer_id
     * @param {string} extension_type
     * @returns {string} Resource name string.
     */
    customerExtensionSettingPath(customerId, extensionType) {
        return this.pathTemplates.customerExtensionSettingPathTemplate.render({
            customer_id: customerId,
            extension_type: extensionType,
        });
    }
    /**
     * Parse the customer_id from CustomerExtensionSetting resource.
     *
     * @param {string} customerExtensionSettingName
     *   A fully-qualified path representing CustomerExtensionSetting resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomerExtensionSettingName(customerExtensionSettingName) {
        return this.pathTemplates.customerExtensionSettingPathTemplate.match(customerExtensionSettingName).customer_id;
    }
    /**
     * Parse the extension_type from CustomerExtensionSetting resource.
     *
     * @param {string} customerExtensionSettingName
     *   A fully-qualified path representing CustomerExtensionSetting resource.
     * @returns {string} A string representing the extension_type.
     */
    matchExtensionTypeFromCustomerExtensionSettingName(customerExtensionSettingName) {
        return this.pathTemplates.customerExtensionSettingPathTemplate.match(customerExtensionSettingName).extension_type;
    }
    /**
     * Return a fully-qualified customerFeed resource name string.
     *
     * @param {string} customer_id
     * @param {string} feed_id
     * @returns {string} Resource name string.
     */
    customerFeedPath(customerId, feedId) {
        return this.pathTemplates.customerFeedPathTemplate.render({
            customer_id: customerId,
            feed_id: feedId,
        });
    }
    /**
     * Parse the customer_id from CustomerFeed resource.
     *
     * @param {string} customerFeedName
     *   A fully-qualified path representing CustomerFeed resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomerFeedName(customerFeedName) {
        return this.pathTemplates.customerFeedPathTemplate.match(customerFeedName).customer_id;
    }
    /**
     * Parse the feed_id from CustomerFeed resource.
     *
     * @param {string} customerFeedName
     *   A fully-qualified path representing CustomerFeed resource.
     * @returns {string} A string representing the feed_id.
     */
    matchFeedIdFromCustomerFeedName(customerFeedName) {
        return this.pathTemplates.customerFeedPathTemplate.match(customerFeedName).feed_id;
    }
    /**
     * Return a fully-qualified customerLabel resource name string.
     *
     * @param {string} customer_id
     * @param {string} label_id
     * @returns {string} Resource name string.
     */
    customerLabelPath(customerId, labelId) {
        return this.pathTemplates.customerLabelPathTemplate.render({
            customer_id: customerId,
            label_id: labelId,
        });
    }
    /**
     * Parse the customer_id from CustomerLabel resource.
     *
     * @param {string} customerLabelName
     *   A fully-qualified path representing CustomerLabel resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomerLabelName(customerLabelName) {
        return this.pathTemplates.customerLabelPathTemplate.match(customerLabelName).customer_id;
    }
    /**
     * Parse the label_id from CustomerLabel resource.
     *
     * @param {string} customerLabelName
     *   A fully-qualified path representing CustomerLabel resource.
     * @returns {string} A string representing the label_id.
     */
    matchLabelIdFromCustomerLabelName(customerLabelName) {
        return this.pathTemplates.customerLabelPathTemplate.match(customerLabelName).label_id;
    }
    /**
     * Return a fully-qualified customerManagerLink resource name string.
     *
     * @param {string} customer_id
     * @param {string} manager_customer_id
     * @param {string} manager_link_id
     * @returns {string} Resource name string.
     */
    customerManagerLinkPath(customerId, managerCustomerId, managerLinkId) {
        return this.pathTemplates.customerManagerLinkPathTemplate.render({
            customer_id: customerId,
            manager_customer_id: managerCustomerId,
            manager_link_id: managerLinkId,
        });
    }
    /**
     * Parse the customer_id from CustomerManagerLink resource.
     *
     * @param {string} customerManagerLinkName
     *   A fully-qualified path representing CustomerManagerLink resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomerManagerLinkName(customerManagerLinkName) {
        return this.pathTemplates.customerManagerLinkPathTemplate.match(customerManagerLinkName).customer_id;
    }
    /**
     * Parse the manager_customer_id from CustomerManagerLink resource.
     *
     * @param {string} customerManagerLinkName
     *   A fully-qualified path representing CustomerManagerLink resource.
     * @returns {string} A string representing the manager_customer_id.
     */
    matchManagerCustomerIdFromCustomerManagerLinkName(customerManagerLinkName) {
        return this.pathTemplates.customerManagerLinkPathTemplate.match(customerManagerLinkName).manager_customer_id;
    }
    /**
     * Parse the manager_link_id from CustomerManagerLink resource.
     *
     * @param {string} customerManagerLinkName
     *   A fully-qualified path representing CustomerManagerLink resource.
     * @returns {string} A string representing the manager_link_id.
     */
    matchManagerLinkIdFromCustomerManagerLinkName(customerManagerLinkName) {
        return this.pathTemplates.customerManagerLinkPathTemplate.match(customerManagerLinkName).manager_link_id;
    }
    /**
     * Return a fully-qualified customerNegativeCriterion resource name string.
     *
     * @param {string} customer_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    customerNegativeCriterionPath(customerId, criterionId) {
        return this.pathTemplates.customerNegativeCriterionPathTemplate.render({
            customer_id: customerId,
            criterion_id: criterionId,
        });
    }
    /**
     * Parse the customer_id from CustomerNegativeCriterion resource.
     *
     * @param {string} customerNegativeCriterionName
     *   A fully-qualified path representing CustomerNegativeCriterion resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomerNegativeCriterionName(customerNegativeCriterionName) {
        return this.pathTemplates.customerNegativeCriterionPathTemplate.match(customerNegativeCriterionName).customer_id;
    }
    /**
     * Parse the criterion_id from CustomerNegativeCriterion resource.
     *
     * @param {string} customerNegativeCriterionName
     *   A fully-qualified path representing CustomerNegativeCriterion resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromCustomerNegativeCriterionName(customerNegativeCriterionName) {
        return this.pathTemplates.customerNegativeCriterionPathTemplate.match(customerNegativeCriterionName).criterion_id;
    }
    /**
     * Return a fully-qualified customerSearchTermInsight resource name string.
     *
     * @param {string} customer_id
     * @param {string} cluster_id
     * @returns {string} Resource name string.
     */
    customerSearchTermInsightPath(customerId, clusterId) {
        return this.pathTemplates.customerSearchTermInsightPathTemplate.render({
            customer_id: customerId,
            cluster_id: clusterId,
        });
    }
    /**
     * Parse the customer_id from CustomerSearchTermInsight resource.
     *
     * @param {string} customerSearchTermInsightName
     *   A fully-qualified path representing CustomerSearchTermInsight resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomerSearchTermInsightName(customerSearchTermInsightName) {
        return this.pathTemplates.customerSearchTermInsightPathTemplate.match(customerSearchTermInsightName).customer_id;
    }
    /**
     * Parse the cluster_id from CustomerSearchTermInsight resource.
     *
     * @param {string} customerSearchTermInsightName
     *   A fully-qualified path representing CustomerSearchTermInsight resource.
     * @returns {string} A string representing the cluster_id.
     */
    matchClusterIdFromCustomerSearchTermInsightName(customerSearchTermInsightName) {
        return this.pathTemplates.customerSearchTermInsightPathTemplate.match(customerSearchTermInsightName).cluster_id;
    }
    /**
     * Return a fully-qualified customerSkAdNetworkConversionValueSchema resource name string.
     *
     * @param {string} customer_id
     * @param {string} account_link_id
     * @returns {string} Resource name string.
     */
    customerSkAdNetworkConversionValueSchemaPath(customerId, accountLinkId) {
        return this.pathTemplates.customerSkAdNetworkConversionValueSchemaPathTemplate.render({
            customer_id: customerId,
            account_link_id: accountLinkId,
        });
    }
    /**
     * Parse the customer_id from CustomerSkAdNetworkConversionValueSchema resource.
     *
     * @param {string} customerSkAdNetworkConversionValueSchemaName
     *   A fully-qualified path representing CustomerSkAdNetworkConversionValueSchema resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomerSkAdNetworkConversionValueSchemaName(customerSkAdNetworkConversionValueSchemaName) {
        return this.pathTemplates.customerSkAdNetworkConversionValueSchemaPathTemplate.match(customerSkAdNetworkConversionValueSchemaName).customer_id;
    }
    /**
     * Parse the account_link_id from CustomerSkAdNetworkConversionValueSchema resource.
     *
     * @param {string} customerSkAdNetworkConversionValueSchemaName
     *   A fully-qualified path representing CustomerSkAdNetworkConversionValueSchema resource.
     * @returns {string} A string representing the account_link_id.
     */
    matchAccountLinkIdFromCustomerSkAdNetworkConversionValueSchemaName(customerSkAdNetworkConversionValueSchemaName) {
        return this.pathTemplates.customerSkAdNetworkConversionValueSchemaPathTemplate.match(customerSkAdNetworkConversionValueSchemaName).account_link_id;
    }
    /**
     * Return a fully-qualified customerUserAccess resource name string.
     *
     * @param {string} customer_id
     * @param {string} user_id
     * @returns {string} Resource name string.
     */
    customerUserAccessPath(customerId, userId) {
        return this.pathTemplates.customerUserAccessPathTemplate.render({
            customer_id: customerId,
            user_id: userId,
        });
    }
    /**
     * Parse the customer_id from CustomerUserAccess resource.
     *
     * @param {string} customerUserAccessName
     *   A fully-qualified path representing CustomerUserAccess resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomerUserAccessName(customerUserAccessName) {
        return this.pathTemplates.customerUserAccessPathTemplate.match(customerUserAccessName).customer_id;
    }
    /**
     * Parse the user_id from CustomerUserAccess resource.
     *
     * @param {string} customerUserAccessName
     *   A fully-qualified path representing CustomerUserAccess resource.
     * @returns {string} A string representing the user_id.
     */
    matchUserIdFromCustomerUserAccessName(customerUserAccessName) {
        return this.pathTemplates.customerUserAccessPathTemplate.match(customerUserAccessName).user_id;
    }
    /**
     * Return a fully-qualified customerUserAccessInvitation resource name string.
     *
     * @param {string} customer_id
     * @param {string} invitation_id
     * @returns {string} Resource name string.
     */
    customerUserAccessInvitationPath(customerId, invitationId) {
        return this.pathTemplates.customerUserAccessInvitationPathTemplate.render({
            customer_id: customerId,
            invitation_id: invitationId,
        });
    }
    /**
     * Parse the customer_id from CustomerUserAccessInvitation resource.
     *
     * @param {string} customerUserAccessInvitationName
     *   A fully-qualified path representing CustomerUserAccessInvitation resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomerUserAccessInvitationName(customerUserAccessInvitationName) {
        return this.pathTemplates.customerUserAccessInvitationPathTemplate.match(customerUserAccessInvitationName).customer_id;
    }
    /**
     * Parse the invitation_id from CustomerUserAccessInvitation resource.
     *
     * @param {string} customerUserAccessInvitationName
     *   A fully-qualified path representing CustomerUserAccessInvitation resource.
     * @returns {string} A string representing the invitation_id.
     */
    matchInvitationIdFromCustomerUserAccessInvitationName(customerUserAccessInvitationName) {
        return this.pathTemplates.customerUserAccessInvitationPathTemplate.match(customerUserAccessInvitationName).invitation_id;
    }
    /**
     * Return a fully-qualified customizerAttribute resource name string.
     *
     * @param {string} customer_id
     * @param {string} customizer_attribute_id
     * @returns {string} Resource name string.
     */
    customizerAttributePath(customerId, customizerAttributeId) {
        return this.pathTemplates.customizerAttributePathTemplate.render({
            customer_id: customerId,
            customizer_attribute_id: customizerAttributeId,
        });
    }
    /**
     * Parse the customer_id from CustomizerAttribute resource.
     *
     * @param {string} customizerAttributeName
     *   A fully-qualified path representing CustomizerAttribute resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromCustomizerAttributeName(customizerAttributeName) {
        return this.pathTemplates.customizerAttributePathTemplate.match(customizerAttributeName).customer_id;
    }
    /**
     * Parse the customizer_attribute_id from CustomizerAttribute resource.
     *
     * @param {string} customizerAttributeName
     *   A fully-qualified path representing CustomizerAttribute resource.
     * @returns {string} A string representing the customizer_attribute_id.
     */
    matchCustomizerAttributeIdFromCustomizerAttributeName(customizerAttributeName) {
        return this.pathTemplates.customizerAttributePathTemplate.match(customizerAttributeName).customizer_attribute_id;
    }
    /**
     * Return a fully-qualified detailPlacementView resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @returns {string} Resource name string.
     */
    detailPlacementViewPath(customerId, adGroupId) {
        return this.pathTemplates.detailPlacementViewPathTemplate.render({
            customer_id: customerId,
            ad_group_id: adGroupId,
        });
    }
    /**
     * Parse the customer_id from DetailPlacementView resource.
     *
     * @param {string} detailPlacementViewName
     *   A fully-qualified path representing DetailPlacementView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromDetailPlacementViewName(detailPlacementViewName) {
        return this.pathTemplates.detailPlacementViewPathTemplate.match(detailPlacementViewName).customer_id;
    }
    /**
     * Parse the ad_group_id from DetailPlacementView resource.
     *
     * @param {string} detailPlacementViewName
     *   A fully-qualified path representing DetailPlacementView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromDetailPlacementViewName(detailPlacementViewName) {
        return this.pathTemplates.detailPlacementViewPathTemplate.match(detailPlacementViewName).ad_group_id;
    }
    /**
     * Return a fully-qualified detailedDemographic resource name string.
     *
     * @param {string} customer_id
     * @param {string} detailed_demographic_id
     * @returns {string} Resource name string.
     */
    detailedDemographicPath(customerId, detailedDemographicId) {
        return this.pathTemplates.detailedDemographicPathTemplate.render({
            customer_id: customerId,
            detailed_demographic_id: detailedDemographicId,
        });
    }
    /**
     * Parse the customer_id from DetailedDemographic resource.
     *
     * @param {string} detailedDemographicName
     *   A fully-qualified path representing DetailedDemographic resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromDetailedDemographicName(detailedDemographicName) {
        return this.pathTemplates.detailedDemographicPathTemplate.match(detailedDemographicName).customer_id;
    }
    /**
     * Parse the detailed_demographic_id from DetailedDemographic resource.
     *
     * @param {string} detailedDemographicName
     *   A fully-qualified path representing DetailedDemographic resource.
     * @returns {string} A string representing the detailed_demographic_id.
     */
    matchDetailedDemographicIdFromDetailedDemographicName(detailedDemographicName) {
        return this.pathTemplates.detailedDemographicPathTemplate.match(detailedDemographicName).detailed_demographic_id;
    }
    /**
     * Return a fully-qualified displayKeywordView resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    displayKeywordViewPath(customerId, adGroupId, criterionId) {
        return this.pathTemplates.displayKeywordViewPathTemplate.render({
            customer_id: customerId,
            ad_group_id: adGroupId,
            criterion_id: criterionId,
        });
    }
    /**
     * Parse the customer_id from DisplayKeywordView resource.
     *
     * @param {string} displayKeywordViewName
     *   A fully-qualified path representing DisplayKeywordView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromDisplayKeywordViewName(displayKeywordViewName) {
        return this.pathTemplates.displayKeywordViewPathTemplate.match(displayKeywordViewName).customer_id;
    }
    /**
     * Parse the ad_group_id from DisplayKeywordView resource.
     *
     * @param {string} displayKeywordViewName
     *   A fully-qualified path representing DisplayKeywordView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromDisplayKeywordViewName(displayKeywordViewName) {
        return this.pathTemplates.displayKeywordViewPathTemplate.match(displayKeywordViewName).ad_group_id;
    }
    /**
     * Parse the criterion_id from DisplayKeywordView resource.
     *
     * @param {string} displayKeywordViewName
     *   A fully-qualified path representing DisplayKeywordView resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromDisplayKeywordViewName(displayKeywordViewName) {
        return this.pathTemplates.displayKeywordViewPathTemplate.match(displayKeywordViewName).criterion_id;
    }
    /**
     * Return a fully-qualified distanceView resource name string.
     *
     * @param {string} customer_id
     * @param {string} placeholder_chain_id
     * @param {string} distance_bucket
     * @returns {string} Resource name string.
     */
    distanceViewPath(customerId, placeholderChainId, distanceBucket) {
        return this.pathTemplates.distanceViewPathTemplate.render({
            customer_id: customerId,
            placeholder_chain_id: placeholderChainId,
            distance_bucket: distanceBucket,
        });
    }
    /**
     * Parse the customer_id from DistanceView resource.
     *
     * @param {string} distanceViewName
     *   A fully-qualified path representing DistanceView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromDistanceViewName(distanceViewName) {
        return this.pathTemplates.distanceViewPathTemplate.match(distanceViewName).customer_id;
    }
    /**
     * Parse the placeholder_chain_id from DistanceView resource.
     *
     * @param {string} distanceViewName
     *   A fully-qualified path representing DistanceView resource.
     * @returns {string} A string representing the placeholder_chain_id.
     */
    matchPlaceholderChainIdFromDistanceViewName(distanceViewName) {
        return this.pathTemplates.distanceViewPathTemplate.match(distanceViewName).placeholder_chain_id;
    }
    /**
     * Parse the distance_bucket from DistanceView resource.
     *
     * @param {string} distanceViewName
     *   A fully-qualified path representing DistanceView resource.
     * @returns {string} A string representing the distance_bucket.
     */
    matchDistanceBucketFromDistanceViewName(distanceViewName) {
        return this.pathTemplates.distanceViewPathTemplate.match(distanceViewName).distance_bucket;
    }
    /**
     * Return a fully-qualified domainCategory resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} language_code
     * @returns {string} Resource name string.
     */
    domainCategoryPath(customerId, campaignId, languageCode) {
        return this.pathTemplates.domainCategoryPathTemplate.render({
            customer_id: customerId,
            campaign_id: campaignId,
            language_code: languageCode,
        });
    }
    /**
     * Parse the customer_id from DomainCategory resource.
     *
     * @param {string} domainCategoryName
     *   A fully-qualified path representing DomainCategory resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromDomainCategoryName(domainCategoryName) {
        return this.pathTemplates.domainCategoryPathTemplate.match(domainCategoryName).customer_id;
    }
    /**
     * Parse the campaign_id from DomainCategory resource.
     *
     * @param {string} domainCategoryName
     *   A fully-qualified path representing DomainCategory resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromDomainCategoryName(domainCategoryName) {
        return this.pathTemplates.domainCategoryPathTemplate.match(domainCategoryName).campaign_id;
    }
    /**
     * Parse the language_code from DomainCategory resource.
     *
     * @param {string} domainCategoryName
     *   A fully-qualified path representing DomainCategory resource.
     * @returns {string} A string representing the language_code.
     */
    matchLanguageCodeFromDomainCategoryName(domainCategoryName) {
        return this.pathTemplates.domainCategoryPathTemplate.match(domainCategoryName).language_code;
    }
    /**
     * Return a fully-qualified dynamicSearchAdsSearchTermView resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} search_term_fingerprint
     * @param {string} headline_fingerprint
     * @param {string} landing_page_fingerprint
     * @param {string} page_url_fingerprint
     * @returns {string} Resource name string.
     */
    dynamicSearchAdsSearchTermViewPath(customerId, adGroupId, searchTermFingerprint, headlineFingerprint, landingPageFingerprint, pageUrlFingerprint) {
        return this.pathTemplates.dynamicSearchAdsSearchTermViewPathTemplate.render({
            customer_id: customerId,
            ad_group_id: adGroupId,
            search_term_fingerprint: searchTermFingerprint,
            headline_fingerprint: headlineFingerprint,
            landing_page_fingerprint: landingPageFingerprint,
            page_url_fingerprint: pageUrlFingerprint,
        });
    }
    /**
     * Parse the customer_id from DynamicSearchAdsSearchTermView resource.
     *
     * @param {string} dynamicSearchAdsSearchTermViewName
     *   A fully-qualified path representing DynamicSearchAdsSearchTermView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromDynamicSearchAdsSearchTermViewName(dynamicSearchAdsSearchTermViewName) {
        return this.pathTemplates.dynamicSearchAdsSearchTermViewPathTemplate.match(dynamicSearchAdsSearchTermViewName).customer_id;
    }
    /**
     * Parse the ad_group_id from DynamicSearchAdsSearchTermView resource.
     *
     * @param {string} dynamicSearchAdsSearchTermViewName
     *   A fully-qualified path representing DynamicSearchAdsSearchTermView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromDynamicSearchAdsSearchTermViewName(dynamicSearchAdsSearchTermViewName) {
        return this.pathTemplates.dynamicSearchAdsSearchTermViewPathTemplate.match(dynamicSearchAdsSearchTermViewName).ad_group_id;
    }
    /**
     * Parse the search_term_fingerprint from DynamicSearchAdsSearchTermView resource.
     *
     * @param {string} dynamicSearchAdsSearchTermViewName
     *   A fully-qualified path representing DynamicSearchAdsSearchTermView resource.
     * @returns {string} A string representing the search_term_fingerprint.
     */
    matchSearchTermFingerprintFromDynamicSearchAdsSearchTermViewName(dynamicSearchAdsSearchTermViewName) {
        return this.pathTemplates.dynamicSearchAdsSearchTermViewPathTemplate.match(dynamicSearchAdsSearchTermViewName).search_term_fingerprint;
    }
    /**
     * Parse the headline_fingerprint from DynamicSearchAdsSearchTermView resource.
     *
     * @param {string} dynamicSearchAdsSearchTermViewName
     *   A fully-qualified path representing DynamicSearchAdsSearchTermView resource.
     * @returns {string} A string representing the headline_fingerprint.
     */
    matchHeadlineFingerprintFromDynamicSearchAdsSearchTermViewName(dynamicSearchAdsSearchTermViewName) {
        return this.pathTemplates.dynamicSearchAdsSearchTermViewPathTemplate.match(dynamicSearchAdsSearchTermViewName).headline_fingerprint;
    }
    /**
     * Parse the landing_page_fingerprint from DynamicSearchAdsSearchTermView resource.
     *
     * @param {string} dynamicSearchAdsSearchTermViewName
     *   A fully-qualified path representing DynamicSearchAdsSearchTermView resource.
     * @returns {string} A string representing the landing_page_fingerprint.
     */
    matchLandingPageFingerprintFromDynamicSearchAdsSearchTermViewName(dynamicSearchAdsSearchTermViewName) {
        return this.pathTemplates.dynamicSearchAdsSearchTermViewPathTemplate.match(dynamicSearchAdsSearchTermViewName).landing_page_fingerprint;
    }
    /**
     * Parse the page_url_fingerprint from DynamicSearchAdsSearchTermView resource.
     *
     * @param {string} dynamicSearchAdsSearchTermViewName
     *   A fully-qualified path representing DynamicSearchAdsSearchTermView resource.
     * @returns {string} A string representing the page_url_fingerprint.
     */
    matchPageUrlFingerprintFromDynamicSearchAdsSearchTermViewName(dynamicSearchAdsSearchTermViewName) {
        return this.pathTemplates.dynamicSearchAdsSearchTermViewPathTemplate.match(dynamicSearchAdsSearchTermViewName).page_url_fingerprint;
    }
    /**
     * Return a fully-qualified expandedLandingPageView resource name string.
     *
     * @param {string} customer_id
     * @param {string} expanded_final_url_fingerprint
     * @returns {string} Resource name string.
     */
    expandedLandingPageViewPath(customerId, expandedFinalUrlFingerprint) {
        return this.pathTemplates.expandedLandingPageViewPathTemplate.render({
            customer_id: customerId,
            expanded_final_url_fingerprint: expandedFinalUrlFingerprint,
        });
    }
    /**
     * Parse the customer_id from ExpandedLandingPageView resource.
     *
     * @param {string} expandedLandingPageViewName
     *   A fully-qualified path representing ExpandedLandingPageView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromExpandedLandingPageViewName(expandedLandingPageViewName) {
        return this.pathTemplates.expandedLandingPageViewPathTemplate.match(expandedLandingPageViewName).customer_id;
    }
    /**
     * Parse the expanded_final_url_fingerprint from ExpandedLandingPageView resource.
     *
     * @param {string} expandedLandingPageViewName
     *   A fully-qualified path representing ExpandedLandingPageView resource.
     * @returns {string} A string representing the expanded_final_url_fingerprint.
     */
    matchExpandedFinalUrlFingerprintFromExpandedLandingPageViewName(expandedLandingPageViewName) {
        return this.pathTemplates.expandedLandingPageViewPathTemplate.match(expandedLandingPageViewName).expanded_final_url_fingerprint;
    }
    /**
     * Return a fully-qualified experiment resource name string.
     *
     * @param {string} customer_id
     * @param {string} trial_id
     * @returns {string} Resource name string.
     */
    experimentPath(customerId, trialId) {
        return this.pathTemplates.experimentPathTemplate.render({
            customer_id: customerId,
            trial_id: trialId,
        });
    }
    /**
     * Parse the customer_id from Experiment resource.
     *
     * @param {string} experimentName
     *   A fully-qualified path representing Experiment resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromExperimentName(experimentName) {
        return this.pathTemplates.experimentPathTemplate.match(experimentName).customer_id;
    }
    /**
     * Parse the trial_id from Experiment resource.
     *
     * @param {string} experimentName
     *   A fully-qualified path representing Experiment resource.
     * @returns {string} A string representing the trial_id.
     */
    matchTrialIdFromExperimentName(experimentName) {
        return this.pathTemplates.experimentPathTemplate.match(experimentName).trial_id;
    }
    /**
     * Return a fully-qualified experimentArm resource name string.
     *
     * @param {string} customer_id
     * @param {string} trial_id
     * @param {string} trial_arm_id
     * @returns {string} Resource name string.
     */
    experimentArmPath(customerId, trialId, trialArmId) {
        return this.pathTemplates.experimentArmPathTemplate.render({
            customer_id: customerId,
            trial_id: trialId,
            trial_arm_id: trialArmId,
        });
    }
    /**
     * Parse the customer_id from ExperimentArm resource.
     *
     * @param {string} experimentArmName
     *   A fully-qualified path representing ExperimentArm resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromExperimentArmName(experimentArmName) {
        return this.pathTemplates.experimentArmPathTemplate.match(experimentArmName).customer_id;
    }
    /**
     * Parse the trial_id from ExperimentArm resource.
     *
     * @param {string} experimentArmName
     *   A fully-qualified path representing ExperimentArm resource.
     * @returns {string} A string representing the trial_id.
     */
    matchTrialIdFromExperimentArmName(experimentArmName) {
        return this.pathTemplates.experimentArmPathTemplate.match(experimentArmName).trial_id;
    }
    /**
     * Parse the trial_arm_id from ExperimentArm resource.
     *
     * @param {string} experimentArmName
     *   A fully-qualified path representing ExperimentArm resource.
     * @returns {string} A string representing the trial_arm_id.
     */
    matchTrialArmIdFromExperimentArmName(experimentArmName) {
        return this.pathTemplates.experimentArmPathTemplate.match(experimentArmName).trial_arm_id;
    }
    /**
     * Return a fully-qualified extensionFeedItem resource name string.
     *
     * @param {string} customer_id
     * @param {string} feed_item_id
     * @returns {string} Resource name string.
     */
    extensionFeedItemPath(customerId, feedItemId) {
        return this.pathTemplates.extensionFeedItemPathTemplate.render({
            customer_id: customerId,
            feed_item_id: feedItemId,
        });
    }
    /**
     * Parse the customer_id from ExtensionFeedItem resource.
     *
     * @param {string} extensionFeedItemName
     *   A fully-qualified path representing ExtensionFeedItem resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromExtensionFeedItemName(extensionFeedItemName) {
        return this.pathTemplates.extensionFeedItemPathTemplate.match(extensionFeedItemName).customer_id;
    }
    /**
     * Parse the feed_item_id from ExtensionFeedItem resource.
     *
     * @param {string} extensionFeedItemName
     *   A fully-qualified path representing ExtensionFeedItem resource.
     * @returns {string} A string representing the feed_item_id.
     */
    matchFeedItemIdFromExtensionFeedItemName(extensionFeedItemName) {
        return this.pathTemplates.extensionFeedItemPathTemplate.match(extensionFeedItemName).feed_item_id;
    }
    /**
     * Return a fully-qualified feed resource name string.
     *
     * @param {string} customer_id
     * @param {string} feed_id
     * @returns {string} Resource name string.
     */
    feedPath(customerId, feedId) {
        return this.pathTemplates.feedPathTemplate.render({
            customer_id: customerId,
            feed_id: feedId,
        });
    }
    /**
     * Parse the customer_id from Feed resource.
     *
     * @param {string} feedName
     *   A fully-qualified path representing Feed resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromFeedName(feedName) {
        return this.pathTemplates.feedPathTemplate.match(feedName).customer_id;
    }
    /**
     * Parse the feed_id from Feed resource.
     *
     * @param {string} feedName
     *   A fully-qualified path representing Feed resource.
     * @returns {string} A string representing the feed_id.
     */
    matchFeedIdFromFeedName(feedName) {
        return this.pathTemplates.feedPathTemplate.match(feedName).feed_id;
    }
    /**
     * Return a fully-qualified feedItem resource name string.
     *
     * @param {string} customer_id
     * @param {string} feed_id
     * @param {string} feed_item_id
     * @returns {string} Resource name string.
     */
    feedItemPath(customerId, feedId, feedItemId) {
        return this.pathTemplates.feedItemPathTemplate.render({
            customer_id: customerId,
            feed_id: feedId,
            feed_item_id: feedItemId,
        });
    }
    /**
     * Parse the customer_id from FeedItem resource.
     *
     * @param {string} feedItemName
     *   A fully-qualified path representing FeedItem resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromFeedItemName(feedItemName) {
        return this.pathTemplates.feedItemPathTemplate.match(feedItemName).customer_id;
    }
    /**
     * Parse the feed_id from FeedItem resource.
     *
     * @param {string} feedItemName
     *   A fully-qualified path representing FeedItem resource.
     * @returns {string} A string representing the feed_id.
     */
    matchFeedIdFromFeedItemName(feedItemName) {
        return this.pathTemplates.feedItemPathTemplate.match(feedItemName).feed_id;
    }
    /**
     * Parse the feed_item_id from FeedItem resource.
     *
     * @param {string} feedItemName
     *   A fully-qualified path representing FeedItem resource.
     * @returns {string} A string representing the feed_item_id.
     */
    matchFeedItemIdFromFeedItemName(feedItemName) {
        return this.pathTemplates.feedItemPathTemplate.match(feedItemName).feed_item_id;
    }
    /**
     * Return a fully-qualified feedItemSet resource name string.
     *
     * @param {string} customer_id
     * @param {string} feed_id
     * @param {string} feed_item_set_id
     * @returns {string} Resource name string.
     */
    feedItemSetPath(customerId, feedId, feedItemSetId) {
        return this.pathTemplates.feedItemSetPathTemplate.render({
            customer_id: customerId,
            feed_id: feedId,
            feed_item_set_id: feedItemSetId,
        });
    }
    /**
     * Parse the customer_id from FeedItemSet resource.
     *
     * @param {string} feedItemSetName
     *   A fully-qualified path representing FeedItemSet resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromFeedItemSetName(feedItemSetName) {
        return this.pathTemplates.feedItemSetPathTemplate.match(feedItemSetName).customer_id;
    }
    /**
     * Parse the feed_id from FeedItemSet resource.
     *
     * @param {string} feedItemSetName
     *   A fully-qualified path representing FeedItemSet resource.
     * @returns {string} A string representing the feed_id.
     */
    matchFeedIdFromFeedItemSetName(feedItemSetName) {
        return this.pathTemplates.feedItemSetPathTemplate.match(feedItemSetName).feed_id;
    }
    /**
     * Parse the feed_item_set_id from FeedItemSet resource.
     *
     * @param {string} feedItemSetName
     *   A fully-qualified path representing FeedItemSet resource.
     * @returns {string} A string representing the feed_item_set_id.
     */
    matchFeedItemSetIdFromFeedItemSetName(feedItemSetName) {
        return this.pathTemplates.feedItemSetPathTemplate.match(feedItemSetName).feed_item_set_id;
    }
    /**
     * Return a fully-qualified feedItemSetLink resource name string.
     *
     * @param {string} customer_id
     * @param {string} feed_id
     * @param {string} feed_item_set_id
     * @param {string} feed_item_id
     * @returns {string} Resource name string.
     */
    feedItemSetLinkPath(customerId, feedId, feedItemSetId, feedItemId) {
        return this.pathTemplates.feedItemSetLinkPathTemplate.render({
            customer_id: customerId,
            feed_id: feedId,
            feed_item_set_id: feedItemSetId,
            feed_item_id: feedItemId,
        });
    }
    /**
     * Parse the customer_id from FeedItemSetLink resource.
     *
     * @param {string} feedItemSetLinkName
     *   A fully-qualified path representing FeedItemSetLink resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromFeedItemSetLinkName(feedItemSetLinkName) {
        return this.pathTemplates.feedItemSetLinkPathTemplate.match(feedItemSetLinkName).customer_id;
    }
    /**
     * Parse the feed_id from FeedItemSetLink resource.
     *
     * @param {string} feedItemSetLinkName
     *   A fully-qualified path representing FeedItemSetLink resource.
     * @returns {string} A string representing the feed_id.
     */
    matchFeedIdFromFeedItemSetLinkName(feedItemSetLinkName) {
        return this.pathTemplates.feedItemSetLinkPathTemplate.match(feedItemSetLinkName).feed_id;
    }
    /**
     * Parse the feed_item_set_id from FeedItemSetLink resource.
     *
     * @param {string} feedItemSetLinkName
     *   A fully-qualified path representing FeedItemSetLink resource.
     * @returns {string} A string representing the feed_item_set_id.
     */
    matchFeedItemSetIdFromFeedItemSetLinkName(feedItemSetLinkName) {
        return this.pathTemplates.feedItemSetLinkPathTemplate.match(feedItemSetLinkName).feed_item_set_id;
    }
    /**
     * Parse the feed_item_id from FeedItemSetLink resource.
     *
     * @param {string} feedItemSetLinkName
     *   A fully-qualified path representing FeedItemSetLink resource.
     * @returns {string} A string representing the feed_item_id.
     */
    matchFeedItemIdFromFeedItemSetLinkName(feedItemSetLinkName) {
        return this.pathTemplates.feedItemSetLinkPathTemplate.match(feedItemSetLinkName).feed_item_id;
    }
    /**
     * Return a fully-qualified feedItemTarget resource name string.
     *
     * @param {string} customer_id
     * @param {string} feed_id
     * @param {string} feed_item_id
     * @param {string} feed_item_target_type
     * @param {string} feed_item_target_id
     * @returns {string} Resource name string.
     */
    feedItemTargetPath(customerId, feedId, feedItemId, feedItemTargetType, feedItemTargetId) {
        return this.pathTemplates.feedItemTargetPathTemplate.render({
            customer_id: customerId,
            feed_id: feedId,
            feed_item_id: feedItemId,
            feed_item_target_type: feedItemTargetType,
            feed_item_target_id: feedItemTargetId,
        });
    }
    /**
     * Parse the customer_id from FeedItemTarget resource.
     *
     * @param {string} feedItemTargetName
     *   A fully-qualified path representing FeedItemTarget resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromFeedItemTargetName(feedItemTargetName) {
        return this.pathTemplates.feedItemTargetPathTemplate.match(feedItemTargetName).customer_id;
    }
    /**
     * Parse the feed_id from FeedItemTarget resource.
     *
     * @param {string} feedItemTargetName
     *   A fully-qualified path representing FeedItemTarget resource.
     * @returns {string} A string representing the feed_id.
     */
    matchFeedIdFromFeedItemTargetName(feedItemTargetName) {
        return this.pathTemplates.feedItemTargetPathTemplate.match(feedItemTargetName).feed_id;
    }
    /**
     * Parse the feed_item_id from FeedItemTarget resource.
     *
     * @param {string} feedItemTargetName
     *   A fully-qualified path representing FeedItemTarget resource.
     * @returns {string} A string representing the feed_item_id.
     */
    matchFeedItemIdFromFeedItemTargetName(feedItemTargetName) {
        return this.pathTemplates.feedItemTargetPathTemplate.match(feedItemTargetName).feed_item_id;
    }
    /**
     * Parse the feed_item_target_type from FeedItemTarget resource.
     *
     * @param {string} feedItemTargetName
     *   A fully-qualified path representing FeedItemTarget resource.
     * @returns {string} A string representing the feed_item_target_type.
     */
    matchFeedItemTargetTypeFromFeedItemTargetName(feedItemTargetName) {
        return this.pathTemplates.feedItemTargetPathTemplate.match(feedItemTargetName).feed_item_target_type;
    }
    /**
     * Parse the feed_item_target_id from FeedItemTarget resource.
     *
     * @param {string} feedItemTargetName
     *   A fully-qualified path representing FeedItemTarget resource.
     * @returns {string} A string representing the feed_item_target_id.
     */
    matchFeedItemTargetIdFromFeedItemTargetName(feedItemTargetName) {
        return this.pathTemplates.feedItemTargetPathTemplate.match(feedItemTargetName).feed_item_target_id;
    }
    /**
     * Return a fully-qualified feedMapping resource name string.
     *
     * @param {string} customer_id
     * @param {string} feed_id
     * @param {string} feed_mapping_id
     * @returns {string} Resource name string.
     */
    feedMappingPath(customerId, feedId, feedMappingId) {
        return this.pathTemplates.feedMappingPathTemplate.render({
            customer_id: customerId,
            feed_id: feedId,
            feed_mapping_id: feedMappingId,
        });
    }
    /**
     * Parse the customer_id from FeedMapping resource.
     *
     * @param {string} feedMappingName
     *   A fully-qualified path representing FeedMapping resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromFeedMappingName(feedMappingName) {
        return this.pathTemplates.feedMappingPathTemplate.match(feedMappingName).customer_id;
    }
    /**
     * Parse the feed_id from FeedMapping resource.
     *
     * @param {string} feedMappingName
     *   A fully-qualified path representing FeedMapping resource.
     * @returns {string} A string representing the feed_id.
     */
    matchFeedIdFromFeedMappingName(feedMappingName) {
        return this.pathTemplates.feedMappingPathTemplate.match(feedMappingName).feed_id;
    }
    /**
     * Parse the feed_mapping_id from FeedMapping resource.
     *
     * @param {string} feedMappingName
     *   A fully-qualified path representing FeedMapping resource.
     * @returns {string} A string representing the feed_mapping_id.
     */
    matchFeedMappingIdFromFeedMappingName(feedMappingName) {
        return this.pathTemplates.feedMappingPathTemplate.match(feedMappingName).feed_mapping_id;
    }
    /**
     * Return a fully-qualified feedPlaceholderView resource name string.
     *
     * @param {string} customer_id
     * @param {string} placeholder_type
     * @returns {string} Resource name string.
     */
    feedPlaceholderViewPath(customerId, placeholderType) {
        return this.pathTemplates.feedPlaceholderViewPathTemplate.render({
            customer_id: customerId,
            placeholder_type: placeholderType,
        });
    }
    /**
     * Parse the customer_id from FeedPlaceholderView resource.
     *
     * @param {string} feedPlaceholderViewName
     *   A fully-qualified path representing FeedPlaceholderView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromFeedPlaceholderViewName(feedPlaceholderViewName) {
        return this.pathTemplates.feedPlaceholderViewPathTemplate.match(feedPlaceholderViewName).customer_id;
    }
    /**
     * Parse the placeholder_type from FeedPlaceholderView resource.
     *
     * @param {string} feedPlaceholderViewName
     *   A fully-qualified path representing FeedPlaceholderView resource.
     * @returns {string} A string representing the placeholder_type.
     */
    matchPlaceholderTypeFromFeedPlaceholderViewName(feedPlaceholderViewName) {
        return this.pathTemplates.feedPlaceholderViewPathTemplate.match(feedPlaceholderViewName).placeholder_type;
    }
    /**
     * Return a fully-qualified genderView resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    genderViewPath(customerId, adGroupId, criterionId) {
        return this.pathTemplates.genderViewPathTemplate.render({
            customer_id: customerId,
            ad_group_id: adGroupId,
            criterion_id: criterionId,
        });
    }
    /**
     * Parse the customer_id from GenderView resource.
     *
     * @param {string} genderViewName
     *   A fully-qualified path representing GenderView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromGenderViewName(genderViewName) {
        return this.pathTemplates.genderViewPathTemplate.match(genderViewName).customer_id;
    }
    /**
     * Parse the ad_group_id from GenderView resource.
     *
     * @param {string} genderViewName
     *   A fully-qualified path representing GenderView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromGenderViewName(genderViewName) {
        return this.pathTemplates.genderViewPathTemplate.match(genderViewName).ad_group_id;
    }
    /**
     * Parse the criterion_id from GenderView resource.
     *
     * @param {string} genderViewName
     *   A fully-qualified path representing GenderView resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromGenderViewName(genderViewName) {
        return this.pathTemplates.genderViewPathTemplate.match(genderViewName).criterion_id;
    }
    /**
     * Return a fully-qualified geoTargetConstant resource name string.
     *
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    geoTargetConstantPath(criterionId) {
        return this.pathTemplates.geoTargetConstantPathTemplate.render({
            criterion_id: criterionId,
        });
    }
    /**
     * Parse the criterion_id from GeoTargetConstant resource.
     *
     * @param {string} geoTargetConstantName
     *   A fully-qualified path representing GeoTargetConstant resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromGeoTargetConstantName(geoTargetConstantName) {
        return this.pathTemplates.geoTargetConstantPathTemplate.match(geoTargetConstantName).criterion_id;
    }
    /**
     * Return a fully-qualified geographicView resource name string.
     *
     * @param {string} customer_id
     * @param {string} country_criterion_id
     * @param {string} location_type
     * @returns {string} Resource name string.
     */
    geographicViewPath(customerId, countryCriterionId, locationType) {
        return this.pathTemplates.geographicViewPathTemplate.render({
            customer_id: customerId,
            country_criterion_id: countryCriterionId,
            location_type: locationType,
        });
    }
    /**
     * Parse the customer_id from GeographicView resource.
     *
     * @param {string} geographicViewName
     *   A fully-qualified path representing GeographicView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromGeographicViewName(geographicViewName) {
        return this.pathTemplates.geographicViewPathTemplate.match(geographicViewName).customer_id;
    }
    /**
     * Parse the country_criterion_id from GeographicView resource.
     *
     * @param {string} geographicViewName
     *   A fully-qualified path representing GeographicView resource.
     * @returns {string} A string representing the country_criterion_id.
     */
    matchCountryCriterionIdFromGeographicViewName(geographicViewName) {
        return this.pathTemplates.geographicViewPathTemplate.match(geographicViewName).country_criterion_id;
    }
    /**
     * Parse the location_type from GeographicView resource.
     *
     * @param {string} geographicViewName
     *   A fully-qualified path representing GeographicView resource.
     * @returns {string} A string representing the location_type.
     */
    matchLocationTypeFromGeographicViewName(geographicViewName) {
        return this.pathTemplates.geographicViewPathTemplate.match(geographicViewName).location_type;
    }
    /**
     * Return a fully-qualified googleAdsField resource name string.
     *
     * @param {string} google_ads_field
     * @returns {string} Resource name string.
     */
    googleAdsFieldPath(googleAdsField) {
        return this.pathTemplates.googleAdsFieldPathTemplate.render({
            google_ads_field: googleAdsField,
        });
    }
    /**
     * Parse the google_ads_field from GoogleAdsField resource.
     *
     * @param {string} googleAdsFieldName
     *   A fully-qualified path representing GoogleAdsField resource.
     * @returns {string} A string representing the google_ads_field.
     */
    matchGoogleAdsFieldFromGoogleAdsFieldName(googleAdsFieldName) {
        return this.pathTemplates.googleAdsFieldPathTemplate.match(googleAdsFieldName).google_ads_field;
    }
    /**
     * Return a fully-qualified groupPlacementView resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @returns {string} Resource name string.
     */
    groupPlacementViewPath(customerId, adGroupId) {
        return this.pathTemplates.groupPlacementViewPathTemplate.render({
            customer_id: customerId,
            ad_group_id: adGroupId,
        });
    }
    /**
     * Parse the customer_id from GroupPlacementView resource.
     *
     * @param {string} groupPlacementViewName
     *   A fully-qualified path representing GroupPlacementView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromGroupPlacementViewName(groupPlacementViewName) {
        return this.pathTemplates.groupPlacementViewPathTemplate.match(groupPlacementViewName).customer_id;
    }
    /**
     * Parse the ad_group_id from GroupPlacementView resource.
     *
     * @param {string} groupPlacementViewName
     *   A fully-qualified path representing GroupPlacementView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromGroupPlacementViewName(groupPlacementViewName) {
        return this.pathTemplates.groupPlacementViewPathTemplate.match(groupPlacementViewName).ad_group_id;
    }
    /**
     * Return a fully-qualified hotelGroupView resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    hotelGroupViewPath(customerId, adGroupId, criterionId) {
        return this.pathTemplates.hotelGroupViewPathTemplate.render({
            customer_id: customerId,
            ad_group_id: adGroupId,
            criterion_id: criterionId,
        });
    }
    /**
     * Parse the customer_id from HotelGroupView resource.
     *
     * @param {string} hotelGroupViewName
     *   A fully-qualified path representing HotelGroupView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromHotelGroupViewName(hotelGroupViewName) {
        return this.pathTemplates.hotelGroupViewPathTemplate.match(hotelGroupViewName).customer_id;
    }
    /**
     * Parse the ad_group_id from HotelGroupView resource.
     *
     * @param {string} hotelGroupViewName
     *   A fully-qualified path representing HotelGroupView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromHotelGroupViewName(hotelGroupViewName) {
        return this.pathTemplates.hotelGroupViewPathTemplate.match(hotelGroupViewName).ad_group_id;
    }
    /**
     * Parse the criterion_id from HotelGroupView resource.
     *
     * @param {string} hotelGroupViewName
     *   A fully-qualified path representing HotelGroupView resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromHotelGroupViewName(hotelGroupViewName) {
        return this.pathTemplates.hotelGroupViewPathTemplate.match(hotelGroupViewName).criterion_id;
    }
    /**
     * Return a fully-qualified hotelPerformanceView resource name string.
     *
     * @param {string} customer_id
     * @returns {string} Resource name string.
     */
    hotelPerformanceViewPath(customerId) {
        return this.pathTemplates.hotelPerformanceViewPathTemplate.render({
            customer_id: customerId,
        });
    }
    /**
     * Parse the customer_id from HotelPerformanceView resource.
     *
     * @param {string} hotelPerformanceViewName
     *   A fully-qualified path representing HotelPerformanceView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromHotelPerformanceViewName(hotelPerformanceViewName) {
        return this.pathTemplates.hotelPerformanceViewPathTemplate.match(hotelPerformanceViewName).customer_id;
    }
    /**
     * Return a fully-qualified hotelReconciliation resource name string.
     *
     * @param {string} customer_id
     * @param {string} commission_id
     * @returns {string} Resource name string.
     */
    hotelReconciliationPath(customerId, commissionId) {
        return this.pathTemplates.hotelReconciliationPathTemplate.render({
            customer_id: customerId,
            commission_id: commissionId,
        });
    }
    /**
     * Parse the customer_id from HotelReconciliation resource.
     *
     * @param {string} hotelReconciliationName
     *   A fully-qualified path representing HotelReconciliation resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromHotelReconciliationName(hotelReconciliationName) {
        return this.pathTemplates.hotelReconciliationPathTemplate.match(hotelReconciliationName).customer_id;
    }
    /**
     * Parse the commission_id from HotelReconciliation resource.
     *
     * @param {string} hotelReconciliationName
     *   A fully-qualified path representing HotelReconciliation resource.
     * @returns {string} A string representing the commission_id.
     */
    matchCommissionIdFromHotelReconciliationName(hotelReconciliationName) {
        return this.pathTemplates.hotelReconciliationPathTemplate.match(hotelReconciliationName).commission_id;
    }
    /**
     * Return a fully-qualified incomeRangeView resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    incomeRangeViewPath(customerId, adGroupId, criterionId) {
        return this.pathTemplates.incomeRangeViewPathTemplate.render({
            customer_id: customerId,
            ad_group_id: adGroupId,
            criterion_id: criterionId,
        });
    }
    /**
     * Parse the customer_id from IncomeRangeView resource.
     *
     * @param {string} incomeRangeViewName
     *   A fully-qualified path representing IncomeRangeView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromIncomeRangeViewName(incomeRangeViewName) {
        return this.pathTemplates.incomeRangeViewPathTemplate.match(incomeRangeViewName).customer_id;
    }
    /**
     * Parse the ad_group_id from IncomeRangeView resource.
     *
     * @param {string} incomeRangeViewName
     *   A fully-qualified path representing IncomeRangeView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromIncomeRangeViewName(incomeRangeViewName) {
        return this.pathTemplates.incomeRangeViewPathTemplate.match(incomeRangeViewName).ad_group_id;
    }
    /**
     * Parse the criterion_id from IncomeRangeView resource.
     *
     * @param {string} incomeRangeViewName
     *   A fully-qualified path representing IncomeRangeView resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromIncomeRangeViewName(incomeRangeViewName) {
        return this.pathTemplates.incomeRangeViewPathTemplate.match(incomeRangeViewName).criterion_id;
    }
    /**
     * Return a fully-qualified invoice resource name string.
     *
     * @param {string} customer_id
     * @param {string} invoice_id
     * @returns {string} Resource name string.
     */
    invoicePath(customerId, invoiceId) {
        return this.pathTemplates.invoicePathTemplate.render({
            customer_id: customerId,
            invoice_id: invoiceId,
        });
    }
    /**
     * Parse the customer_id from Invoice resource.
     *
     * @param {string} invoiceName
     *   A fully-qualified path representing Invoice resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromInvoiceName(invoiceName) {
        return this.pathTemplates.invoicePathTemplate.match(invoiceName).customer_id;
    }
    /**
     * Parse the invoice_id from Invoice resource.
     *
     * @param {string} invoiceName
     *   A fully-qualified path representing Invoice resource.
     * @returns {string} A string representing the invoice_id.
     */
    matchInvoiceIdFromInvoiceName(invoiceName) {
        return this.pathTemplates.invoicePathTemplate.match(invoiceName).invoice_id;
    }
    /**
     * Return a fully-qualified keywordPlan resource name string.
     *
     * @param {string} customer_id
     * @param {string} keyword_plan_id
     * @returns {string} Resource name string.
     */
    keywordPlanPath(customerId, keywordPlanId) {
        return this.pathTemplates.keywordPlanPathTemplate.render({
            customer_id: customerId,
            keyword_plan_id: keywordPlanId,
        });
    }
    /**
     * Parse the customer_id from KeywordPlan resource.
     *
     * @param {string} keywordPlanName
     *   A fully-qualified path representing KeywordPlan resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromKeywordPlanName(keywordPlanName) {
        return this.pathTemplates.keywordPlanPathTemplate.match(keywordPlanName).customer_id;
    }
    /**
     * Parse the keyword_plan_id from KeywordPlan resource.
     *
     * @param {string} keywordPlanName
     *   A fully-qualified path representing KeywordPlan resource.
     * @returns {string} A string representing the keyword_plan_id.
     */
    matchKeywordPlanIdFromKeywordPlanName(keywordPlanName) {
        return this.pathTemplates.keywordPlanPathTemplate.match(keywordPlanName).keyword_plan_id;
    }
    /**
     * Return a fully-qualified keywordPlanAdGroup resource name string.
     *
     * @param {string} customer_id
     * @param {string} keyword_plan_ad_group_id
     * @returns {string} Resource name string.
     */
    keywordPlanAdGroupPath(customerId, keywordPlanAdGroupId) {
        return this.pathTemplates.keywordPlanAdGroupPathTemplate.render({
            customer_id: customerId,
            keyword_plan_ad_group_id: keywordPlanAdGroupId,
        });
    }
    /**
     * Parse the customer_id from KeywordPlanAdGroup resource.
     *
     * @param {string} keywordPlanAdGroupName
     *   A fully-qualified path representing KeywordPlanAdGroup resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromKeywordPlanAdGroupName(keywordPlanAdGroupName) {
        return this.pathTemplates.keywordPlanAdGroupPathTemplate.match(keywordPlanAdGroupName).customer_id;
    }
    /**
     * Parse the keyword_plan_ad_group_id from KeywordPlanAdGroup resource.
     *
     * @param {string} keywordPlanAdGroupName
     *   A fully-qualified path representing KeywordPlanAdGroup resource.
     * @returns {string} A string representing the keyword_plan_ad_group_id.
     */
    matchKeywordPlanAdGroupIdFromKeywordPlanAdGroupName(keywordPlanAdGroupName) {
        return this.pathTemplates.keywordPlanAdGroupPathTemplate.match(keywordPlanAdGroupName).keyword_plan_ad_group_id;
    }
    /**
     * Return a fully-qualified keywordPlanAdGroupKeyword resource name string.
     *
     * @param {string} customer_id
     * @param {string} keyword_plan_ad_group_keyword_id
     * @returns {string} Resource name string.
     */
    keywordPlanAdGroupKeywordPath(customerId, keywordPlanAdGroupKeywordId) {
        return this.pathTemplates.keywordPlanAdGroupKeywordPathTemplate.render({
            customer_id: customerId,
            keyword_plan_ad_group_keyword_id: keywordPlanAdGroupKeywordId,
        });
    }
    /**
     * Parse the customer_id from KeywordPlanAdGroupKeyword resource.
     *
     * @param {string} keywordPlanAdGroupKeywordName
     *   A fully-qualified path representing KeywordPlanAdGroupKeyword resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromKeywordPlanAdGroupKeywordName(keywordPlanAdGroupKeywordName) {
        return this.pathTemplates.keywordPlanAdGroupKeywordPathTemplate.match(keywordPlanAdGroupKeywordName).customer_id;
    }
    /**
     * Parse the keyword_plan_ad_group_keyword_id from KeywordPlanAdGroupKeyword resource.
     *
     * @param {string} keywordPlanAdGroupKeywordName
     *   A fully-qualified path representing KeywordPlanAdGroupKeyword resource.
     * @returns {string} A string representing the keyword_plan_ad_group_keyword_id.
     */
    matchKeywordPlanAdGroupKeywordIdFromKeywordPlanAdGroupKeywordName(keywordPlanAdGroupKeywordName) {
        return this.pathTemplates.keywordPlanAdGroupKeywordPathTemplate.match(keywordPlanAdGroupKeywordName).keyword_plan_ad_group_keyword_id;
    }
    /**
     * Return a fully-qualified keywordPlanCampaign resource name string.
     *
     * @param {string} customer_id
     * @param {string} keyword_plan_campaign_id
     * @returns {string} Resource name string.
     */
    keywordPlanCampaignPath(customerId, keywordPlanCampaignId) {
        return this.pathTemplates.keywordPlanCampaignPathTemplate.render({
            customer_id: customerId,
            keyword_plan_campaign_id: keywordPlanCampaignId,
        });
    }
    /**
     * Parse the customer_id from KeywordPlanCampaign resource.
     *
     * @param {string} keywordPlanCampaignName
     *   A fully-qualified path representing KeywordPlanCampaign resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromKeywordPlanCampaignName(keywordPlanCampaignName) {
        return this.pathTemplates.keywordPlanCampaignPathTemplate.match(keywordPlanCampaignName).customer_id;
    }
    /**
     * Parse the keyword_plan_campaign_id from KeywordPlanCampaign resource.
     *
     * @param {string} keywordPlanCampaignName
     *   A fully-qualified path representing KeywordPlanCampaign resource.
     * @returns {string} A string representing the keyword_plan_campaign_id.
     */
    matchKeywordPlanCampaignIdFromKeywordPlanCampaignName(keywordPlanCampaignName) {
        return this.pathTemplates.keywordPlanCampaignPathTemplate.match(keywordPlanCampaignName).keyword_plan_campaign_id;
    }
    /**
     * Return a fully-qualified keywordPlanCampaignKeyword resource name string.
     *
     * @param {string} customer_id
     * @param {string} keyword_plan_campaign_keyword_id
     * @returns {string} Resource name string.
     */
    keywordPlanCampaignKeywordPath(customerId, keywordPlanCampaignKeywordId) {
        return this.pathTemplates.keywordPlanCampaignKeywordPathTemplate.render({
            customer_id: customerId,
            keyword_plan_campaign_keyword_id: keywordPlanCampaignKeywordId,
        });
    }
    /**
     * Parse the customer_id from KeywordPlanCampaignKeyword resource.
     *
     * @param {string} keywordPlanCampaignKeywordName
     *   A fully-qualified path representing KeywordPlanCampaignKeyword resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromKeywordPlanCampaignKeywordName(keywordPlanCampaignKeywordName) {
        return this.pathTemplates.keywordPlanCampaignKeywordPathTemplate.match(keywordPlanCampaignKeywordName).customer_id;
    }
    /**
     * Parse the keyword_plan_campaign_keyword_id from KeywordPlanCampaignKeyword resource.
     *
     * @param {string} keywordPlanCampaignKeywordName
     *   A fully-qualified path representing KeywordPlanCampaignKeyword resource.
     * @returns {string} A string representing the keyword_plan_campaign_keyword_id.
     */
    matchKeywordPlanCampaignKeywordIdFromKeywordPlanCampaignKeywordName(keywordPlanCampaignKeywordName) {
        return this.pathTemplates.keywordPlanCampaignKeywordPathTemplate.match(keywordPlanCampaignKeywordName).keyword_plan_campaign_keyword_id;
    }
    /**
     * Return a fully-qualified keywordThemeConstant resource name string.
     *
     * @param {string} express_category_id
     * @param {string} express_sub_category_id
     * @returns {string} Resource name string.
     */
    keywordThemeConstantPath(expressCategoryId, expressSubCategoryId) {
        return this.pathTemplates.keywordThemeConstantPathTemplate.render({
            express_category_id: expressCategoryId,
            express_sub_category_id: expressSubCategoryId,
        });
    }
    /**
     * Parse the express_category_id from KeywordThemeConstant resource.
     *
     * @param {string} keywordThemeConstantName
     *   A fully-qualified path representing KeywordThemeConstant resource.
     * @returns {string} A string representing the express_category_id.
     */
    matchExpressCategoryIdFromKeywordThemeConstantName(keywordThemeConstantName) {
        return this.pathTemplates.keywordThemeConstantPathTemplate.match(keywordThemeConstantName).express_category_id;
    }
    /**
     * Parse the express_sub_category_id from KeywordThemeConstant resource.
     *
     * @param {string} keywordThemeConstantName
     *   A fully-qualified path representing KeywordThemeConstant resource.
     * @returns {string} A string representing the express_sub_category_id.
     */
    matchExpressSubCategoryIdFromKeywordThemeConstantName(keywordThemeConstantName) {
        return this.pathTemplates.keywordThemeConstantPathTemplate.match(keywordThemeConstantName).express_sub_category_id;
    }
    /**
     * Return a fully-qualified keywordView resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    keywordViewPath(customerId, adGroupId, criterionId) {
        return this.pathTemplates.keywordViewPathTemplate.render({
            customer_id: customerId,
            ad_group_id: adGroupId,
            criterion_id: criterionId,
        });
    }
    /**
     * Parse the customer_id from KeywordView resource.
     *
     * @param {string} keywordViewName
     *   A fully-qualified path representing KeywordView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromKeywordViewName(keywordViewName) {
        return this.pathTemplates.keywordViewPathTemplate.match(keywordViewName).customer_id;
    }
    /**
     * Parse the ad_group_id from KeywordView resource.
     *
     * @param {string} keywordViewName
     *   A fully-qualified path representing KeywordView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromKeywordViewName(keywordViewName) {
        return this.pathTemplates.keywordViewPathTemplate.match(keywordViewName).ad_group_id;
    }
    /**
     * Parse the criterion_id from KeywordView resource.
     *
     * @param {string} keywordViewName
     *   A fully-qualified path representing KeywordView resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromKeywordViewName(keywordViewName) {
        return this.pathTemplates.keywordViewPathTemplate.match(keywordViewName).criterion_id;
    }
    /**
     * Return a fully-qualified label resource name string.
     *
     * @param {string} customer_id
     * @param {string} label_id
     * @returns {string} Resource name string.
     */
    labelPath(customerId, labelId) {
        return this.pathTemplates.labelPathTemplate.render({
            customer_id: customerId,
            label_id: labelId,
        });
    }
    /**
     * Parse the customer_id from Label resource.
     *
     * @param {string} labelName
     *   A fully-qualified path representing Label resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromLabelName(labelName) {
        return this.pathTemplates.labelPathTemplate.match(labelName).customer_id;
    }
    /**
     * Parse the label_id from Label resource.
     *
     * @param {string} labelName
     *   A fully-qualified path representing Label resource.
     * @returns {string} A string representing the label_id.
     */
    matchLabelIdFromLabelName(labelName) {
        return this.pathTemplates.labelPathTemplate.match(labelName).label_id;
    }
    /**
     * Return a fully-qualified landingPageView resource name string.
     *
     * @param {string} customer_id
     * @param {string} unexpanded_final_url_fingerprint
     * @returns {string} Resource name string.
     */
    landingPageViewPath(customerId, unexpandedFinalUrlFingerprint) {
        return this.pathTemplates.landingPageViewPathTemplate.render({
            customer_id: customerId,
            unexpanded_final_url_fingerprint: unexpandedFinalUrlFingerprint,
        });
    }
    /**
     * Parse the customer_id from LandingPageView resource.
     *
     * @param {string} landingPageViewName
     *   A fully-qualified path representing LandingPageView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromLandingPageViewName(landingPageViewName) {
        return this.pathTemplates.landingPageViewPathTemplate.match(landingPageViewName).customer_id;
    }
    /**
     * Parse the unexpanded_final_url_fingerprint from LandingPageView resource.
     *
     * @param {string} landingPageViewName
     *   A fully-qualified path representing LandingPageView resource.
     * @returns {string} A string representing the unexpanded_final_url_fingerprint.
     */
    matchUnexpandedFinalUrlFingerprintFromLandingPageViewName(landingPageViewName) {
        return this.pathTemplates.landingPageViewPathTemplate.match(landingPageViewName).unexpanded_final_url_fingerprint;
    }
    /**
     * Return a fully-qualified languageConstant resource name string.
     *
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    languageConstantPath(criterionId) {
        return this.pathTemplates.languageConstantPathTemplate.render({
            criterion_id: criterionId,
        });
    }
    /**
     * Parse the criterion_id from LanguageConstant resource.
     *
     * @param {string} languageConstantName
     *   A fully-qualified path representing LanguageConstant resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromLanguageConstantName(languageConstantName) {
        return this.pathTemplates.languageConstantPathTemplate.match(languageConstantName).criterion_id;
    }
    /**
     * Return a fully-qualified leadFormSubmissionData resource name string.
     *
     * @param {string} customer_id
     * @param {string} lead_form_user_submission_id
     * @returns {string} Resource name string.
     */
    leadFormSubmissionDataPath(customerId, leadFormUserSubmissionId) {
        return this.pathTemplates.leadFormSubmissionDataPathTemplate.render({
            customer_id: customerId,
            lead_form_user_submission_id: leadFormUserSubmissionId,
        });
    }
    /**
     * Parse the customer_id from LeadFormSubmissionData resource.
     *
     * @param {string} leadFormSubmissionDataName
     *   A fully-qualified path representing LeadFormSubmissionData resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromLeadFormSubmissionDataName(leadFormSubmissionDataName) {
        return this.pathTemplates.leadFormSubmissionDataPathTemplate.match(leadFormSubmissionDataName).customer_id;
    }
    /**
     * Parse the lead_form_user_submission_id from LeadFormSubmissionData resource.
     *
     * @param {string} leadFormSubmissionDataName
     *   A fully-qualified path representing LeadFormSubmissionData resource.
     * @returns {string} A string representing the lead_form_user_submission_id.
     */
    matchLeadFormUserSubmissionIdFromLeadFormSubmissionDataName(leadFormSubmissionDataName) {
        return this.pathTemplates.leadFormSubmissionDataPathTemplate.match(leadFormSubmissionDataName).lead_form_user_submission_id;
    }
    /**
     * Return a fully-qualified lifeEvent resource name string.
     *
     * @param {string} customer_id
     * @param {string} life_event_id
     * @returns {string} Resource name string.
     */
    lifeEventPath(customerId, lifeEventId) {
        return this.pathTemplates.lifeEventPathTemplate.render({
            customer_id: customerId,
            life_event_id: lifeEventId,
        });
    }
    /**
     * Parse the customer_id from LifeEvent resource.
     *
     * @param {string} lifeEventName
     *   A fully-qualified path representing LifeEvent resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromLifeEventName(lifeEventName) {
        return this.pathTemplates.lifeEventPathTemplate.match(lifeEventName).customer_id;
    }
    /**
     * Parse the life_event_id from LifeEvent resource.
     *
     * @param {string} lifeEventName
     *   A fully-qualified path representing LifeEvent resource.
     * @returns {string} A string representing the life_event_id.
     */
    matchLifeEventIdFromLifeEventName(lifeEventName) {
        return this.pathTemplates.lifeEventPathTemplate.match(lifeEventName).life_event_id;
    }
    /**
     * Return a fully-qualified locationView resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    locationViewPath(customerId, campaignId, criterionId) {
        return this.pathTemplates.locationViewPathTemplate.render({
            customer_id: customerId,
            campaign_id: campaignId,
            criterion_id: criterionId,
        });
    }
    /**
     * Parse the customer_id from LocationView resource.
     *
     * @param {string} locationViewName
     *   A fully-qualified path representing LocationView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromLocationViewName(locationViewName) {
        return this.pathTemplates.locationViewPathTemplate.match(locationViewName).customer_id;
    }
    /**
     * Parse the campaign_id from LocationView resource.
     *
     * @param {string} locationViewName
     *   A fully-qualified path representing LocationView resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromLocationViewName(locationViewName) {
        return this.pathTemplates.locationViewPathTemplate.match(locationViewName).campaign_id;
    }
    /**
     * Parse the criterion_id from LocationView resource.
     *
     * @param {string} locationViewName
     *   A fully-qualified path representing LocationView resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromLocationViewName(locationViewName) {
        return this.pathTemplates.locationViewPathTemplate.match(locationViewName).criterion_id;
    }
    /**
     * Return a fully-qualified managedPlacementView resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    managedPlacementViewPath(customerId, adGroupId, criterionId) {
        return this.pathTemplates.managedPlacementViewPathTemplate.render({
            customer_id: customerId,
            ad_group_id: adGroupId,
            criterion_id: criterionId,
        });
    }
    /**
     * Parse the customer_id from ManagedPlacementView resource.
     *
     * @param {string} managedPlacementViewName
     *   A fully-qualified path representing ManagedPlacementView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromManagedPlacementViewName(managedPlacementViewName) {
        return this.pathTemplates.managedPlacementViewPathTemplate.match(managedPlacementViewName).customer_id;
    }
    /**
     * Parse the ad_group_id from ManagedPlacementView resource.
     *
     * @param {string} managedPlacementViewName
     *   A fully-qualified path representing ManagedPlacementView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromManagedPlacementViewName(managedPlacementViewName) {
        return this.pathTemplates.managedPlacementViewPathTemplate.match(managedPlacementViewName).ad_group_id;
    }
    /**
     * Parse the criterion_id from ManagedPlacementView resource.
     *
     * @param {string} managedPlacementViewName
     *   A fully-qualified path representing ManagedPlacementView resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromManagedPlacementViewName(managedPlacementViewName) {
        return this.pathTemplates.managedPlacementViewPathTemplate.match(managedPlacementViewName).criterion_id;
    }
    /**
     * Return a fully-qualified mediaFile resource name string.
     *
     * @param {string} customer_id
     * @param {string} media_file_id
     * @returns {string} Resource name string.
     */
    mediaFilePath(customerId, mediaFileId) {
        return this.pathTemplates.mediaFilePathTemplate.render({
            customer_id: customerId,
            media_file_id: mediaFileId,
        });
    }
    /**
     * Parse the customer_id from MediaFile resource.
     *
     * @param {string} mediaFileName
     *   A fully-qualified path representing MediaFile resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromMediaFileName(mediaFileName) {
        return this.pathTemplates.mediaFilePathTemplate.match(mediaFileName).customer_id;
    }
    /**
     * Parse the media_file_id from MediaFile resource.
     *
     * @param {string} mediaFileName
     *   A fully-qualified path representing MediaFile resource.
     * @returns {string} A string representing the media_file_id.
     */
    matchMediaFileIdFromMediaFileName(mediaFileName) {
        return this.pathTemplates.mediaFilePathTemplate.match(mediaFileName).media_file_id;
    }
    /**
     * Return a fully-qualified merchantCenterLink resource name string.
     *
     * @param {string} customer_id
     * @param {string} merchant_center_id
     * @returns {string} Resource name string.
     */
    merchantCenterLinkPath(customerId, merchantCenterId) {
        return this.pathTemplates.merchantCenterLinkPathTemplate.render({
            customer_id: customerId,
            merchant_center_id: merchantCenterId,
        });
    }
    /**
     * Parse the customer_id from MerchantCenterLink resource.
     *
     * @param {string} merchantCenterLinkName
     *   A fully-qualified path representing MerchantCenterLink resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromMerchantCenterLinkName(merchantCenterLinkName) {
        return this.pathTemplates.merchantCenterLinkPathTemplate.match(merchantCenterLinkName).customer_id;
    }
    /**
     * Parse the merchant_center_id from MerchantCenterLink resource.
     *
     * @param {string} merchantCenterLinkName
     *   A fully-qualified path representing MerchantCenterLink resource.
     * @returns {string} A string representing the merchant_center_id.
     */
    matchMerchantCenterIdFromMerchantCenterLinkName(merchantCenterLinkName) {
        return this.pathTemplates.merchantCenterLinkPathTemplate.match(merchantCenterLinkName).merchant_center_id;
    }
    /**
     * Return a fully-qualified mobileAppCategoryConstant resource name string.
     *
     * @param {string} mobile_app_category_id
     * @returns {string} Resource name string.
     */
    mobileAppCategoryConstantPath(mobileAppCategoryId) {
        return this.pathTemplates.mobileAppCategoryConstantPathTemplate.render({
            mobile_app_category_id: mobileAppCategoryId,
        });
    }
    /**
     * Parse the mobile_app_category_id from MobileAppCategoryConstant resource.
     *
     * @param {string} mobileAppCategoryConstantName
     *   A fully-qualified path representing MobileAppCategoryConstant resource.
     * @returns {string} A string representing the mobile_app_category_id.
     */
    matchMobileAppCategoryIdFromMobileAppCategoryConstantName(mobileAppCategoryConstantName) {
        return this.pathTemplates.mobileAppCategoryConstantPathTemplate.match(mobileAppCategoryConstantName).mobile_app_category_id;
    }
    /**
     * Return a fully-qualified mobileDeviceConstant resource name string.
     *
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    mobileDeviceConstantPath(criterionId) {
        return this.pathTemplates.mobileDeviceConstantPathTemplate.render({
            criterion_id: criterionId,
        });
    }
    /**
     * Parse the criterion_id from MobileDeviceConstant resource.
     *
     * @param {string} mobileDeviceConstantName
     *   A fully-qualified path representing MobileDeviceConstant resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromMobileDeviceConstantName(mobileDeviceConstantName) {
        return this.pathTemplates.mobileDeviceConstantPathTemplate.match(mobileDeviceConstantName).criterion_id;
    }
    /**
     * Return a fully-qualified offlineUserDataJob resource name string.
     *
     * @param {string} customer_id
     * @param {string} offline_user_data_update_id
     * @returns {string} Resource name string.
     */
    offlineUserDataJobPath(customerId, offlineUserDataUpdateId) {
        return this.pathTemplates.offlineUserDataJobPathTemplate.render({
            customer_id: customerId,
            offline_user_data_update_id: offlineUserDataUpdateId,
        });
    }
    /**
     * Parse the customer_id from OfflineUserDataJob resource.
     *
     * @param {string} offlineUserDataJobName
     *   A fully-qualified path representing OfflineUserDataJob resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromOfflineUserDataJobName(offlineUserDataJobName) {
        return this.pathTemplates.offlineUserDataJobPathTemplate.match(offlineUserDataJobName).customer_id;
    }
    /**
     * Parse the offline_user_data_update_id from OfflineUserDataJob resource.
     *
     * @param {string} offlineUserDataJobName
     *   A fully-qualified path representing OfflineUserDataJob resource.
     * @returns {string} A string representing the offline_user_data_update_id.
     */
    matchOfflineUserDataUpdateIdFromOfflineUserDataJobName(offlineUserDataJobName) {
        return this.pathTemplates.offlineUserDataJobPathTemplate.match(offlineUserDataJobName).offline_user_data_update_id;
    }
    /**
     * Return a fully-qualified operatingSystemVersionConstant resource name string.
     *
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    operatingSystemVersionConstantPath(criterionId) {
        return this.pathTemplates.operatingSystemVersionConstantPathTemplate.render({
            criterion_id: criterionId,
        });
    }
    /**
     * Parse the criterion_id from OperatingSystemVersionConstant resource.
     *
     * @param {string} operatingSystemVersionConstantName
     *   A fully-qualified path representing OperatingSystemVersionConstant resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromOperatingSystemVersionConstantName(operatingSystemVersionConstantName) {
        return this.pathTemplates.operatingSystemVersionConstantPathTemplate.match(operatingSystemVersionConstantName).criterion_id;
    }
    /**
     * Return a fully-qualified paidOrganicSearchTermView resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} ad_group_id
     * @returns {string} Resource name string.
     */
    paidOrganicSearchTermViewPath(customerId, campaignId, adGroupId) {
        return this.pathTemplates.paidOrganicSearchTermViewPathTemplate.render({
            customer_id: customerId,
            campaign_id: campaignId,
            ad_group_id: adGroupId,
        });
    }
    /**
     * Parse the customer_id from PaidOrganicSearchTermView resource.
     *
     * @param {string} paidOrganicSearchTermViewName
     *   A fully-qualified path representing PaidOrganicSearchTermView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromPaidOrganicSearchTermViewName(paidOrganicSearchTermViewName) {
        return this.pathTemplates.paidOrganicSearchTermViewPathTemplate.match(paidOrganicSearchTermViewName).customer_id;
    }
    /**
     * Parse the campaign_id from PaidOrganicSearchTermView resource.
     *
     * @param {string} paidOrganicSearchTermViewName
     *   A fully-qualified path representing PaidOrganicSearchTermView resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromPaidOrganicSearchTermViewName(paidOrganicSearchTermViewName) {
        return this.pathTemplates.paidOrganicSearchTermViewPathTemplate.match(paidOrganicSearchTermViewName).campaign_id;
    }
    /**
     * Parse the ad_group_id from PaidOrganicSearchTermView resource.
     *
     * @param {string} paidOrganicSearchTermViewName
     *   A fully-qualified path representing PaidOrganicSearchTermView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromPaidOrganicSearchTermViewName(paidOrganicSearchTermViewName) {
        return this.pathTemplates.paidOrganicSearchTermViewPathTemplate.match(paidOrganicSearchTermViewName).ad_group_id;
    }
    /**
     * Return a fully-qualified parentalStatusView resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    parentalStatusViewPath(customerId, adGroupId, criterionId) {
        return this.pathTemplates.parentalStatusViewPathTemplate.render({
            customer_id: customerId,
            ad_group_id: adGroupId,
            criterion_id: criterionId,
        });
    }
    /**
     * Parse the customer_id from ParentalStatusView resource.
     *
     * @param {string} parentalStatusViewName
     *   A fully-qualified path representing ParentalStatusView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromParentalStatusViewName(parentalStatusViewName) {
        return this.pathTemplates.parentalStatusViewPathTemplate.match(parentalStatusViewName).customer_id;
    }
    /**
     * Parse the ad_group_id from ParentalStatusView resource.
     *
     * @param {string} parentalStatusViewName
     *   A fully-qualified path representing ParentalStatusView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromParentalStatusViewName(parentalStatusViewName) {
        return this.pathTemplates.parentalStatusViewPathTemplate.match(parentalStatusViewName).ad_group_id;
    }
    /**
     * Parse the criterion_id from ParentalStatusView resource.
     *
     * @param {string} parentalStatusViewName
     *   A fully-qualified path representing ParentalStatusView resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromParentalStatusViewName(parentalStatusViewName) {
        return this.pathTemplates.parentalStatusViewPathTemplate.match(parentalStatusViewName).criterion_id;
    }
    /**
     * Return a fully-qualified paymentsAccount resource name string.
     *
     * @param {string} customer_id
     * @param {string} payments_account_id
     * @returns {string} Resource name string.
     */
    paymentsAccountPath(customerId, paymentsAccountId) {
        return this.pathTemplates.paymentsAccountPathTemplate.render({
            customer_id: customerId,
            payments_account_id: paymentsAccountId,
        });
    }
    /**
     * Parse the customer_id from PaymentsAccount resource.
     *
     * @param {string} paymentsAccountName
     *   A fully-qualified path representing PaymentsAccount resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromPaymentsAccountName(paymentsAccountName) {
        return this.pathTemplates.paymentsAccountPathTemplate.match(paymentsAccountName).customer_id;
    }
    /**
     * Parse the payments_account_id from PaymentsAccount resource.
     *
     * @param {string} paymentsAccountName
     *   A fully-qualified path representing PaymentsAccount resource.
     * @returns {string} A string representing the payments_account_id.
     */
    matchPaymentsAccountIdFromPaymentsAccountName(paymentsAccountName) {
        return this.pathTemplates.paymentsAccountPathTemplate.match(paymentsAccountName).payments_account_id;
    }
    /**
     * Return a fully-qualified perStoreView resource name string.
     *
     * @param {string} customer_id
     * @param {string} place_id
     * @returns {string} Resource name string.
     */
    perStoreViewPath(customerId, placeId) {
        return this.pathTemplates.perStoreViewPathTemplate.render({
            customer_id: customerId,
            place_id: placeId,
        });
    }
    /**
     * Parse the customer_id from PerStoreView resource.
     *
     * @param {string} perStoreViewName
     *   A fully-qualified path representing PerStoreView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromPerStoreViewName(perStoreViewName) {
        return this.pathTemplates.perStoreViewPathTemplate.match(perStoreViewName).customer_id;
    }
    /**
     * Parse the place_id from PerStoreView resource.
     *
     * @param {string} perStoreViewName
     *   A fully-qualified path representing PerStoreView resource.
     * @returns {string} A string representing the place_id.
     */
    matchPlaceIdFromPerStoreViewName(perStoreViewName) {
        return this.pathTemplates.perStoreViewPathTemplate.match(perStoreViewName).place_id;
    }
    /**
     * Return a fully-qualified productBiddingCategoryConstant resource name string.
     *
     * @param {string} country_code
     * @param {string} level
     * @param {string} id
     * @returns {string} Resource name string.
     */
    productBiddingCategoryConstantPath(countryCode, level, id) {
        return this.pathTemplates.productBiddingCategoryConstantPathTemplate.render({
            country_code: countryCode,
            level: level,
            id: id,
        });
    }
    /**
     * Parse the country_code from ProductBiddingCategoryConstant resource.
     *
     * @param {string} productBiddingCategoryConstantName
     *   A fully-qualified path representing ProductBiddingCategoryConstant resource.
     * @returns {string} A string representing the country_code.
     */
    matchCountryCodeFromProductBiddingCategoryConstantName(productBiddingCategoryConstantName) {
        return this.pathTemplates.productBiddingCategoryConstantPathTemplate.match(productBiddingCategoryConstantName).country_code;
    }
    /**
     * Parse the level from ProductBiddingCategoryConstant resource.
     *
     * @param {string} productBiddingCategoryConstantName
     *   A fully-qualified path representing ProductBiddingCategoryConstant resource.
     * @returns {string} A string representing the level.
     */
    matchLevelFromProductBiddingCategoryConstantName(productBiddingCategoryConstantName) {
        return this.pathTemplates.productBiddingCategoryConstantPathTemplate.match(productBiddingCategoryConstantName).level;
    }
    /**
     * Parse the id from ProductBiddingCategoryConstant resource.
     *
     * @param {string} productBiddingCategoryConstantName
     *   A fully-qualified path representing ProductBiddingCategoryConstant resource.
     * @returns {string} A string representing the id.
     */
    matchIdFromProductBiddingCategoryConstantName(productBiddingCategoryConstantName) {
        return this.pathTemplates.productBiddingCategoryConstantPathTemplate.match(productBiddingCategoryConstantName).id;
    }
    /**
     * Return a fully-qualified productGroupView resource name string.
     *
     * @param {string} customer_id
     * @param {string} adgroup_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    productGroupViewPath(customerId, adgroupId, criterionId) {
        return this.pathTemplates.productGroupViewPathTemplate.render({
            customer_id: customerId,
            adgroup_id: adgroupId,
            criterion_id: criterionId,
        });
    }
    /**
     * Parse the customer_id from ProductGroupView resource.
     *
     * @param {string} productGroupViewName
     *   A fully-qualified path representing ProductGroupView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromProductGroupViewName(productGroupViewName) {
        return this.pathTemplates.productGroupViewPathTemplate.match(productGroupViewName).customer_id;
    }
    /**
     * Parse the adgroup_id from ProductGroupView resource.
     *
     * @param {string} productGroupViewName
     *   A fully-qualified path representing ProductGroupView resource.
     * @returns {string} A string representing the adgroup_id.
     */
    matchAdgroupIdFromProductGroupViewName(productGroupViewName) {
        return this.pathTemplates.productGroupViewPathTemplate.match(productGroupViewName).adgroup_id;
    }
    /**
     * Parse the criterion_id from ProductGroupView resource.
     *
     * @param {string} productGroupViewName
     *   A fully-qualified path representing ProductGroupView resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromProductGroupViewName(productGroupViewName) {
        return this.pathTemplates.productGroupViewPathTemplate.match(productGroupViewName).criterion_id;
    }
    /**
     * Return a fully-qualified productLink resource name string.
     *
     * @param {string} customer_id
     * @param {string} product_link_id
     * @returns {string} Resource name string.
     */
    productLinkPath(customerId, productLinkId) {
        return this.pathTemplates.productLinkPathTemplate.render({
            customer_id: customerId,
            product_link_id: productLinkId,
        });
    }
    /**
     * Parse the customer_id from ProductLink resource.
     *
     * @param {string} productLinkName
     *   A fully-qualified path representing ProductLink resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromProductLinkName(productLinkName) {
        return this.pathTemplates.productLinkPathTemplate.match(productLinkName).customer_id;
    }
    /**
     * Parse the product_link_id from ProductLink resource.
     *
     * @param {string} productLinkName
     *   A fully-qualified path representing ProductLink resource.
     * @returns {string} A string representing the product_link_id.
     */
    matchProductLinkIdFromProductLinkName(productLinkName) {
        return this.pathTemplates.productLinkPathTemplate.match(productLinkName).product_link_id;
    }
    /**
     * Return a fully-qualified qualifyingQuestion resource name string.
     *
     * @param {string} qualifying_question_id
     * @returns {string} Resource name string.
     */
    qualifyingQuestionPath(qualifyingQuestionId) {
        return this.pathTemplates.qualifyingQuestionPathTemplate.render({
            qualifying_question_id: qualifyingQuestionId,
        });
    }
    /**
     * Parse the qualifying_question_id from QualifyingQuestion resource.
     *
     * @param {string} qualifyingQuestionName
     *   A fully-qualified path representing QualifyingQuestion resource.
     * @returns {string} A string representing the qualifying_question_id.
     */
    matchQualifyingQuestionIdFromQualifyingQuestionName(qualifyingQuestionName) {
        return this.pathTemplates.qualifyingQuestionPathTemplate.match(qualifyingQuestionName).qualifying_question_id;
    }
    /**
     * Return a fully-qualified recommendation resource name string.
     *
     * @param {string} customer_id
     * @param {string} recommendation_id
     * @returns {string} Resource name string.
     */
    recommendationPath(customerId, recommendationId) {
        return this.pathTemplates.recommendationPathTemplate.render({
            customer_id: customerId,
            recommendation_id: recommendationId,
        });
    }
    /**
     * Parse the customer_id from Recommendation resource.
     *
     * @param {string} recommendationName
     *   A fully-qualified path representing Recommendation resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromRecommendationName(recommendationName) {
        return this.pathTemplates.recommendationPathTemplate.match(recommendationName).customer_id;
    }
    /**
     * Parse the recommendation_id from Recommendation resource.
     *
     * @param {string} recommendationName
     *   A fully-qualified path representing Recommendation resource.
     * @returns {string} A string representing the recommendation_id.
     */
    matchRecommendationIdFromRecommendationName(recommendationName) {
        return this.pathTemplates.recommendationPathTemplate.match(recommendationName).recommendation_id;
    }
    /**
     * Return a fully-qualified remarketingAction resource name string.
     *
     * @param {string} customer_id
     * @param {string} remarketing_action_id
     * @returns {string} Resource name string.
     */
    remarketingActionPath(customerId, remarketingActionId) {
        return this.pathTemplates.remarketingActionPathTemplate.render({
            customer_id: customerId,
            remarketing_action_id: remarketingActionId,
        });
    }
    /**
     * Parse the customer_id from RemarketingAction resource.
     *
     * @param {string} remarketingActionName
     *   A fully-qualified path representing RemarketingAction resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromRemarketingActionName(remarketingActionName) {
        return this.pathTemplates.remarketingActionPathTemplate.match(remarketingActionName).customer_id;
    }
    /**
     * Parse the remarketing_action_id from RemarketingAction resource.
     *
     * @param {string} remarketingActionName
     *   A fully-qualified path representing RemarketingAction resource.
     * @returns {string} A string representing the remarketing_action_id.
     */
    matchRemarketingActionIdFromRemarketingActionName(remarketingActionName) {
        return this.pathTemplates.remarketingActionPathTemplate.match(remarketingActionName).remarketing_action_id;
    }
    /**
     * Return a fully-qualified searchTermView resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} ad_group_id
     * @param {string} query
     * @returns {string} Resource name string.
     */
    searchTermViewPath(customerId, campaignId, adGroupId, query) {
        return this.pathTemplates.searchTermViewPathTemplate.render({
            customer_id: customerId,
            campaign_id: campaignId,
            ad_group_id: adGroupId,
            query: query,
        });
    }
    /**
     * Parse the customer_id from SearchTermView resource.
     *
     * @param {string} searchTermViewName
     *   A fully-qualified path representing SearchTermView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromSearchTermViewName(searchTermViewName) {
        return this.pathTemplates.searchTermViewPathTemplate.match(searchTermViewName).customer_id;
    }
    /**
     * Parse the campaign_id from SearchTermView resource.
     *
     * @param {string} searchTermViewName
     *   A fully-qualified path representing SearchTermView resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromSearchTermViewName(searchTermViewName) {
        return this.pathTemplates.searchTermViewPathTemplate.match(searchTermViewName).campaign_id;
    }
    /**
     * Parse the ad_group_id from SearchTermView resource.
     *
     * @param {string} searchTermViewName
     *   A fully-qualified path representing SearchTermView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromSearchTermViewName(searchTermViewName) {
        return this.pathTemplates.searchTermViewPathTemplate.match(searchTermViewName).ad_group_id;
    }
    /**
     * Parse the query from SearchTermView resource.
     *
     * @param {string} searchTermViewName
     *   A fully-qualified path representing SearchTermView resource.
     * @returns {string} A string representing the query.
     */
    matchQueryFromSearchTermViewName(searchTermViewName) {
        return this.pathTemplates.searchTermViewPathTemplate.match(searchTermViewName).query;
    }
    /**
     * Return a fully-qualified sharedCriterion resource name string.
     *
     * @param {string} customer_id
     * @param {string} shared_set_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    sharedCriterionPath(customerId, sharedSetId, criterionId) {
        return this.pathTemplates.sharedCriterionPathTemplate.render({
            customer_id: customerId,
            shared_set_id: sharedSetId,
            criterion_id: criterionId,
        });
    }
    /**
     * Parse the customer_id from SharedCriterion resource.
     *
     * @param {string} sharedCriterionName
     *   A fully-qualified path representing SharedCriterion resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromSharedCriterionName(sharedCriterionName) {
        return this.pathTemplates.sharedCriterionPathTemplate.match(sharedCriterionName).customer_id;
    }
    /**
     * Parse the shared_set_id from SharedCriterion resource.
     *
     * @param {string} sharedCriterionName
     *   A fully-qualified path representing SharedCriterion resource.
     * @returns {string} A string representing the shared_set_id.
     */
    matchSharedSetIdFromSharedCriterionName(sharedCriterionName) {
        return this.pathTemplates.sharedCriterionPathTemplate.match(sharedCriterionName).shared_set_id;
    }
    /**
     * Parse the criterion_id from SharedCriterion resource.
     *
     * @param {string} sharedCriterionName
     *   A fully-qualified path representing SharedCriterion resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromSharedCriterionName(sharedCriterionName) {
        return this.pathTemplates.sharedCriterionPathTemplate.match(sharedCriterionName).criterion_id;
    }
    /**
     * Return a fully-qualified sharedSet resource name string.
     *
     * @param {string} customer_id
     * @param {string} shared_set_id
     * @returns {string} Resource name string.
     */
    sharedSetPath(customerId, sharedSetId) {
        return this.pathTemplates.sharedSetPathTemplate.render({
            customer_id: customerId,
            shared_set_id: sharedSetId,
        });
    }
    /**
     * Parse the customer_id from SharedSet resource.
     *
     * @param {string} sharedSetName
     *   A fully-qualified path representing SharedSet resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromSharedSetName(sharedSetName) {
        return this.pathTemplates.sharedSetPathTemplate.match(sharedSetName).customer_id;
    }
    /**
     * Parse the shared_set_id from SharedSet resource.
     *
     * @param {string} sharedSetName
     *   A fully-qualified path representing SharedSet resource.
     * @returns {string} A string representing the shared_set_id.
     */
    matchSharedSetIdFromSharedSetName(sharedSetName) {
        return this.pathTemplates.sharedSetPathTemplate.match(sharedSetName).shared_set_id;
    }
    /**
     * Return a fully-qualified shoppingPerformanceView resource name string.
     *
     * @param {string} customer_id
     * @returns {string} Resource name string.
     */
    shoppingPerformanceViewPath(customerId) {
        return this.pathTemplates.shoppingPerformanceViewPathTemplate.render({
            customer_id: customerId,
        });
    }
    /**
     * Parse the customer_id from ShoppingPerformanceView resource.
     *
     * @param {string} shoppingPerformanceViewName
     *   A fully-qualified path representing ShoppingPerformanceView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromShoppingPerformanceViewName(shoppingPerformanceViewName) {
        return this.pathTemplates.shoppingPerformanceViewPathTemplate.match(shoppingPerformanceViewName).customer_id;
    }
    /**
     * Return a fully-qualified smartCampaignSearchTermView resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @param {string} query
     * @returns {string} Resource name string.
     */
    smartCampaignSearchTermViewPath(customerId, campaignId, query) {
        return this.pathTemplates.smartCampaignSearchTermViewPathTemplate.render({
            customer_id: customerId,
            campaign_id: campaignId,
            query: query,
        });
    }
    /**
     * Parse the customer_id from SmartCampaignSearchTermView resource.
     *
     * @param {string} smartCampaignSearchTermViewName
     *   A fully-qualified path representing SmartCampaignSearchTermView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromSmartCampaignSearchTermViewName(smartCampaignSearchTermViewName) {
        return this.pathTemplates.smartCampaignSearchTermViewPathTemplate.match(smartCampaignSearchTermViewName).customer_id;
    }
    /**
     * Parse the campaign_id from SmartCampaignSearchTermView resource.
     *
     * @param {string} smartCampaignSearchTermViewName
     *   A fully-qualified path representing SmartCampaignSearchTermView resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromSmartCampaignSearchTermViewName(smartCampaignSearchTermViewName) {
        return this.pathTemplates.smartCampaignSearchTermViewPathTemplate.match(smartCampaignSearchTermViewName).campaign_id;
    }
    /**
     * Parse the query from SmartCampaignSearchTermView resource.
     *
     * @param {string} smartCampaignSearchTermViewName
     *   A fully-qualified path representing SmartCampaignSearchTermView resource.
     * @returns {string} A string representing the query.
     */
    matchQueryFromSmartCampaignSearchTermViewName(smartCampaignSearchTermViewName) {
        return this.pathTemplates.smartCampaignSearchTermViewPathTemplate.match(smartCampaignSearchTermViewName).query;
    }
    /**
     * Return a fully-qualified smartCampaignSetting resource name string.
     *
     * @param {string} customer_id
     * @param {string} campaign_id
     * @returns {string} Resource name string.
     */
    smartCampaignSettingPath(customerId, campaignId) {
        return this.pathTemplates.smartCampaignSettingPathTemplate.render({
            customer_id: customerId,
            campaign_id: campaignId,
        });
    }
    /**
     * Parse the customer_id from SmartCampaignSetting resource.
     *
     * @param {string} smartCampaignSettingName
     *   A fully-qualified path representing SmartCampaignSetting resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromSmartCampaignSettingName(smartCampaignSettingName) {
        return this.pathTemplates.smartCampaignSettingPathTemplate.match(smartCampaignSettingName).customer_id;
    }
    /**
     * Parse the campaign_id from SmartCampaignSetting resource.
     *
     * @param {string} smartCampaignSettingName
     *   A fully-qualified path representing SmartCampaignSetting resource.
     * @returns {string} A string representing the campaign_id.
     */
    matchCampaignIdFromSmartCampaignSettingName(smartCampaignSettingName) {
        return this.pathTemplates.smartCampaignSettingPathTemplate.match(smartCampaignSettingName).campaign_id;
    }
    /**
     * Return a fully-qualified thirdPartyAppAnalyticsLink resource name string.
     *
     * @param {string} customer_id
     * @param {string} customer_link_id
     * @returns {string} Resource name string.
     */
    thirdPartyAppAnalyticsLinkPath(customerId, customerLinkId) {
        return this.pathTemplates.thirdPartyAppAnalyticsLinkPathTemplate.render({
            customer_id: customerId,
            customer_link_id: customerLinkId,
        });
    }
    /**
     * Parse the customer_id from ThirdPartyAppAnalyticsLink resource.
     *
     * @param {string} thirdPartyAppAnalyticsLinkName
     *   A fully-qualified path representing ThirdPartyAppAnalyticsLink resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromThirdPartyAppAnalyticsLinkName(thirdPartyAppAnalyticsLinkName) {
        return this.pathTemplates.thirdPartyAppAnalyticsLinkPathTemplate.match(thirdPartyAppAnalyticsLinkName).customer_id;
    }
    /**
     * Parse the customer_link_id from ThirdPartyAppAnalyticsLink resource.
     *
     * @param {string} thirdPartyAppAnalyticsLinkName
     *   A fully-qualified path representing ThirdPartyAppAnalyticsLink resource.
     * @returns {string} A string representing the customer_link_id.
     */
    matchCustomerLinkIdFromThirdPartyAppAnalyticsLinkName(thirdPartyAppAnalyticsLinkName) {
        return this.pathTemplates.thirdPartyAppAnalyticsLinkPathTemplate.match(thirdPartyAppAnalyticsLinkName).customer_link_id;
    }
    /**
     * Return a fully-qualified topicConstant resource name string.
     *
     * @param {string} topic_id
     * @returns {string} Resource name string.
     */
    topicConstantPath(topicId) {
        return this.pathTemplates.topicConstantPathTemplate.render({
            topic_id: topicId,
        });
    }
    /**
     * Parse the topic_id from TopicConstant resource.
     *
     * @param {string} topicConstantName
     *   A fully-qualified path representing TopicConstant resource.
     * @returns {string} A string representing the topic_id.
     */
    matchTopicIdFromTopicConstantName(topicConstantName) {
        return this.pathTemplates.topicConstantPathTemplate.match(topicConstantName).topic_id;
    }
    /**
     * Return a fully-qualified topicView resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    topicViewPath(customerId, adGroupId, criterionId) {
        return this.pathTemplates.topicViewPathTemplate.render({
            customer_id: customerId,
            ad_group_id: adGroupId,
            criterion_id: criterionId,
        });
    }
    /**
     * Parse the customer_id from TopicView resource.
     *
     * @param {string} topicViewName
     *   A fully-qualified path representing TopicView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromTopicViewName(topicViewName) {
        return this.pathTemplates.topicViewPathTemplate.match(topicViewName).customer_id;
    }
    /**
     * Parse the ad_group_id from TopicView resource.
     *
     * @param {string} topicViewName
     *   A fully-qualified path representing TopicView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromTopicViewName(topicViewName) {
        return this.pathTemplates.topicViewPathTemplate.match(topicViewName).ad_group_id;
    }
    /**
     * Parse the criterion_id from TopicView resource.
     *
     * @param {string} topicViewName
     *   A fully-qualified path representing TopicView resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromTopicViewName(topicViewName) {
        return this.pathTemplates.topicViewPathTemplate.match(topicViewName).criterion_id;
    }
    /**
     * Return a fully-qualified travelActivityGroupView resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    travelActivityGroupViewPath(customerId, adGroupId, criterionId) {
        return this.pathTemplates.travelActivityGroupViewPathTemplate.render({
            customer_id: customerId,
            ad_group_id: adGroupId,
            criterion_id: criterionId,
        });
    }
    /**
     * Parse the customer_id from TravelActivityGroupView resource.
     *
     * @param {string} travelActivityGroupViewName
     *   A fully-qualified path representing TravelActivityGroupView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromTravelActivityGroupViewName(travelActivityGroupViewName) {
        return this.pathTemplates.travelActivityGroupViewPathTemplate.match(travelActivityGroupViewName).customer_id;
    }
    /**
     * Parse the ad_group_id from TravelActivityGroupView resource.
     *
     * @param {string} travelActivityGroupViewName
     *   A fully-qualified path representing TravelActivityGroupView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromTravelActivityGroupViewName(travelActivityGroupViewName) {
        return this.pathTemplates.travelActivityGroupViewPathTemplate.match(travelActivityGroupViewName).ad_group_id;
    }
    /**
     * Parse the criterion_id from TravelActivityGroupView resource.
     *
     * @param {string} travelActivityGroupViewName
     *   A fully-qualified path representing TravelActivityGroupView resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromTravelActivityGroupViewName(travelActivityGroupViewName) {
        return this.pathTemplates.travelActivityGroupViewPathTemplate.match(travelActivityGroupViewName).criterion_id;
    }
    /**
     * Return a fully-qualified travelActivityPerformanceView resource name string.
     *
     * @param {string} customer_id
     * @returns {string} Resource name string.
     */
    travelActivityPerformanceViewPath(customerId) {
        return this.pathTemplates.travelActivityPerformanceViewPathTemplate.render({
            customer_id: customerId,
        });
    }
    /**
     * Parse the customer_id from TravelActivityPerformanceView resource.
     *
     * @param {string} travelActivityPerformanceViewName
     *   A fully-qualified path representing TravelActivityPerformanceView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromTravelActivityPerformanceViewName(travelActivityPerformanceViewName) {
        return this.pathTemplates.travelActivityPerformanceViewPathTemplate.match(travelActivityPerformanceViewName).customer_id;
    }
    /**
     * Return a fully-qualified userInterest resource name string.
     *
     * @param {string} customer_id
     * @param {string} user_interest_id
     * @returns {string} Resource name string.
     */
    userInterestPath(customerId, userInterestId) {
        return this.pathTemplates.userInterestPathTemplate.render({
            customer_id: customerId,
            user_interest_id: userInterestId,
        });
    }
    /**
     * Parse the customer_id from UserInterest resource.
     *
     * @param {string} userInterestName
     *   A fully-qualified path representing UserInterest resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromUserInterestName(userInterestName) {
        return this.pathTemplates.userInterestPathTemplate.match(userInterestName).customer_id;
    }
    /**
     * Parse the user_interest_id from UserInterest resource.
     *
     * @param {string} userInterestName
     *   A fully-qualified path representing UserInterest resource.
     * @returns {string} A string representing the user_interest_id.
     */
    matchUserInterestIdFromUserInterestName(userInterestName) {
        return this.pathTemplates.userInterestPathTemplate.match(userInterestName).user_interest_id;
    }
    /**
     * Return a fully-qualified userList resource name string.
     *
     * @param {string} customer_id
     * @param {string} user_list_id
     * @returns {string} Resource name string.
     */
    userListPath(customerId, userListId) {
        return this.pathTemplates.userListPathTemplate.render({
            customer_id: customerId,
            user_list_id: userListId,
        });
    }
    /**
     * Parse the customer_id from UserList resource.
     *
     * @param {string} userListName
     *   A fully-qualified path representing UserList resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromUserListName(userListName) {
        return this.pathTemplates.userListPathTemplate.match(userListName).customer_id;
    }
    /**
     * Parse the user_list_id from UserList resource.
     *
     * @param {string} userListName
     *   A fully-qualified path representing UserList resource.
     * @returns {string} A string representing the user_list_id.
     */
    matchUserListIdFromUserListName(userListName) {
        return this.pathTemplates.userListPathTemplate.match(userListName).user_list_id;
    }
    /**
     * Return a fully-qualified userLocationView resource name string.
     *
     * @param {string} customer_id
     * @param {string} country_criterion_id
     * @param {string} is_targeting_location
     * @returns {string} Resource name string.
     */
    userLocationViewPath(customerId, countryCriterionId, isTargetingLocation) {
        return this.pathTemplates.userLocationViewPathTemplate.render({
            customer_id: customerId,
            country_criterion_id: countryCriterionId,
            is_targeting_location: isTargetingLocation,
        });
    }
    /**
     * Parse the customer_id from UserLocationView resource.
     *
     * @param {string} userLocationViewName
     *   A fully-qualified path representing UserLocationView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromUserLocationViewName(userLocationViewName) {
        return this.pathTemplates.userLocationViewPathTemplate.match(userLocationViewName).customer_id;
    }
    /**
     * Parse the country_criterion_id from UserLocationView resource.
     *
     * @param {string} userLocationViewName
     *   A fully-qualified path representing UserLocationView resource.
     * @returns {string} A string representing the country_criterion_id.
     */
    matchCountryCriterionIdFromUserLocationViewName(userLocationViewName) {
        return this.pathTemplates.userLocationViewPathTemplate.match(userLocationViewName).country_criterion_id;
    }
    /**
     * Parse the is_targeting_location from UserLocationView resource.
     *
     * @param {string} userLocationViewName
     *   A fully-qualified path representing UserLocationView resource.
     * @returns {string} A string representing the is_targeting_location.
     */
    matchIsTargetingLocationFromUserLocationViewName(userLocationViewName) {
        return this.pathTemplates.userLocationViewPathTemplate.match(userLocationViewName).is_targeting_location;
    }
    /**
     * Return a fully-qualified video resource name string.
     *
     * @param {string} customer_id
     * @param {string} video_id
     * @returns {string} Resource name string.
     */
    videoPath(customerId, videoId) {
        return this.pathTemplates.videoPathTemplate.render({
            customer_id: customerId,
            video_id: videoId,
        });
    }
    /**
     * Parse the customer_id from Video resource.
     *
     * @param {string} videoName
     *   A fully-qualified path representing Video resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromVideoName(videoName) {
        return this.pathTemplates.videoPathTemplate.match(videoName).customer_id;
    }
    /**
     * Parse the video_id from Video resource.
     *
     * @param {string} videoName
     *   A fully-qualified path representing Video resource.
     * @returns {string} A string representing the video_id.
     */
    matchVideoIdFromVideoName(videoName) {
        return this.pathTemplates.videoPathTemplate.match(videoName).video_id;
    }
    /**
     * Return a fully-qualified webpageView resource name string.
     *
     * @param {string} customer_id
     * @param {string} ad_group_id
     * @param {string} criterion_id
     * @returns {string} Resource name string.
     */
    webpageViewPath(customerId, adGroupId, criterionId) {
        return this.pathTemplates.webpageViewPathTemplate.render({
            customer_id: customerId,
            ad_group_id: adGroupId,
            criterion_id: criterionId,
        });
    }
    /**
     * Parse the customer_id from WebpageView resource.
     *
     * @param {string} webpageViewName
     *   A fully-qualified path representing WebpageView resource.
     * @returns {string} A string representing the customer_id.
     */
    matchCustomerIdFromWebpageViewName(webpageViewName) {
        return this.pathTemplates.webpageViewPathTemplate.match(webpageViewName).customer_id;
    }
    /**
     * Parse the ad_group_id from WebpageView resource.
     *
     * @param {string} webpageViewName
     *   A fully-qualified path representing WebpageView resource.
     * @returns {string} A string representing the ad_group_id.
     */
    matchAdGroupIdFromWebpageViewName(webpageViewName) {
        return this.pathTemplates.webpageViewPathTemplate.match(webpageViewName).ad_group_id;
    }
    /**
     * Parse the criterion_id from WebpageView resource.
     *
     * @param {string} webpageViewName
     *   A fully-qualified path representing WebpageView resource.
     * @returns {string} A string representing the criterion_id.
     */
    matchCriterionIdFromWebpageViewName(webpageViewName) {
        return this.pathTemplates.webpageViewPathTemplate.match(webpageViewName).criterion_id;
    }
    /**
     * Terminate the gRPC channel and close the client.
     *
     * The client will no longer be usable and all future behavior is undefined.
     * @returns {Promise} A promise that resolves when the client is closed.
     */
    close() {
        if (this.billingSetupServiceStub && !this._terminated) {
            return this.billingSetupServiceStub.then(stub => {
                this._terminated = true;
                stub.close();
            });
        }
        return Promise.resolve();
    }
}
exports.BillingSetupServiceClient = BillingSetupServiceClient;
//# sourceMappingURL=billing_setup_service_client.js.map